import typing
import enum
import pydantic


def choice_of_validator(choices, optional):
    def check_at_least_one(cls, values):

        setted_values = len(
            set(k for k, v in values.items() if v is not None) & choices
        )
        if setted_values > 1:
            raise ValueError(f"Only one of the fields is allowed to be set ({choices})")
        elif not optional and setted_values < 1:
            raise ValueError(f"A t least one of the fields needs to be set ({choices})")
        return values

    return check_at_least_one

class AbstractType(enum.Enum):
    
    type = "Type"
    """A place holder that means any kind of data type """
    
    any = "Any"
    """A place holder that means any kind of resource """
    
class AccountStatus(enum.Enum):
    
    active = "active"
    """This account is active and may be used. """
    
    inactive = "inactive"
    """This account is inactive and should not be used to track financial information. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
    onHold = "on-hold"
    """This account is on hold. """
    
    unknown = "unknown"
    """The account status is unknown. """
    
class ActionCardinalityBehavior(enum.Enum):
    
    single = "single"
    """The action may only be selected one time. """
    
    multiple = "multiple"
    """The action may be selected multiple times. """
    
class ActionConditionKind(enum.Enum):
    
    applicability = "applicability"
    """The condition describes whether or not a given action is applicable. """
    
    start = "start"
    """The condition is a starting condition for the action. """
    
    stop = "stop"
    """The condition is a stop, or exit condition for the action. """
    
class ActionGroupingBehavior(enum.Enum):
    
    visualGroup = "visual-group"
    """Any group marked with this behavior should be displayed as a visual group to the end user. """
    
    logicalGroup = "logical-group"
    """A group with this behavior logically groups its sub-elements, and may be shown as a visual group to the end user, but it is not required to do so. """
    
    sentenceGroup = "sentence-group"
    """A group of related alternative actions is a sentence group if the target referenced by the action is the same in all the actions and each action simply constitutes a different variation on how to specify the details for the target. For example, two actions that could be in a SentenceGroup are "aspirin, 500 mg, 2 times per day" and "aspirin, 300 mg, 3 times per day". In both cases, aspirin is the target referenced by the action, and the two actions represent different options for how aspirin might be ordered for the patient. Note that a SentenceGroup would almost always have an associated selection behavior of "AtMostOne", unless it's a required action, in which case, it would be "ExactlyOne". """
    
class ActionParticipantType(enum.Enum):
    
    patient = "patient"
    """The participant is the patient under evaluation. """
    
    practitioner = "practitioner"
    """The participant is a practitioner involved in the patient's care. """
    
    relatedPerson = "related-person"
    """The participant is a person related to the patient. """
    
    device = "device"
    """The participant is a system or device used in the care of the patient. """
    
class ActionPrecheckBehavior(enum.Enum):
    
    yes = "yes"
    """An action with this behavior is one of the most frequent action that is, or should be, included by an end user, for the particular context in which the action occurs. The system displaying the action to the end user should consider "pre-checking" such an action as a convenience for the user. """
    
    no = "no"
    """An action with this behavior is one of the less frequent actions included by the end user, for the particular context in which the action occurs. The system displaying the actions to the end user would typically not "pre-check" such an action. """
    
class ActionRelationshipType(enum.Enum):
    
    beforeStart = "before-start"
    """The action must be performed before the start of the related action. """
    
    before = "before"
    """The action must be performed before the related action. """
    
    beforeEnd = "before-end"
    """The action must be performed before the end of the related action. """
    
    concurrentWithStart = "concurrent-with-start"
    """The action must be performed concurrent with the start of the related action. """
    
    concurrent = "concurrent"
    """The action must be performed concurrent with the related action. """
    
    concurrentWithEnd = "concurrent-with-end"
    """The action must be performed concurrent with the end of the related action. """
    
    afterStart = "after-start"
    """The action must be performed after the start of the related action. """
    
    after = "after"
    """The action must be performed after the related action. """
    
    afterEnd = "after-end"
    """The action must be performed after the end of the related action. """
    
class ActionRequiredBehavior(enum.Enum):
    
    must = "must"
    """An action with this behavior must be included in the actions processed by the end user; the end user SHALL NOT choose not to include this action. """
    
    could = "could"
    """An action with this behavior may be included in the set of actions processed by the end user. """
    
    mustUnlessDocumented = "must-unless-documented"
    """An action with this behavior must be included in the set of actions processed by the end user, unless the end user provides documentation as to why the action was not included. """
    
class ActionSelectionBehavior(enum.Enum):
    
    any = "any"
    """Any number of the actions in the group may be chosen, from zero to all. """
    
    all = "all"
    """All the actions in the group must be selected as a single unit. """
    
    allOrNone = "all-or-none"
    """All the actions in the group are meant to be chosen as a single unit: either all must be selected by the end user, or none may be selected. """
    
    exactlyOne = "exactly-one"
    """The end user must choose one and only one of the selectable actions in the group. The user SHALL NOT choose none of the actions in the group. """
    
    atMostOne = "at-most-one"
    """The end user may choose zero or at most one of the actions in the group. """
    
    oneOrMore = "one-or-more"
    """The end user must choose a minimum of one, and as many additional as desired. """
    
class ActionType(enum.Enum):
    
    create = "create"
    """The action is to create a new resource. """
    
    update = "update"
    """The action is to update an existing resource. """
    
    remove = "remove"
    """The action is to remove an existing resource. """
    
    fireEvent = "fire-event"
    """The action is to fire a specific event. """
    
class ActivityDefinitionCategory(enum.Enum):
    
    treatment = "treatment"
    """The activity is intended to provide or is related to treatment of the patient. """
    
    education = "education"
    """The activity is intended to provide or is related to education of the patient. """
    
    assessment = "assessment"
    """The activity is intended to perform or is related to assessment of the patient. """
    
class AdditionalMaterialCodes(enum.Enum):
    
    xray = "xray"
    """XRay """
    
    image = "image"
    """Image """
    
    email = "email"
    """Email """
    
    model = "model"
    """Model """
    
    document = "document"
    """Document """
    
    other = "other"
    """Other """
    
class AddressType(enum.Enum):
    
    postal = "postal"
    """Mailing addresses - PO Boxes and care-of addresses. """
    
    physical = "physical"
    """A physical address that can be visited. """
    
    both = "both"
    """An address that is both physical and postal. """
    
class AddressUse(enum.Enum):
    
    home = "home"
    """A communication address at a home. """
    
    work = "work"
    """An office address. First choice for business related contacts during business hours. """
    
    temp = "temp"
    """A temporary address. The period can provide more detailed information. """
    
    old = "old"
    """This address is no longer in use (or was never correct but retained for records). """
    
    billing = "billing"
    """An address to be used to send bills, invoices, receipts etc. """
    
class AdjudicationReasonCodes(enum.Enum):
    
    ar001 = "ar001"
    """Not covered """
    
    ar002 = "ar002"
    """Plan Limit Reached """
    
class AdjudicationValueCodes(enum.Enum):
    
    submitted = "submitted"
    """The total submitted amount for the claim or group or line item. """
    
    copay = "copay"
    """Patient Co-Payment """
    
    eligible = "eligible"
    """Amount of the change which is considered for adjudication. """
    
    deductible = "deductible"
    """Amount deducted from the eligible amount prior to adjudication. """
    
    unallocdeduct = "unallocdeduct"
    """The amount of deductible which could not allocated to other line items. """
    
    eligpercent = "eligpercent"
    """Eligible Percentage. """
    
    tax = "tax"
    """The amount of tax. """
    
    benefit = "benefit"
    """Amount payable under the coverage """
    
class AdministrativeGender(enum.Enum):
    
    male = "male"
    """Male. """
    
    female = "female"
    """Female. """
    
    other = "other"
    """Other. """
    
    unknown = "unknown"
    """Unknown. """
    
class AdmitSource(enum.Enum):
    
    hospTrans = "hosp-trans"
    """The Patient has been transferred from another hospital for this encounter. """
    
    emd = "emd"
    """The patient has been transferred from the emergency department within the hospital. This is typically used in the transition to an inpatient encounter """
    
    outp = "outp"
    """The patient has been transferred from an outpatient department within the hospital. """
    
    born = "born"
    """The patient is a newborn and the encounter will track the baby related activities (as opposed to the Mothers encounter - that may be associated using the newborn encounters partof property) """
    
    gp = "gp"
    """The patient has been admitted due to a referred from a General Practitioner. """
    
    mp = "mp"
    """The patient has been admitted due to a referred from a Specialist (as opposed to a General Practitioner). """
    
    nursing = "nursing"
    """The patient has been transferred from a nursing home. """
    
    psych = "psych"
    """The patient has been transferred from a psychiatric facility. """
    
    rehab = "rehab"
    """The patient has been transferred from a rehabilitation facility or clinic. """
    
    other = "other"
    """The patient has been admitted from a source otherwise not specified here. """
    
class AdverseEventActuality(enum.Enum):
    
    actual = "actual"
    """The adverse event actually happened regardless of whether anyone was affected or harmed. """
    
    potential = "potential"
    """A potential adverse event. """
    
class AdverseEventCategory(enum.Enum):
    
    productProblem = "product-problem"
    """The adverse event pertains to a product problem. """
    
    productQuality = "product-quality"
    """The adverse event pertains to product quality. """
    
    productUseError = "product-use-error"
    """The adverse event pertains to a product use error. """
    
    wrongDose = "wrong-dose"
    """The adverse event pertains to a wrong dose. """
    
    incorrectPrescribingInformation = "incorrect-prescribing-information"
    """The adverse event pertains to incorrect perscribing information. """
    
    wrongTechnique = "wrong-technique"
    """The adverse event pertains to a wrong technique. """
    
    wrongRouteOfAdministration = "wrong-route-of-administration"
    """The adverse event pertains to a wrong route of administration. """
    
    wrongRate = "wrong-rate"
    """The adverse event pertains to a wrong rate. """
    
    wrongDuration = "wrong-duration"
    """The adverse event pertains to a wrong duration. """
    
    wrongTime = "wrong-time"
    """The adverse event pertains to a wrong time. """
    
    expiredDrug = "expired-drug"
    """The adverse event pertains to an expired drug. """
    
    medicalDeviceUseError = "medical-device-use-error"
    """The adverse event pertains to a medical device use error. """
    
    problemDifferentManufacturer = "problem-different-manufacturer"
    """The adverse event pertains to a problem with a different manufacturer of the same medication. """
    
    unsafePhysicalEnvironment = "unsafe-physical-environment"
    """The adverse event pertains to an unsafe physical environment. """
    
class AdverseEventCausalityAssessment(enum.Enum):
    
    certain = "Certain"
    """i) Event or laboratory test abnormality, with plausible time relationship to drug intake; ii) Cannot be explained by disease or other drugs; iii) Response to withdrawal plausible (pharmacologically, pathologically); iv) Event definitive pharmacologically or phenomenologically (i.e. an objective and specific medical disorder or a recognized pharmacological phenomenon); or v) Re-challenge satisfactory, if necessary. """
    
    probablyLikely = "Probably-Likely"
    """i) Event or laboratory test abnormality, with reasonable time relationship to drug intake; ii) Unlikely to be attributed to disease or other drugs; iii) Response to withdrawal clinically reasonable; or iv) Re-challenge not required. """
    
    possible = "Possible"
    """i) Event or laboratory test abnormality, with reasonable time relationship to drug intake; ii) Could also be explained by disease or other drugs; or iii) Information on drug withdrawal may be lacking or unclear. """
    
    unlikely = "Unlikely"
    """i) Event or laboratory test abnormality, with a time to drug intake that makes a relationship improbable (but not impossible); or ii) Disease or other drugs provide plausible explanations. """
    
    conditionalClassified = "Conditional-Classified"
    """i) Event or laboratory test abnormality; ii) More data for proper assessment needed; or iii) Additional data under examination. """
    
    unassessableUnclassifiable = "Unassessable-Unclassifiable"
    """i) Report suggesting an adverse reaction; ii) Cannot be judged because information is insufficient or contradictory; or iii) Data cannot be supplemented or verified. """
    
class AdverseEventCausalityMethod(enum.Enum):
    
    probabilityScale = "ProbabilityScale"
    """probabilityScale """
    
    bayesian = "Bayesian"
    """bayesian """
    
    checklist = "Checklist"
    """checklist """
    
class AdverseEventOutcome(enum.Enum):
    
    resolved = "resolved"
    """resolved """
    
    recovering = "recovering"
    """recovering """
    
    ongoing = "ongoing"
    """ongoing """
    
    resolvedWithSequelae = "resolvedWithSequelae"
    """resolvedWithSequelae """
    
    fatal = "fatal"
    """fatal """
    
    unknown = "unknown"
    """unknown """
    
class AdverseEventSeriousness(enum.Enum):
    
    nonSerious = "Non-serious"
    """Non-serious. """
    
    serious = "Serious"
    """Serious. """
    
    seriousResultsInDeath = "SeriousResultsInDeath"
    """Results in death. """
    
    seriousIsLifeThreatening = "SeriousIsLifeThreatening"
    """Is Life-threatening. """
    
    seriousResultsInHospitalization = "SeriousResultsInHospitalization"
    """Requires inpatient hospitalization or causes prolongation of existing hospitalization. """
    
    seriousResultsInDisability = "SeriousResultsInDisability"
    """Results in persistent or significant disability/incapacity. """
    
    seriousIsBirthDefect = "SeriousIsBirthDefect"
    """Is a congenital anomaly/birth defect. """
    
    seriousRequiresPreventImpairment = "SeriousRequiresPreventImpairment"
    """Requires intervention to prevent permanent impairment or damage (i.e., an important medical event that requires medical judgement). """
    
class AdverseEventSeverity(enum.Enum):
    
    mild = "mild"
    """mild """
    
    moderate = "moderate"
    """moderate """
    
    severe = "severe"
    """severe """
    
class AggregationMode(enum.Enum):
    
    contained = "contained"
    """The reference is a local reference to a contained resource. """
    
    referenced = "referenced"
    """The reference to a resource that has to be resolved externally to the resource that includes the reference. """
    
    bundled = "bundled"
    """The resource the reference points to will be found in the same bundle as the resource that includes the reference. """
    
class AllergyIntoleranceCategory(enum.Enum):
    
    food = "food"
    """Any substance consumed to provide nutritional support for the body. """
    
    medication = "medication"
    """Substances administered to achieve a physiological effect. """
    
    environment = "environment"
    """Any substances that are encountered in the environment, including any substance not already classified as food, medication, or biologic. """
    
    biologic = "biologic"
    """A preparation that is synthesized from living organisms or their products, especially a human or animal protein, such as a hormone or antitoxin, that is used as a diagnostic, preventive, or therapeutic agent. Examples of biologic medications include: vaccines; allergenic extracts, which are used for both diagnosis and treatment (for example, allergy shots); gene therapies; cellular therapies.  There are other biologic products, such as tissues, which are not typically associated with allergies. """
    
class AllergyIntoleranceCertainty(enum.Enum):
    
    unlikely = "unlikely"
    """There is a low level of clinical certainty that the reaction was caused by the identified substance. """
    
    likely = "likely"
    """There is a high level of clinical certainty that the reaction was caused by the identified substance. """
    
    confirmed = "confirmed"
    """There is a very high level of clinical certainty that the reaction was due to the identified substance, which may include clinical evidence by testing or rechallenge. """
    
    unknown = "unknown"
    """The clinical certainty that the reaction was caused by the identified substance is unknown.  It is an explicit assertion that certainty is not known. """
    
class AllergyIntoleranceClinicalStatusCodes(enum.Enum):
    
    active = "active"
    """The subject is currently experiencing, or is at risk of, a reaction to the identified substance. """
    
    inactive = "inactive"
    """The subject is no longer at risk of a reaction to the identified substance. """
    
    resolved = "resolved"
    """A reaction to the identified substance has been clinically reassessed by testing or re-exposure and is considered no longer to be present. Re-exposure could be accidental, unplanned, or outside of any clinical setting. """
    
class AllergyIntoleranceCriticality(enum.Enum):
    
    low = "low"
    """Worst case result of a future exposure is not assessed to be life-threatening or having high potential for organ system failure. """
    
    high = "high"
    """Worst case result of a future exposure is assessed to be life-threatening or having high potential for organ system failure. """
    
    unableToAssess = "unable-to-assess"
    """Unable to assess the worst case result of a future exposure. """
    
class AllergyIntoleranceSeverity(enum.Enum):
    
    mild = "mild"
    """Causes mild physiological effects. """
    
    moderate = "moderate"
    """Causes moderate physiological effects. """
    
    severe = "severe"
    """Causes severe physiological effects. """
    
class AllergyIntoleranceSubstanceExposureRisk(enum.Enum):
    
    knownReactionRisk = "known-reaction-risk"
    """Known risk of allergy or intolerance reaction upon exposure to the specified substance. """
    
    noKnownReactionRisk = "no-known-reaction-risk"
    """No known risk of allergy or intolerance reaction upon exposure to the specified substance. """
    
class AllergyIntoleranceType(enum.Enum):
    
    allergy = "allergy"
    """A propensity for hypersensitive reaction(s) to a substance.  These reactions are most typically type I hypersensitivity, plus other "allergy-like" reactions, including pseudoallergy. """
    
    intolerance = "intolerance"
    """A propensity for adverse reactions to a substance that is not judged to be allergic or "allergy-like".  These reactions are typically (but not necessarily) non-immune.  They are to some degree idiosyncratic and/or patient-specific (i.e. are not a reaction that is expected to occur with most or all patients given similar circumstances). """
    
class AllergyIntoleranceVerificationStatusCodes(enum.Enum):
    
    unconfirmed = "unconfirmed"
    """A low level of certainty about the propensity for a reaction to the identified substance. """
    
    confirmed = "confirmed"
    """A high level of certainty about the propensity for a reaction to the identified substance, which may include clinical evidence by testing or rechallenge. """
    
    refuted = "refuted"
    """A propensity for a reaction to the identified substance has been disputed or disproven with a sufficient level of clinical certainty to justify invalidating the assertion. This might or might not include testing or rechallenge. """
    
    enteredInError = "entered-in-error"
    """The statement was entered in error and is not valid. """
    
class AlternativeCodeKind(enum.Enum):
    
    alternate = "alternate"
    """The code is an alternative code that can be used in any of the circumstances that the primary code can be used. """
    
    deprecated = "deprecated"
    """The code should no longer be used, but was used in the past. """
    
    caseInsensitive = "case-insensitive"
    """The code is an alternative to be used when a case insensitive code is required (when the primary codes are case sensitive). """
    
    caseSensitive = "case-sensitive"
    """The code is an alternative to be used when a case sensitive code is required (when the primary codes are case insensitive). """
    
    expression = "expression"
    """The code is an alternative for the primary code that is built using the expression grammar defined by the code system. """
    
class AlternativeCodeKind(enum.Enum):
    
    alternate = "alternate"
    """The code is an alternative code that can be used in any of the circumstances that the primary code can be used. """
    
    deprecated = "deprecated"
    """The code should no longer be used, but was used in the past. """
    
    caseInsensitive = "case-insensitive"
    """The code is an alternative to be used when a case insensitive code is required (when the primary codes are case sensitive). """
    
    caseSensitive = "case-sensitive"
    """The code is an alternative to be used when a case sensitive code is required (when the primary codes are case insensitive). """
    
    expression = "expression"
    """The code is an alternative for the primary code that is built using the expression grammar defined by the code system. """
    
class AnimalSpecies(enum.Enum):
    
    canislf = "canislf"
    """Canis lupus familiaris """
    
    ovisa = "ovisa"
    """Ovis aries """
    
    serinuscd = "serinuscd"
    """Serinus canaria domestica """
    
class AppointmentStatus(enum.Enum):
    
    proposed = "proposed"
    """None of the participant(s) have finalized their acceptance of the appointment request, and the start/end time might not be set yet. """
    
    pending = "pending"
    """Some or all of the participant(s) have not finalized their acceptance of the appointment request. """
    
    booked = "booked"
    """All participant(s) have been considered and the appointment is confirmed to go ahead at the date/times specified. """
    
    arrived = "arrived"
    """The patient/patients has/have arrived and is/are waiting to be seen. """
    
    fulfilled = "fulfilled"
    """The planning stages of the appointment are now complete, the encounter resource will exist and will track further status changes. Note that an encounter may exist before the appointment status is fulfilled for many reasons. """
    
    cancelled = "cancelled"
    """The appointment has been cancelled. """
    
    noshow = "noshow"
    """Some or all of the participant(s) have not/did not appear for the appointment (usually the patient). """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
    checkedIn = "checked-in"
    """When checked in, all pre-encounter administrative work is complete, and the encounter may begin. (where multiple patients are involved, they are all present). """
    
    waitlist = "waitlist"
    """The appointment has been placed on a waitlist, to be scheduled/confirmed in the future when a slot/service is available.
A specific time might or might not be pre-allocated. """
    
class AssertionDirectionType(enum.Enum):
    
    response = "response"
    """The assertion is evaluated on the response. This is the default value. """
    
    request = "request"
    """The assertion is evaluated on the request. """
    
class AssertionOperatorType(enum.Enum):
    
    equals = "equals"
    """Default value. Equals comparison. """
    
    notEquals = "notEquals"
    """Not equals comparison. """
    
    in_ = "in"
    """Compare value within a known set of values. """
    
    notIn = "notIn"
    """Compare value not within a known set of values. """
    
    greaterThan = "greaterThan"
    """Compare value to be greater than a known value. """
    
    lessThan = "lessThan"
    """Compare value to be less than a known value. """
    
    empty = "empty"
    """Compare value is empty. """
    
    notEmpty = "notEmpty"
    """Compare value is not empty. """
    
    contains = "contains"
    """Compare value string contains a known value. """
    
    notContains = "notContains"
    """Compare value string does not contain a known value. """
    
    eval = "eval"
    """Evaluate the FHIRPath expression as a boolean condition. """
    
class AssertionResponseTypes(enum.Enum):
    
    okay = "okay"
    """Response code is 200. """
    
    created = "created"
    """Response code is 201. """
    
    noContent = "noContent"
    """Response code is 204. """
    
    notModified = "notModified"
    """Response code is 304. """
    
    bad = "bad"
    """Response code is 400. """
    
    forbidden = "forbidden"
    """Response code is 403. """
    
    notFound = "notFound"
    """Response code is 404. """
    
    methodNotAllowed = "methodNotAllowed"
    """Response code is 405. """
    
    conflict = "conflict"
    """Response code is 409. """
    
    gone = "gone"
    """Response code is 410. """
    
    preconditionFailed = "preconditionFailed"
    """Response code is 412. """
    
    unprocessable = "unprocessable"
    """Response code is 422. """
    
class AuditEventAction(enum.Enum):
    
    C = "C"
    """Create a new database object, such as placing an order. """
    
    R = "R"
    """Display or print data, such as a doctor census. """
    
    U = "U"
    """Update data, such as revise patient information. """
    
    D = "D"
    """Delete items, such as a doctor master file record. """
    
    E = "E"
    """Perform a system or application function such as log-on, program execution or use of an object's method, or perform a query/search operation. """
    
class AuditEventID(enum.Enum):
    
    rest = "rest"
    """Audit Event: Execution of a RESTful operation as defined by FHIR. """
    
class BasicResourceTypes(enum.Enum):
    
    consent = "consent"
    """An assertion of permission for an activity or set of activities to occur, possibly subject to particular limitations; e.g. surgical consent, information disclosure consent, etc. """
    
    referral = "referral"
    """A request that care of a particular type be provided to a patient.  Could involve the transfer of care, a consult, etc. """
    
    advevent = "advevent"
    """An undesired reaction caused by exposure to some agent (e.g. a medication, immunization, food, or environmental agent). """
    
    aptmtreq = "aptmtreq"
    """A request that a time be scheduled for a type of service for a specified patient, potentially subject to other constraints """
    
    transfer = "transfer"
    """The transition of a patient or set of material from one location to another """
    
    diet = "diet"
    """The specification of a set of food and/or other nutritional material to be delivered to a patient. """
    
    adminact = "adminact"
    """An occurrence of a non-care-related event in the healthcare domain, such as approvals, reviews, etc. """
    
    exposure = "exposure"
    """Record of a situation where a subject was exposed to a substance.  Usually of interest to public health. """
    
    investigation = "investigation"
    """A formalized inquiry into the circumstances surrounding a particular unplanned event or potential event for the purposes of identifying possible causes and contributing factors for the event """
    
    account = "account"
    """A financial instrument used to track costs, charges or other amounts. """
    
    invoice = "invoice"
    """A request for payment for goods and/or services.  Includes the idea of a healthcare insurance claim. """
    
    adjudicat = "adjudicat"
    """The determination of what will be paid against a particular invoice based on coverage, plan rules, etc. """
    
    predetreq = "predetreq"
    """A request for a pre-determination of the cost that would be paid under an insurance plan for a hypothetical claim for goods or services """
    
    predetermine = "predetermine"
    """An adjudication of what would be paid under an insurance plan for a hypothetical claim for goods or services """
    
    study = "study"
    """An investigation to determine information about a particular therapy or product """
    
    protocol = "protocol"
    """A set of (possibly conditional) steps to be taken to achieve some aim.  Includes study protocols, treatment protocols, emergency protocols, etc. """
    
class BenefitCostApplicability(enum.Enum):
    
    inNetwork = "in-network"
    """Provider is contracted with the health insurance company to provide services to plan members for specific pre-negotiated rates """
    
    outOfNetwork = "out-of-network"
    """Provider is  not contracted with the health insurance company to provide services to plan members for specific pre-negotiated rates """
    
    other = "other"
    """Other applicability """
    
class BenefitTermCodes(enum.Enum):
    
    annual = "annual"
    """Annual, renewing on the anniversary """
    
    day = "day"
    """Per day """
    
    lifetime = "lifetime"
    """For the total term, lifetime, of the policy or coverage """
    
class BenefitTypeCodes(enum.Enum):
    
    benefit = "benefit"
    """Maximum benefit allowable. """
    
    deductible = "deductible"
    """Cost to be incurred before benefits are applied """
    
    visit = "visit"
    """Service visit """
    
    room = "room"
    """Type of room """
    
    copay = "copay"
    """Copayment per service """
    
    copayPercent = "copay-percent"
    """Copayment percentage per service """
    
    copayMaximum = "copay-maximum"
    """Copayment maximum per service """
    
    visionExam = "vision-exam"
    """Vision Exam """
    
    visionGlasses = "vision-glasses"
    """Frames and lenses """
    
    visionContacts = "vision-contacts"
    """Contact Lenses """
    
    medicalPrimarycare = "medical-primarycare"
    """Medical Primary Health Coverage """
    
    pharmacyDispense = "pharmacy-dispense"
    """Pharmacy Dispense Coverage """
    
class BindingStrength(enum.Enum):
    
    required = "required"
    """To be conformant, the concept in this element SHALL be from the specified value set. """
    
    extensible = "extensible"
    """To be conformant, the concept in this element SHALL be from the specified value set if any of the codes within the value set can apply to the concept being communicated.  If the value set does not cover the concept (based on human review), alternate codings (or, data type allowing, text) may be included instead. """
    
    preferred = "preferred"
    """Instances are encouraged to draw from the specified codes for interoperability purposes but are not required to do so to be considered conformant. """
    
    example = "example"
    """Instances are not expected or even encouraged to draw from the specified value set.  The value set merely provides examples of the types of concepts intended to be included. """
    
class BiologicallyDerivedProductCategory(enum.Enum):
    
    organ = "organ"
    """A collection of tissues joined in a structural unit to serve a common function. """
    
    tissue = "tissue"
    """An ensemble of similar cells and their extracellular matrix from the same origin that together carry out a specific function. """
    
    fluid = "fluid"
    """Body fluid. """
    
    cells = "cells"
    """Collection of cells. """
    
    biologicalAgent = "biologicalAgent"
    """Biological agent of unspecified type. """
    
class BiologicallyDerivedProductStatus(enum.Enum):
    
    available = "available"
    """Product is currently available for use. """
    
    unavailable = "unavailable"
    """Product is not currently available for use. """
    
class BiologicallyDerivedProductStorageScale(enum.Enum):
    
    farenheit = "farenheit"
    """Fahrenheit temperature scale. """
    
    celsius = "celsius"
    """Celsius or centigrade temperature scale. """
    
    kelvin = "kelvin"
    """Kelvin absolute thermodynamic temperature scale. """
    
class BundleType(enum.Enum):
    
    document = "document"
    """The bundle is a document. The first resource is a Composition. """
    
    message = "message"
    """The bundle is a message. The first resource is a MessageHeader. """
    
    transaction = "transaction"
    """The bundle is a transaction - intended to be processed by a server as an atomic commit. """
    
    transactionResponse = "transaction-response"
    """The bundle is a transaction response. Because the response is a transaction response, the transaction has succeeded, and all responses are error free. """
    
    batch = "batch"
    """The bundle is a set of actions - intended to be processed by a server as a group of independent actions. """
    
    batchResponse = "batch-response"
    """The bundle is a batch response. Note that as a batch, some responses may indicate failure and others success. """
    
    history = "history"
    """The bundle is a list of resources from a history interaction on a server. """
    
    searchset = "searchset"
    """The bundle is a list of resources returned as a result of a search/query interaction, operation, or message. """
    
    collection = "collection"
    """The bundle is a set of resources collected into a single package for ease of distribution that imposes no processing obligations or behavioral rules beyond persistence. """
    
class CanPushUpdates(enum.Enum):
    
    yes = "yes"
    """yes """
    
    no = "no"
    """no """
    
    undetermined = "undetermined"
    """undetermined """
    
class CanonicalStatusCodesForFHIRResources(enum.Enum):
    
    error = "error"
    """The resource was created in error, and should not be treated as valid (note: in many cases, for various data integrity related reasons, the information cannot be removed from the record) """
    
    proposed = "proposed"
    """The resource describes an action or plan that is proposed, and not yet approved by the participants """
    
    planned = "planned"
    """The resource describes a course of action that is planned and agreed/approved, but at the time of recording was still future """
    
    draft = "draft"
    """The information in the resource is still being prepared and edited """
    
    requested = "requested"
    """A fulfiller has been asked to perform this action, but it has not yet occurred """
    
    received = "received"
    """The fulfiller has received the request, but not yet agreed to carry out the action """
    
    declined = "declined"
    """The fulfiller chose not to perform the action """
    
    accepted = "accepted"
    """The fulfiller has decided to perform the action, and plans are in train to do this in the future """
    
    arrived = "arrived"
    """The pre-conditions for the action are all fulfilled, and it is imminent """
    
    active = "active"
    """The resource describes information that is currently valid or a process that is presently occuring """
    
    suspended = "suspended"
    """The process described/requested in this resource has been halted for some reason """
    
    failed = "failed"
    """The process described/requested in the resource could not be completed, and no further action is planned """
    
    replaced = "replaced"
    """The information in this resource has been replaced by information in another resource """
    
    complete = "complete"
    """The process described/requested in the resource has been completed, and no further action is planned """
    
    inactive = "inactive"
    """The resource describes information that is no longer valid or a process that is stopped occurring """
    
    abandoned = "abandoned"
    """The process described/requested in the resource did not complete - usually due to some workflow error, and no further action is planned """
    
    unknown = "unknown"
    """Authoring system does not know the status """
    
    unconfirmed = "unconfirmed"
    """The information in this resource is not yet approved """
    
    confirmed = "confirmed"
    """The information in this resource is approved """
    
    resolved = "resolved"
    """The issue identified by this resource is no longer of concern """
    
    refuted = "refuted"
    """This information has been ruled out by testing and evaluation """
    
    differential = "differential"
    """Potentially true? """
    
    partial = "partial"
    """This information is still being assembled """
    
    busyUnavailable = "busy-unavailable"
    """not available at this time/location """
    
    free = "free"
    """Free for scheduling """
    
    onTarget = "on-target"
    """Ready to act """
    
    aheadOfTarget = "ahead-of-target"
    """Ahead of the planned timelines """
    
    behindTarget = "behind-target"
    """behindTarget """
    
    notReady = "not-ready"
    """Behind the planned timelines """
    
    transducDiscon = "transduc-discon"
    """The device transducer is disconnected """
    
    hwDiscon = "hw-discon"
    """The hardware is disconnected """
    
class CapabilityStatementKind(enum.Enum):
    
    instance = "instance"
    """The CapabilityStatement instance represents the present capabilities of a specific system instance.  This is the kind returned by /metadata for a FHIR server end-point. """
    
    capability = "capability"
    """The CapabilityStatement instance represents the capabilities of a system or piece of software, independent of a particular installation. """
    
    requirements = "requirements"
    """The CapabilityStatement instance represents a set of requirements for other systems to meet; e.g. as part of an implementation guide or 'request for proposal'. """
    
class CarePlanActivityStatus(enum.Enum):
    
    notStarted = "not-started"
    """Care plan activity is planned but no action has yet been taken. """
    
    scheduled = "scheduled"
    """Appointment or other booking has occurred but activity has not yet begun. """
    
    inProgress = "in-progress"
    """Care plan activity has been started but is not yet complete. """
    
    onHold = "on-hold"
    """Care plan activity was started but has temporarily ceased with an expectation of resumption at a future time. """
    
    completed = "completed"
    """Care plan activity has been completed (more or less) as planned. """
    
    cancelled = "cancelled"
    """The planned care plan activity has been withdrawn. """
    
    stopped = "stopped"
    """The planned care plan activity has been ended prior to completion after the activity was started. """
    
    unknown = "unknown"
    """The current state of the care plan activity is not known.  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, but the authoring/source system does not know which one. """
    
    enteredInError = "entered-in-error"
    """Care plan activity was entered in error and voided. """
    
class CareTeamStatus(enum.Enum):
    
    proposed = "proposed"
    """The care team has been drafted and proposed, but not yet participating in the coordination and delivery of patient care. """
    
    active = "active"
    """The care team is currently participating in the coordination and delivery of care. """
    
    suspended = "suspended"
    """The care team is temporarily on hold or suspended and not participating in the coordination and delivery of care. """
    
    inactive = "inactive"
    """The care team was, but is no longer, participating in the coordination and delivery of care. """
    
    enteredInError = "entered-in-error"
    """The care team should have never existed. """
    
class CatalogEntryRelationType(enum.Enum):
    
    triggers = "triggers"
    """the related entry represents an activity that may be triggered by the current item. """
    
    isReplacedBy = "is-replaced-by"
    """the related entry represents an item that replaces the current retired item. """
    
class CatalogType(enum.Enum):
    
    medication = "medication"
    """Medication Catalog. """
    
    device = "device"
    """Device Catalog. """
    
    protocol = "protocol"
    """Protocol List. """
    
class CertaintySubcomponentRating(enum.Enum):
    
    noChange = "no-change"
    """no change to quality rating. """
    
    downcode1 = "downcode1"
    """reduce quality rating by 1. """
    
    downcode2 = "downcode2"
    """reduce quality rating by 2. """
    
    downcode3 = "downcode3"
    """reduce quality rating by 3. """
    
    upcode1 = "upcode1"
    """increase quality rating by 1. """
    
    upcode2 = "upcode2"
    """increase quality rating by 2. """
    
    noConcern = "no-concern"
    """no serious concern. """
    
    seriousConcern = "serious-concern"
    """serious concern. """
    
    criticalConcern = "critical-concern"
    """critical concern. """
    
    present = "present"
    """possible reason for increasing quality rating was checked and found to bepresent. """
    
    absent = "absent"
    """possible reason for increasing quality rating was checked and found to be absent. """
    
class CertaintySubcomponentType(enum.Enum):
    
    riskOfBias = "RiskOfBias"
    """methodologic concerns reducing internal validity. """
    
    inconsistency = "Inconsistency"
    """concerns that findings are not similar enough to support certainty. """
    
    indirectness = "Indirectness"
    """concerns reducing external validity. """
    
    imprecision = "Imprecision"
    """High quality evidence. """
    
    publicationBias = "PublicationBias"
    """likelihood that what is published misrepresents what is available to publish. """
    
    doseResponseGradient = "DoseResponseGradient"
    """higher certainty due to dose response relationship. """
    
    plausibleConfounding = "PlausibleConfounding"
    """higher certainty due to risk of bias in opposite direction. """
    
    largeEffect = "LargeEffect"
    """higher certainty due to large effect size. """
    
class ChargeItemStatus(enum.Enum):
    
    planned = "planned"
    """The charge item has been entered, but the charged service is not  yet complete, so it shall not be billed yet but might be used in the context of pre-authorization. """
    
    billable = "billable"
    """The charge item is ready for billing. """
    
    notBillable = "not-billable"
    """The charge item has been determined to be not billable (e.g. due to rules associated with the billing code). """
    
    aborted = "aborted"
    """The processing of the charge was aborted. """
    
    billed = "billed"
    """The charge item has been billed (e.g. a billing engine has generated financial transactions by applying the associated ruled for the charge item to the context of the Encounter, and placed them into Claims/Invoices. """
    
    enteredInError = "entered-in-error"
    """The charge item has been entered in error and should not be processed for billing. """
    
    unknown = "unknown"
    """The authoring system does not know which of the status values currently applies for this charge item  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, it's just not known which one. """
    
class ChoiceListOrientation(enum.Enum):
    
    horizontal = "horizontal"
    """List choices along the horizontal axis. """
    
    vertical = "vertical"
    """List choices down the vertical axis. """
    
class ClaimCareTeamRoleCodes(enum.Enum):
    
    primary = "primary"
    """The primary care provider. """
    
    assist = "assist"
    """Assisting care provider. """
    
    supervisor = "supervisor"
    """Supervising care provider. """
    
    other = "other"
    """Other role on the care team. """
    
class ClaimInformationCategoryCodes(enum.Enum):
    
    info = "info"
    """Codes conveying additional situation and condition information. """
    
    discharge = "discharge"
    """Discharge status and discharge to locations. """
    
    onset = "onset"
    """Period, start or end dates of aspects of the Condition. """
    
    related = "related"
    """Nature and date of the related event e.g. Last exam, service, X-ray etc. """
    
    exception = "exception"
    """Insurance policy exceptions. """
    
    material = "material"
    """Materials being forwarded, e.g. Models, molds, images, documents. """
    
    attachment = "attachment"
    """Materials attached such as images, documents and resources. """
    
    missingtooth = "missingtooth"
    """Teeth which are missing for any reason, for example: prior extraction, never developed. """
    
    prosthesis = "prosthesis"
    """The type of prosthesis and date of supply if a previously supplied prosthesis. """
    
    other = "other"
    """Other information identified by the type.system. """
    
    hospitalized = "hospitalized"
    """An indication that the patient was hospitalized, the period if known otherwise a Yes/No (boolean). """
    
    employmentimpacted = "employmentimpacted"
    """An indication that the patient was unable to work, the period if known otherwise a Yes/No (boolean). """
    
    externalcause = "externalcause"
    """The external cause of an illness or injury. """
    
    patientreasonforvisit = "patientreasonforvisit"
    """The reason for the patient visit. """
    
class ClaimItemTypeCodes(enum.Enum):
    
    group = "group"
    """A group of products and/or Services, amount ar the summary or detail level products and services. """
    
    product = "product"
    """A billed product line item. """
    
    service = "service"
    """A billed service line item. """
    
class ClaimPayeeResourceType(enum.Enum):
    
    organization = "organization"
    """Organization resource. """
    
    patient = "patient"
    """Patient resource. """
    
    practitioner = "practitioner"
    """Practitioner resource. """
    
    relatedperson = "relatedperson"
    """RelatedPerson resource. """
    
class ClaimProcessingCodes(enum.Enum):
    
    queued = "queued"
    """The Claim/Pre-authorization/Pre-determination has been received but processing has not begun. """
    
    complete = "complete"
    """The processing has completed without errors """
    
    error = "error"
    """One or more errors have been detected in the Claim """
    
    partial = "partial"
    """No errors have been detected in the Claim and some of the adjudication has been performed. """
    
class ClaimTypeCodes(enum.Enum):
    
    institutional = "institutional"
    """Hospital, clinic and typically inpatient claims. """
    
    oral = "oral"
    """Dental, Denture and Hygiene claims. """
    
    pharmacy = "pharmacy"
    """Pharmacy claims for goods and services. """
    
    professional = "professional"
    """Typically, outpatient claims from Physician, Psychological, Chiropractor, Physiotherapy, Speech Pathology, rehabilitative, consulting. """
    
    vision = "vision"
    """Vision claims for professional services and products such as glasses and contact lenses. """
    
class CodeSearchSupport(enum.Enum):
    
    explicit = "explicit"
    """The search for code on ValueSet only includes codes explicitly detailed on includes or expansions. """
    
    all = "all"
    """The search for code on ValueSet only includes all codes based on the expansion of the value set. """
    
class CodeSystemContentMode(enum.Enum):
    
    notPresent = "not-present"
    """None of the concepts defined by the code system are included in the code system resource. """
    
    example = "example"
    """A few representative concepts are included in the code system resource. There is no useful intent in the subset choice and there's no process to make it workable: it's not intended to be workable. """
    
    fragment = "fragment"
    """A subset of the code system concepts are included in the code system resource. This is a curated subset released for a specific purpose under the governance of the code system steward, and that the intent, bounds and consequences of the fragmentation are clearly defined in the fragment or the code system documentation. Fragments are also known as partitions. """
    
    complete = "complete"
    """All the concepts defined by the code system are included in the code system resource. """
    
    supplement = "supplement"
    """The resource doesn't define any new concepts; it just provides additional designations and properties to another code system. """
    
class CodeSystemHierarchyMeaning(enum.Enum):
    
    groupedBy = "grouped-by"
    """No particular relationship between the concepts can be assumed, except what can be determined by inspection of the definitions of the elements (possible reasons to use this: importing from a source where this is not defined, or where various parts of the hierarchy have different meanings). """
    
    isA = "is-a"
    """A hierarchy where the child concepts have an IS-A relationship with the parents - that is, all the properties of the parent are also true for its child concepts. Not that is-a is a property of the concepts, so additional subsumption relationships may be defined using properties or the [subsumes](extension-codesystem-subsumes.html) extension. """
    
    partOf = "part-of"
    """Child elements list the individual parts of a composite whole (e.g. body site). """
    
    classifiedWith = "classified-with"
    """Child concepts in the hierarchy may have only one parent, and there is a presumption that the code system is a "closed world" meaning all things must be in the hierarchy. This results in concepts such as "not otherwise classified.". """
    
class CommonTags(enum.Enum):
    
    actionable = "actionable"
    """This request is intended to be acted upon, not merely stored """
    
class CommunicationCategory(enum.Enum):
    
    alert = "alert"
    """The communication conveys an alert. """
    
    notification = "notification"
    """The communication conveys a notification. """
    
    reminder = "reminder"
    """The communication conveys a reminder. """
    
    instruction = "instruction"
    """The communication conveys an instruction. """
    
class CommunicationNotDoneReason(enum.Enum):
    
    unknown = "unknown"
    """The communication was not done due to an unknown reason. """
    
    systemError = "system-error"
    """The communication was not done due to a system error. """
    
    invalidPhoneNumber = "invalid-phone-number"
    """The communication was not done due to an invalid phone number. """
    
    recipientUnavailable = "recipient-unavailable"
    """The communication was not done due to the recipient being unavailable. """
    
    familyObjection = "family-objection"
    """The communication was not done due to a family objection. """
    
    patientObjection = "patient-objection"
    """The communication was not done due to a patient objection. """
    
class CommunicationTopic(enum.Enum):
    
    prescriptionRefillRequest = "prescription-refill-request"
    """The purpose or content of the communication is a prescription refill request. """
    
    progressUpdate = "progress-update"
    """The purpose or content of the communication is a progress update. """
    
    reportLabs = "report-labs"
    """The purpose or content of the communication is to report labs. """
    
    appointmentReminder = "appointment-reminder"
    """The purpose or content of the communication is an appointment reminder. """
    
    phoneConsult = "phone-consult"
    """The purpose or content of the communication is a phone consult. """
    
    summaryReport = "summary-report"
    """The purpose or content of the communication is a summary report. """
    
class CompartmentType(enum.Enum):
    
    patient = "Patient"
    """The compartment definition is for the patient compartment. """
    
    encounter = "Encounter"
    """The compartment definition is for the encounter compartment. """
    
    relatedPerson = "RelatedPerson"
    """The compartment definition is for the related-person compartment. """
    
    practitioner = "Practitioner"
    """The compartment definition is for the practitioner compartment. """
    
    device = "Device"
    """The compartment definition is for the device compartment. """
    
class CompositeMeasureScoring(enum.Enum):
    
    opportunity = "opportunity"
    """Opportunity scoring combines the scores from component measures by combining the numerators and denominators for each component. """
    
    allOrNothing = "all-or-nothing"
    """All-or-nothing scoring includes an individual in the numerator of the composite measure if they are in the numerators of all of the component measures in which they are in the denominator. """
    
    linear = "linear"
    """Linear scoring gives an individual a score based on the number of numerators in which they appear. """
    
    weighted = "weighted"
    """Weighted scoring gives an individual a score based on a weighted factor for each component numerator in which they appear. """
    
class CompositionAttestationMode(enum.Enum):
    
    personal = "personal"
    """The person authenticated the content in their personal capacity. """
    
    professional = "professional"
    """The person authenticated the content in their professional capacity. """
    
    legal = "legal"
    """The person authenticated the content and accepted legal responsibility for its content. """
    
    official = "official"
    """The organization authenticated the content as consistent with their policies and procedures. """
    
class CompositionStatus(enum.Enum):
    
    preliminary = "preliminary"
    """This is a preliminary composition or document (also known as initial or interim). The content may be incomplete or unverified. """
    
    final = "final"
    """This version of the composition is complete and verified by an appropriate person and no further work is planned. Any subsequent updates would be on a new version of the composition. """
    
    amended = "amended"
    """The composition content or the referenced resources have been modified (edited or added to) subsequent to being released as "final" and the composition is complete and verified by an authorized person. """
    
    enteredInError = "entered-in-error"
    """The composition or document was originally created/issued in error, and this is an amendment that marks that the entire series should not be considered as valid. """
    
class ConceptMapEquivalence(enum.Enum):
    
    relatedto = "relatedto"
    """The concepts are related to each other, and have at least some overlap in meaning, but the exact relationship is not known. """
    
    equivalent = "equivalent"
    """The definitions of the concepts mean the same thing (including when structural implications of meaning are considered) (i.e. extensionally identical). """
    
    equal = "equal"
    """The definitions of the concepts are exactly the same (i.e. only grammatical differences) and structural implications of meaning are identical or irrelevant (i.e. intentionally identical). """
    
    wider = "wider"
    """The target mapping is wider in meaning than the source concept. """
    
    subsumes = "subsumes"
    """The target mapping subsumes the meaning of the source concept (e.g. the source is-a target). """
    
    narrower = "narrower"
    """The target mapping is narrower in meaning than the source concept. The sense in which the mapping is narrower SHALL be described in the comments in this case, and applications should be careful when attempting to use these mappings operationally. """
    
    specializes = "specializes"
    """The target mapping specializes the meaning of the source concept (e.g. the target is-a source). """
    
    inexact = "inexact"
    """The target mapping overlaps with the source concept, but both source and target cover additional meaning, or the definitions are imprecise and it is uncertain whether they have the same boundaries to their meaning. The sense in which the mapping is inexact SHALL be described in the comments in this case, and applications should be careful when attempting to use these mappings operationally. """
    
    unmatched = "unmatched"
    """There is no match for this concept in the target code system. """
    
    disjoint = "disjoint"
    """This is an explicit assertion that there is no mapping between the source and target concept. """
    
class ConceptMapGroupUnmappedMode(enum.Enum):
    
    provided = "provided"
    """Use the code as provided in the $translate request. """
    
    fixed = "fixed"
    """Use the code explicitly provided in the group.unmapped. """
    
    otherMap = "other-map"
    """Use the map identified by the canonical URL in the url element. """
    
class ConceptSubsumptionOutcome(enum.Enum):
    
    equivalent = "equivalent"
    """The two concepts are equivalent (have the same properties). """
    
    subsumes = "subsumes"
    """Coding/code "A" subsumes Coding/code "B" (e.g. B has all the properties A has, and some of it's own). """
    
    subsumedBy = "subsumed-by"
    """Coding/code "A" is subsumed by Coding/code "B" (e.g. A has all the properties B has, and some of it's own). """
    
    notSubsumed = "not-subsumed"
    """Coding/code "A" and Coding/code "B" are disjoint (e.g. each has propeties that the other doesn't have). """
    
class ConditionCategoryCodes(enum.Enum):
    
    problemListItem = "problem-list-item"
    """An item on a problem list that can be managed over time and can be expressed by a practitioner (e.g. physician, nurse), patient, or related person. """
    
    encounterDiagnosis = "encounter-diagnosis"
    """A point in time diagnosis (e.g. from a physician or nurse) in context of an encounter. """
    
class ConditionClinicalStatusCodes(enum.Enum):
    
    active = "active"
    """The subject is currently experiencing the symptoms of the condition or there is evidence of the condition. """
    
    recurrence = "recurrence"
    """The subject is experiencing a re-occurence or repeating of a previously resolved condition, e.g. urinary tract infection, pancreatitis, cholangitis, conjunctivitis. """
    
    relapse = "relapse"
    """The subject is experiencing a return of a condition, or signs and symptoms after a period of improvement or remission, e.g. relapse of cancer, multiple sclerosis, rheumatoid arthritis, systemic lupus erythematosus, bipolar disorder, [psychotic relapse of] schizophrenia, etc. """
    
    inactive = "inactive"
    """The subject is no longer experiencing the symptoms of the condition or there is no longer evidence of the condition. """
    
    remission = "remission"
    """The subject is no longer experiencing the symptoms of the condition, but there is a risk of the symptoms returning. """
    
    resolved = "resolved"
    """The subject is no longer experiencing the symptoms of the condition and there is a negligible perceived risk of the symptoms returning. """
    
class ConditionState(enum.Enum):
    
    active = "active"
    """The condition is active. """
    
    inactive = "inactive"
    """The condition is inactive, but not resolved. """
    
    resolved = "resolved"
    """The condition is resolved. """
    
class ConditionVerificationStatus(enum.Enum):
    
    unconfirmed = "unconfirmed"
    """There is not sufficient diagnostic and/or clinical evidence to treat this as a confirmed condition. """
    
    provisional = "provisional"
    """This is a tentative diagnosis - still a candidate that is under consideration. """
    
    differential = "differential"
    """One of a set of potential (and typically mutually exclusive) diagnoses asserted to further guide the diagnostic process and preliminary treatment. """
    
    confirmed = "confirmed"
    """There is sufficient diagnostic and/or clinical evidence to treat this as a confirmed condition. """
    
    refuted = "refuted"
    """This condition has been ruled out by diagnostic and clinical evidence. """
    
    enteredInError = "entered-in-error"
    """The statement was entered in error and is not valid. """
    
class ConditionalDeleteStatus(enum.Enum):
    
    notSupported = "not-supported"
    """No support for conditional deletes. """
    
    single = "single"
    """Conditional deletes are supported, but only single resources at a time. """
    
    multiple = "multiple"
    """Conditional deletes are supported, and multiple resources can be deleted in a single interaction. """
    
class ConditionalReadStatus(enum.Enum):
    
    notSupported = "not-supported"
    """No support for conditional reads. """
    
    modifiedSince = "modified-since"
    """Conditional reads are supported, but only with the If-Modified-Since HTTP Header. """
    
    notMatch = "not-match"
    """Conditional reads are supported, but only with the If-None-Match HTTP Header. """
    
    fullSupport = "full-support"
    """Conditional reads are supported, with both If-Modified-Since and If-None-Match HTTP Headers. """
    
class ConformanceExpectation(enum.Enum):
    
    SHALL = "SHALL"
    """Support for the specified capability is required to be considered conformant. """
    
    SHOULD = "SHOULD"
    """Support for the specified capability is strongly encouraged, and failure to support it should only occur after careful consideration. """
    
    MAY = "MAY"
    """Support for the specified capability is not necessary to be considered conformant, and the requirement should be considered strictly optional. """
    
    SHOULDNOT = "SHOULD-NOT"
    """Support for the specified capability is strongly discouraged and should occur only after careful consideration. """
    
class ConsentActionCodes(enum.Enum):
    
    collect = "collect"
    """Gather retrieved information for storage """
    
    access = "access"
    """Retrieval without permitting collection, use or disclosure. e.g., no screen-scraping for collection, use or disclosure (view-only access) """
    
    use = "use"
    """Utilize the retrieved information """
    
    disclose = "disclose"
    """Transfer retrieved information """
    
    correct = "correct"
    """Allow retrieval of a patient's information for the purpose of update or rectify """
    
class ConsentCategoryCodes(enum.Enum):
    
    acd = "acd"
    """Any instructions, written or given verbally by a patient to a health care provider in anticipation of potential need for medical treatment. [2005 Honor My Wishes] """
    
    dnr = "dnr"
    """A legal document, signed by both the patient and their provider, stating a desire not to have CPR initiated in case of a cardiac event. Note: This form was replaced in 2003 with the Physician Orders for Life-Sustaining Treatment [POLST]. """
    
    emrgonly = "emrgonly"
    """Opt-in to disclosure of health information for emergency only consent directive. Comment: This general consent directive specifically limits disclosure of health information for purpose of emergency treatment. Additional parameters may further limit the disclosure to specific users, roles, duration, types of information, and impose uses obligations. [ActConsentDirective (2.16.840.1.113883.1.11.20425)] """
    
    hcd = "hcd"
    """Patient's document telling patient's health care provider what the patient wants or does not want if the patient is diagnosed as being terminally ill and in a persistent vegetative state or in a permanently unconscious condition.[2005 Honor My Wishes] """
    
    npp = "npp"
    """Acknowledgement of custodian notice of privacy practices. Usage Notes: This type of consent directive acknowledges a custodian's notice of privacy practices including its permitted collection, access, use and disclosure of health information to users and for purposes of use specified. [ActConsentDirective (2.16.840.1.113883.1.11.20425)] """
    
    polst = "polst"
    """The Physician Order for Life-Sustaining Treatment form records a person's health care wishes for end of life emergency treatment and translates them into an order by the physician. It must be reviewed and signed by both the patient and the physician, Advanced Registered Nurse Practitioner or Physician Assistant. [2005 Honor My Wishes] Comment: Opt-in Consent Directive with restrictions. """
    
    research = "research"
    """Consent to have healthcare information in an electronic health record accessed for research purposes. [VALUE SET: ActConsentType (2.16.840.1.113883.1.11.19897)] """
    
    rsdid = "rsdid"
    """Consent to have de-identified healthcare information in an electronic health record that is accessed for research purposes, but without consent to re-identify the information under any circumstance. [VALUE SET: ActConsentType (2.16.840.1.113883.1.11.19897) """
    
    rsreid = "rsreid"
    """Consent to have de-identified healthcare information in an electronic health record that is accessed for research purposes re-identified under specific circumstances outlined in the consent. [VALUE SET: ActConsentType (2.16.840.1.113883.1.11.19897)] """
    
class ConsentDataMeaning(enum.Enum):
    
    instance = "instance"
    """The consent applies directly to the instance of the resource. """
    
    related = "related"
    """The consent applies directly to the instance of the resource and instances it refers to. """
    
    dependents = "dependents"
    """The consent applies directly to the instance of the resource and instances that refer to it. """
    
    authoredby = "authoredby"
    """The consent applies to instances of resources that are authored by. """
    
class ConsentPolicyRuleCodes(enum.Enum):
    
    cric = "cric"
    """45 CFR part 46 §46.116 General requirements for informed consent; and §46.117 Documentation of informed consent. https://www.gpo.gov/fdsys/pkg/FR-2017-01-19/pdf/2017-01058.pdf """
    
    illinoisMinorProcedure = "illinois-minor-procedure"
    """The consent to the performance of a medical or surgical procedure by a physician licensed to practice medicine and surgery, a licensed advanced practice nurse, or a licensed physician assistant executed by a married person who is a minor, by a parent who is a minor, by a pregnant woman who is a minor, or by any person 18 years of age or older, is not voidable because of such minority, and, for such purpose, a married person who is a minor, a parent who is a minor, a pregnant woman who is a minor, or any person 18 years of age or older, is deemed to have the same legal capacity to act and has the same powers and obligations as has a person of legal age. Consent by Minors to Medical Procedures Act. (410 ILCS 210/0.01) (from Ch. 111, par. 4500) Sec. 0.01. Short title. This Act may be cited as the Consent by Minors to Medical Procedures Act. (Source: P.A. 86-1324.) http://www.ilga.gov/legislation/ilcs/ilcs3.asp?ActID=1539&ChapterID=35 """
    
    hipaaAuth = "hipaa-auth"
    """HIPAA 45 CFR Section 164.508 Uses and disclosures for which an authorization is required. (a) Standard: Authorizations for uses and disclosures. (1) Authorization required: General rule. Except as otherwise permitted or required by this subchapter, a covered entity SHALL not use or disclose protected health information without an authorization that is valid under this section. When a covered entity obtains or receives a valid authorization for its use or disclosure of protected health information, such use or disclosure must be consistent with such authorization. Usage Note: Authorizations governed under this regulation meet the definition of an opt in class of consent directive. """
    
    hipaaNpp = "hipaa-npp"
    """164.520  Notice of privacy practices for protected health information. (1) Right to notice. Except as provided by paragraph (a)(2) or (3) of this section, an individual has a right to adequate notice of the uses and disclosures of protected health information that may be made by the covered entity, and of the individual's rights and the covered entity's legal duties with respect to protected health information. Usage Note: Restrictions governed under this regulation meet the definition of an implied with an opportunity to dissent class of consent directive. """
    
    hipaaRestrictions = "hipaa-restrictions"
    """HIPAA 45 CFR 164.510 - Uses and disclosures requiring an opportunity for the individual to agree or to object. A covered entity may use or disclose protected health information, provided that the individual is informed in advance of the use or disclosure and has the opportunity to agree to or prohibit or restrict the use or disclosure, in accordance with the applicable requirements of this section. The covered entity may orally inform the individual of and obtain the individual's oral agreement or objection to a use or disclosure permitted by this section. Usage Note: Restrictions governed under this regulation meet the definition of an opt out with exception class of consent directive. """
    
    hipaaResearch = "hipaa-research"
    """HIPAA 45 CFR 164.508 - Uses and disclosures for which an authorization is required. (a) Standard: Authorizations for uses and disclosures. (3) Compound authorizations. An authorization for use or disclosure of protected health information SHALL NOT be combined with any other document to create a compound authorization, except as follows: (i) An authorization for the use or disclosure of protected health information for a research study may be combined with any other type of written permission for the same or another research study. This exception includes combining an authorization for the use or disclosure of protected health information for a research study with another authorization for the same research study, with an authorization for the creation or maintenance of a research database or repository, or with a consent to participate in research. Where a covered health care provider has conditioned the provision of research-related treatment on the provision of one of the authorizations, as permitted under paragraph (b)(4)(i) of this section, any compound authorization created under this paragraph must clearly differentiate between the conditioned and unconditioned components and provide the individual with an opportunity to opt in to the research activities described in the unconditioned authorization. Usage Notes: See HHS http://www.hhs.gov/hipaa/for-professionals/special-topics/research/index.html and OCR http://www.hhs.gov/hipaa/for-professionals/special-topics/research/index.html """
    
    hipaaSelfPay = "hipaa-self-pay"
    """HIPAA 45 CFR 164.522(a) Right To Request a Restriction of Uses and Disclosures. (vi) A covered entity must agree to the request of an individual to restrict disclosure of protected health information about the individual to a health plan if: (A) The disclosure is for the purpose of carrying out payment or health care operations and is not otherwise required by law; and (B) The protected health information pertains solely to a health care item or service for which the individual, or person other than the health plan on behalf of the individual, has paid the covered entity in full. Usage Note: Restrictions governed under this regulation meet the definition of an opt out with exception class of consent directive. Opt out is limited to disclosures to a payer for payment and operations purpose of use. See HL7 HIPAA Self-Pay code in ActPrivacyLaw (2.16.840.1.113883.1.11.20426). """
    
    mdhhs5515 = "mdhhs-5515"
    """On January 1, 2015, the Michigan Department of Health and Human Services (MDHHS) released a standard consent form for the sharing of health information specific to behavioral health and substance use treatment in accordance with Public Act 129 of 2014. In Michigan, while providers are not required to use this new standard form (MDHHS-5515), they are required to accept it. Note: Form is available at http://www.michigan.gov/documents/mdhhs/Consent_to_Share_Behavioral_Health_Information_for_Care_Coordination_Purposes_548835_7.docx For more information see http://www.michigan.gov/documents/mdhhs/Behavioral_Health_Consent_Form_Background_Information_548864_7.pdf """
    
    nyssipp = "nyssipp"
    """The New York State Surgical and Invasive Procedure Protocol (NYSSIPP) applies to all operative and invasive procedures including endoscopy, general surgery or interventional radiology. Other procedures that involve puncture or incision of the skin, or insertion of an instrument or foreign material into the body are within the scope of the protocol. This protocol also applies to those anesthesia procedures either prior to a surgical procedure or independent of a surgical procedure such as spinal facet blocks. Example: Certain 'minor' procedures such as venipuncture, peripheral IV placement, insertion of nasogastric tube and foley catheter insertion are not within the scope of the protocol. From http://www.health.ny.gov/professionals/protocols_and_guidelines/surgical_and_invasive_procedure/nyssipp_faq.htm Note: HHC 100B-1 Form is available at http://www.downstate.edu/emergency_medicine/documents/Consent_CT_with_contrast.pdf """
    
    va100484 = "va-10-0484"
    """VA Form 10-0484 Revocation for Release of Individually-Identifiable Health Information enables a veteran to revoke authorization for the VA to release specified copies of individually-identifiable health information with the non-VA health care provider organizations participating in the eHealth Exchange and partnering with VA. Comment: Opt-in Consent Directive with status = rescinded (aka 'revoked'). Note: Form is available at http://www.va.gov/vaforms/medical/pdf/vha-10-0484-fill.pdf """
    
    va100485 = "va-10-0485"
    """VA Form 10-0485 Request for and Authorization to Release Protected Health Information to eHealth Exchange enables a veteran to request and authorize a VA health care facility to release protected health information (PHI) for treatment purposes only to the communities that are participating in the eHealth Exchange, VLER Directive, and other Health Information Exchanges with who VA has an agreement. This information may consist of the diagnosis of Sickle Cell Anemia, the treatment of or referral for Drug Abuse, treatment of or referral for Alcohol Abuse or the treatment of or testing for infection with Human Immunodeficiency Virus. This authorization covers the diagnoses that I may have upon signing of the authorization and the diagnoses that I may acquire in the future including those protected by 38 U.S.C. 7332. Comment: Opt-in Consent Directive. Note: Form is available at http://www.va.gov/vaforms/medical/pdf/10-0485-fill.pdf """
    
    va105345 = "va-10-5345"
    """VA Form 10-5345 Request for and Authorization to Release Medical Records or Health Information enables a veteran to request and authorize the VA to release specified copies of protected health information (PHI), such as hospital summary or outpatient treatment notes, which may include information about conditions governed under Title 38 Section 7332 (drug abuse, alcoholism or alcohol abuse, testing for or infection with HIV, and sickle cell anemia). Comment: Opt-in Consent Directive. Note: Form is available at http://www.va.gov/vaforms/medical/pdf/vha-10-5345-fill.pdf """
    
    va105345a = "va-10-5345a"
    """VA Form 10-5345a Individuals' Request for a Copy of Their Own Health Information enables a veteran to request and authorize the VA to release specified copies of protected health information (PHI), such as hospital summary or outpatient treatment notes. Note: Form is available at http://www.va.gov/vaforms/medical/pdf/vha-10-5345a-fill.pdf """
    
    va105345aMhv = "va-10-5345a-mhv"
    """VA Form 10-5345a-MHV Individual's Request for a Copy of their own health information from MyHealtheVet enables a veteran to receive a copy of all available personal health information to be delivered through the veteran's My HealtheVet account. Note: Form is available at http://www.va.gov/vaforms/medical/pdf/vha-10-5345a-MHV-fill.pdf """
    
    va1010116 = "va-10-10116"
    """VA Form 10-10116 Revocation of Authorization for Use and Release of Individually Identifiable Health Information for Veterans Health Administration Research. Comment: Opt-in with Restriction Consent Directive with status = 'completed'. Note: Form is available at http://www.northerncalifornia.va.gov/northerncalifornia/services/rnd/docs/vha-10-10116.pdf  """
    
    va214142 = "va-21-4142"
    """VA Form 21-4142 (Authorization and Consent to Release Information to the Department of Veterans Affairs (VA) enables a veteran to authorize the US Veterans Administration [VA] to request veteran's health information from non-VA providers. Aka VA Compensation Application Note: Form is available at http://www.vba.va.gov/pubs/forms/VBA-21-4142-ARE.pdf . For additional information regarding VA Form 21-4142, refer to the following website: www.benefits.va.gov/compensation/consent_privateproviders """
    
    ssa827 = "ssa-827"
    """SA Form SSA-827 (Authorization to Disclose Information to the Social Security Administration (SSA)). Form is available at https://www.socialsecurity.gov/forms/ssa-827-inst-sp.pdf """
    
    dch3927 = "dch-3927"
    """Michigan DCH-3927 Consent to Share Behavioral Health Information for Care Coordination Purposes, which combines 42 CFR Part 2 and Michigan Mental Health Code, Act 258 of 1974. Form is available at http://www.michigan.gov/documents/mdch/DCH-3927_Consent_to_Share_Health_Information_477005_7.docx """
    
    squaxin = "squaxin"
    """Squaxin Indian HIPAA and 42 CFR Part 2 Consent for Release and Exchange of Confidential Information, which permits consenter to select healthcare record type and types of treatment purposes.  This consent requires disclosers and recipients to comply with 42 C.F.R. Part 2, and HIPAA 45 C.F.R. parts 160 and 164. It includes patient notice of the refrain policy not to disclose without consent, and revocation rights. https://www.ncsacw.samhsa.gov/files/SI_ConsentForReleaseAndExchange.PDF """
    
    nlLsp = "nl-lsp"
    """LSP (National Exchange Point) requires that providers, hospitals and pharmacy obtain explicit permission [opt-in] from healthcare consumers to submit and retrieve all or only some of a subject of care’s health information collected by the LSP for purpose of treatment, which can be revoked.  Without permission, a provider cannot access LSP information even in an emergency. The LSP provides healthcare consumers with accountings of disclosures. https://www.vzvz.nl/uploaded/FILES/htmlcontent/Formulieren/TOESTEMMINGSFORMULIER.pdf, https://www.ikgeeftoestemming.nl/en, https://www.ikgeeftoestemming.nl/en/registration/find-healthcare-provider """
    
    atElga = "at-elga"
    """Pursuant to Sec. 2 no. 9 Health Telematics Act 2012, ELGA Health Data ( “ELGA-Gesundheitsdaten”) = Medical documents. Austria opted for an opt-out approach. This means that a person is by default ‘ELGA participant’ unless he/she objects. ELGA participants have the following options: General opt out: No participation in ELGA, Partial opt-out: No participation in a particular ELGA application, e.g. eMedication and Case-specific opt-out: No participation in ELGA only regarding a particular case/treatment. There is the possibility to opt-in again. ELGA participants can also exclude the access of a particular ELGA healthcare provider to a particular piece of or all of their ELGA data. http://ec.europa.eu/health/ehealth/docs/laws_austria_en.pdf """
    
    nihHipaa = "nih-hipaa"
    """Guidance and template form https://privacyruleandresearch.nih.gov/pdf/authorization.pdf """
    
    nci = "nci"
    """see http://ctep.cancer.gov/protocolDevelopment/docs/Informed_Consent_Template.docx """
    
    nihGrdr = "nih-grdr"
    """Global Rare Disease Patient Registry and Data Repository (GRDR) consent is an agreement of a healthcare consumer to permit collection, access, use and disclosure of de-identified rare disease information and collection of bio-specimens, medical information, family history and other related information from patients to permit the registry collection of health and genetic information, and specimens for pseudonymized disclosure for research purpose of use. https://rarediseases.info.nih.gov/files/informed_consent_template.pdf """
    
    nih527 = "nih-527"
    """NIH Authorization for the Release of Medical Information is a patient’s consent for the National Institutes of Health Clinical Center to release medical information to care providers, which can be revoked. Note: Consent Form available @ http://cc.nih.gov/participate/_pdf/NIH-527.pdf """
    
    ga4gh = "ga4gh"
    """Global Alliance for Genomic Health Data Sharing Consent Form is an example of the GA4GH Population origins and ancestry research consent form. Consenters agree to permitting a specified research project to collect ancestry and genetic information in controlled-access databases, and to allow other researchers to use deidentified information from those databases. http://www.commonaccord.org/index.php?action=doc&file=Wx/org/genomicsandhealth/REWG/Demo/Roberta_Robinson_US """
    
class ConsentProvisionType(enum.Enum):
    
    deny = "deny"
    """Consent is denied for actions meeting these rules. """
    
    permit = "permit"
    """Consent is provided for actions meeting these rules. """
    
class ConsentScopeCodes(enum.Enum):
    
    adr = "adr"
    """Actions to be taken if they are no longer able to make decisions for themselves """
    
    research = "research"
    """Consent to participate in research protocol and information sharing required """
    
    patientPrivacy = "patient-privacy"
    """Agreement to collect, access, use or disclose (share) information """
    
    treatment = "treatment"
    """Consent to undergo a specific treatment """
    
class ConsentState(enum.Enum):
    
    draft = "draft"
    """The consent is in development or awaiting use but is not yet intended to be acted upon. """
    
    proposed = "proposed"
    """The consent has been proposed but not yet agreed to by all parties. The negotiation stage. """
    
    active = "active"
    """The consent is to be followed and enforced. """
    
    rejected = "rejected"
    """The consent has been rejected by one or more of the parties. """
    
    inactive = "inactive"
    """The consent is terminated or replaced. """
    
    enteredInError = "entered-in-error"
    """The consent was created wrongly (e.g. wrong patient) and should be ignored. """
    
class ConstraintSeverity(enum.Enum):
    
    error = "error"
    """If the constraint is violated, the resource is not conformant. """
    
    warning = "warning"
    """If the constraint is violated, the resource is conformant, but it is not necessarily following best practice. """
    
class ContactEntityType(enum.Enum):
    
    BILL = "BILL"
    """Contact details for information regarding to billing/general finance enquiries. """
    
    ADMIN = "ADMIN"
    """Contact details for administrative enquiries. """
    
    HR = "HR"
    """Contact details for issues related to Human Resources, such as staff matters, OH&S etc. """
    
    PAYOR = "PAYOR"
    """Contact details for dealing with issues related to insurance claims/adjudication/payment. """
    
    PATINF = "PATINF"
    """Generic information contact for patients. """
    
    PRESS = "PRESS"
    """Dedicated contact point for matters relating to press enquiries. """
    
class ContactPointSystem(enum.Enum):
    
    phone = "phone"
    """The value is a telephone number used for voice calls. Use of full international numbers starting with + is recommended to enable automatic dialing support but not required. """
    
    fax = "fax"
    """The value is a fax machine. Use of full international numbers starting with + is recommended to enable automatic dialing support but not required. """
    
    email = "email"
    """The value is an email address. """
    
    pager = "pager"
    """The value is a pager number. These may be local pager numbers that are only usable on a particular pager system. """
    
    url = "url"
    """A contact that is not a phone, fax, pager or email address and is expressed as a URL.  This is intended for various institutional or personal contacts including web sites, blogs, Skype, Twitter, Facebook, etc. Do not use for email addresses. """
    
    sms = "sms"
    """A contact that can be used for sending an sms message (e.g. mobile phones, some landlines). """
    
    other = "other"
    """A contact that is not a phone, fax, page or email address and is not expressible as a URL.  E.g. Internal mail address.  This SHOULD NOT be used for contacts that are expressible as a URL (e.g. Skype, Twitter, Facebook, etc.)  Extensions may be used to distinguish "other" contact types. """
    
class ContactPointUse(enum.Enum):
    
    home = "home"
    """A communication contact point at a home; attempted contacts for business purposes might intrude privacy and chances are one will contact family or other household members instead of the person one wishes to call. Typically used with urgent cases, or if no other contacts are available. """
    
    work = "work"
    """An office contact point. First choice for business related contacts during business hours. """
    
    temp = "temp"
    """A temporary contact point. The period can provide more detailed information. """
    
    old = "old"
    """This contact point is no longer in use (or was never correct, but retained for records). """
    
    mobile = "mobile"
    """A telecommunication device that moves and stays with its owner. May have characteristics of all other use codes, suitable for urgent matters, not the first choice for routine business. """
    
class ContainerCap(enum.Enum):
    
    red = "red"
    """red cap. """
    
    yellow = "yellow"
    """yellow cap. """
    
    darkYellow = "dark-yellow"
    """dark yellow cap. """
    
    grey = "grey"
    """grey cap. """
    
    lightBlue = "light-blue"
    """light blue cap. """
    
    black = "black"
    """black cap. """
    
    green = "green"
    """green cap. """
    
    lightGreen = "light-green"
    """light green cap. """
    
    lavender = "lavender"
    """lavender cap. """
    
    brown = "brown"
    """brown cap. """
    
    white = "white"
    """white cap. """
    
    pink = "pink"
    """pink cap. """
    
class ContractActionCodes(enum.Enum):
    
    actionA = "action-a"
    """Definition for Action A """
    
    actionB = "action-b"
    """Definition for Action B """
    
class ContractActorRoleCodes(enum.Enum):
    
    practitioner = "practitioner"
    """Someone who provides health care related services to people or animals including both clinical and support services. """
    
    patient = "patient"
    """A receiver, human or animal, of health care related goods and services. """
    
class ContractContentDerivationCodes(enum.Enum):
    
    registration = "registration"
    """Content derivative that conveys sufficient information needed to register the source basal content from which it is derived.  This derivative content may be used to register the basal content as it changes status in its lifecycle.  For example, content registration may occur when the basal content is created, updated, inactive, or deleted. """
    
    retrieval = "retrieval"
    """A content derivative that conveys sufficient information to locate and retrieve the content. """
    
    statement = "statement"
    """Content derivative that has less than full fidelity to the basal information source from which it was 'transcribed'. It provides recipients with the full content representation they may require for compliance purposes, and typically include a reference to or an attached unstructured representation for recipients needing an exact copy of the legal agreement. """
    
    shareable = "shareable"
    """A Content Derivative that conveys sufficient information to determine the authorized entities with which the content may be shared. """
    
class ContractDataMeaning(enum.Enum):
    
    instance = "instance"
    """The consent applies directly to the instance of the resource. """
    
    related = "related"
    """The consent applies directly to the instance of the resource and instances it refers to. """
    
    dependents = "dependents"
    """The consent applies directly to the instance of the resource and instances that refer to it. """
    
    authoredby = "authoredby"
    """The consent applies to instances of resources that are authored by. """
    
class ContractResourceActionStatusCodes(enum.Enum):
    
    complete = "complete"
    """To be completed """
    
class ContractResourceAssetAvailiabilityCodes(enum.Enum):
    
    lease = "lease"
    """To be completed """
    
class ContractResourceAssetContextCodes(enum.Enum):
    
    custodian = "custodian"
    """To be completed """
    
class ContractResourceAssetScopeCodes(enum.Enum):
    
    thing = "thing"
    """To be completed """
    
class ContractResourceAssetSubTypeCodes(enum.Enum):
    
    participation = "participation"
    """To be completed """
    
class ContractResourceAssetTypeCodes(enum.Enum):
    
    participation = "participation"
    """To be completed """
    
class ContractResourceDecisionModeCodes(enum.Enum):
    
    policy = "policy"
    """To be completed """
    
class ContractResourceDefinitionSubtypeCodes(enum.Enum):
    
    temp = "temp"
    """To be completed """
    
class ContractResourceDefinitionTypeCodes(enum.Enum):
    
    temp = "temp"
    """To be completed """
    
class ContractResourceExpirationTypeCodes(enum.Enum):
    
    breach = "breach"
    """To be completed """
    
class ContractResourceLegalStateCodes(enum.Enum):
    
    amended = "amended"
    """Contract is augmented with additional information to correct errors in a predecessor or to updated values in a predecessor. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: revised; replaced. """
    
    appended = "appended"
    """Contract is augmented with additional information that was missing from a predecessor Contract. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: updated, replaced. """
    
    cancelled = "cancelled"
    """Contract is terminated due to failure of the Grantor and/or the Grantee to fulfil one or more contract provisions. Usage: Abnormal contract termination. Precedence Order = 10. Comparable FHIR and v.3 status codes: stopped; failed; aborted. """
    
    disputed = "disputed"
    """Contract is pended to rectify failure of the Grantor or the Grantee to fulfil contract provision(s). E.g., Grantee complaint about Grantor's failure to comply with contract provisions. Usage: Contract pended. Precedence Order = 7. Comparable FHIR and v.3 status codes: on hold; pended; suspended. """
    
    enteredInError = "entered-in-error"
    """Contract was created in error. No Precedence Order.  Status may be applied to a Contract with any status. """
    
    executable = "executable"
    """Contract execution pending; may be executed when either the Grantor or the Grantee accepts the contract provisions by signing. I.e., where either the Grantor or the Grantee has signed, but not both. E.g., when an insurance applicant signs the insurers application, which references the policy. Usage: Optional first step of contract execution activity.  May be skipped and contracting activity moves directly to executed state. Precedence Order = 3. Comparable FHIR and v.3 status codes: draft; preliminary; planned; intended; active. """
    
    executed = "executed"
    """Contract is activated for period stipulated when both the Grantor and Grantee have signed it. Usage: Required state for normal completion of contracting activity.  Precedence Order = 6. Comparable FHIR and v.3 status codes: accepted; completed. """
    
    negotiable = "negotiable"
    """Contract execution is suspended while either or both the Grantor and Grantee propose and consider new or revised contract provisions. I.e., where the party which has not signed proposes changes to the terms.  E .g., a life insurer declines to agree to the signed application because the life insurer has evidence that the applicant, who asserted to being younger or a non-smoker to get a lower premium rate - but offers instead to agree to a higher premium based on the applicants actual age or smoking status. Usage: Optional contract activity between executable and executed state. Precedence Order = 4. Comparable FHIR and v.3 status codes: in progress; review; held. """
    
    offered = "offered"
    """Contract is a proposal by either the Grantor or the Grantee. Aka - A Contract hard copy or electronic 'template', 'form' or 'application'. E.g., health insurance application; consent directive form. Usage: Beginning of contract negotiation, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 2. Comparable FHIR and v.3 status codes: requested; new. """
    
    policy = "policy"
    """Contract template is available as the basis for an application or offer by the Grantor or Grantee. E.g., health insurance policy; consent directive policy.  Usage: Required initial contract activity, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 1. Comparable FHIR and v.3 status codes: proposed; intended. """
    
    rejected = "rejected"
    """ Execution of the Contract is not completed because either or both the Grantor and Grantee decline to accept some or all of the contract provisions. Usage: Optional contract activity between executable and abnormal termination. Precedence Order = 5. Comparable FHIR and v.3 status codes:  stopped; cancelled. """
    
    renewed = "renewed"
    """Beginning of a successor Contract at the termination of predecessor Contract lifecycle. Usage: Follows termination of a preceding Contract that has reached its expiry date. Precedence Order = 13. Comparable FHIR and v.3 status codes: superseded. """
    
    revoked = "revoked"
    """A Contract that is rescinded.  May be required prior to replacing with an updated Contract. Comparable FHIR and v.3 status codes: nullified. """
    
    resolved = "resolved"
    """Contract is reactivated after being pended because of faulty execution. *E.g., competency of the signer(s), or where the policy is substantially different from and did not accompany the application/form so that the applicant could not compare them. Aka - ''reactivated''. Usage: Optional stage where a pended contract is reactivated. Precedence Order = 8. Comparable FHIR and v.3 status codes: reactivated. """
    
    terminated = "terminated"
    """Contract reaches its expiry date. It might or might not be renewed or renegotiated. Usage: Normal end of contract period. Precedence Order = 12. Comparable FHIR and v.3 status codes: Obsoleted. """
    
class ContractResourcePartyRoleCodes(enum.Enum):
    
    flunky = "flunky"
    """To be completed """
    
class ContractResourcePublicationStatusCodes(enum.Enum):
    
    amended = "amended"
    """Contract is augmented with additional information to correct errors in a predecessor or to updated values in a predecessor. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: revised; replaced. """
    
    appended = "appended"
    """Contract is augmented with additional information that was missing from a predecessor Contract. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: updated, replaced. """
    
    cancelled = "cancelled"
    """Contract is terminated due to failure of the Grantor and/or the Grantee to fulfil one or more contract provisions. Usage: Abnormal contract termination. Precedence Order = 10. Comparable FHIR and v.3 status codes: stopped; failed; aborted. """
    
    disputed = "disputed"
    """Contract is pended to rectify failure of the Grantor or the Grantee to fulfil contract provision(s). E.g., Grantee complaint about Grantor's failure to comply with contract provisions. Usage: Contract pended. Precedence Order = 7. Comparable FHIR and v.3 status codes: on hold; pended; suspended. """
    
    enteredInError = "entered-in-error"
    """Contract was created in error. No Precedence Order.  Status may be applied to a Contract with any status. """
    
    executable = "executable"
    """Contract execution pending; may be executed when either the Grantor or the Grantee accepts the contract provisions by signing. I.e., where either the Grantor or the Grantee has signed, but not both. E.g., when an insurance applicant signs the insurers application, which references the policy. Usage: Optional first step of contract execution activity.  May be skipped and contracting activity moves directly to executed state. Precedence Order = 3. Comparable FHIR and v.3 status codes: draft; preliminary; planned; intended; active. """
    
    executed = "executed"
    """Contract is activated for period stipulated when both the Grantor and Grantee have signed it. Usage: Required state for normal completion of contracting activity.  Precedence Order = 6. Comparable FHIR and v.3 status codes: accepted; completed. """
    
    negotiable = "negotiable"
    """Contract execution is suspended while either or both the Grantor and Grantee propose and consider new or revised contract provisions. I.e., where the party which has not signed proposes changes to the terms.  E .g., a life insurer declines to agree to the signed application because the life insurer has evidence that the applicant, who asserted to being younger or a non-smoker to get a lower premium rate - but offers instead to agree to a higher premium based on the applicants actual age or smoking status. Usage: Optional contract activity between executable and executed state. Precedence Order = 4. Comparable FHIR and v.3 status codes: in progress; review; held. """
    
    offered = "offered"
    """Contract is a proposal by either the Grantor or the Grantee. Aka - A Contract hard copy or electronic 'template', 'form' or 'application'. E.g., health insurance application; consent directive form. Usage: Beginning of contract negotiation, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 2. Comparable FHIR and v.3 status codes: requested; new. """
    
    policy = "policy"
    """Contract template is available as the basis for an application or offer by the Grantor or Grantee. E.g., health insurance policy; consent directive policy.  Usage: Required initial contract activity, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 1. Comparable FHIR and v.3 status codes: proposed; intended. """
    
    rejected = "rejected"
    """ Execution of the Contract is not completed because either or both the Grantor and Grantee decline to accept some or all of the contract provisions. Usage: Optional contract activity between executable and abnormal termination. Precedence Order = 5. Comparable FHIR and v.3 status codes:  stopped; cancelled. """
    
    renewed = "renewed"
    """Beginning of a successor Contract at the termination of predecessor Contract lifecycle. Usage: Follows termination of a preceding Contract that has reached its expiry date. Precedence Order = 13. Comparable FHIR and v.3 status codes: superseded. """
    
    revoked = "revoked"
    """A Contract that is rescinded.  May be required prior to replacing with an updated Contract. Comparable FHIR and v.3 status codes: nullified. """
    
    resolved = "resolved"
    """Contract is reactivated after being pended because of faulty execution. *E.g., competency of the signer(s), or where the policy is substantially different from and did not accompany the application/form so that the applicant could not compare them. Aka - ''reactivated''. Usage: Optional stage where a pended contract is reactivated. Precedence Order = 8. Comparable FHIR and v.3 status codes: reactivated. """
    
    terminated = "terminated"
    """Contract reaches its expiry date. It might or might not be renewed or renegotiated. Usage: Normal end of contract period. Precedence Order = 12. Comparable FHIR and v.3 status codes: Obsoleted. """
    
class ContractResourceScopeCodes(enum.Enum):
    
    policy = "policy"
    """To be completed """
    
class ContractResourceScopeCodes(enum.Enum):
    
    policy = "policy"
    """To be completed """
    
class ContractResourceScopeCodes(enum.Enum):
    
    policy = "policy"
    """To be completed """
    
class ContractResourceSecurityControlCodes(enum.Enum):
    
    policy = "policy"
    """To be completed """
    
class ContractResourceStatusCodes(enum.Enum):
    
    amended = "amended"
    """Contract is augmented with additional information to correct errors in a predecessor or to updated values in a predecessor. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: revised; replaced. """
    
    appended = "appended"
    """Contract is augmented with additional information that was missing from a predecessor Contract. Usage: Contract altered within effective time. Precedence Order = 9. Comparable FHIR and v.3 status codes: updated, replaced. """
    
    cancelled = "cancelled"
    """Contract is terminated due to failure of the Grantor and/or the Grantee to fulfil one or more contract provisions. Usage: Abnormal contract termination. Precedence Order = 10. Comparable FHIR and v.3 status codes: stopped; failed; aborted. """
    
    disputed = "disputed"
    """Contract is pended to rectify failure of the Grantor or the Grantee to fulfil contract provision(s). E.g., Grantee complaint about Grantor's failure to comply with contract provisions. Usage: Contract pended. Precedence Order = 7. Comparable FHIR and v.3 status codes: on hold; pended; suspended. """
    
    enteredInError = "entered-in-error"
    """Contract was created in error. No Precedence Order.  Status may be applied to a Contract with any status. """
    
    executable = "executable"
    """Contract execution pending; may be executed when either the Grantor or the Grantee accepts the contract provisions by signing. I.e., where either the Grantor or the Grantee has signed, but not both. E.g., when an insurance applicant signs the insurers application, which references the policy. Usage: Optional first step of contract execution activity.  May be skipped and contracting activity moves directly to executed state. Precedence Order = 3. Comparable FHIR and v.3 status codes: draft; preliminary; planned; intended; active. """
    
    executed = "executed"
    """Contract is activated for period stipulated when both the Grantor and Grantee have signed it. Usage: Required state for normal completion of contracting activity.  Precedence Order = 6. Comparable FHIR and v.3 status codes: accepted; completed. """
    
    negotiable = "negotiable"
    """Contract execution is suspended while either or both the Grantor and Grantee propose and consider new or revised contract provisions. I.e., where the party which has not signed proposes changes to the terms.  E .g., a life insurer declines to agree to the signed application because the life insurer has evidence that the applicant, who asserted to being younger or a non-smoker to get a lower premium rate - but offers instead to agree to a higher premium based on the applicants actual age or smoking status. Usage: Optional contract activity between executable and executed state. Precedence Order = 4. Comparable FHIR and v.3 status codes: in progress; review; held. """
    
    offered = "offered"
    """Contract is a proposal by either the Grantor or the Grantee. Aka - A Contract hard copy or electronic 'template', 'form' or 'application'. E.g., health insurance application; consent directive form. Usage: Beginning of contract negotiation, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 2. Comparable FHIR and v.3 status codes: requested; new. """
    
    policy = "policy"
    """Contract template is available as the basis for an application or offer by the Grantor or Grantee. E.g., health insurance policy; consent directive policy.  Usage: Required initial contract activity, which may have been completed as a precondition because used for 0..* contracts. Precedence Order = 1. Comparable FHIR and v.3 status codes: proposed; intended. """
    
    rejected = "rejected"
    """ Execution of the Contract is not completed because either or both the Grantor and Grantee decline to accept some or all of the contract provisions. Usage: Optional contract activity between executable and abnormal termination. Precedence Order = 5. Comparable FHIR and v.3 status codes:  stopped; cancelled. """
    
    renewed = "renewed"
    """Beginning of a successor Contract at the termination of predecessor Contract lifecycle. Usage: Follows termination of a preceding Contract that has reached its expiry date. Precedence Order = 13. Comparable FHIR and v.3 status codes: superseded. """
    
    revoked = "revoked"
    """A Contract that is rescinded.  May be required prior to replacing with an updated Contract. Comparable FHIR and v.3 status codes: nullified. """
    
    resolved = "resolved"
    """Contract is reactivated after being pended because of faulty execution. *E.g., competency of the signer(s), or where the policy is substantially different from and did not accompany the application/form so that the applicant could not compare them. Aka - ''reactivated''. Usage: Optional stage where a pended contract is reactivated. Precedence Order = 8. Comparable FHIR and v.3 status codes: reactivated. """
    
    terminated = "terminated"
    """Contract reaches its expiry date. It might or might not be renewed or renegotiated. Usage: Normal end of contract period. Precedence Order = 12. Comparable FHIR and v.3 status codes: Obsoleted. """
    
class ContractSignerTypeCodes(enum.Enum):
    
    AMENDER = "AMENDER"
    """A person who has corrected, edited, or amended pre-existing information. """
    
    AUTHN = "AUTHN"
    """A person in the role of verifier who attests to the accuracy of an act, but who does not have privileges to legally authenticate information content. An example would be a resident physician who sees a patient and dictates a note, then later signs it. The resident's signature constitutes an authentication. """
    
    AUT = "AUT"
    """An entity that authored specific content. There can be multiple authors of content, which may take such forms as a contract, a healthcare record entry or document, a policy, or a consent directive. """
    
    AFFL = "AFFL"
    """An entity that has a business or professional relationship with another entity in accordance with an agreement. """
    
    AGNT = "AGNT"
    """An entity that acts or is authorized to act on behalf of another entity in accordance with an agreement. """
    
    ASSIGNED = "ASSIGNED"
    """An agent role in which the agent is an Entity acting in the employ of an organization. The focus is on functional role on behalf of the organization, unlike the Employee role where the focus is on the 'Human Resources' relationship between the employee and the organization. """
    
    CIT = "CIT"
    """The member of a jurisdiction afforded certain rights and encumbered with certain obligation in accordance with jurisdictional policy. """
    
    CLAIMANT = "CLAIMANT"
    """A party that makes a claim for coverage under a policy. """
    
    COAUTH = "COAUTH"
    """The entity that co-authored content. There can be multiple co-authors of content, which may take such forms as a contract, a healthcare record entry or document, a policy, or a consent directive. """
    
    CONSENTER = "CONSENTER"
    """A patient or patient representative who is the grantee in a healthcare related agreement such as a consent for healthcare services, advanced directive, or a privacy consent directive in accordance with jurisdictional, organizational, or patient policy. """
    
    CONSWIT = "CONSWIT"
    """A person who has witnessed and attests to observing a patient being counseled about a healthcare related agreement such as a consent for healthcare services, advanced directive, or a privacy consent directive. """
    
    CONT = "CONT"
    """A person or an organization that provides or receives information regarding another entity. Examples; patient NOK and emergency contacts; guarantor contact; employer contact. """
    
    COPART = "COPART"
    """A person who participates in the generation of and attest to veracity of content but is not an author or co-author. For example, a surgeon who is required by institutional, regulatory, or legal rules to sign an operative report, but who was not involved in the authorship of that report. """
    
    COVPTY = "COVPTY"
    """An entity, which is the insured, that receives benefits such as healthcare services, reimbursement for out-of-pocket expenses, or compensation for losses through coverage under the terms of an insurance policy. The underwriter of that policy is the scoping entity. The covered party receives coverage because of some contractual or other relationship with the holder of that policy. Note that a particular policy may cover several individuals one of whom may be, but need not be, the policy holder. Thus the notion of covered party is a role that is distinct from that of the policy holder. """
    
    DELEGATEE = "DELEGATEE"
    """A party to whom some right or authority is delegated by a delegator. """
    
    delegator = "delegator"
    """A party that delegates a right or authority to another party. """
    
    DEPEND = "DEPEND"
    """A person covered under an insurance policy or program based on an association with a subscriber, which is recognized by the policy holder. The dependent has an association with the subscriber such as a financial dependency or personal relationship such as that of a spouse, or a natural or adopted child. The policy holder may be required by law to recognize certain associations or may have discretion about the associations. For example, a policy holder may dictate the criteria for the dependent status of adult children who are students, such as requiring full time enrollment, or may recognize domestic partners as dependents. Under certain circumstances, the dependent may be under the indirect authority of a responsible party acting as a surrogate for the subscriber, for example, if the subscriber is differently-abled or deceased, a guardian ad lidem or estate executor may be appointed to assume the subscriber's legal standing in the relationship with the dependent. """
    
    DPOWATT = "DPOWATT"
    """A person who has been granted the authority to represent or act on another's behalf generally in a manner which is a legally binding upon the person giving such authority as if he or she personally were to do the acts. Unlike ordinary powers of attorney, durable powers can survive for long periods of time, and again, unlike standard powers of attorney, durable powers can continue after incompetency. """
    
    EMGCON = "EMGCON"
    """An entity to be contacted in the event of an emergency """
    
    EVTWIT = "EVTWIT"
    """A person who attests to observing an occurrence.  For example, the witness has observed a procedure and is attesting to this fact. """
    
    EXCEST = "EXCEST"
    """A person who has been granted the authority to act as an estate executor for a deceased person who was the responsible party. """
    
    GRANTEE = "GRANTEE"
    """A person who grants to another person the authority to represent or act on that person's behalf.  Examples include (1) exercising specific rights belonging to the grantee; (2) performing specific duties on behalf of a grantee; and (3) making specific decisions concerning a grantee. """
    
    GRANTOR = "GRANTOR"
    """A person who has been granted the authority to represent or act on another's behalf. Examples include (1) exercising specific rights belonging to the grantee; (2) performing specific duties on behalf of a grantee; and (3) making specific decisions concerning a grantee. """
    
    GUAR = "GUAR"
    """A person or organization contractually recognized by the issuer as an entity that has assumed fiscal responsibility (e.g., by making or giving a promise, assurance, or pledge) for another entity's financial obligations by guaranteeing to pay for amounts owed to a particular account.  In a healthcare context, the account may be a patient's billing account for services rendered by a provider or a health plan premium account. """
    
    GUARD = "GUARD"
    """A person or organization legally empowered with responsibility for the care of a ward. """
    
    GUADLTM = "GUADLTM"
    """A person appointed by the court to look out for the best interests of a minor child during the course of legal proceedings. """
    
    INF = "INF"
    """An entity that is the source of reported information (e.g., a next of kin who answers questions about the patient's history). For history questions, the patient is logically an informant, yet the informant of history questions is implicitly the subject. """
    
    INTPRT = "INTPRT"
    """A person who converts spoken or written language into the language of key participants in an event such as when a provider is obtaining a patient's consent to treatment or permission to disclose information. """
    
    INSBJ = "INSBJ"
    """An entity that is the subject of an investigation. This role is scoped by the party responsible for the investigation. """
    
    HPOWATT = "HPOWATT"
    """A person who has been granted the authority to represent or act on another's behalf for healthcare related matters in a manner which is a legally binding upon the person giving such authority as if he or she personally were to do the acts. Examples include (1) exercising specific healthcare legal rights belonging to the grantee such as signing a consent directive; (2) performing specific healthcare related legal duties on behalf of a grantee such as claims payment; and (3) making specific healthcare legal decisions concerning a grantee such as consenting to healthcare services. """
    
    HPROV = "HPROV"
    """An entity that is authorized to provide health care services by an authorizing organization or jurisdiction. """
    
    LEGAUTHN = "LEGAUTHN"
    """A person in the role of verifier who attests to the accuracy of information content, and who has privileges to certify the legal authenticity of that content with a signature that constitutes a legal authentication.  For example, a licensed physician who signs a consult authored by a resident physician who authenticated it. """
    
    NMDINS = "NMDINS"
    """A party to an insurance policy under which the insurer agrees to indemnify for losses, provides benefits for, or renders services. A named insured may be either a person, non-person living subject, or an organization, or a group of persons, non-person living subject that is the named insured under a comprehensive automobile, disability, or property and casualty policy.  The named insured and might or might not be the policy holder. """
    
    NOK = "NOK"
    """A person, who is a type of contact, designated to receive notifications on behalf of another person who is a relative. """
    
    NOTARY = "NOTARY"
    """The party credentialed to legally attest to the contract binding by verifying the identity and capacity of the grantor and grantee, and witnessing their signing of the contract or agreement such as a real estate transaction, pre-nuptial agreement, or a will. """
    
    PAT = "PAT"
    """A person, animal, or other living subject that is the actual or potential recipient of health care services. """
    
    POWATT = "POWATT"
    """A person who has been granted the authority to represent or act on another's behalf generally in a manner which is a legally binding upon the person giving such authority as if he or she personally were to do the acts. Examples include (1) exercising specific legal rights belonging to the grantee such as signing a contract; (2) performing specific legal duties on behalf of a grantee such as making loan payments; and (3) making specific legal decisions concerning a grantee such as financial investment decisions. """
    
    PRIMAUTH = "PRIMAUTH"
    """An entity that is the primary or sole author of information content.  In the healthcare context, there can be only one primary author of health information content in a record entry or document. """
    
    PRIRECIP = "PRIRECIP"
    """An entity that may, should receive, or has received information or an object to which it was primarily addressed. """
    
    RECIP = "RECIP"
    """An entity that may, should receive, or has received information or an object, which might not have been primarily addressed to it. For example, the staff of a provider, a clearinghouse, or other intermediary. """
    
    RESPRSN = "RESPRSN"
    """An entity that has legal responsibility for another party. """
    
    REVIEWER = "REVIEWER"
    """A person, device, or algorithm that has used approved criteria for filtered data for inclusion into the patient record.  Examples: (1) a medical records clerk who scans a document for inclusion in the medical record, enters header information, or catalogues and classifies the data, or a combination thereof; (2) a gateway that receives data from another computer system and interprets that data or changes its format, or both, before entering it into the patient record. """
    
    TRANS = "TRANS"
    """An entity entering the data into the originating system. This includes the transcriptionist for dictated text transcribed into electronic form. """
    
    SOURCE = "SOURCE"
    """An automated data source that generates a signature along with content. Examples: (1) the signature for an image that is generated by a device for inclusion in the patient record; (2) the signature for an ECG derived by an ECG system for inclusion in the patient record; (3) the data from a biomedical monitoring device or system that is for inclusion in the patient record. """
    
    SPOWATT = "SPOWATT"
    """A person who has been granted the authority to represent or act on another's behalf for a limited set of specific matters in a manner which is a legally binding upon the person giving such authority as if he or she personally were to do the acts. Examples include (1) exercising specific legal rights belonging to the grantee such as drafting a will; (2) performing specific legal duties on behalf of a grantee such as making a reversible mortgage to pay for end of life expenses; and (3) making specific legal decisions concerning a grantee such as managing a trust. """
    
    VALID = "VALID"
    """A person who validates a health information document for inclusion in the patient record. For example, a medical student or resident is credentialed to perform history or physical examinations and to write progress notes. The attending physician signs the history and physical examination to validate the entry for inclusion in the patient's medical record. """
    
    VERF = "VERF"
    """A person who asserts the correctness and appropriateness of an act or the recording of the act, and is accountable for the assertion that the act or the recording of the act complies with jurisdictional or organizational policy. For example, a physician is required to countersign a verbal order that has previously been recorded in the medical record by a registered nurse who has carried out the verbal order. """
    
    WIT = "WIT"
    """A person witnessing the signature of another party. A witness is not knowledgeable about the content being signed, much less approves of anything stated in the content. For example, an advanced directive witness or a witness that a party to a contract signed that certain demographic or financial information is truthful. """
    
class ContractSubtypeCodes(enum.Enum):
    
    disclosureCa = "disclosure-ca"
    """Canadian health information disclosure policy. """
    
    disclosureUs = "disclosure-us"
    """United States health information disclosure policy. """
    
class ContractTermSubtypeCodes(enum.Enum):
    
    condition = "condition"
    """Terms that go to the very root of a contract. """
    
    warranty = "warranty"
    """Less imperative than a condition, so the contract will survive a breach """
    
    innominate = "innominate"
    """Breach of which might or might not go to the root of the contract depending upon the nature of the breach """
    
class ContractTermTypeCodes(enum.Enum):
    
    statutory = "statutory"
    """Based on specialized statutes that deal with particular subjects. """
    
    subjectTo = "subject-to"
    """Execution of the term in the contract is conditional on the execution of other actions. """
    
class ContractTypeCodes(enum.Enum):
    
    privacy = "privacy"
    """Privacy policy. """
    
    disclosure = "disclosure"
    """Information disclosure policy. """
    
    healthinsurance = "healthinsurance"
    """Health Insurance policy. """
    
    supply = "supply"
    """Contract to supply goods or services. """
    
    consent = "consent"
    """Consent Directive. """
    
class ContributorType(enum.Enum):
    
    author = "author"
    """An author of the content of the module. """
    
    editor = "editor"
    """An editor of the content of the module. """
    
    reviewer = "reviewer"
    """A reviewer of the content of the module. """
    
    endorser = "endorser"
    """An endorser of the content of the module. """
    
class CopyNumberEvent(enum.Enum):
    
    amp = "amp"
    """amplification. """
    
    del_ = "del"
    """deletion. """
    
    lof = "lof"
    """loss of function. """
    
class CoverageClassCodes(enum.Enum):
    
    group = "group"
    """An employee group """
    
    subgroup = "subgroup"
    """A sub-group of an employee group """
    
    plan = "plan"
    """A specific suite of benefits. """
    
    subplan = "subplan"
    """A subset of a specific suite of benefits. """
    
    class_ = "class"
    """A class of benefits. """
    
    subclass = "subclass"
    """A subset of a class of benefits. """
    
    sequence = "sequence"
    """A sequence number associated with a short-term continuance of the coverage. """
    
    rxbin = "rxbin"
    """Pharmacy benefit manager's Business Identification Number. """
    
    rxpcn = "rxpcn"
    """A Pharmacy Benefit Manager specified Processor Control Number. """
    
    rxid = "rxid"
    """A Pharmacy Benefit Manager specified Member ID. """
    
    rxgroup = "rxgroup"
    """A Pharmacy Benefit Manager specified Group number. """
    
class CoverageCopayTypeCodes(enum.Enum):
    
    gpvisit = "gpvisit"
    """An office visit for a general practitioner of a discipline. """
    
    spvisit = "spvisit"
    """An office visit for a specialist practitioner of a discipline """
    
    emergency = "emergency"
    """An episode in an emergency department. """
    
    inpthosp = "inpthosp"
    """An episode of an Inpatient hospital stay. """
    
    televisit = "televisit"
    """A visit held where the patient is remote relative to the practitioner, e.g. by phone, computer or video conference. """
    
    urgentcare = "urgentcare"
    """A visit to an urgent care facility - typically a community care clinic. """
    
    copaypct = "copaypct"
    """A standard percentage applied to all classes or service or product not otherwise specified. """
    
    copay = "copay"
    """A standard fixed currency amount applied to all classes or service or product not otherwise specified. """
    
    deductible = "deductible"
    """The accumulated amount of patient payment before the coverage begins to pay for services. """
    
    maxoutofpocket = "maxoutofpocket"
    """The maximum amout of payment for services which a patient, or family, is expected to incur - typically annually. """
    
class CoverageEligibilityResponseAuthSupportCodes(enum.Enum):
    
    laborder = "laborder"
    """A request or authorization for laboratory diagnostic tests. """
    
    labreport = "labreport"
    """A report on laboratory diagnostic test(s). """
    
    diagnosticimageorder = "diagnosticimageorder"
    """A request or authorization for diagnostic imaging. """
    
    diagnosticimagereport = "diagnosticimagereport"
    """A report on diagnostic image(s). """
    
    professionalreport = "professionalreport"
    """A report from a licensed professional regarding the siutation, condition or proposed treatment. """
    
    accidentreport = "accidentreport"
    """A formal accident report as would be filed with police or a simlar official body. """
    
    model = "model"
    """A physical model of the affected area. """
    
    picture = "picture"
    """A photograph of the affected area. """
    
class CoverageSelfPayCodes(enum.Enum):
    
    pay = "pay"
    """An individual or organization is paying directly for goods and services. """
    
class DataAbsentReason(enum.Enum):
    
    unknown = "unknown"
    """The value is expected to exist but is not known. """
    
    askedUnknown = "asked-unknown"
    """The source was asked but does not know the value. """
    
    tempUnknown = "temp-unknown"
    """There is reason to expect (from the workflow) that the value may become known. """
    
    notAsked = "not-asked"
    """The workflow didn't lead to this value being known. """
    
    askedDeclined = "asked-declined"
    """The source was asked but declined to answer. """
    
    masked = "masked"
    """The information is not available due to security, privacy or related reasons. """
    
    notApplicable = "not-applicable"
    """There is no proper value for this element (e.g. last menstrual period for a male). """
    
    unsupported = "unsupported"
    """The source system wasn't capable of supporting this element. """
    
    asText = "as-text"
    """The content of the data is represented in the resource narrative. """
    
    error = "error"
    """Some system or workflow process error means that the information is not available. """
    
    notANumber = "not-a-number"
    """The numeric value is undefined or unrepresentable due to a floating point processing error. """
    
    negativeInfinity = "negative-infinity"
    """The numeric value is excessively low and unrepresentable due to a floating point processing error. """
    
    positiveInfinity = "positive-infinity"
    """The numeric value is excessively high and unrepresentable due to a floating point processing error. """
    
    notPerformed = "not-performed"
    """The value is not available because the observation procedure (test, etc.) was not performed. """
    
    notPermitted = "not-permitted"
    """The value is not permitted in this context (e.g. due to profiles, or the base data types). """
    
class DataType(enum.Enum):
    
    address = "Address"
    """An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world. """
    
    age = "Age"
    """A duration of time during which an organism (or a process) has existed. """
    
    annotation = "Annotation"
    """A  text note which also  contains information about who made the statement and when. """
    
    attachment = "Attachment"
    """For referring to data content defined in other formats. """
    
    backboneElement = "BackboneElement"
    """Base definition for all elements that are defined inside a resource - but not those in a data type. """
    
    codeableConcept = "CodeableConcept"
    """A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text. """
    
    coding = "Coding"
    """A reference to a code defined by a terminology system. """
    
    contactDetail = "ContactDetail"
    """Specifies contact information for a person or organization. """
    
    contactPoint = "ContactPoint"
    """Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc. """
    
    contributor = "Contributor"
    """A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers. """
    
    count = "Count"
    """A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies. """
    
    dataRequirement = "DataRequirement"
    """Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data. """
    
    distance = "Distance"
    """A length - a value with a unit that is a physical distance. """
    
    dosage = "Dosage"
    """Indicates how the medication is/was taken or should be taken by the patient. """
    
    duration = "Duration"
    """A length of time. """
    
    element = "Element"
    """Base definition for all elements in a resource. """
    
    elementDefinition = "ElementDefinition"
    """Captures constraints on each element within the resource, profile, or extension. """
    
    expression = "Expression"
    """A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used. """
    
    extension = "Extension"
    """Optional Extension Element - found in all resources. """
    
    humanName = "HumanName"
    """A human's name with the ability to identify parts and usage. """
    
    identifier = "Identifier"
    """An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers. """
    
    marketingStatus = "MarketingStatus"
    """The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available. """
    
    meta = "Meta"
    """The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource. """
    
    money = "Money"
    """An amount of economic utility in some recognized currency. """
    
    moneyQuantity = "MoneyQuantity"
    """moneyQuantity """
    
    narrative = "Narrative"
    """A human-readable summary of the resource conveying the essential clinical and business information for the resource. """
    
    parameterDefinition = "ParameterDefinition"
    """The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse. """
    
    period = "Period"
    """A time period defined by a start and end date and optionally time. """
    
    population = "Population"
    """A populatioof people with some set of grouping criteria. """
    
    prodCharacteristic = "ProdCharacteristic"
    """The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available. """
    
    productShelfLife = "ProductShelfLife"
    """The shelf-life and storage information for a medicinal product item or container can be described using this class. """
    
    quantity = "Quantity"
    """A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies. """
    
    range = "Range"
    """A set of ordered Quantities defined by a low and high limit. """
    
    ratio = "Ratio"
    """A relationship of two Quantity values - expressed as a numerator and a denominator. """
    
    reference = "Reference"
    """A reference from one resource to another. """
    
    relatedArtifact = "RelatedArtifact"
    """Related artifacts such as additional documentation, justification, or bibliographic references. """
    
    sampledData = "SampledData"
    """A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data. """
    
    signature = "Signature"
    """A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities. """
    
    simpleQuantity = "SimpleQuantity"
    """simpleQuantity """
    
    substanceAmount = "SubstanceAmount"
    """Chemical substances are a single substance type whose primary defining element is the molecular structure. Chemical substances shall be defined on the basis of their complete covalent molecular structure; the presence of a salt (counter-ion) and/or solvates (water, alcohols) is also captured. Purity, grade, physical form or particle size are not taken into account in the definition of a chemical substance or in the assignment of a Substance ID. """
    
    timing = "Timing"
    """Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out. """
    
    triggerDefinition = "TriggerDefinition"
    """A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element. """
    
    usageContext = "UsageContext"
    """Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care). """
    
    base64Binary = "base64Binary"
    """A stream of bytes """
    
    boolean = "boolean"
    """Value of "true" or "false" """
    
    canonical = "canonical"
    """A URI that is a reference to a canonical URL on a FHIR resource """
    
    code = "code"
    """A string which has at least one character and no leading or trailing whitespace and where there is no whitespace other than single spaces in the contents """
    
    date = "date"
    """A date or partial date (e.g. just year or year + month). There is no time zone. The format is a union of the schema types gYear, gYearMonth and date.  Dates SHALL be valid dates. """
    
    dateTime = "dateTime"
    """A date, date-time or partial date (e.g. just year or year + month).  If hours and minutes are specified, a time zone SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored.                 Dates SHALL be valid dates. """
    
    decimal = "decimal"
    """A rational number with implicit precision """
    
    id = "id"
    """Any combination of letters, numerals, "-" and ".", with a length limit of 64 characters.  (This might be an integer, an unprefixed OID, UUID or any other identifier pattern that meets these constraints.)  Ids are case-insensitive. """
    
    instant = "instant"
    """An instant in time - known at least to the second """
    
    integer = "integer"
    """A whole number """
    
    markdown = "markdown"
    """A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine """
    
    oid = "oid"
    """An OID represented as a URI """
    
    positiveInt = "positiveInt"
    """An integer with a value that is positive (e.g. >0) """
    
    string = "string"
    """A sequence of Unicode characters """
    
    time = "time"
    """A time during the day, with no date specified """
    
    unsignedInt = "unsignedInt"
    """An integer with a value that is not negative (e.g. >= 0) """
    
    uri = "uri"
    """String of characters used to identify a name or a resource """
    
    url = "url"
    """A URI that is a literal reference """
    
    uuid = "uuid"
    """A UUID, represented as a URI """
    
    xhtml = "xhtml"
    """XHTML format, as defined by W3C, but restricted usage (mainly, no active content) """
    
class DaysOfWeek(enum.Enum):
    
    mon = "mon"
    """Monday. """
    
    tue = "tue"
    """Tuesday. """
    
    wed = "wed"
    """Wednesday. """
    
    thu = "thu"
    """Thursday. """
    
    fri = "fri"
    """Friday. """
    
    sat = "sat"
    """Saturday. """
    
    sun = "sun"
    """Sunday. """
    
class DefinitionResourceType(enum.Enum):
    
    activityDefinition = "ActivityDefinition"
    """This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context. """
    
    eventDefinition = "EventDefinition"
    """The EventDefinition resource provides a reusable description of when a particular event can occur. """
    
    measure = "Measure"
    """The Measure resource provides the definition of a quality measure. """
    
    operationDefinition = "OperationDefinition"
    """A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction). """
    
    planDefinition = "PlanDefinition"
    """This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical artifacts such as clinical decision support rules, order sets and protocols. """
    
    questionnaire = "Questionnaire"
    """A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection. """
    
class DefinitionStatus(enum.Enum):
    
    draft = "draft"
    """The definition is in the design stage and is not yet considered to be "ready for use". """
    
    active = "active"
    """The definition is considered ready for use. """
    
    withdrawn = "withdrawn"
    """The definition should no longer be used. """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this resource.  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply,  but the authoring/source system does not know which. """
    
class DefinitionTopic(enum.Enum):
    
    treatment = "treatment"
    """The definition is related to treatment of the patient. """
    
    education = "education"
    """The definition is related to education of the patient. """
    
    assessment = "assessment"
    """The definition is related to assessment of the patient. """
    
class DefinitionUseCodes(enum.Enum):
    
    fhirStructure = "fhir-structure"
    """This structure is defined as part of the base FHIR Specification """
    
    customResource = "custom-resource"
    """This structure is intended to be treated like a FHIR resource (e.g. on the FHIR API) """
    
    dam = "dam"
    """This structure captures an analysis of a domain """
    
    wireFormat = "wire-format"
    """This structure represents and existing structure (e.g. CDA, HL7 v2) """
    
    archetype = "archetype"
    """This structure captures an analysis of a domain """
    
    template = "template"
    """This structure is a template (n.b: 'template' has many meanings) """
    
class DetectedIssueSeverity(enum.Enum):
    
    high = "high"
    """Indicates the issue may be life-threatening or has the potential to cause permanent injury. """
    
    moderate = "moderate"
    """Indicates the issue may result in noticeable adverse consequences but is unlikely to be life-threatening or cause permanent injury. """
    
    low = "low"
    """Indicates the issue may result in some adverse consequences but is unlikely to substantially affect the situation of the subject. """
    
class DeviceDefinitionParameterGroup(enum.Enum):
    
    haemodynamic = "haemodynamic"
    """Haemodynamic Parameter Group - MDC_PGRP_HEMO. """
    
    ecg = "ecg"
    """ECG Parameter Group - MDC_PGRP_ECG. """
    
    respiratory = "respiratory"
    """Respiratory Parameter Group - MDC_PGRP_RESP. """
    
    ventilation = "ventilation"
    """Ventilation Parameter Group - MDC_PGRP_VENT. """
    
    neurological = "neurological"
    """Neurological Parameter Group - MDC_PGRP_NEURO. """
    
    drugDelivery = "drug-delivery"
    """Drug Delivery Parameter Group - MDC_PGRP_DRUG. """
    
    fluidChemistry = "fluid-chemistry"
    """Fluid Chemistry Parameter Group - MDC_PGRP_FLUID. """
    
    bloodChemistry = "blood-chemistry"
    """Blood Chemistry Parameter Group - MDC_PGRP_BLOOD_CHEM. """
    
    miscellaneous = "miscellaneous"
    """Miscellaneous Parameter Group - MDC_PGRP_MISC. """
    
class DeviceMetricCalibrationState(enum.Enum):
    
    notCalibrated = "not-calibrated"
    """The metric has not been calibrated. """
    
    calibrationRequired = "calibration-required"
    """The metric needs to be calibrated. """
    
    calibrated = "calibrated"
    """The metric has been calibrated. """
    
    unspecified = "unspecified"
    """The state of calibration of this metric is unspecified. """
    
class DeviceMetricCalibrationType(enum.Enum):
    
    unspecified = "unspecified"
    """Metric calibration method has not been identified. """
    
    offset = "offset"
    """Offset metric calibration method. """
    
    gain = "gain"
    """Gain metric calibration method. """
    
    twoPoint = "two-point"
    """Two-point metric calibration method. """
    
class DeviceMetricCategory(enum.Enum):
    
    measurement = "measurement"
    """DeviceObservations generated for this DeviceMetric are measured. """
    
    setting = "setting"
    """DeviceObservations generated for this DeviceMetric is a setting that will influence the behavior of the Device. """
    
    calculation = "calculation"
    """DeviceObservations generated for this DeviceMetric are calculated. """
    
    unspecified = "unspecified"
    """The category of this DeviceMetric is unspecified. """
    
class DeviceMetricColor(enum.Enum):
    
    black = "black"
    """Color for representation - black. """
    
    red = "red"
    """Color for representation - red. """
    
    green = "green"
    """Color for representation - green. """
    
    yellow = "yellow"
    """Color for representation - yellow. """
    
    blue = "blue"
    """Color for representation - blue. """
    
    magenta = "magenta"
    """Color for representation - magenta. """
    
    cyan = "cyan"
    """Color for representation - cyan. """
    
    white = "white"
    """Color for representation - white. """
    
class DeviceMetricOperationalStatus(enum.Enum):
    
    on = "on"
    """The DeviceMetric is operating and will generate DeviceObservations. """
    
    off = "off"
    """The DeviceMetric is not operating. """
    
    standby = "standby"
    """The DeviceMetric is operating, but will not generate any DeviceObservations. """
    
    enteredInError = "entered-in-error"
    """The DeviceMetric was entered in error. """
    
class DeviceNameType(enum.Enum):
    
    udiLabelName = "udi-label-name"
    """UDI Label name. """
    
    userFriendlyName = "user-friendly-name"
    """User Friendly name. """
    
    patientReportedName = "patient-reported-name"
    """Patient Reported name. """
    
    manufacturerName = "manufacturer-name"
    """Manufacturer name. """
    
    modelName = "model-name"
    """Model name. """
    
    other = "other"
    """other. """
    
class DeviceUseStatementStatus(enum.Enum):
    
    active = "active"
    """The device is still being used. """
    
    completed = "completed"
    """The device is no longer being used. """
    
    enteredInError = "entered-in-error"
    """The statement was recorded incorrectly. """
    
    intended = "intended"
    """The device may be used at some time in the future. """
    
    stopped = "stopped"
    """Actions implied by the statement have been permanently halted, before all of them occurred. """
    
    onHold = "on-hold"
    """Actions implied by the statement have been temporarily halted, but are expected to continue later. May also be called "suspended". """
    
class DiagnosisRole(enum.Enum):
    
    AD = "AD"
    """AD """
    
    DD = "DD"
    """DD """
    
    CC = "CC"
    """CC """
    
    CM = "CM"
    """CM """
    
    preOp = "pre-op"
    """preOp """
    
    postOp = "post-op"
    """postOp """
    
    billing = "billing"
    """billing """
    
class DiagnosticReportStatus(enum.Enum):
    
    registered = "registered"
    """The existence of the report is registered, but there is nothing yet available. """
    
    partial = "partial"
    """This is a partial (e.g. initial, interim or preliminary) report: data in the report may be incomplete or unverified. """
    
    preliminary = "preliminary"
    """Verified early results are available, but not all  results are final. """
    
    final = "final"
    """The report is complete and verified by an authorized person. """
    
    amended = "amended"
    """Subsequent to being final, the report has been modified.  This includes any change in the results, diagnosis, narrative text, or other content of a report that has been issued. """
    
    corrected = "corrected"
    """Subsequent to being final, the report has been modified  to correct an error in the report or referenced results. """
    
    appended = "appended"
    """Subsequent to being final, the report has been modified by adding new content. The existing content is unchanged. """
    
    cancelled = "cancelled"
    """The report is unavailable because the measurement was not started or not completed (also sometimes called "aborted"). """
    
    enteredInError = "entered-in-error"
    """The report has been withdrawn following a previous final release.  This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be "cancelled" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this observation. Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, but the authoring/source system does not know which. """
    
class Diet(enum.Enum):
    
    vegetarian = "vegetarian"
    """Food without meat, poultry or seafood. """
    
    dairyFree = "dairy-free"
    """Excludes dairy products. """
    
    nutFree = "nut-free"
    """Excludes ingredients containing nuts. """
    
    glutenFree = "gluten-free"
    """Excludes ingredients containing gluten. """
    
    vegan = "vegan"
    """Food without meat, poultry, seafood, eggs, dairy products and other animal-derived substances. """
    
    halal = "halal"
    """Foods that conform to Islamic law. """
    
    kosher = "kosher"
    """Foods that conform to Jewish dietary law. """
    
class DischargeDisposition(enum.Enum):
    
    home = "home"
    """The patient was dicharged and has indicated that they are going to return home afterwards. """
    
    altHome = "alt-home"
    """The patient was discharged and has indicated that they are going to return home afterwards, but not the patient's home - e.g. a family member's home. """
    
    otherHcf = "other-hcf"
    """The patient was transferred to another healthcare facility. """
    
    hosp = "hosp"
    """The patient has been discharged into palliative care. """
    
    long = "long"
    """The patient has been discharged into long-term care where is likely to be monitored through an ongoing episode-of-care. """
    
    aadvice = "aadvice"
    """The patient self discharged against medical advice. """
    
    exp = "exp"
    """The patient has deceased during this encounter. """
    
    psy = "psy"
    """The patient has been transferred to a psychiatric facility. """
    
    rehab = "rehab"
    """The patient was discharged and is to receive post acute care rehabilitation services. """
    
    snf = "snf"
    """The patient has been discharged to a skilled nursing facility for the patient to receive additional care. """
    
    oth = "oth"
    """The discharge disposition has not otherwise defined. """
    
class DiscriminatorType(enum.Enum):
    
    value = "value"
    """The slices have different values in the nominated element. """
    
    exists = "exists"
    """The slices are differentiated by the presence or absence of the nominated element. """
    
    pattern = "pattern"
    """The slices have different values in the nominated element, as determined by testing them against the applicable ElementDefinition.pattern[x]. """
    
    type = "type"
    """The slices are differentiated by type of the nominated element. """
    
    profile = "profile"
    """The slices are differentiated by conformance of the nominated element to a specified profile. Note that if the path specifies .resolve() then the profile is the target profile on the reference. In this case, validation by the possible profiles is required to differentiate the slices. """
    
class DocumentMode(enum.Enum):
    
    producer = "producer"
    """The application produces documents of the specified type. """
    
    consumer = "consumer"
    """The application consumes documents of the specified type. """
    
class DocumentReferenceStatus(enum.Enum):
    
    current = "current"
    """This is the current reference for this document. """
    
    superseded = "superseded"
    """This reference has been superseded by another reference. """
    
    enteredInError = "entered-in-error"
    """This reference was created in error. """
    
class DocumentRelationshipType(enum.Enum):
    
    replaces = "replaces"
    """This document logically replaces or supersedes the target document. """
    
    transforms = "transforms"
    """This document was generated by transforming the target document (e.g. format or language conversion). """
    
    signs = "signs"
    """This document is a signature of the target document. """
    
    appends = "appends"
    """This document adds additional information to the target document. """
    
class DoseAndRateType(enum.Enum):
    
    calculated = "calculated"
    """The dose specified is calculated by the prescriber or the system. """
    
    ordered = "ordered"
    """The dose specified is as ordered by the prescriber. """
    
class EffectEstimateType(enum.Enum):
    
    relativeRR = "relative-RR"
    """relative risk (a type of relative effect estimate). """
    
    relativeOR = "relative-OR"
    """odds ratio (a type of relative effect estimate). """
    
    relativeHR = "relative-HR"
    """hazard ratio (a type of relative effect estimate). """
    
    absoluteARD = "absolute-ARD"
    """absolute risk difference (a type of absolute effect estimate). """
    
    absoluteMeanDiff = "absolute-MeanDiff"
    """mean difference (a type of absolute effect estimate). """
    
    absoluteSMD = "absolute-SMD"
    """standardized mean difference (a type of absolute effect estimate). """
    
    absoluteMedianDiff = "absolute-MedianDiff"
    """median difference (a type of absolute effect estimate). """
    
class EligibilityRequestPurpose(enum.Enum):
    
    authRequirements = "auth-requirements"
    """The prior authorization requirements for the listed, or discovered if specified, converages for the categories of service and/or specifed biling codes are requested. """
    
    benefits = "benefits"
    """The plan benefits and optionally benefits consumed  for the listed, or discovered if specified, converages are requested. """
    
    discovery = "discovery"
    """The insurer is requested to report on any coverages which they are aware of in addition to any specifed. """
    
    validation = "validation"
    """A check that the specified coverages are in-force is requested. """
    
class EligibilityResponsePurpose(enum.Enum):
    
    authRequirements = "auth-requirements"
    """The prior authorization requirements for the listed, or discovered if specified, converages for the categories of service and/or specifed biling codes are requested. """
    
    benefits = "benefits"
    """The plan benefits and optionally benefits consumed  for the listed, or discovered if specified, converages are requested. """
    
    discovery = "discovery"
    """The insurer is requested to report on any coverages which they are aware of in addition to any specifed. """
    
    validation = "validation"
    """A check that the specified coverages are in-force is requested. """
    
class EnableWhenBehavior(enum.Enum):
    
    all = "all"
    """Enable the question when all the enableWhen criteria are satisfied. """
    
    any = "any"
    """Enable the question when any of the enableWhen criteria are satisfied. """
    
class EncounterLocationStatus(enum.Enum):
    
    planned = "planned"
    """The patient is planned to be moved to this location at some point in the future. """
    
    active = "active"
    """The patient is currently at this location, or was between the period specified.

A system may update these records when the patient leaves the location to either reserved, or completed. """
    
    reserved = "reserved"
    """This location is held empty for this patient. """
    
    completed = "completed"
    """The patient was at this location during the period specified.

Not to be used when the patient is currently at the location. """
    
class EncounterStatus(enum.Enum):
    
    planned = "planned"
    """The Encounter has not yet started. """
    
    arrived = "arrived"
    """The Patient is present for the encounter, however is not currently meeting with a practitioner. """
    
    triaged = "triaged"
    """The patient has been assessed for the priority of their treatment based on the severity of their condition. """
    
    inProgress = "in-progress"
    """The Encounter has begun and the patient is present / the practitioner and the patient are meeting. """
    
    onleave = "onleave"
    """The Encounter has begun, but the patient is temporarily on leave. """
    
    finished = "finished"
    """The Encounter has ended. """
    
    cancelled = "cancelled"
    """The Encounter has ended before it has begun. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
    unknown = "unknown"
    """The encounter status is unknown. Note that "unknown" is a value of last resort and every attempt should be made to provide a meaningful value other than "unknown". """
    
class EncounterType(enum.Enum):
    
    ADMS = "ADMS"
    """ADMS """
    
    bDBMClin = "BD/BM-clin"
    """bDBMClin """
    
    CCS60 = "CCS60"
    """CCS60 """
    
    OKI = "OKI"
    """OKI """
    
class EndpointConnectionType(enum.Enum):
    
    iheXcpd = "ihe-xcpd"
    """IHE Cross Community Patient Discovery Profile (XCPD) - http://wiki.ihe.net/index.php/Cross-Community_Patient_Discovery """
    
    iheXca = "ihe-xca"
    """IHE Cross Community Access Profile (XCA) - http://wiki.ihe.net/index.php/Cross-Community_Access """
    
    iheXdr = "ihe-xdr"
    """IHE Cross-Enterprise Document Reliable Exchange (XDR) - http://wiki.ihe.net/index.php/Cross-enterprise_Document_Reliable_Interchange """
    
    iheXds = "ihe-xds"
    """IHE Cross-Enterprise Document Sharing (XDS) - http://wiki.ihe.net/index.php/Cross-Enterprise_Document_Sharing """
    
    iheIid = "ihe-iid"
    """IHE Invoke Image Display (IID) - http://wiki.ihe.net/index.php/Invoke_Image_Display """
    
    dicomWadoRs = "dicom-wado-rs"
    """DICOMweb RESTful Image Retrieve - http://dicom.nema.org/medical/dicom/current/output/chtml/part18/sect_6.5.html """
    
    dicomQidoRs = "dicom-qido-rs"
    """DICOMweb RESTful Image query - http://dicom.nema.org/medical/dicom/current/output/chtml/part18/sect_6.7.html """
    
    dicomStowRs = "dicom-stow-rs"
    """DICOMweb RESTful image sending and storage - http://dicom.nema.org/medical/dicom/current/output/chtml/part18/sect_6.6.html """
    
    dicomWadoUri = "dicom-wado-uri"
    """DICOMweb Image Retrieve - http://dicom.nema.org/dicom/2013/output/chtml/part18/sect_6.3.html """
    
    hl7FhirRest = "hl7-fhir-rest"
    """Interact with the server interface using FHIR's RESTful interface. For details on its version/capabilities you should connect the value in Endpoint.address and retrieve the FHIR CapabilityStatement. """
    
    hl7FhirMsg = "hl7-fhir-msg"
    """Use the servers FHIR Messaging interface. Details can be found on the messaging.html page in the FHIR Specification. The FHIR server's base address is specified in the Endpoint.address property. """
    
    hl7v2Mllp = "hl7v2-mllp"
    """HL7v2 messages over an LLP TCP connection """
    
    secureEmail = "secure-email"
    """Email delivery using a digital certificate to encrypt the content using the public key, receiver must have the private key to decrypt the content """
    
    directProject = "direct-project"
    """Direct Project information - http://wiki.directproject.org/ """
    
class EndpointPayloadType(enum.Enum):
    
    any = "any"
    """Any payload type can be used with this endpoint, it is either a payload agnostic infrastructure (such as a storage repository), or some other type of endpoint where payload considerations are internally handled, and not available """
    
    none = "none"
    """This endpoint does not require any content to be sent; simply connecting to the endpoint is enough notification. This can be used as a 'ping' to wakeup a service to retrieve content, which could be to ensure security considerations are correctly handled """
    
class EndpointStatus(enum.Enum):
    
    active = "active"
    """This endpoint is expected to be active and can be used. """
    
    suspended = "suspended"
    """This endpoint is temporarily unavailable. """
    
    error = "error"
    """This endpoint has exceeded connectivity thresholds and is considered in an error state and should no longer be attempted to connect to until corrective action is taken. """
    
    off = "off"
    """This endpoint is no longer to be used. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
    test = "test"
    """This endpoint is not intended for production usage. """
    
class EnteralFormulaAdditiveTypeCode(enum.Enum):
    
    lipid = "lipid"
    """Modular lipid enteral formula component """
    
    protein = "protein"
    """Modular protein enteral formula component """
    
    carbohydrate = "carbohydrate"
    """Modular carbohydrate enteral formula component """
    
    fiber = "fiber"
    """Modular fiber enteral formula component """
    
    water = "water"
    """Added water """
    
class EpisodeOfCareStatus(enum.Enum):
    
    planned = "planned"
    """This episode of care is planned to start at the date specified in the period.start. During this status, an organization may perform assessments to determine if the patient is eligible to receive services, or be organizing to make resources available to provide care services. """
    
    waitlist = "waitlist"
    """This episode has been placed on a waitlist, pending the episode being made active (or cancelled). """
    
    active = "active"
    """This episode of care is current. """
    
    onhold = "onhold"
    """This episode of care is on hold; the organization has limited responsibility for the patient (such as while on respite). """
    
    finished = "finished"
    """This episode of care is finished and the organization is not expecting to be providing further care to the patient. Can also be known as "closed", "completed" or other similar terms. """
    
    cancelled = "cancelled"
    """The episode of care was cancelled, or withdrawn from service, often selected during the planned stage as the patient may have gone elsewhere, or the circumstances have changed and the organization is unable to provide the care. It indicates that services terminated outside the planned/expected workflow. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
class EpisodeOfCareType(enum.Enum):
    
    hacc = "hacc"
    """hacc """
    
    pac = "pac"
    """pac """
    
    diab = "diab"
    """diab """
    
    da = "da"
    """da """
    
    cacp = "cacp"
    """cacp """
    
class EventCapabilityMode(enum.Enum):
    
    sender = "sender"
    """The application sends requests and receives responses. """
    
    receiver = "receiver"
    """The application receives requests and sends responses. """
    
class EventResourceType(enum.Enum):
    
    chargeItem = "ChargeItem"
    """Item containing charge code(s) associated with the provision of healthcare provider products. """
    
    claimResponse = "ClaimResponse"
    """Remittance resource. """
    
    clinicalImpression = "ClinicalImpression"
    """A clinical assessment performed when planning treatments and management strategies for a patient. """
    
    communication = "Communication"
    """A record of information transmitted from a sender to a receiver. """
    
    composition = "Composition"
    """A set of resources composed into a single coherent clinical statement with clinical attestation. """
    
    condition = "Condition"
    """Detailed information about conditions, problems or diagnoses. """
    
    consent = "Consent"
    """A healthcare consumer's policy choices to permits or denies recipients or roles to perform actions for specific purposes and periods of time. """
    
    coverage = "Coverage"
    """Insurance or medical plan or a payment agreement. """
    
    deviceUseStatement = "DeviceUseStatement"
    """Record of use of a device. """
    
    diagnosticReport = "DiagnosticReport"
    """A Diagnostic report - a combination of request information, atomic results, images, interpretation, as well as formatted reports. """
    
    documentManifest = "DocumentManifest"
    """A list that defines a set of documents. """
    
    documentReference = "DocumentReference"
    """A reference to a document. """
    
    encounter = "Encounter"
    """An interaction during which services are provided to the patient. """
    
    enrollmentResponse = "EnrollmentResponse"
    """EnrollmentResponse resource. """
    
    episodeOfCare = "EpisodeOfCare"
    """An association of a Patient with an Organization and  Healthcare Provider(s) for a period of time that the Organization assumes some level of responsibility. """
    
    explanationOfBenefit = "ExplanationOfBenefit"
    """Explanation of Benefit resource. """
    
    familyMemberHistory = "FamilyMemberHistory"
    """Information about patient's relatives, relevant for patient. """
    
    guidanceResponse = "GuidanceResponse"
    """The formal response to a guidance request. """
    
    imagingStudy = "ImagingStudy"
    """A set of images produced in single study (one or more series of references images). """
    
    immunization = "Immunization"
    """Immunization event information. """
    
    measureReport = "MeasureReport"
    """Results of a measure evaluation. """
    
    media = "Media"
    """A photo, video, or audio recording acquired or used in healthcare. The actual content may be inline or provided by direct reference. """
    
    medicationAdministration = "MedicationAdministration"
    """Administration of medication to a patient. """
    
    medicationDispense = "MedicationDispense"
    """Dispensing a medication to a named patient. """
    
    medicationStatement = "MedicationStatement"
    """Record of medication being taken by a patient. """
    
    observation = "Observation"
    """Measurements and simple assertions. """
    
    paymentNotice = "PaymentNotice"
    """PaymentNotice request. """
    
    paymentReconciliation = "PaymentReconciliation"
    """PaymentReconciliation resource. """
    
    procedure = "Procedure"
    """An action that is being or was performed on a patient. """
    
    processResponse = "ProcessResponse"
    """ProcessResponse resource. """
    
    questionnaireResponse = "QuestionnaireResponse"
    """A structured set of questions and their answers. """
    
    riskAssessment = "RiskAssessment"
    """Potential outcomes for a subject with likelihood. """
    
    supplyDelivery = "SupplyDelivery"
    """Delivery of bulk Supplies. """
    
    task = "Task"
    """A task to be performed. """
    
class EventStatus(enum.Enum):
    
    preparation = "preparation"
    """The core event has not started yet, but some staging activities have begun (e.g. surgical suite preparation).  Preparation stages may be tracked for billing purposes. """
    
    inProgress = "in-progress"
    """The event is currently occurring. """
    
    notDone = "not-done"
    """The event was terminated prior to any activity beyond preparation.  I.e. The 'main' activity has not yet begun.  The boundary between preparatory and the 'main' activity is context-specific. """
    
    onHold = "on-hold"
    """The event has been temporarily stopped but is expected to resume in the future. """
    
    stopped = "stopped"
    """The event was terminated prior to the full completion of the intended activity but after at least some of the 'main' activity (beyond preparation) has occurred. """
    
    completed = "completed"
    """The event has now concluded. """
    
    enteredInError = "entered-in-error"
    """This electronic record should never have existed, though it is possible that real-world decisions were based on it.  (If real-world activity has occurred, the status should be "stopped" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this event.  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply,  but the authoring/source system does not know which. """
    
class EventTiming(enum.Enum):
    
    MORN = "MORN"
    """Event occurs during the morning. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    mORNEarly = "MORN.early"
    """Event occurs during the early morning. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    mORNLate = "MORN.late"
    """Event occurs during the late morning. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    NOON = "NOON"
    """Event occurs around 12:00pm. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    AFT = "AFT"
    """Event occurs during the afternoon. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    aFTEarly = "AFT.early"
    """Event occurs during the early afternoon. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    aFTLate = "AFT.late"
    """Event occurs during the late afternoon. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    EVE = "EVE"
    """Event occurs during the evening. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    eVEEarly = "EVE.early"
    """Event occurs during the early evening. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    eVELate = "EVE.late"
    """Event occurs during the late evening. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    NIGHT = "NIGHT"
    """Event occurs during the night. The exact time is unspecified and established by institution convention or patient interpretation. """
    
    PHS = "PHS"
    """Event occurs [offset] after subject goes to sleep. The exact time is unspecified and established by institution convention or patient interpretation. """
    
class EvidenceVariableType(enum.Enum):
    
    dichotomous = "dichotomous"
    """The variable is dichotomous, such as present or absent. """
    
    continuous = "continuous"
    """The variable is a continuous result such as a quantity. """
    
    descriptive = "descriptive"
    """The variable is described narratively rather than quantitatively. """
    
class EvidenceVariantState(enum.Enum):
    
    lowRisk = "low-risk"
    """low risk estimate. """
    
    mediumRisk = "medium-risk"
    """medium risk estimate. """
    
    highRisk = "high-risk"
    """high risk estimate. """
    
class ExampleClaimSubTypeCodes(enum.Enum):
    
    ortho = "ortho"
    """A claim for Orthodontic Services. """
    
    emergency = "emergency"
    """A claim for emergency services. """
    
class ExampleCoverageFinancialExceptionCodes(enum.Enum):
    
    retired = "retired"
    """Retired persons have all copays and deductibles reduced. """
    
    foster = "foster"
    """Children in the foster care have all copays and deductibles waived. """
    
class ExampleDiagnosisOnAdmissionCodes(enum.Enum):
    
    Y = "y"
    """Diagnosis was present at time of inpatient admission. """
    
    N = "n"
    """Diagnosis was not present at time of inpatient admission. """
    
    U = "u"
    """Documentation insufficient to determine if condition was present at the time of inpatient admission. """
    
    W = "w"
    """Clinically undetermined. Provider unable to clinically determine whether the condition was present at the time of inpatient admission. """
    
class ExampleDiagnosisTypeCodes(enum.Enum):
    
    admitting = "admitting"
    """The diagnosis given as the reason why the patient was admitted to the hospital. """
    
    clinical = "clinical"
    """A diagnosis made on the basis of medical signs and patient-reported symptoms, rather than diagnostic tests. """
    
    differential = "differential"
    """One of a set of the possible diagnoses that could be connected to the signs, symptoms, and lab findings. """
    
    discharge = "discharge"
    """The diagnosis given when the patient is discharged from the hospital. """
    
    laboratory = "laboratory"
    """A diagnosis based significantly on laboratory reports or test results, rather than the physical examination of the patient. """
    
    nursing = "nursing"
    """A diagnosis which identifies people's responses to situations in their lives, such as a readiness to change or a willingness to accept assistance. """
    
    prenatal = "prenatal"
    """A diagnosis determined prior to birth. """
    
    principal = "principal"
    """The single medical diagnosis that is most relevant to the patient's chief complaint or need for treatment. """
    
    radiology = "radiology"
    """A diagnosis based primarily on the results from medical imaging studies. """
    
    remote = "remote"
    """A diagnosis determined using telemedicine techniques. """
    
    retrospective = "retrospective"
    """The labeling of an illness in a specific historical event using modern knowledge, methods and disease classifications. """
    
    self = "self"
    """A diagnosis determined by the patient. """
    
class ExampleMessageReasonCodes(enum.Enum):
    
    admit = "admit"
    """The patient has been admitted. """
    
    discharge = "discharge"
    """The patient has been discharged. """
    
    absent = "absent"
    """The patient has temporarily left the institution. """
    
    return_ = "return"
    """The patient has returned from a temporary absence. """
    
    moved = "moved"
    """The patient has been moved to a new location. """
    
    edit = "edit"
    """Encounter details have been updated (e.g. to correct a coding error). """
    
class ExampleOnsetTypeReasonCodes(enum.Enum):
    
    lxm = "lxm"
    """Date of last examination. """
    
    sym = "sym"
    """Date when symptoms were first noticed. """
    
    lmn = "lmn"
    """Start date of last menstruation. """
    
class ExamplePaymentTypeCodes(enum.Enum):
    
    complete = "complete"
    """Complete (final) payment of the benefit under the Claim less any adjustments. """
    
    partial = "partial"
    """Partial payment of the benefit under the Claim less any adjustments. """
    
class ExamplePharmacyServiceCodes(enum.Enum):
    
    smokecess = "smokecess"
    """Smoking cessation """
    
    flushot = "flushot"
    """Flu Shot """
    
    drugcost = "drugcost"
    """The wholesale price of the medication. """
    
    markup = "markup"
    """The additional cost assessed on the drug. """
    
    dispensefee = "dispensefee"
    """The professional fee charged for dispensing the product or service. """
    
    compoundfee = "compoundfee"
    """The professional fee charged for compounding the medication. """
    
class ExampleProcedureTypeCodes(enum.Enum):
    
    primary = "primary"
    """The first procedure in a series required to produce and overall patient outcome. """
    
    secondary = "secondary"
    """The second procedure in a series required to produce and overall patient outcome. """
    
class ExampleProgramReasonCodes(enum.Enum):
    
    as_ = "as"
    """Child Asthma Program """
    
    hd = "hd"
    """Hemodialysis Program. """
    
    auscr = "auscr"
    """Autism Screening Program. """
    
    none = "none"
    """No program code applies. """
    
class ExampleRelatedClaimRelationshipCodes(enum.Enum):
    
    prior = "prior"
    """A prior claim instance for the same intended suite of services. """
    
    associated = "associated"
    """A claim for a different suite of services which is related the suite claimed here. """
    
class ExampleScenarioActorType(enum.Enum):
    
    person = "person"
    """A person. """
    
    entity = "entity"
    """A system. """
    
class ExampleServiceModifierCodes(enum.Enum):
    
    sr = "sr"
    """Services provided on the side of the road or such other non-conventional setting. """
    
    ah = "ah"
    """Services provided outside or normal business hours. """
    
class ExampleServiceProductCodes(enum.Enum):
    
    exam = "exam"
    """Exam """
    
    flushot = "flushot"
    """Flu shot """
    
class ExampleUseCodesForList(enum.Enum):
    
    alerts = "alerts"
    """A list of alerts for the patient. """
    
    adverserxns = "adverserxns"
    """A list of part adverse reactions. """
    
    allergies = "allergies"
    """A list of Allergies for the patient. """
    
    medications = "medications"
    """A list of medication statements for the patient. """
    
    problems = "problems"
    """A list of problems that the patient is known of have (or have had in the past). """
    
    worklist = "worklist"
    """A list of items that constitute a set of work to be performed (typically this code would be specialized for more specific uses, such as a ward round list). """
    
    waiting = "waiting"
    """A list of items waiting for an event (perhaps a surgical patient waiting list). """
    
    protocols = "protocols"
    """A set of protocols to be followed. """
    
    plans = "plans"
    """A set of care plans that apply in a particular context of care. """
    
class ExampleVisionPrescriptionProductCodes(enum.Enum):
    
    lens = "lens"
    """A lens to be fitted to a frame to comprise a pair of glasses. """
    
    contact = "contact"
    """A lens to be fitted for wearing directly on an eye. """
    
class ExceptionCodes(enum.Enum):
    
    student = "student"
    """Fulltime Student """
    
    disabled = "disabled"
    """Disabled """
    
class ExpansionParameterSource(enum.Enum):
    
    input = "input"
    """The parameter was supplied by the client in the $expand request. """
    
    server = "server"
    """The parameter was added by the expansion engine on the server. """
    
    codesystem = "codesystem"
    """The parameter was added from one the code systems used in the $expand operation. """
    
class ExpansionProcessingRule(enum.Enum):
    
    allCodes = "all-codes"
    """The expansion (when in UI mode) includes all codes *and* any defined groups (in extensions). """
    
    ungrouped = "ungrouped"
    """The expanion (when in UI mode) lists the groups, and then any codes that have not been included in a group. """
    
    groupsOnly = "groups-only"
    """The expansion (when in UI mode) only includes the defined groups. """
    
class ExplanationOfBenefitStatus(enum.Enum):
    
    active = "active"
    """The resource instance is currently in-force. """
    
    cancelled = "cancelled"
    """The resource instance is withdrawn, rescinded or reversed. """
    
    draft = "draft"
    """A new resource instance the contents of which is not complete. """
    
    enteredInError = "entered-in-error"
    """The resource instance was entered in error. """
    
class ExposureState(enum.Enum):
    
    exposure = "exposure"
    """used when the results by exposure is describing the results for the primary exposure of interest. """
    
    exposureAlternative = "exposure-alternative"
    """used when the results by exposure is describing the results for the alternative exposure state, control state or comparator state. """
    
class ExpressionLanguage(enum.Enum):
    
    textCql = "text/cql"
    """Clinical Quality Language. """
    
    textFhirpath = "text/fhirpath"
    """FHIRPath. """
    
    applicationXFhirQuery = "application/x-fhir-query"
    """FHIR's RESTful query syntax - typically independent of base URL. """
    
class ExtensionContextType(enum.Enum):
    
    fhirpath = "fhirpath"
    """The context is all elements that match the FHIRPath query found in the expression. """
    
    element = "element"
    """The context is any element that has an ElementDefinition.id that matches that found in the expression. This includes ElementDefinition Ids that have slicing identifiers. The full path for the element is [url]#[elementid]. If there is no #, the Element id is one defined in the base specification. """
    
    extension = "extension"
    """The context is a particular extension from a particular StructureDefinition, and the expression is just a uri that identifies the extension. """
    
class FHIRDefinedConceptProperties(enum.Enum):
    
    inactive = "inactive"
    """True if the concept is not considered active - e.g. not a valid concept any more. Property type is boolean, default value is false """
    
    deprecated = "deprecated"
    """The date at which a concept was deprecated. Concepts that are deprecated but not inactive can still be used, but their use is discouraged, and they should be expected to be made inactive in a future release. Property type is dateTime """
    
    notSelectable = "notSelectable"
    """The concept is not intended to be chosen by the user - only intended to be used as a selector for other concepts. Note, though, that the interpretation of this is highly contextual; all concepts are selectable in some context. Property type is boolean """
    
    parent = "parent"
    """The concept identified in this property is a parent of the concept on which it is a property. The property type will be 'code'. The meaning of 'parent' is defined by the hierarchyMeaning attribute """
    
    child = "child"
    """The concept identified in this property is a child of the concept on which it is a property. The property type will be 'code'. The meaning of 'child' is defined by the hierarchyMeaning attribute """
    
class FHIRDeviceStatus(enum.Enum):
    
    active = "active"
    """The device is available for use.  Note: For *implanted devices*  this means that the device is implanted in the patient. """
    
    inactive = "inactive"
    """The device is no longer available for use (e.g. lost, expired, damaged).  Note: For *implanted devices*  this means that the device has been removed from the patient. """
    
    enteredInError = "entered-in-error"
    """The device was entered in error and voided. """
    
    unknown = "unknown"
    """The status of the device has not been determined. """
    
class FHIRDeviceStatus(enum.Enum):
    
    active = "active"
    """The device is available for use.  Note: For *implanted devices*  this means that the device is implanted in the patient. """
    
    inactive = "inactive"
    """The device is no longer available for use (e.g. lost, expired, damaged).  Note: For *implanted devices*  this means that the device has been removed from the patient. """
    
    enteredInError = "entered-in-error"
    """The device was entered in error and voided. """
    
    unknown = "unknown"
    """The status of the device has not been determined. """
    
class FHIRDeviceStatusReason(enum.Enum):
    
    online = "online"
    """The device is off. """
    
    paused = "paused"
    """The device is paused. """
    
    standby = "standby"
    """The device is ready but not actively operating. """
    
    offline = "offline"
    """The device is offline. """
    
    notReady = "not-ready"
    """The device is not ready. """
    
    transducDiscon = "transduc-discon"
    """The device transducer is disconnected. """
    
    hwDiscon = "hw-discon"
    """The device hardware is disconnected. """
    
    off = "off"
    """The device is off. """
    
class FHIRRestfulInteractions(enum.Enum):
    
    read = "read"
    """Read the current state of the resource. """
    
    vread = "vread"
    """Read the state of a specific version of the resource. """
    
    update = "update"
    """Update an existing resource by its id (or create it if it is new). """
    
    patch = "patch"
    """Update an existing resource by posting a set of changes to it. """
    
    delete = "delete"
    """Delete a resource. """
    
    history = "history"
    """Retrieve the change history for a particular resource, type of resource, or the entire system. """
    
    historyInstance = "history-instance"
    """Retrieve the change history for a particular resource. """
    
    historyType = "history-type"
    """Retrieve the change history for all resources of a particular type. """
    
    historySystem = "history-system"
    """Retrieve the change history for all resources on a system. """
    
    create = "create"
    """Create a new resource with a server assigned id. """
    
    search = "search"
    """Search a resource type or all resources based on some filter criteria. """
    
    searchType = "search-type"
    """Search all resources of the specified type based on some filter criteria. """
    
    searchSystem = "search-system"
    """Search all resources based on some filter criteria. """
    
    capabilities = "capabilities"
    """Get a Capability Statement for the system. """
    
    transaction = "transaction"
    """Update, create or delete a set of resources as a single transaction. """
    
    batch = "batch"
    """perform a set of a separate interactions in a single http operation """
    
    operation = "operation"
    """Perform an operation as defined by an OperationDefinition. """
    
class FHIRSubstanceStatus(enum.Enum):
    
    active = "active"
    """The substance is considered for use or reference. """
    
    inactive = "inactive"
    """The substance is considered for reference, but not for use. """
    
    enteredInError = "entered-in-error"
    """The substance was entered in error. """
    
class FailureAction(enum.Enum):
    
    fatal = "fatal"
    """fatal """
    
    warn = "warn"
    """warn """
    
    recOnly = "rec-only"
    """recOnly """
    
    none = "none"
    """none """
    
class FamilyHistoryAbsentReason(enum.Enum):
    
    subjectUnknown = "subject-unknown"
    """Patient does not know the subject, e.g. the biological parent of an adopted patient. """
    
    withheld = "withheld"
    """The patient withheld or refused to share the information. """
    
    unableToObtain = "unable-to-obtain"
    """Information cannot be obtained; e.g. unconscious patient. """
    
    deferred = "deferred"
    """Patient does not have the information now, but can provide the information at a later date. """
    
class FamilyHistoryStatus(enum.Enum):
    
    partial = "partial"
    """Some health information is known and captured, but not complete - see notes for details. """
    
    completed = "completed"
    """All available related health information is captured as of the date (and possibly time) when the family member history was taken. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
    healthUnknown = "health-unknown"
    """Health information for this family member is unavailable/unknown. """
    
class FeedingDeviceCodes(enum.Enum):
    
    standardNipple = "standard-nipple"
    """Standard nipple definition: """
    
    preemieNipple = "preemie-nipple"
    """Preemie nipple definition: """
    
    orthoNipple = "ortho-nipple"
    """Orthodontic nipple definition: """
    
    slofloNipple = "sloflo-nipple"
    """Slow flow nipple definition: """
    
    midfloNipple = "midflo-nipple"
    """Middle flow nipple definition: """
    
    bigcutNipple = "bigcut-nipple"
    """Enlarged, cross-cut nipple definition: """
    
    habermanBottle = "haberman-bottle"
    """Haberman bottle definition: """
    
    sippyValve = "sippy-valve"
    """Sippy cup with valve definition: """
    
    sippyNoValve = "sippy-no-valve"
    """Sippy cup without valve definition: """
    
    provaleCup = "provale-cup"
    """Provale Cup definition: """
    
    glassLid = "glass-lid"
    """Glass with lid/sippy cup definition: """
    
    handholdCup = "handhold-cup"
    """Double handhold on glass/cup definition: """
    
    rubberMat = "rubber-mat"
    """Rubber matting under tray definition: """
    
    straw = "straw"
    """Straw definition: """
    
    noseCup = "nose-cup"
    """Nose cup definition: """
    
    scoopPlate = "scoop-plate"
    """Scoop plate definition: """
    
    utensilHolder = "utensil-holder"
    """Hand wrap utensil holder definition: """
    
    foamHandle = "foam-handle"
    """Foam handle utensils definition: """
    
    angledUtensil = "angled-utensil"
    """Angled utensils definition: """
    
    spoutCup = "spout-cup"
    """Spout cup definition: """
    
    autofeedingDevice = "autofeeding-device"
    """Automated feeding devices definition: """
    
    rockerKnife = "rocker-knife"
    """Rocker knife definition: """
    
class FilterOperator(enum.Enum):
    
    eq = "="
    """The specified property of the code equals the provided value. """
    
    isA = "is-a"
    """Includes all concept ids that have a transitive is-a relationship with the concept Id provided as the value, including the provided concept itself (include descendant codes and self). """
    
    descendentOf = "descendent-of"
    """Includes all concept ids that have a transitive is-a relationship with the concept Id provided as the value, excluding the provided concept itself i.e. include descendant codes only). """
    
    isNotA = "is-not-a"
    """The specified property of the code does not have an is-a relationship with the provided value. """
    
    regex = "regex"
    """The specified property of the code  matches the regex specified in the provided value. """
    
    in_ = "in"
    """The specified property of the code is in the set of codes or concepts specified in the provided value (comma separated list). """
    
    notIn = "not-in"
    """The specified property of the code is not in the set of codes or concepts specified in the provided value (comma separated list). """
    
    generalizes = "generalizes"
    """Includes all concept ids that have a transitive is-a relationship from the concept Id provided as the value, including the provided concept itself (i.e. include ancestor codes and self). """
    
    exists = "exists"
    """The specified property of the code has at least one value (if the specified value is true; if the specified value is false, then matches when the specified property of the code has no values). """
    
class FinancialResourceStatusCodes(enum.Enum):
    
    active = "active"
    """The instance is currently in-force. """
    
    cancelled = "cancelled"
    """The instance is withdrawn, rescinded or reversed. """
    
    draft = "draft"
    """A new instance the contents of which is not complete. """
    
    enteredInError = "entered-in-error"
    """The instance was entered in error. """
    
class FinancialTaskCodes(enum.Enum):
    
    cancel = "cancel"
    """Cancel or reverse a resource, such as a claim or preauthorization, which is in-process or complete. """
    
    poll = "poll"
    """Retrieve selected or all queued resources or messages. """
    
    release = "release"
    """Release any reserved funds or material obligations associated with a resource. For example, any unused but reserved funds or treatment allowance associated with a preauthorization once treatment is complete. """
    
    reprocess = "reprocess"
    """Indication that the processing of a resource, such as a claim, for some or all of the required work is now being requested. """
    
    status = "status"
    """Check on the processing status of a resource such as the adjudication of a claim. """
    
class FinancialTaskInputTypeCodes(enum.Enum):
    
    include = "include"
    """The name of a resource to include in a selection. """
    
    exclude = "exclude"
    """The name of a resource to not include in a selection. """
    
    origresponse = "origresponse"
    """A reference to the response resource to the original processing of a resource. """
    
    reference = "reference"
    """A reference value which must be quoted to authorize an action. """
    
    item = "item"
    """The sequence number associated with an item for reprocessing. """
    
    period = "period"
    """The reference period for the action being requested. """
    
    status = "status"
    """The processing status from a check on the processing status of a resource such as the adjudication of a claim. """
    
class FlagCategory(enum.Enum):
    
    diet = "diet"
    """Flags related to the subject's dietary needs. """
    
    drug = "drug"
    """Flags related to the subject's medications. """
    
    lab = "lab"
    """Flags related to performing laboratory tests and related processes (e.g. phlebotomy). """
    
    admin = "admin"
    """Flags related to administrative and financial processes. """
    
    contact = "contact"
    """Flags related to coming into contact with the patient. """
    
    clinical = "clinical"
    """Flags related to the subject's clinical data. """
    
    behavioral = "behavioral"
    """Flags related to behavior. """
    
    research = "research"
    """Flags related to research. """
    
    advanceDirective = "advance-directive"
    """Flags related to subject's advance directives. """
    
    safety = "safety"
    """Flags related to safety precautions. """
    
class FlagPriorityCodes(enum.Enum):
    
    PN = "PN"
    """No alarm. """
    
    PL = "PL"
    """Low priority. """
    
    PM = "PM"
    """Medium priority. """
    
    PH = "PH"
    """High priority. """
    
class FlagStatus(enum.Enum):
    
    active = "active"
    """A current flag that should be displayed to a user. A system may use the category to determine which user roles should view the flag. """
    
    inactive = "inactive"
    """The flag no longer needs to be displayed. """
    
    enteredInError = "entered-in-error"
    """The flag was added in error and should no longer be displayed. """
    
class GenderIdentity(enum.Enum):
    
    transgenderFemale = "transgender-female"
    """the patient identifies as transgender male-to-female """
    
    transgenderMale = "transgender-male"
    """the patient identifies as transgender female-to-male """
    
    nonBinary = "non-binary"
    """the patient identifies with neither/both female and male """
    
    male = "male"
    """the patient identifies as male """
    
    female = "female"
    """the patient identifies as female """
    
    other = "other"
    """other gender identity """
    
    nonDisclose = "non-disclose"
    """the patient does not wish to disclose his gender identity """
    
class GenderStatus(enum.Enum):
    
    neutered = "neutered"
    """The animal has been sterilized, castrated or otherwise made infertile. """
    
    intact = "intact"
    """The animal's reproductive organs are intact. """
    
    unknown = "unknown"
    """Unable to determine whether the animal has been neutered. """
    
class GoalAcceptanceStatus(enum.Enum):
    
    agree = "agree"
    """Stakeholder supports pursuit of the goal. """
    
    disagree = "disagree"
    """Stakeholder is not in support of the pursuit of the goal. """
    
    pending = "pending"
    """Stakeholder has not yet made a decision on whether they support the goal. """
    
class GoalAchievementStatus(enum.Enum):
    
    inProgress = "in-progress"
    """The goal is being sought but has not yet been reached. (Also applies if the goal was reached in the past but there has been regression and the goal is again being sought). """
    
    improving = "improving"
    """The goal is being sought, and is progressing. """
    
    worsening = "worsening"
    """The goal is being sought, but is regressing. """
    
    noChange = "no-change"
    """The goal is being sought, but the trend is flat. """
    
    achieved = "achieved"
    """The goal has been met. """
    
    sustaining = "sustaining"
    """The goal has been met, but ongoing activity is needed to sustain the goal objective. """
    
    notAchieved = "not-achieved"
    """The goal has not been met and there might or might not have been progress towards target. """
    
    noProgress = "no-progress"
    """The goal has not been met and little to no progress towards target. """
    
    notAttainable = "not-attainable"
    """The goal is not possible to be met. """
    
class GoalCategory(enum.Enum):
    
    dietary = "dietary"
    """Goals related to the consumption of food and/or beverages. """
    
    safety = "safety"
    """Goals related to the personal protection of the subject. """
    
    behavioral = "behavioral"
    """Goals related to the manner in which the subject acts. """
    
    nursing = "nursing"
    """Goals related to the practice of nursing or established by nurses. """
    
    physiotherapy = "physiotherapy"
    """Goals related to the mobility and/or motor capability of the subject. """
    
class GoalLifecycleStatus(enum.Enum):
    
    proposed = "proposed"
    """A goal is proposed for this patient. """
    
    planned = "planned"
    """A goal is planned for this patient. """
    
    accepted = "accepted"
    """A proposed goal was accepted or acknowledged. """
    
    active = "active"
    """The goal is being sought actively. """
    
    onHold = "on-hold"
    """The goal remains a long term objective but is no longer being actively pursued for a temporary period of time. """
    
    completed = "completed"
    """The goal is no longer being sought. """
    
    cancelled = "cancelled"
    """The goal has been abandoned. """
    
    enteredInError = "entered-in-error"
    """The goal was entered in error and voided. """
    
    rejected = "rejected"
    """A proposed goal was rejected. """
    
class GoalPriority(enum.Enum):
    
    highPriority = "high-priority"
    """Indicates that the goal is of considerable importance and should be a primary focus of care delivery. """
    
    mediumPriority = "medium-priority"
    """Indicates that the goal has a reasonable degree of importance and that concrete action should be taken towards the goal.  Attainment is not as critical as high-priority goals. """
    
    lowPriority = "low-priority"
    """The goal is desirable but is not sufficiently important to devote significant resources to.  Achievement of the goal may be sought when incidental to achieving other goals. """
    
class GoalRelationshipType(enum.Enum):
    
    predecessor = "predecessor"
    """Indicates that the target goal is one which must be met before striving for the current goal. """
    
    successor = "successor"
    """Indicates that the target goal is a desired objective once the current goal is met. """
    
    replacement = "replacement"
    """Indicates that this goal has been replaced by the target goal. """
    
    milestone = "milestone"
    """Indicates that the target goal is considered to be a "piece" of attaining this goal. """
    
    other = "other"
    """Indicates that the relationship is not covered by one of the pre-defined codes.  (An extension may convey more information about the meaning of the relationship.). """
    
class GoalStatusReason(enum.Enum):
    
    surgery = "surgery"
    """Goal suspended or ended because of a surgical procedure. """
    
    lifeEvent = "life-event"
    """Goal suspended or ended because of a significant life event (marital change, bereavement, etc.). """
    
    replaced = "replaced"
    """Goal has been superseded by a new goal. """
    
    patientRequest = "patient-request"
    """Patient wishes the goal to be set aside, at least temporarily. """
    
    tempNotAttainable = "temp-not-attainable"
    """Goal cannot be reached temporarily. """
    
    permanentNotAttainable = "permanent-not-attainable"
    """Goal cannot be reached permanently. """
    
    financialBarrier = "financial-barrier"
    """Goal cannot be reached due to financial barrier or reason. """
    
    lackOfTransportation = "lack-of-transportation"
    """Goal cannot be reached due to a lack of transportation. """
    
    lackOfSocialSupport = "lack-of-social-support"
    """Goal cannot be reached due to a lack of social support. """
    
class GraphCompartmentRule(enum.Enum):
    
    identical = "identical"
    """The compartment must be identical (the same literal reference). """
    
    matching = "matching"
    """The compartment must be the same - the record must be about the same patient, but the reference may be different. """
    
    different = "different"
    """The compartment must be different. """
    
    custom = "custom"
    """The compartment rule is defined in the accompanying FHIRPath expression. """
    
class GraphCompartmentUse(enum.Enum):
    
    condition = "condition"
    """This compartment rule is a condition for whether the rule applies. """
    
    requirement = "requirement"
    """This compartment rule is enforced on any relationships that meet the conditions. """
    
class GroupMeasure(enum.Enum):
    
    mean = "mean"
    """Aggregated using Mean of participant values. """
    
    median = "median"
    """Aggregated using Median of participant values. """
    
    meanOfMean = "mean-of-mean"
    """Aggregated using Mean of study mean values. """
    
    meanOfMedian = "mean-of-median"
    """Aggregated using Mean of study median values. """
    
    medianOfMean = "median-of-mean"
    """Aggregated using Median of study mean values. """
    
    medianOfMedian = "median-of-median"
    """Aggregated using Median of study median values. """
    
class GroupType(enum.Enum):
    
    person = "person"
    """Group contains "person" Patient resources. """
    
    animal = "animal"
    """Group contains "animal" Patient resources. """
    
    practitioner = "practitioner"
    """Group contains healthcare practitioner resources (Practitioner or PractitionerRole). """
    
    device = "device"
    """Group contains Device resources. """
    
    medication = "medication"
    """Group contains Medication resources. """
    
    substance = "substance"
    """Group contains Substance resources. """
    
class GuidanceResponseStatus(enum.Enum):
    
    success = "success"
    """The request was processed successfully. """
    
    dataRequested = "data-requested"
    """The request was processed successfully, but more data may result in a more complete evaluation. """
    
    dataRequired = "data-required"
    """The request was processed, but more data is required to complete the evaluation. """
    
    inProgress = "in-progress"
    """The request is currently being processed. """
    
    failure = "failure"
    """The request was not processed successfully. """
    
    enteredInError = "entered-in-error"
    """The response was entered in error. """
    
class GuidePageGeneration(enum.Enum):
    
    html = "html"
    """Page is proper xhtml with no templating.  Will be brought across unchanged for standard post-processing. """
    
    markdown = "markdown"
    """Page is markdown with templating.  Will use the template to create a file that imports the markdown file prior to post-processing. """
    
    xml = "xml"
    """Page is xml with templating.  Will use the template to create a file that imports the source file and run the nominated XSLT transform (see parameters) if present prior to post-processing. """
    
    generated = "generated"
    """Page will be generated by the publication process - no source to bring across. """
    
class GuideParameterCode(enum.Enum):
    
    apply = "apply"
    """If the value of this string 0..* parameter is one of the metadata fields then all conformance resources will have any specified [Resource].[field] overwritten with the ImplementationGuide.[field], where field is one of: version, date, status, publisher, contact, copyright, experimental, jurisdiction, useContext. """
    
    pathResource = "path-resource"
    """The value of this string 0..* parameter is a subfolder of the build context's location that is to be scanned to load resources. Scope is (if present) a particular resource type. """
    
    pathPages = "path-pages"
    """The value of this string 0..1 parameter is a subfolder of the build context's location that contains files that are part of the html content processed by the builder. """
    
    pathTxCache = "path-tx-cache"
    """The value of this string 0..1 parameter is a subfolder of the build context's location that is used as the terminology cache. If this is not present, the terminology cache is on the local system, not under version control. """
    
    expansionParameter = "expansion-parameter"
    """The value of this string 0..* parameter is a parameter (name=value) when expanding value sets for this implementation guide. This is particularly used to specify the versions of published terminologies such as SNOMED CT. """
    
    ruleBrokenLinks = "rule-broken-links"
    """The value of this string 0..1 parameter is either "warning" or "error" (default = "error"). If the value is "warning" then IG build tools allow the IG to be considered successfully build even when there is no internal broken links. """
    
    generateXml = "generate-xml"
    """The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in XML format. If not present, the Publication Tool decides whether to generate XML. """
    
    generateJson = "generate-json"
    """The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in JSON format. If not present, the Publication Tool decides whether to generate JSON. """
    
    generateTurtle = "generate-turtle"
    """The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in Turtle format. If not present, the Publication Tool decides whether to generate Turtle. """
    
    htmlTemplate = "html-template"
    """The value of this string singleton parameter is the name of the file to use as the builder template for each generated page (see templating). """
    
class HL7Workgroup(enum.Enum):
    
    cbcc = "cbcc"
    """Community Based Collaborative Care (http://www.hl7.org/Special/committees/cbcc/index.cfm). """
    
    cds = "cds"
    """Clinical Decision Support (http://www.hl7.org/Special/committees/dss/index.cfm). """
    
    cqi = "cqi"
    """Clinical Quality Information (http://www.hl7.org/Special/committees/cqi/index.cfm). """
    
    cg = "cg"
    """Clinical Genomics (http://www.hl7.org/Special/committees/clingenomics/index.cfm). """
    
    dev = "dev"
    """Health Care Devices (http://www.hl7.org/Special/committees/healthcaredevices/index.cfm). """
    
    ehr = "ehr"
    """Electronic Health Records (http://www.hl7.org/special/committees/ehr/index.cfm). """
    
    fhir = "fhir"
    """FHIR Infrastructure (http://www.hl7.org/Special/committees/fiwg/index.cfm). """
    
    fm = "fm"
    """Financial Management (http://www.hl7.org/Special/committees/fm/index.cfm). """
    
    hsi = "hsi"
    """Health Standards Integration (http://www.hl7.org/Special/committees/hsi/index.cfm). """
    
    ii = "ii"
    """Imaging Integration (http://www.hl7.org/Special/committees/imagemgt/index.cfm). """
    
    inm = "inm"
    """Infrastructure And Messaging (http://www.hl7.org/special/committees/inm/index.cfm). """
    
    its = "its"
    """Implementable Technology Specifications (http://www.hl7.org/special/committees/xml/index.cfm). """
    
    mnm = "mnm"
    """Modeling and Methodology (http://www.hl7.org/Special/committees/mnm/index.cfm). """
    
    oo = "oo"
    """Orders and Observations (http://www.hl7.org/Special/committees/orders/index.cfm). """
    
    pa = "pa"
    """Patient Administration (http://www.hl7.org/Special/committees/pafm/index.cfm). """
    
    pc = "pc"
    """Patient Care (http://www.hl7.org/Special/committees/patientcare/index.cfm). """
    
    pher = "pher"
    """Public Health and Emergency Response (http://www.hl7.org/Special/committees/pher/index.cfm). """
    
    phx = "phx"
    """Pharmacy (http://www.hl7.org/Special/committees/medication/index.cfm). """
    
    brr = "brr"
    """Biomedical Research and Regulation (http://www.hl7.org/Special/committees/rcrim/index.cfm). """
    
    sd = "sd"
    """Structured Documents (http://www.hl7.org/Special/committees/structure/index.cfm). """
    
    sec = "sec"
    """Security (http://www.hl7.org/Special/committees/secure/index.cfm). """
    
    us = "us"
    """US Realm Taskforce (http://www.hl7.org/Special/committees/usrealm/index.cfm). """
    
    vocab = "vocab"
    """Vocabulary (http://www.hl7.org/Special/committees/Vocab/index.cfm). """
    
    aid = "aid"
    """Application Implementation and Design (http://www.hl7.org/Special/committees/java/index.cfm). """
    
class HTTPVerb(enum.Enum):
    
    GET = "GET"
    """HTTP GET Command. """
    
    HEAD = "HEAD"
    """HTTP HEAD Command. """
    
    POST = "POST"
    """HTTP POST Command. """
    
    PUT = "PUT"
    """HTTP PUT Command. """
    
    DELETE = "DELETE"
    """HTTP DELETE Command. """
    
    PATCH = "PATCH"
    """HTTP PATCH Command. """
    
class HandlingConditionSet(enum.Enum):
    
    room = "room"
    """room temperature. """
    
    refrigerated = "refrigerated"
    """refrigerated temperature. """
    
    frozen = "frozen"
    """frozen temperature. """
    
class HumanNameAssemblyOrder(enum.Enum):
    
    NL1 = "NL1"
    """NL1 """
    
    NL2 = "NL2"
    """NL2 """
    
    NL3 = "NL3"
    """NL3 """
    
    NL4 = "NL4"
    """NL4 """
    
class ISO210892017HealthRecordLifecycleEvents(enum.Enum):
    
    access = "access"
    """Occurs when an agent causes the system to obtain and open a record entry for inspection or review. """
    
    hold = "hold"
    """Occurs when an agent causes the system to tag or otherwise indicate special access management and suspension of record entry deletion/destruction, if deemed relevant to a lawsuit or which are reasonably anticipated to be relevant or to fulfill organizational policy under the legal doctrine of “duty to preserve”. """
    
    amend = "amend"
    """Occurs when an agent makes any change to record entry content currently residing in storage considered permanent (persistent). """
    
    archive = "archive"
    """Occurs when an agent causes the system to create and move archive artifacts containing record entry content, typically to long-term offline storage. """
    
    attest = "attest"
    """Occurs when an agent causes the system to capture the agent’s digital signature (or equivalent indication) during formal validation of record entry content. """
    
    decrypt = "decrypt"
    """Occurs when an agent causes the system to decode record entry content from a cipher. """
    
    deidentify = "deidentify"
    """Occurs when an agent causes the system to scrub record entry content to reduce the association between a set of identifying data and the data subject in a way that might or might not be reversible. """
    
    deprecate = "deprecate"
    """Occurs when an agent causes the system to tag record entry(ies) as obsolete, erroneous or untrustworthy, to warn against its future use. """
    
    destroy = "destroy"
    """Occurs when an agent causes the system to permanently erase record entry content from the system. """
    
    disclose = "disclose"
    """Occurs when an agent causes the system to release, transfer, provision access to, or otherwise divulge record entry content. """
    
    encrypt = "encrypt"
    """Occurs when an agent causes the system to encode record entry content in a cipher. """
    
    extract = "extract"
    """Occurs when an agent causes the system to selectively pull out a subset of record entry content, based on explicit criteria. """
    
    link = "link"
    """Occurs when an agent causes the system to connect related record entries. """
    
    merge = "merge"
    """Occurs when an agent causes the system to combine or join content from two or more record entries, resulting in a single logical record entry. """
    
    originate = "originate"
    """Occurs when an agent causes the system to: a) initiate capture of potential record content, and b) incorporate that content into the storage considered a permanent part of the health record. """
    
    pseudonymize = "pseudonymize"
    """Occurs when an agent causes the system to remove record entry content to reduce the association between a set of identifying data and the data subject in a way that may be reversible. """
    
    reactivate = "reactivate"
    """Occurs when an agent causes the system to recreate or restore full status to record entries previously deleted or deprecated. """
    
    receive = "receive"
    """Occurs when an agent causes the system to a) initiate capture of data content from elsewhere, and b) incorporate that content into the storage considered a permanent part of the health record. """
    
    reidentify = "reidentify"
    """Occurs when an agent causes the system to restore information to data that allows identification of information source and/or information subject. """
    
    unhold = "unhold"
    """Occurs when an agent causes the system to remove a tag or other cues for special access management had required to fulfill organizational policy under the legal doctrine of “duty to preserve”. """
    
    report = "report"
    """Occurs when an agent causes the system to produce and deliver record entry content in a particular form and manner. """
    
    restore = "restore"
    """Occurs when an agent causes the system to recreate record entries and their content from a previous created archive artefact. """
    
    transform = "transform"
    """Occurs when an agent causes the system to change the form, language or code system used to represent record entry content. """
    
    transmit = "transmit"
    """Occurs when an agent causes the system to send record entry content from one (EHR/PHR/other) system to another. """
    
    unlink = "unlink"
    """Occurs when an agent causes the system to disconnect two or more record entries previously connected, rendering them separate (disconnected) again. """
    
    unmerge = "unmerge"
    """Occurs when an agent causes the system to reverse a previous record entry merge operation, rendering them separate again. """
    
    verify = "verify"
    """Occurs when an agent causes the system to confirm compliance of data or data objects with regulations, requirements, specifications, or other imposed conditions based on organizational policy. """
    
class IdentifierUse(enum.Enum):
    
    usual = "usual"
    """The identifier recommended for display and use in real-world interactions. """
    
    official = "official"
    """The identifier considered to be most trusted for the identification of this item. Sometimes also known as "primary" and "main". The determination of "official" is subjective and implementation guides often provide additional guidelines for use. """
    
    temp = "temp"
    """A temporary identifier. """
    
    secondary = "secondary"
    """An identifier that was assigned in secondary use - it serves to identify the object in a relative context, but cannot be consistently assigned to the same object again in a different context. """
    
    old = "old"
    """The identifier id no longer considered valid, but may be relevant for search purposes.  E.g. Changes to identifier schemes, account merges, etc. """
    
class IdentityAssuranceLevel(enum.Enum):
    
    level1 = "level1"
    """Little or no confidence in the asserted identity's accuracy. """
    
    level2 = "level2"
    """Some confidence in the asserted identity's accuracy. """
    
    level3 = "level3"
    """High confidence in the asserted identity's accuracy. """
    
    level4 = "level4"
    """Very high confidence in the asserted identity's accuracy. """
    
class ImagingStudyStatus(enum.Enum):
    
    registered = "registered"
    """The existence of the imaging study is registered, but there is nothing yet available. """
    
    available = "available"
    """At least one instance has been associated with this imaging study. """
    
    cancelled = "cancelled"
    """The imaging study is unavailable because the imaging study was not started or not completed (also sometimes called "aborted"). """
    
    enteredInError = "entered-in-error"
    """The imaging study has been withdrawn following a previous final release.  This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be "cancelled" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The system does not know which of the status values currently applies for this request. Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, it's just not known which one. """
    
class ImmunizationEvaluationDoseStatusCodes(enum.Enum):
    
    valid = "valid"
    """The dose counts toward fulfilling a path to immunity for a patient, providing protection against the target disease. """
    
    notvalid = "notvalid"
    """The dose does not count toward fulfilling a path to immunity for a patient. """
    
class ImmunizationEvaluationDoseStatusReasonCodes(enum.Enum):
    
    advstorage = "advstorage"
    """The product was stored in a manner inconsistent with manufacturer guidelines potentially reducing the effectiveness of the product. """
    
    coldchbrk = "coldchbrk"
    """The product was stored at a temperature inconsistent with manufacturer guidelines potentially reducing the effectiveness of the product. """
    
    explot = "explot"
    """The product was administered after the expiration date associated with lot of vaccine. """
    
    outsidesched = "outsidesched"
    """The product was administered at a time inconsistent with the documented schedule. """
    
    prodrecall = "prodrecall"
    """The product administered has been recalled by the manufacturer. """
    
class ImmunizationFundingSource(enum.Enum):
    
    private = "private"
    """The vaccine was purchased with private funds. """
    
    public = "public"
    """The vaccine was purchased with public funds. """
    
class ImmunizationOriginCodes(enum.Enum):
    
    provider = "provider"
    """The data for the immunization event originated with another provider. """
    
    record = "record"
    """The data for the immunization event originated with a written record for the patient. """
    
    recall = "recall"
    """The data for the immunization event originated from the recollection of the patient or parent/guardian of the patient. """
    
    school = "school"
    """The data for the immunization event originated with a school record for the patient. """
    
    jurisdiction = "jurisdiction"
    """The data for the immunization event originated with an immunization information system (IIS) or registry operating within the jurisdiction. """
    
class ImmunizationProgramEligibility(enum.Enum):
    
    ineligible = "ineligible"
    """The patient is not eligible for the funding program. """
    
    uninsured = "uninsured"
    """The patient is eligible for the funding program because they are uninsured. """
    
class ImmunizationRecommendationStatusCodes(enum.Enum):
    
    due = "due"
    """The patient is due for their next vaccination. """
    
    overdue = "overdue"
    """The patient is considered overdue for their next vaccination. """
    
    immune = "immune"
    """The patient is immune to the target disease and further immunization against the disease is not likely to provide benefit. """
    
    contraindicated = "contraindicated"
    """The patient is contraindicated for futher doses. """
    
    complete = "complete"
    """The patient is fully protected and no further doses are recommended. """
    
class ImmunizationSubpotentReason(enum.Enum):
    
    partial = "partial"
    """The full volume of the dose was not administered to the patient. """
    
    coldchainbreak = "coldchainbreak"
    """The vaccine experienced a cold chain break. """
    
    recall = "recall"
    """The vaccine was recalled by the manufacturer. """
    
class ImplantStatus(enum.Enum):
    
    functional = "functional"
    """The implanted device is working normally. """
    
    nonFunctional = "non-functional"
    """The implanted device is not working. """
    
    disabled = "disabled"
    """The implanted device has been turned off. """
    
    unknown = "unknown"
    """the functional status of the implant has not been determined. """
    
class Indicator(enum.Enum):
    
    info = "info"
    """info """
    
    warning = "warning"
    """warning """
    
    critical = "critical"
    """critical """
    
class InterventionCodes(enum.Enum):
    
    unknown = "unknown"
    """Unknown """
    
    other = "other"
    """Other """
    
class InvoicePriceComponentType(enum.Enum):
    
    base = "base"
    """the amount is the base price used for calculating the total price before applying surcharges, discount or taxes. """
    
    surcharge = "surcharge"
    """the amount is a surcharge applied on the base price. """
    
    deduction = "deduction"
    """the amount is a deduction applied on the base price. """
    
    discount = "discount"
    """the amount is a discount applied on the base price. """
    
    tax = "tax"
    """the amount is the tax component of the total price. """
    
    informational = "informational"
    """the amount is of informational character, it has not been applied in the calculation of the total price. """
    
class InvoiceStatus(enum.Enum):
    
    draft = "draft"
    """the invoice has been prepared but not yet finalized. """
    
    issued = "issued"
    """the invoice has been finalized and sent to the recipient. """
    
    balanced = "balanced"
    """the invoice has been balaced / completely paid. """
    
    cancelled = "cancelled"
    """the invoice was cancelled. """
    
    enteredInError = "entered-in-error"
    """the invoice was determined as entered in error before it was issued. """
    
class IssueSeverity(enum.Enum):
    
    fatal = "fatal"
    """The issue caused the action to fail and no further checking could be performed. """
    
    error = "error"
    """The issue is sufficiently important to cause the action to fail. """
    
    warning = "warning"
    """The issue is not important enough to cause the action to fail but may cause it to be performed suboptimally or in a way that is not as desired. """
    
    information = "information"
    """The issue has no relation to the degree of success of the action. """
    
class IssueType(enum.Enum):
    
    invalid = "invalid"
    """Content invalid against the specification or a profile. """
    
    structure = "structure"
    """A structural issue in the content such as wrong namespace, unable to parse the content completely, invalid syntax, etc. """
    
    required = "required"
    """A required element is missing. """
    
    value = "value"
    """An element or header value is invalid. """
    
    invariant = "invariant"
    """A content validation rule failed - e.g. a schematron rule. """
    
    security = "security"
    """An authentication/authorization/permissions issue of some kind. """
    
    login = "login"
    """The client needs to initiate an authentication process. """
    
    unknown = "unknown"
    """The user or system was not able to be authenticated (either there is no process, or the proferred token is unacceptable). """
    
    expired = "expired"
    """User session expired; a login may be required. """
    
    forbidden = "forbidden"
    """The user does not have the rights to perform this action. """
    
    suppressed = "suppressed"
    """Some information was not or might not have been returned due to business rules, consent or privacy rules, or access permission constraints.  This information may be accessible through alternate processes. """
    
    processing = "processing"
    """Processing issues. These are expected to be final e.g. there is no point resubmitting the same content unchanged. """
    
    notSupported = "not-supported"
    """The interaction, operation, resource or profile is not supported. """
    
    duplicate = "duplicate"
    """An attempt was made to create a duplicate record. """
    
    multipleMatches = "multiple-matches"
    """Multiple matching records were found when the operation required only one match. """
    
    notFound = "not-found"
    """The reference provided was not found. In a pure RESTful environment, this would be an HTTP 404 error, but this code may be used where the content is not found further into the application architecture. """
    
    deleted = "deleted"
    """The reference pointed to content (usually a resource) that has been deleted. """
    
    tooLong = "too-long"
    """Provided content is too long (typically, this is a denial of service protection type of error). """
    
    codeInvalid = "code-invalid"
    """The code or system could not be understood, or it was not valid in the context of a particular ValueSet.code. """
    
    extension = "extension"
    """An extension was found that was not acceptable, could not be resolved, or a modifierExtension was not recognized. """
    
    tooCostly = "too-costly"
    """The operation was stopped to protect server resources; e.g. a request for a value set expansion on all of SNOMED CT. """
    
    businessRule = "business-rule"
    """The content/operation failed to pass some business rule and so could not proceed. """
    
    conflict = "conflict"
    """Content could not be accepted because of an edit conflict (i.e. version aware updates). (In a pure RESTful environment, this would be an HTTP 409 error, but this code may be used where the conflict is discovered further into the application architecture.). """
    
    transient = "transient"
    """Transient processing issues. The system receiving the message may be able to resubmit the same content once an underlying issue is resolved. """
    
    lockError = "lock-error"
    """A resource/record locking failure (usually in an underlying database). """
    
    noStore = "no-store"
    """The persistent store is unavailable; e.g. the database is down for maintenance or similar action, and the interaction or operation cannot be processed. """
    
    exception = "exception"
    """An unexpected internal error has occurred. """
    
    timeout = "timeout"
    """An internal timeout has occurred. """
    
    incomplete = "incomplete"
    """Not all data sources typically accessed could be reached or responded in time, so the returned information might not be complete (applies to search interactions and some operations). """
    
    throttled = "throttled"
    """The system is not prepared to handle this request due to load management. """
    
    informational = "informational"
    """A message unrelated to the processing success of the completed operation (examples of the latter include things like reminders of password expiry, system maintenance times, etc.). """
    
class KnowledgeResourceType(enum.Enum):
    
    activityDefinition = "ActivityDefinition"
    """The definition of a specific activity to be taken, independent of any particular patient or context. """
    
    codeSystem = "CodeSystem"
    """A set of codes drawn from one or more code systems. """
    
    conceptMap = "ConceptMap"
    """A map from one set of concepts to one or more other concepts. """
    
    library = "Library"
    """Represents a library of quality improvement components. """
    
    measure = "Measure"
    """A quality measure definition. """
    
    planDefinition = "PlanDefinition"
    """The definition of a plan for a series of actions, independent of any specific patient or context. """
    
    structureDefinition = "StructureDefinition"
    """Structural Definition. """
    
    structureMap = "StructureMap"
    """A Map of relationships between 2 structures that can be used to transform data. """
    
    valueSet = "ValueSet"
    """A set of codes drawn from one or more code systems. """
    
class LanguagePreferenceType(enum.Enum):
    
    verbal = "verbal"
    """The patient prefers to verbally communicate with the associated language. """
    
    written = "written"
    """The patient prefers to communicate in writing with the associated language. """
    
class LibraryType(enum.Enum):
    
    logicLibrary = "logic-library"
    """The resource is a shareable library of formalized knowledge. """
    
    modelDefinition = "model-definition"
    """The resource is a definition of an information model. """
    
    assetCollection = "asset-collection"
    """The resource is a collection of knowledge assets. """
    
    moduleDefinition = "module-definition"
    """The resource defines the dependencies, parameters, and data requirements for a particular module or evaluation context. """
    
class LinkType(enum.Enum):
    
    replacedBy = "replaced-by"
    """The patient resource containing this link must no longer be used. The link points forward to another patient resource that must be used in lieu of the patient resource that contains this link. """
    
    replaces = "replaces"
    """The patient resource containing this link is the current active patient record. The link points back to an inactive patient resource that has been merged into this resource, and should be consulted to retrieve additional referenced information. """
    
    refer = "refer"
    """The patient resource containing this link is in use and valid but not considered the main source of information about a patient. The link points forward to another patient resource that should be consulted to retrieve additional patient information. """
    
    seealso = "seealso"
    """The patient resource containing this link is in use and valid, but points to another patient resource that is known to contain data about the same person. Data in this resource might overlap or contradict information found in the other patient resource. This link does not indicate any relative importance of the resources concerned, and both should be regarded as equally valid. """
    
class LinkageType(enum.Enum):
    
    source = "source"
    """The resource represents the "source of truth" (from the perspective of this Linkage resource) for the underlying event/condition/etc. """
    
    alternate = "alternate"
    """The resource represents an alternative view of the underlying event/condition/etc.  The resource may still be actively maintained, even though it is not considered to be the source of truth. """
    
    historical = "historical"
    """The resource represents an obsolete record of the underlying event/condition/etc.  It is not expected to be actively maintained. """
    
class ListEmptyReasons(enum.Enum):
    
    nilknown = "nilknown"
    """Clinical judgment that there are no known items for this list after reasonable investigation. Note that this a positive statement by a clinical user, and not a default position asserted by a computer system in the lack of other information. Example uses:  * For allergies: the patient or patient's agent/guardian has asserted that he/she is not aware of any allergies (NKA - nil known allergies)  * For medications: the patient or patient's agent/guardian has asserted that the patient is known to be taking no medications  * For diagnoses, problems and procedures: the patient or patient's agent/guardian has asserted that there is no known event to record. """
    
    notasked = "notasked"
    """The investigation to find out whether there are items for this list has not occurred. """
    
    withheld = "withheld"
    """The content of the list was not provided due to privacy or confidentiality concerns. Note that it should not be assumed that this means that the particular information in question was withheld due to its contents - it can also be a policy decision. """
    
    unavailable = "unavailable"
    """Information to populate this list cannot be obtained; e.g. unconscious patient. """
    
    notstarted = "notstarted"
    """The work to populate this list has not yet begun. """
    
    closed = "closed"
    """This list has now closed or has ceased to be relevant or useful. """
    
class ListMode(enum.Enum):
    
    working = "working"
    """This list is the master list, maintained in an ongoing fashion with regular updates as the real world list it is tracking changes. """
    
    snapshot = "snapshot"
    """This list was prepared as a snapshot. It should not be assumed to be current. """
    
    changes = "changes"
    """A point-in-time list that shows what changes have been made or recommended.  E.g. a discharge medication list showing what was added and removed during an encounter. """
    
class ListOrderCodes(enum.Enum):
    
    user = "user"
    """The list was sorted by a user. The criteria the user used are not specified. """
    
    system = "system"
    """The list was sorted by the system. The criteria the user used are not specified; define additional codes to specify a particular order (or use other defined codes). """
    
    eventDate = "event-date"
    """The list is sorted by the data of the event. This can be used when the list has items which are dates with past or future events. """
    
    entryDate = "entry-date"
    """The list is sorted by the date the item was added to the list. Note that the date added to the list is not explicit in the list itself. """
    
    priority = "priority"
    """The list is sorted by priority. The exact method in which priority has been determined is not specified. """
    
    alphabetic = "alphabetic"
    """The list is sorted alphabetically by an unspecified property of the items in the list. """
    
    category = "category"
    """The list is sorted categorically by an unspecified property of the items in the list. """
    
    patient = "patient"
    """The list is sorted by patient, with items for each patient grouped together. """
    
class ListStatus(enum.Enum):
    
    current = "current"
    """The list is considered to be an active part of the patient's record. """
    
    retired = "retired"
    """The list is "old" and should no longer be considered accurate or relevant. """
    
    enteredInError = "entered-in-error"
    """The list was never accurate.  It is retained for medico-legal purposes only. """
    
class LocationMode(enum.Enum):
    
    instance = "instance"
    """The Location resource represents a specific instance of a location (e.g. Operating Theatre 1A). """
    
    kind = "kind"
    """The Location represents a class of locations (e.g. Any Operating Theatre) although this class of locations could be constrained within a specific boundary (such as organization, or parent location, address etc.). """
    
class LocationStatus(enum.Enum):
    
    active = "active"
    """The location is operational. """
    
    suspended = "suspended"
    """The location is temporarily closed. """
    
    inactive = "inactive"
    """The location is no longer used. """
    
class LocationType(enum.Enum):
    
    si = "si"
    """A collection of buildings or other locations such as a site or a campus. """
    
    bu = "bu"
    """Any Building or structure. This may contain rooms, corridors, wings, etc. It might not have walls, or a roof, but is considered a defined/allocated space. """
    
    wi = "wi"
    """A Wing within a Building, this often contains levels, rooms and corridors. """
    
    wa = "wa"
    """A Ward is a section of a medical facility that may contain rooms and other types of location. """
    
    lvl = "lvl"
    """A Level in a multi-level Building/Structure. """
    
    co = "co"
    """Any corridor within a Building, that may connect rooms. """
    
    ro = "ro"
    """A space that is allocated as a room, it may have walls/roof etc., but does not require these. """
    
    bd = "bd"
    """A space that is allocated for sleeping/laying on. This is not the physical bed/trolley that may be moved about, but the space it may occupy. """
    
    ve = "ve"
    """A means of transportation. """
    
    ho = "ho"
    """A residential dwelling. Usually used to reference a location that a person/patient may reside. """
    
    ca = "ca"
    """A container that can store goods, equipment, medications or other items. """
    
    rd = "rd"
    """A defined path to travel between 2 points that has a known name. """
    
    area = "area"
    """A defined physical boundary of something, such as a flood risk zone, region, postcode """
    
    jdn = "jdn"
    """A wide scope that covers a conceptual domain, such as a Nation (Country wide community or Federal Government - e.g. Ministry of Health),  Province or State (community or Government), Business (throughout the enterprise), Nation with a business scope of an agency (e.g. CDC, FDA etc.) or a Business segment (UK Pharmacy), not just an physical boundary """
    
class MatchGrade(enum.Enum):
    
    certain = "certain"
    """This record meets the matching criteria to be automatically considered as a full match. """
    
    probable = "probable"
    """This record is a close match, but not a certain match. Additional review (e.g. by a human) may be required before using this as a match. """
    
    possible = "possible"
    """This record may be a matching one. Additional review (e.g. by a human) SHOULD be performed before using this as a match. """
    
    certainlyNot = "certainly-not"
    """This record is known not to be a match. Note that usually non-matching records are not returned, but in some cases records previously or likely considered as a match may specifically be negated by the matching engine. """
    
class MaxOccurs(enum.Enum):
    
    max = "*"
    """Element can repeat an unlimited number of times. """
    
class MeasureDataUsage(enum.Enum):
    
    supplementalData = "supplemental-data"
    """The data is intended to be provided as additional information alongside the measure results. """
    
    riskAdjustmentFactor = "risk-adjustment-factor"
    """The data is intended to be used to calculate and apply a risk adjustment model for the measure. """
    
class MeasureImprovementNotation(enum.Enum):
    
    increase = "increase"
    """Improvement is indicated as an increase in the score or measurement (e.g. Higher score indicates better quality). """
    
    decrease = "decrease"
    """Improvement is indicated as a decrease in the score or measurement (e.g. Lower score indicates better quality). """
    
class MeasurePopulationType(enum.Enum):
    
    initialPopulation = "initial-population"
    """The initial population refers to all patients or events to be evaluated by a quality measure involving patients who share a common set of specified characterstics. All patients or events counted (for example, as numerator, as denominator) are drawn from the initial population. """
    
    numerator = "numerator"
    """The upper portion of a fraction used to calculate a rate, proportion, or ratio. Also called the measure focus, it is the target process, condition, event, or outcome. Numerator criteria are the processes or outcomes expected for each patient, or event defined in the denominator. A numerator statement describes the clinical action that satisfies the conditions of the measure. """
    
    numeratorExclusion = "numerator-exclusion"
    """Numerator exclusion criteria define patients or events to be removed from the numerator. Numerator exclusions are used in proportion and ratio measures to help narrow the numerator (for inverted measures). """
    
    denominator = "denominator"
    """The lower portion of a fraction used to calculate a rate, proportion, or ratio. The denominator can be the same as the initial population, or a subset of the initial population to further constrain the population for the purpose of the measure. """
    
    denominatorExclusion = "denominator-exclusion"
    """Denominator exclusion criteria define patients or events that should be removed from the denominator before determining if numerator criteria are met. Denominator exclusions are used in proportion and ratio measures to help narrow the denominator. For example, patients with bilateral lower extremity amputations would be listed as a denominator exclusion for a measure requiring foot exams. """
    
    denominatorException = "denominator-exception"
    """Denominator exceptions are conditions that should remove a patient or event from the denominator of a measure only if the numerator criteria are not met. Denominator exception allows for adjustment of the calculated score for those providers with higher risk populations. Denominator exception criteria are only used in proportion measures. """
    
    measurePopulation = "measure-population"
    """Measure population criteria define the patients or events for which the individual observation for the measure should be taken. Measure populations are used for continuous variable measures rather than numerator and denominator criteria. """
    
    measurePopulationExclusion = "measure-population-exclusion"
    """Measure population criteria define the patients or events that should be removed from the measure population before determining the outcome of one or more continuous variables defined for the measure observation. Measure population exclusion criteria are used within continuous variable measures to help narrow the measure population. """
    
    measureObservation = "measure-observation"
    """Defines the individual observation to be performed for each patient or event in the measure population. Measure observations for each case in the population are aggregated to determine the overall measure score for the population. """
    
class MeasureReportStatus(enum.Enum):
    
    complete = "complete"
    """The report is complete and ready for use. """
    
    pending = "pending"
    """The report is currently being generated. """
    
    error = "error"
    """An error occurred attempting to generate the report. """
    
class MeasureReportType(enum.Enum):
    
    individual = "individual"
    """An individual report that provides information on the performance for a given measure with respect to a single subject. """
    
    subjectList = "subject-list"
    """A subject list report that includes a listing of subjects that satisfied each population criteria in the measure. """
    
    summary = "summary"
    """A summary report that returns the number of members in each population criteria for the measure. """
    
    dataCollection = "data-collection"
    """A data collection report that contains data-of-interest for the measure. """
    
class MeasureScoring(enum.Enum):
    
    proportion = "proportion"
    """The measure score is defined using a proportion. """
    
    ratio = "ratio"
    """The measure score is defined using a ratio. """
    
    continuousVariable = "continuous-variable"
    """The score is defined by a calculation of some quantity. """
    
    cohort = "cohort"
    """The measure is a cohort definition. """
    
class MeasureType(enum.Enum):
    
    process = "process"
    """A measure which focuses on a process which leads to a certain outcome, meaning that a scientific basis exists for believing that the process, when executed well, will increase the probability of achieving a desired outcome. """
    
    outcome = "outcome"
    """A measure that indicates the result of the performance (or non-performance) of a function or process. """
    
    structure = "structure"
    """A measure that focuses on a health care provider's capacity, systems, and processes to provide high-quality care. """
    
    patientReportedOutcome = "patient-reported-outcome"
    """A measure that focuses on patient-reported information such as patient engagement or patient experience measures. """
    
    composite = "composite"
    """A measure that combines multiple component measures in to a single quality measure. """
    
class MediaModality(enum.Enum):
    
    diagram = "diagram"
    """A diagram. Often used in diagnostic reports """
    
    fax = "fax"
    """A digital record of a fax document """
    
    scan = "scan"
    """A digital scan of a document. This is reserved for when there is not enough metadata to create a document reference """
    
    retina = "retina"
    """A retinal image used for identification purposes """
    
    fingerprint = "fingerprint"
    """A finger print scan used for identification purposes """
    
    iris = "iris"
    """An iris scan used for identification purposes """
    
    palm = "palm"
    """A palm scan used for identification purposes """
    
    face = "face"
    """A face scan used for identification purposes """
    
class MediaType(enum.Enum):
    
    image = "image"
    """The media consists of one or more unmoving images, including photographs, computer-generated graphs and charts, and scanned documents """
    
    video = "video"
    """The media consists of a series of frames that capture a moving image """
    
    audio = "audio"
    """The media consists of a sound recording """
    
class MedicationAdministrationCategoryCodes(enum.Enum):
    
    inpatient = "inpatient"
    """Includes administrations in an inpatient or acute care setting """
    
    outpatient = "outpatient"
    """Includes administrations in an outpatient setting (for example, Emergency Department, Outpatient Clinic, Outpatient Surgery, Doctor's office) """
    
    community = "community"
    """Includes administrations by the patient in their home (this would include long term care or nursing homes, hospices, etc.) """
    
class MedicationAdministrationPerformerFunctionCodes(enum.Enum):
    
    performer = "performer"
    """A person, non-person living subject, organization or device that who actually and principally carries out the action """
    
    verifier = "verifier"
    """A person who verifies the correctness and appropriateness of the service (plan, order, event, etc.) and hence takes on accountability. """
    
    witness = "witness"
    """A person witnessing the action happening without doing anything. A witness is not necessarily aware, much less approves of anything stated in the service event. Example for a witness is students watching an operation or an advanced directive witness. """
    
class MedicationAdministrationStatusCodes(enum.Enum):
    
    inProgress = "in-progress"
    """The administration has started but has not yet completed. """
    
    notDone = "not-done"
    """The administration was terminated prior to any impact on the subject (though preparatory actions may have been taken) """
    
    onHold = "on-hold"
    """Actions implied by the administration have been temporarily halted, but are expected to continue later. May also be called 'suspended'. """
    
    completed = "completed"
    """All actions that are implied by the administration have occurred. """
    
    enteredInError = "entered-in-error"
    """The administration was entered in error and therefore nullified. """
    
    stopped = "stopped"
    """Actions implied by the administration have been permanently halted, before all of them occurred. """
    
    unknown = "unknown"
    """The authoring system does not know which of the status values currently applies for this request. Note: This concept is not to be used for 'other' - one of the listed statuses is presumed to apply, it's just not known which one. """
    
class MedicationDispenseCategoryCodes(enum.Enum):
    
    inpatient = "inpatient"
    """Includes dispenses for medications to be administered or consumed in an inpatient or acute care setting. """
    
    outpatient = "outpatient"
    """Includes dispenses for medications to be administered or consumed in an outpatient setting (for example, Emergency Department, Outpatient Clinic, Outpatient Surgery, Doctor's office). """
    
    community = "community"
    """Includes dispenses for medications to be administered or consumed by the patient in their home (this would include long term care or nursing homes, hospices, etc.). """
    
    discharge = "discharge"
    """Includes dispenses for medications created when the patient is being released from a facility. """
    
class MedicationDispensePerformerFunctionCodes(enum.Enum):
    
    dataenterer = "dataenterer"
    """Recorded the details of the request """
    
    packager = "packager"
    """Prepared the medication. """
    
    checker = "checker"
    """Performed initial quality assurance on the prepared medication """
    
    finalchecker = "finalchecker"
    """Performed the final quality assurance on the prepared medication against the request. Typically, this is a pharmacist function. """
    
class MedicationDispenseStatusCodes(enum.Enum):
    
    preparation = "preparation"
    """The core event has not started yet, but some staging activities have begun (e.g. initial compounding or packaging of medication). Preparation stages may be tracked for billing purposes. """
    
    inProgress = "in-progress"
    """The dispensed product is ready for pickup. """
    
    cancelled = "cancelled"
    """The dispensed product was not and will never be picked up by the patient. """
    
    onHold = "on-hold"
    """The dispense process is paused while waiting for an external event to reactivate the dispense.  For example, new stock has arrived or the prescriber has called. """
    
    completed = "completed"
    """The dispensed product has been picked up. """
    
    enteredInError = "entered-in-error"
    """The dispense was entered in error and therefore nullified. """
    
    stopped = "stopped"
    """Actions implied by the dispense have been permanently halted, before all of them occurred. """
    
    declined = "declined"
    """The dispense was declined and not performed. """
    
    unknown = "unknown"
    """The authoring system does not know which of the status values applies for this medication dispense.  Note: this concept is not to be used for other - one of the listed statuses is presumed to apply, it's just now known which one. """
    
class MedicationDispenseStatusReasonCodes(enum.Enum):
    
    frr01 = "frr01"
    """The order has been stopped by the prescriber but this fact has not necessarily captured electronically. Example: A verbal stop, a fax, etc. """
    
    frr02 = "frr02"
    """Order has not been fulfilled within a reasonable amount of time, and might not be current. """
    
    frr03 = "frr03"
    """Data needed to safely act on the order which was expected to become available independent of the order is not yet available. Example: Lab results, diagnostic imaging, etc. """
    
    frr04 = "frr04"
    """Product not available or manufactured. Cannot supply. """
    
    frr05 = "frr05"
    """The dispenser has ethical, religious or moral objections to fulfilling the order/dispensing the product. """
    
    frr06 = "frr06"
    """Fulfiller not able to provide appropriate care associated with fulfilling the order. Example: Therapy requires ongoing monitoring by fulfiller and fulfiller will be ending practice, leaving town, unable to schedule necessary time, etc. """
    
    altchoice = "altchoice"
    """This therapy has been ordered as a backup to a preferred therapy. This order will be released when and if the preferred therapy is unsuccessful. """
    
    clarif = "clarif"
    """Clarification is required before the order can be acted upon. """
    
    drughigh = "drughigh"
    """The current level of the medication in the patient's system is too high. The medication is suspended to allow the level to subside to a safer level. """
    
    hospadm = "hospadm"
    """The patient has been admitted to a care facility and their community medications are suspended until hospital discharge. """
    
    labint = "labint"
    """The therapy would interfere with a planned lab test and the therapy is being withdrawn until the test is completed. """
    
    nonAvail = "non-avail"
    """Patient not available for a period of time due to a scheduled therapy, leave of absence or other reason. """
    
    preg = "preg"
    """The patient is pregnant or breast feeding. The therapy will be resumed when the pregnancy is complete and the patient is no longer breastfeeding. """
    
    saig = "saig"
    """The patient is believed to be allergic to a substance that is part of the therapy and the therapy is being temporarily withdrawn to confirm. """
    
    sddi = "sddi"
    """The drug interacts with a short-term treatment that is more urgently required. This order will be resumed when the short-term treatment is complete. """
    
    sdupther = "sdupther"
    """Another short-term co-occurring therapy fulfills the same purpose as this therapy. This therapy will be resumed when the co-occuring therapy is complete. """
    
    sintol = "sintol"
    """The patient is believed to have an intolerance to a substance that is part of the therapy and the therapy is being temporarily withdrawn to confirm. """
    
    surg = "surg"
    """The drug is contraindicated for patients receiving surgery and the patient is scheduled to be admitted for surgery in the near future. The drug will be resumed when the patient has sufficiently recovered from the surgery. """
    
    washout = "washout"
    """The patient was previously receiving a medication contraindicated with the current medication. The current medication will remain on hold until the prior medication has been cleansed from their system. """
    
    outofstock = "outofstock"
    """Drug out of stock. Cannot supply. """
    
    offmarket = "offmarket"
    """Drug no longer marketed Cannot supply. """
    
class MedicationKnowledgeCharacteristicCodes(enum.Enum):
    
    imprintcd = "imprintcd"
    """Identyifying marks on product """
    
    size = "size"
    """Description of size of the product """
    
    shape = "shape"
    """Description of the shape of the product """
    
    color = "color"
    """Description of the color of the product """
    
    coating = "coating"
    """Description of the coating of the product """
    
    scoring = "scoring"
    """Description of the scoring of the product """
    
    logo = "logo"
    """Description of the Logo of the product """
    
class MedicationKnowledgePackageTypeCodes(enum.Enum):
    
    amp = "amp"
    """amp """
    
    bag = "bag"
    """bag """
    
    blstrpk = "blstrpk"
    """blstrpk """
    
    bot = "bot"
    """bot """
    
    box = "box"
    """box """
    
    can = "can"
    """can """
    
    cart = "cart"
    """cart """
    
    disk = "disk"
    """disk """
    
    doset = "doset"
    """doset """
    
    jar = "jar"
    """jar """
    
    jug = "jug"
    """jug """
    
    minim = "minim"
    """minim """
    
    nebamp = "nebamp"
    """nebamp """
    
    ovul = "ovul"
    """ovul """
    
    pch = "pch"
    """pch """
    
    pkt = "pkt"
    """pkt """
    
    sash = "sash"
    """sash """
    
    strip = "strip"
    """strip """
    
    tin = "tin"
    """tin """
    
    tub = "tub"
    """tub """
    
    tube = "tube"
    """tube """
    
    vial = "vial"
    """vial """
    
class MedicationKnowledgeStatusCodes(enum.Enum):
    
    active = "active"
    """The medication is available for use. """
    
    inactive = "inactive"
    """The medication is not available for use. """
    
    enteredInError = "entered-in-error"
    """The medication was entered in error. """
    
class MedicationRequestCategoryCodes(enum.Enum):
    
    inpatient = "inpatient"
    """Includes requests for medications to be administered or consumed in an inpatient or acute care setting """
    
    outpatient = "outpatient"
    """Includes requests for medications to be administered or consumed in an outpatient setting (for example, Emergency Department, Outpatient Clinic, Outpatient Surgery, Doctor's office) """
    
    community = "community"
    """Includes requests for medications to be administered or consumed by the patient in their home (this would include long term care or nursing homes, hospices, etc.) """
    
    discharge = "discharge"
    """Includes requests for medications created when the patient is being released from a facility """
    
class MedicationRequestCourseOfTherapyCodes(enum.Enum):
    
    continuous = "continuous"
    """A medication which is expected to be continued beyond the present order and which the patient should be assumed to be taking unless explicitly stopped. """
    
    acute = "acute"
    """A medication which the patient is only expected to consume for the duration of the current order and which is not expected to be renewed. """
    
    seasonal = "seasonal"
    """A medication which is expected to be used on a part time basis at certain times of the year """
    
class MedicationRequestIntent(enum.Enum):
    
    proposal = "proposal"
    """The request is a suggestion made by someone/something that doesn't have an intention to ensure it occurs and without providing an authorization to act """
    
    plan = "plan"
    """The request represents an intention to ensure something occurs without providing an authorization for others to act. """
    
    order = "order"
    """The request represents a request/demand and authorization for action """
    
    originalOrder = "original-order"
    """The request represents the original authorization for the medication request. """
    
    reflexOrder = "reflex-order"
    """The request represents an automatically generated supplemental authorization for action based on a parent authorization together with initial results of the action taken against that parent authorization.. """
    
    fillerOrder = "filler-order"
    """The request represents the view of an authorization instantiated by a fulfilling system representing the details of the fulfiller's intention to act upon a submitted order. """
    
    instanceOrder = "instance-order"
    """The request represents an instance for the particular order, for example a medication administration record. """
    
    option = "option"
    """The request represents a component or option for a RequestGroup that establishes timing, conditionality and/or  other constraints among a set of requests. """
    
class MedicationRequestStatusReasonCodes(enum.Enum):
    
    altchoice = "altchoice"
    """This therapy has been ordered as a backup to a preferred therapy. This order will be released when and if the preferred therapy is unsuccessful. """
    
    clarif = "clarif"
    """Clarification is required before the order can be acted upon. """
    
    drughigh = "drughigh"
    """The current level of the medication in the patient's system is too high. The medication is suspended to allow the level to subside to a safer level. """
    
    hospadm = "hospadm"
    """The patient has been admitted to a care facility and their community medications are suspended until hospital discharge. """
    
    labint = "labint"
    """The therapy would interfere with a planned lab test and the therapy is being withdrawn until the test is completed. """
    
    nonAvail = "non-avail"
    """Patient not available for a period of time due to a scheduled therapy, leave of absence or other reason. """
    
    preg = "preg"
    """The patient is pregnant or breast feeding. The therapy will be resumed when the pregnancy is complete and the patient is no longer breastfeeding. """
    
    salg = "salg"
    """The patient is believed to be allergic to a substance that is part of the therapy and the therapy is being temporarily withdrawn to confirm. """
    
    sddi = "sddi"
    """The drug interacts with a short-term treatment that is more urgently required. This order will be resumed when the short-term treatment is complete. """
    
    sdupther = "sdupther"
    """The drug interacts with a short-term treatment that is more urgently required. This order will be resumed when the short-term treatment is complete. """
    
    sintol = "sintol"
    """The drug interacts with a short-term treatment that is more urgently required. This order will be resumed when the short-term treatment is complete. """
    
    surg = "surg"
    """The drug is contraindicated for patients receiving surgery and the patient is scheduled to be admitted for surgery in the near future. The drug will be resumed when the patient has sufficiently recovered from the surgery. """
    
    washout = "washout"
    """The patient was previously receiving a medication contraindicated with the current medication. The current medication will remain on hold until the prior medication has been cleansed from their system. """
    
class MedicationStatusCodes(enum.Enum):
    
    active = "active"
    """The medication is still being taken. """
    
    completed = "completed"
    """The medication is no longer being taken. """
    
    enteredInError = "entered-in-error"
    """Some of the actions that are implied by the medication statement may have occurred.  For example, the patient may have taken some of the medication.  Clinical decision support systems should take this status into account. """
    
    intended = "intended"
    """The medication may be taken at some time in the future. """
    
    stopped = "stopped"
    """Actions implied by the statement have been permanently halted, before all of them occurred. This should not be used if the statement was entered in error. """
    
    onHold = "on-hold"
    """Actions implied by the statement have been temporarily halted, but are expected to continue later. May also be called 'suspended'. """
    
    unknown = "unknown"
    """The state of the medication use is not currently known. """
    
    notTaken = "not-taken"
    """The medication was not consumed by the patient """
    
class MedicationStatusCodes(enum.Enum):
    
    active = "active"
    """The medication is available for use. """
    
    inactive = "inactive"
    """The medication is not available for use. """
    
    enteredInError = "entered-in-error"
    """The medication was entered in error. """
    
class MedicationUsageCategoryCodes(enum.Enum):
    
    inpatient = "inpatient"
    """Includes orders for medications to be administered or consumed in an inpatient or acute care setting """
    
    outpatient = "outpatient"
    """Includes orders for medications to be administered or consumed in an outpatient setting (for example, Emergency Department, Outpatient Clinic, Outpatient Surgery, Doctor's office) """
    
    community = "community"
    """Includes orders for medications to be administered or consumed by the patient in their home (this would include long term care or nursing homes, hospices, etc.). """
    
    patientspecified = "patientspecified"
    """Includes statements about medication use, including over the counter medication, provided by the patient, agent or another provider """
    
class MedicationrequestStatus(enum.Enum):
    
    active = "active"
    """The prescription is 'actionable', but not all actions that are implied by it have occurred yet. """
    
    onHold = "on-hold"
    """Actions implied by the prescription are to be temporarily halted, but are expected to continue later.  May also be called 'suspended'. """
    
    cancelled = "cancelled"
    """The prescription has been withdrawn before any administrations have occurred """
    
    completed = "completed"
    """All actions that are implied by the prescription have occurred. """
    
    enteredInError = "entered-in-error"
    """Some of the actions that are implied by the medication request may have occurred.  For example, the medication may have been dispensed and the patient may have taken some of the medication.  Clinical decision support systems should take this status into account """
    
    stopped = "stopped"
    """Actions implied by the prescription are to be permanently halted, before all of the administrations occurred. This should not be used if the original order was entered in error """
    
    draft = "draft"
    """The prescription is not yet 'actionable', e.g. it is a work in progress, requires sign-off, verification or needs to be run through decision support process. """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this observation. Note: This concept is not to be used for 'other' - one of the listed statuses is presumed to apply, but the authoring/source system does not know which. """
    
class MessageSignificanceCategory(enum.Enum):
    
    consequence = "consequence"
    """The message represents/requests a change that should not be processed more than once; e.g., making a booking for an appointment. """
    
    currency = "currency"
    """The message represents a response to query for current information. Retrospective processing is wrong and/or wasteful. """
    
    notification = "notification"
    """The content is not necessarily intended to be current, and it can be reprocessed, though there may be version issues created by processing old notifications. """
    
class MessageTransport(enum.Enum):
    
    http = "http"
    """The application sends or receives messages using HTTP POST (may be over http: or https:). """
    
    ftp = "ftp"
    """The application sends or receives messages using File Transfer Protocol. """
    
    mllp = "mllp"
    """The application sends or receives messages using HL7's Minimal Lower Level Protocol. """
    
class MessageheaderResponseRequest(enum.Enum):
    
    always = "always"
    """initiator expects a response for this message. """
    
    onError = "on-error"
    """initiator expects a response only if in error. """
    
    never = "never"
    """initiator does not expect a response. """
    
    onSuccess = "on-success"
    """initiator expects a response only if successful. """
    
class MissingToothReasonCodes(enum.Enum):
    
    E = "e"
    """Extraction """
    
    C = "c"
    """Congenital """
    
    U = "u"
    """Unknown """
    
    O = "o"
    """Other """
    
class ModifierTypeCodes(enum.Enum):
    
    A = "a"
    """Repair of prior service or installation. """
    
    B = "b"
    """Temporary service or installation. """
    
    C = "c"
    """Treatment associated with TMJ. """
    
    E = "e"
    """Implant or associated with an implant. """
    
    rooh = "rooh"
    """A Rush service or service performed outside of normal office hours. """
    
    X = "x"
    """None. """
    
class NHINPurposeOfUse(enum.Enum):
    
    TREATMENT = "TREATMENT"
    """Treatment """
    
    PAYMENT = "PAYMENT"
    """Payment """
    
    OPERATIONS = "OPERATIONS"
    """Healthcare Operations """
    
    SYSADMIN = "SYSADMIN"
    """System Administration """
    
    FRAUD = "FRAUD"
    """Fraud detection """
    
    PSYCHOTHERAPY = "PSYCHOTHERAPY"
    """Use or disclosure of Psychotherapy Notes """
    
    TRAINING = "TRAINING"
    """Use or disclosure by the covered entity for its own training programs """
    
    LEGAL = "LEGAL"
    """Use or disclosure by the covered entity to defend itself in a legal action """
    
    MARKETING = "MARKETING"
    """Marketing """
    
    DIRECTORY = "DIRECTORY"
    """Use and disclosure for facility directories """
    
    FAMILY = "FAMILY"
    """Disclose to a family member, other relative, or a close personal friend of the individual """
    
    PRESENT = "PRESENT"
    """Uses and disclosures with the individual present. """
    
    EMERGENCY = "EMERGENCY"
    """Permission cannot practicably be provided because of the individual's incapacity or an emergency. """
    
    DISASTER = "DISASTER"
    """Use and disclosures for disaster relief purposes. """
    
    PUBLICHEALTH = "PUBLICHEALTH"
    """Uses and disclosures for public health activities. """
    
    ABUSE = "ABUSE"
    """Disclosures about victims of abuse, neglect or domestic violence. """
    
    OVERSIGHT = "OVERSIGHT"
    """Uses and disclosures for health oversight activities. """
    
    JUDICIAL = "JUDICIAL"
    """Disclosures for judicial and administrative proceedings. """
    
    LAW = "LAW"
    """Disclosures for law enforcement purposes. """
    
    DECEASED = "DECEASED"
    """Uses and disclosures about decedents. """
    
    DONATION = "DONATION"
    """Uses and disclosures for cadaveric organ,  eye or tissue donation purposes """
    
    RESEARCH = "RESEARCH"
    """Uses and disclosures for research purposes. """
    
    THREAT = "THREAT"
    """Uses and disclosures to avert a serious threat to health or safety. """
    
    GOVERNMENT = "GOVERNMENT"
    """Uses and disclosures for specialized government functions. """
    
    WORKERSCOMP = "WORKERSCOMP"
    """Disclosures for workers' compensation. """
    
    COVERAGE = "COVERAGE"
    """Disclosures for insurance or disability coverage determination """
    
    REQUEST = "REQUEST"
    """Request of the Individual """
    
class NameUse(enum.Enum):
    
    usual = "usual"
    """Known as/conventional/the one you normally use. """
    
    official = "official"
    """The formal name as registered in an official (government) registry, but which name might not be commonly used. May be called "legal name". """
    
    temp = "temp"
    """A temporary name. Name.period can provide more detailed information. This may also be used for temporary names assigned at birth or in emergency situations. """
    
    nickname = "nickname"
    """A name that is used to address the person in an informal manner, but is not part of their formal or usual name. """
    
    anonymous = "anonymous"
    """Anonymous assigned name, alias, or pseudonym (used to protect a person's identity for privacy reasons). """
    
    old = "old"
    """This name is no longer in use (or was never correct, but retained for records). """
    
    maiden = "maiden"
    """A name used prior to changing name because of marriage. This name use is for use by applications that collect and store names that were used prior to a marriage. Marriage naming customs vary greatly around the world, and are constantly changing. This term is not gender specific. The use of this term does not imply any particular history for a person's name. """
    
class NamingSystemIdentifierType(enum.Enum):
    
    oid = "oid"
    """An ISO object identifier; e.g. 1.2.3.4.5. """
    
    uuid = "uuid"
    """A universally unique identifier of the form a5afddf4-e880-459b-876e-e4591b0acc11. """
    
    uri = "uri"
    """A uniform resource identifier (ideally a URL - uniform resource locator); e.g. http://unitsofmeasure.org. """
    
    other = "other"
    """Some other type of unique identifier; e.g. HL7-assigned reserved string such as LN for LOINC. """
    
class NamingSystemType(enum.Enum):
    
    codesystem = "codesystem"
    """The naming system is used to define concepts and symbols to represent those concepts; e.g. UCUM, LOINC, NDC code, local lab codes, etc. """
    
    identifier = "identifier"
    """The naming system is used to manage identifiers (e.g. license numbers, order numbers, etc.). """
    
    root = "root"
    """The naming system is used as the root for other identifiers and naming systems. """
    
class NarrativeStatus(enum.Enum):
    
    generated = "generated"
    """The contents of the narrative are entirely generated from the core elements in the content. """
    
    extensions = "extensions"
    """The contents of the narrative are entirely generated from the core elements in the content and some of the content is generated from extensions. The narrative SHALL reflect the impact of all modifier extensions. """
    
    additional = "additional"
    """The contents of the narrative may contain additional information not found in the structured data. Note that there is no computable way to determine what the extra information is, other than by human inspection. """
    
    empty = "empty"
    """The contents of the narrative are some equivalent of "No human-readable text provided in this case". """
    
class Need(enum.Enum):
    
    none = "none"
    """***TODO*** """
    
    initial = "initial"
    """***TODO*** """
    
    periodic = "periodic"
    """***TODO*** """
    
class NetworkTypeCodes(enum.Enum):
    
    in_ = "in"
    """Services rendered by a Network provider """
    
    out = "out"
    """Services rendered by a provider who is not in the Network """
    
class NoteType(enum.Enum):
    
    display = "display"
    """Display the note. """
    
    print = "print"
    """Print the note on the form. """
    
    printoper = "printoper"
    """Print the note for the operator. """
    
class ObservationCategoryCodes(enum.Enum):
    
    socialHistory = "social-history"
    """Social History Observations define the patient's occupational, personal (e.g., lifestyle), social, familial, and environmental history and health risk factors that may impact the patient's health. """
    
    vitalSigns = "vital-signs"
    """ Clinical observations measure the body's basic functions such as blood pressure, heart rate, respiratory rate, height, weight, body mass index, head circumference, pulse oximetry, temperature, and body surface area. """
    
    imaging = "imaging"
    """Observations generated by imaging. The scope includes observations regarding plain x-ray, ultrasound, CT, MRI, angiography, echocardiography, and nuclear medicine. """
    
    laboratory = "laboratory"
    """The results of observations generated by laboratories.  Laboratory results are typically generated by laboratories providing analytic services in areas such as chemistry, hematology, serology, histology, cytology, anatomic pathology (including digital pathology), microbiology, and/or virology. These observations are based on analysis of specimens obtained from the patient and submitted to the laboratory. """
    
    procedure = "procedure"
    """Observations generated by other procedures.  This category includes observations resulting from interventional and non-interventional procedures excluding laboratory and imaging (e.g., cardiology catheterization, endoscopy, electrodiagnostics, etc.).  Procedure results are typically generated by a clinician to provide more granular information about component observations made during a procedure.  An example would be when a gastroenterologist reports the size of a polyp observed during a colonoscopy. """
    
    survey = "survey"
    """Assessment tool/survey instrument observations (e.g., Apgar Scores, Montreal Cognitive Assessment (MoCA)). """
    
    exam = "exam"
    """Observations generated by physical exam findings including direct observations made by a clinician and use of simple instruments and the result of simple maneuvers performed directly on the patient's body. """
    
    therapy = "therapy"
    """Observations generated by non-interventional treatment protocols (e.g. occupational, physical, radiation, nutritional and medication therapy) """
    
    activity = "activity"
    """Observations that measure or record any bodily activity that enhances or maintains physical fitness and overall health and wellness.  Not under direct supervision of practitioner such as a physical therapist. (e.g., laps swum, steps, sleep data) """
    
class ObservationCategoryCodes(enum.Enum):
    
    acmgVersion1 = "acmg-version1"
    """First release (2013): ACMG Recommendations for Reporting of Incidental Findings in Clinical Exome and Genome Sequencing.  https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3727274/ """
    
    acmgVersion2 = "acmg-version2"
    """Second release (2016): Recommendations for reporting of secondary findings in clinical exome and genome sequencing, 2016 update (ACMG SF v2.0): a policy statement of the American College of Medical Genetics and Genomics. https://www.ncbi.nlm.nih.gov/pubmed/27854360 """
    
class ObservationDataType(enum.Enum):
    
    quantity = "Quantity"
    """A measured amount. """
    
    codeableConcept = "CodeableConcept"
    """A coded concept from a reference terminology and/or text. """
    
    string = "string"
    """A sequence of Unicode characters. """
    
    boolean = "boolean"
    """true or false. """
    
    integer = "integer"
    """A signed integer. """
    
    range = "Range"
    """A set of values bounded by low and high. """
    
    ratio = "Ratio"
    """A ratio of two Quantity values - a numerator and a denominator. """
    
    sampledData = "SampledData"
    """A series of measurements taken by a device. """
    
    time = "time"
    """A time during the day, in the format hh:mm:ss. """
    
    dateTime = "dateTime"
    """A date, date-time or partial date (e.g. just year or year + month) as used in human communication. """
    
    period = "Period"
    """A time range defined by start and end date/time. """
    
class ObservationRangeCategory(enum.Enum):
    
    reference = "reference"
    """Reference (Normal) Range for Ordinal and Continuous Observations. """
    
    critical = "critical"
    """Critical Range for Ordinal and Continuous Observations. """
    
    absolute = "absolute"
    """Absolute Range for Ordinal and Continuous Observations. Results outside this range are not possible. """
    
class ObservationReferenceRangeMeaningCodes(enum.Enum):
    
    type = "type"
    """General types of reference range. """
    
    normal = "normal"
    """Values expected for a normal member of the relevant control population being measured. Typically each results producer such as a laboratory has specific normal ranges and they are usually defined as within two standard deviations from the mean and account for 95.45% of this population. """
    
    recommended = "recommended"
    """The range that is recommended by a relevant professional body. """
    
    treatment = "treatment"
    """The range at which treatment would/should be considered. """
    
    therapeutic = "therapeutic"
    """The optimal range for best therapeutic outcomes. """
    
    pre = "pre"
    """The optimal range for best therapeutic outcomes for a specimen taken immediately before administration. """
    
    post = "post"
    """The optimal range for best therapeutic outcomes for a specimen taken immediately after administration. """
    
    endocrine = "endocrine"
    """Endocrine related states that change the expected value. """
    
    prePuberty = "pre-puberty"
    """An expected range in an individual prior to puberty. """
    
    follicular = "follicular"
    """An expected range in an individual during the follicular stage of the cycle. """
    
    midcycle = "midcycle"
    """An expected range in an individual during the midcycle stage of the cycle. """
    
    luteal = "luteal"
    """An expected range in an individual during the luteal stage of the cycle. """
    
    postmenopausal = "postmenopausal"
    """An expected range in an individual post-menopause. """
    
class ObservationStatus(enum.Enum):
    
    registered = "registered"
    """The existence of the observation is registered, but there is no result yet available. """
    
    preliminary = "preliminary"
    """This is an initial or interim observation: data may be incomplete or unverified. """
    
    final = "final"
    """The observation is complete and there are no further actions needed. Additional information such "released", "signed", etc would be represented using [Provenance](provenance.html) which provides not only the act but also the actors and dates and other related data. These act states would be associated with an observation status of `preliminary` until they are all completed and then a status of `final` would be applied. """
    
    amended = "amended"
    """Subsequent to being Final, the observation has been modified subsequent.  This includes updates/new information and corrections. """
    
    corrected = "corrected"
    """Subsequent to being Final, the observation has been modified to correct an error in the test result. """
    
    cancelled = "cancelled"
    """The observation is unavailable because the measurement was not started or not completed (also sometimes called "aborted"). """
    
    enteredInError = "entered-in-error"
    """The observation has been withdrawn following previous final release.  This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be "cancelled" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this observation. Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, but the authoring/source system does not know which. """
    
class OperationKind(enum.Enum):
    
    operation = "operation"
    """This operation is invoked as an operation. """
    
    query = "query"
    """This operation is a named query, invoked using the search mechanism. """
    
class OperationOutcomeCodes(enum.Enum):
    
    DELETE_MULTIPLE_MATCHES = "DELETE_MULTIPLE_MATCHES"
    """DELETE_MULTIPLE_MATCHES """
    
    MSG_AUTH_REQUIRED = "MSG_AUTH_REQUIRED"
    """MSG_AUTH_REQUIRED """
    
    MSG_BAD_FORMAT = "MSG_BAD_FORMAT"
    """MSG_BAD_FORMAT """
    
    MSG_BAD_SYNTAX = "MSG_BAD_SYNTAX"
    """MSG_BAD_SYNTAX """
    
    MSG_CANT_PARSE_CONTENT = "MSG_CANT_PARSE_CONTENT"
    """MSG_CANT_PARSE_CONTENT """
    
    MSG_CANT_PARSE_ROOT = "MSG_CANT_PARSE_ROOT"
    """MSG_CANT_PARSE_ROOT """
    
    MSG_CREATED = "MSG_CREATED"
    """MSG_CREATED """
    
    MSG_DATE_FORMAT = "MSG_DATE_FORMAT"
    """MSG_DATE_FORMAT """
    
    MSG_DELETED = "MSG_DELETED"
    """MSG_DELETED """
    
    MSG_DELETED_DONE = "MSG_DELETED_DONE"
    """MSG_DELETED_DONE """
    
    MSG_DELETED_ID = "MSG_DELETED_ID"
    """MSG_DELETED_ID """
    
    MSG_DUPLICATE_ID = "MSG_DUPLICATE_ID"
    """MSG_DUPLICATE_ID """
    
    MSG_ERROR_PARSING = "MSG_ERROR_PARSING"
    """MSG_ERROR_PARSING """
    
    MSG_ID_INVALID = "MSG_ID_INVALID"
    """MSG_ID_INVALID """
    
    MSG_ID_TOO_LONG = "MSG_ID_TOO_LONG"
    """MSG_ID_TOO_LONG """
    
    MSG_INVALID_ID = "MSG_INVALID_ID"
    """MSG_INVALID_ID """
    
    MSG_JSON_OBJECT = "MSG_JSON_OBJECT"
    """MSG_JSON_OBJECT """
    
    MSG_LOCAL_FAIL = "MSG_LOCAL_FAIL"
    """MSG_LOCAL_FAIL """
    
    MSG_NO_EXIST = "MSG_NO_EXIST"
    """MSG_NO_EXIST """
    
    MSG_NO_MATCH = "MSG_NO_MATCH"
    """MSG_NO_MATCH """
    
    MSG_NO_MODULE = "MSG_NO_MODULE"
    """MSG_NO_MODULE """
    
    MSG_NO_SUMMARY = "MSG_NO_SUMMARY"
    """MSG_NO_SUMMARY """
    
    MSG_OP_NOT_ALLOWED = "MSG_OP_NOT_ALLOWED"
    """MSG_OP_NOT_ALLOWED """
    
    MSG_PARAM_CHAINED = "MSG_PARAM_CHAINED"
    """MSG_PARAM_CHAINED """
    
    MSG_PARAM_INVALID = "MSG_PARAM_INVALID"
    """MSG_PARAM_INVALID """
    
    MSG_PARAM_MODIFIER_INVALID = "MSG_PARAM_MODIFIER_INVALID"
    """MSG_PARAM_MODIFIER_INVALID """
    
    MSG_PARAM_NO_REPEAT = "MSG_PARAM_NO_REPEAT"
    """MSG_PARAM_NO_REPEAT """
    
    MSG_PARAM_UNKNOWN = "MSG_PARAM_UNKNOWN"
    """MSG_PARAM_UNKNOWN """
    
    MSG_RESOURCE_EXAMPLE_PROTECTED = "MSG_RESOURCE_EXAMPLE_PROTECTED"
    """MSG_RESOURCE_EXAMPLE_PROTECTED """
    
    MSG_RESOURCE_ID_FAIL = "MSG_RESOURCE_ID_FAIL"
    """MSG_RESOURCE_ID_FAIL """
    
    MSG_RESOURCE_ID_MISMATCH = "MSG_RESOURCE_ID_MISMATCH"
    """MSG_RESOURCE_ID_MISMATCH """
    
    MSG_RESOURCE_ID_MISSING = "MSG_RESOURCE_ID_MISSING"
    """MSG_RESOURCE_ID_MISSING """
    
    MSG_RESOURCE_NOT_ALLOWED = "MSG_RESOURCE_NOT_ALLOWED"
    """MSG_RESOURCE_NOT_ALLOWED """
    
    MSG_RESOURCE_REQUIRED = "MSG_RESOURCE_REQUIRED"
    """MSG_RESOURCE_REQUIRED """
    
    MSG_RESOURCE_TYPE_MISMATCH = "MSG_RESOURCE_TYPE_MISMATCH"
    """MSG_RESOURCE_TYPE_MISMATCH """
    
    MSG_SORT_UNKNOWN = "MSG_SORT_UNKNOWN"
    """MSG_SORT_UNKNOWN """
    
    MSG_TRANSACTION_DUPLICATE_ID = "MSG_TRANSACTION_DUPLICATE_ID"
    """MSG_TRANSACTION_DUPLICATE_ID """
    
    MSG_TRANSACTION_MISSING_ID = "MSG_TRANSACTION_MISSING_ID"
    """MSG_TRANSACTION_MISSING_ID """
    
    MSG_UNHANDLED_NODE_TYPE = "MSG_UNHANDLED_NODE_TYPE"
    """MSG_UNHANDLED_NODE_TYPE """
    
    MSG_UNKNOWN_CONTENT = "MSG_UNKNOWN_CONTENT"
    """MSG_UNKNOWN_CONTENT """
    
    MSG_UNKNOWN_OPERATION = "MSG_UNKNOWN_OPERATION"
    """MSG_UNKNOWN_OPERATION """
    
    MSG_UNKNOWN_TYPE = "MSG_UNKNOWN_TYPE"
    """MSG_UNKNOWN_TYPE """
    
    MSG_UPDATED = "MSG_UPDATED"
    """MSG_UPDATED """
    
    MSG_VERSION_AWARE = "MSG_VERSION_AWARE"
    """MSG_VERSION_AWARE """
    
    MSG_VERSION_AWARE_CONFLICT = "MSG_VERSION_AWARE_CONFLICT"
    """MSG_VERSION_AWARE_CONFLICT """
    
    MSG_VERSION_AWARE_URL = "MSG_VERSION_AWARE_URL"
    """MSG_VERSION_AWARE_URL """
    
    MSG_WRONG_NS = "MSG_WRONG_NS"
    """MSG_WRONG_NS """
    
    SEARCH_MULTIPLE = "SEARCH_MULTIPLE"
    """SEARCH_MULTIPLE """
    
    SEARCH_NONE = "SEARCH_NONE"
    """SEARCH_NONE """
    
    UPDATE_MULTIPLE_MATCHES = "UPDATE_MULTIPLE_MATCHES"
    """UPDATE_MULTIPLE_MATCHES """
    
class OperationParameterUse(enum.Enum):
    
    in_ = "in"
    """This is an input parameter. """
    
    out = "out"
    """This is an output parameter. """
    
class OrganizationAffiliationRole(enum.Enum):
    
    provider = "provider"
    """provider """
    
    agency = "agency"
    """An organization such as a public health agency, community/social services provider, etc. """
    
    research = "research"
    """An organization providing research-related services such as conducting research, recruiting research participants, analyzing data, etc. """
    
    payer = "payer"
    """An organization providing reimbursement, payment, or related services """
    
    diagnostics = "diagnostics"
    """An organization providing diagnostic testing/laboratory services """
    
    supplier = "supplier"
    """An organization that provides medical supplies (e.g. medical devices, equipment, pharmaceutical products, etc.) """
    
    HIEHIO = "HIE/HIO"
    """An organization that facilitates electronic clinical data exchange between entities """
    
    member = "member"
    """A type of non-ownership relationship between entities (encompasses partnerships, collaboration, joint ventures, etc.) """
    
class OrganizationType(enum.Enum):
    
    prov = "prov"
    """An organization that provides healthcare services. """
    
    dept = "dept"
    """A department or ward within a hospital (Generally is not applicable to top level organizations) """
    
    team = "team"
    """An organizational team is usually a grouping of practitioners that perform a specific function within an organization (which could be a top level organization, or a department). """
    
    govt = "govt"
    """A political body, often used when including organization records for government bodies such as a Federal Government, State or Local Government. """
    
    ins = "ins"
    """A company that provides insurance to its subscribers that may include healthcare related policies. """
    
    pay = "pay"
    """A company, charity, or governmental organization, which processes claims and/or issues payments to providers on behalf of patients or groups of patients. """
    
    edu = "edu"
    """An educational institution that provides education or research facilities. """
    
    reli = "reli"
    """An organization that is identified as a part of a religious institution. """
    
    crs = "crs"
    """An organization that is identified as a Pharmaceutical/Clinical Research Sponsor. """
    
    cg = "cg"
    """An un-incorporated community group. """
    
    bus = "bus"
    """An organization that is a registered business or corporation but not identified by other types. """
    
    other = "other"
    """Other type of organization not already specified. """
    
class OrientationType(enum.Enum):
    
    sense = "sense"
    """Sense orientation of reference sequence. """
    
    antisense = "antisense"
    """Antisense orientation of reference sequence. """
    
class ParticipantRequired(enum.Enum):
    
    required = "required"
    """The participant is required to attend the appointment. """
    
    optional = "optional"
    """The participant may optionally attend the appointment. """
    
    informationOnly = "information-only"
    """The participant is excluded from the appointment, and might not be informed of the appointment taking place. (Appointment is about them, not for them - such as 2 doctors discussing results about a patient's test). """
    
class ParticipantType(enum.Enum):
    
    translator = "translator"
    """A translator who is facilitating communication with the patient during the encounter. """
    
    emergency = "emergency"
    """A person to be contacted in case of an emergency during the encounter. """
    
class ParticipationStatus(enum.Enum):
    
    accepted = "accepted"
    """The participant has accepted the appointment. """
    
    declined = "declined"
    """The participant has declined the appointment and will not participate in the appointment. """
    
    tentative = "tentative"
    """The participant has  tentatively accepted the appointment. This could be automatically created by a system and requires further processing before it can be accepted. There is no commitment that attendance will occur. """
    
    needsAction = "needs-action"
    """The participant needs to indicate if they accept the appointment by changing this status to one of the other statuses. """
    
class PayeeResourceType(enum.Enum):
    
    organization = "organization"
    """Organization resource. """
    
    patient = "patient"
    """Patient resource. """
    
    practitioner = "practitioner"
    """Practitioner resource. """
    
    relatedperson = "relatedperson"
    """RelatedPerson resource. """
    
class PaymentAdjustmentReasonCodes(enum.Enum):
    
    A001 = "a001"
    """Prior Payment Reversal """
    
    A002 = "a002"
    """Prior Overpayment """
    
class PaymentStatusCodes(enum.Enum):
    
    paid = "paid"
    """The payment has been sent physically or electronically. """
    
    cleared = "cleared"
    """The payment has been received by the payee. """
    
class PaymentTypeCodes(enum.Enum):
    
    payment = "payment"
    """The amount is partial or complete settlement of the amounts due. """
    
    adjustment = "adjustment"
    """The amount is an adjustment regarding claims already paid. """
    
    advance = "advance"
    """The amount is an advance against future claims. """
    
class PerformerRoleCodes(enum.Enum):
    
    consenter = "consenter"
    """An entity or an entity's delegatee who is the grantee in an agreement such as a consent for services, advanced directive, or a privacy consent directive in accordance with jurisdictional, organizational, or patient policy. """
    
    grantee = "grantee"
    """An entity which accepts certain rights or authority from a grantor. """
    
    grantor = "grantor"
    """An entity which agrees to confer certain rights or authority to a grantee. """
    
    delegatee = "delegatee"
    """A party to whom some right or authority is granted by a delegator. """
    
    delegator = "delegator"
    """A party that grants all or some portion its right or authority to another party. """
    
class PlanDefinitionType(enum.Enum):
    
    orderSet = "order-set"
    """A pre-defined and approved group of orders related to a particular clinical condition (e.g. hypertension treatment and monitoring) or stage of care (e.g. hospital admission to Coronary Care Unit). An order set is used as a checklist for the clinician when managing a patient with a specific condition. It is a structured collection of orders relevant to that condition and presented to the clinician in a computerized provider order entry (CPOE) system. """
    
    clinicalProtocol = "clinical-protocol"
    """Defines a desired/typical sequence of clinical activities including preconditions, triggers and temporal relationships. """
    
    ecaRule = "eca-rule"
    """A decision support rule of the form [on Event] if Condition then Action. It is intended to be a shareable, computable definition of actions that should be taken whenever some condition is met in response to a particular event or events. """
    
    workflowDefinition = "workflow-definition"
    """Defines the steps for a group of one or more systems in an event flow process along with the step constraints, sequence, pre-conditions and decision points to complete a particular objective. """
    
class PractitionerRole(enum.Enum):
    
    doctor = "doctor"
    """A qualified/registered medical practitioner """
    
    nurse = "nurse"
    """A practitioner with nursing experience that may be qualified/registered """
    
    pharmacist = "pharmacist"
    """A qualified/registered/licensed pharmacist """
    
    researcher = "researcher"
    """A practitioner that may perform research """
    
    teacher = "teacher"
    """Someone who is able to provide educational services """
    
    ict = "ict"
    """Someone who is qualified in Information and Communication Technologies """
    
class PractitionerSpecialty(enum.Enum):
    
    cardio = "cardio"
    """cardio """
    
    dent = "dent"
    """dent """
    
    dietary = "dietary"
    """dietary """
    
    midw = "midw"
    """midw """
    
    sysarch = "sysarch"
    """sysarch """
    
class PrecisionEstimateType(enum.Enum):
    
    CI = "CI"
    """confidence interval. """
    
    IQR = "IQR"
    """interquartile range. """
    
    SD = "SD"
    """standard deviation. """
    
    SE = "SE"
    """standard error. """
    
class PrimarySourceType(enum.Enum):
    
    licBoard = "lic-board"
    """licBoard """
    
    prim = "prim"
    """prim """
    
    contEd = "cont-ed"
    """contEd """
    
    postServ = "post-serv"
    """postServ """
    
    relOwn = "rel-own"
    """relOwn """
    
    regAuth = "reg-auth"
    """regAuth """
    
    legal = "legal"
    """legal """
    
    issuer = "issuer"
    """issuer """
    
    authSource = "auth-source"
    """authSource """
    
class ProcedureDeviceActionCodes(enum.Enum):
    
    implanted = "implanted"
    """The device was implanted in the patient during the procedure. """
    
    explanted = "explanted"
    """The device was explanted from the patient during the procedure. """
    
    manipulated = "manipulated"
    """The device remains in the patient, but its location, settings, or functionality was changed. """
    
class ProcedureProgressStatusCodes(enum.Enum):
    
    inOperatingRoom = "in-operating-room"
    """A patient is in the Operating Room. """
    
    prepared = "prepared"
    """The patient is prepared for a procedure. """
    
    anesthesiaInduced = "anesthesia-induced"
    """The patient is under anesthesia. """
    
    openIncision = "open-incision"
    """The patient has open incision(s). """
    
    closedIncision = "closed-incision"
    """The patient has incision(s) closed. """
    
    inRecoveryRoom = "in-recovery-room"
    """The patient is in the recovery room. """
    
class ProcessPriorityCodes(enum.Enum):
    
    stat = "stat"
    """Immediately in real time. """
    
    normal = "normal"
    """With best effort. """
    
    deferred = "deferred"
    """Later, when possible. """
    
class PropertyRepresentation(enum.Enum):
    
    xmlAttr = "xmlAttr"
    """In XML, this property is represented as an attribute not an element. """
    
    xmlText = "xmlText"
    """This element is represented using the XML text attribute (primitives only). """
    
    typeAttr = "typeAttr"
    """The type of this element is indicated using xsi:type. """
    
    cdaText = "cdaText"
    """Use CDA narrative instead of XHTML. """
    
    xhtml = "xhtml"
    """The property is represented using XHTML. """
    
class PropertyType(enum.Enum):
    
    code = "code"
    """The property value is a code that identifies a concept defined in the code system. """
    
    coding = "Coding"
    """The property  value is a code defined in an external code system. This may be used for translations, but is not the intent. """
    
    string = "string"
    """The property value is a string. """
    
    integer = "integer"
    """The property value is a string (often used to assign ranking values to concepts for supporting score assessments). """
    
    boolean = "boolean"
    """The property value is a boolean true | false. """
    
    dateTime = "dateTime"
    """The property is a date or a date + time. """
    
    decimal = "decimal"
    """The property value is a decimal number. """
    
class ProvenanceEntityRole(enum.Enum):
    
    derivation = "derivation"
    """A transformation of an entity into another, an update of an entity resulting in a new one, or the construction of a new entity based on a pre-existing entity. """
    
    revision = "revision"
    """A derivation for which the resulting entity is a revised version of some original. """
    
    quotation = "quotation"
    """The repeat of (some or all of) an entity, such as text or image, by someone who might or might not be its original author. """
    
    source = "source"
    """A primary source for a topic refers to something produced by some agent with direct experience and knowledge about the topic, at the time of the topic's study, without benefit from hindsight. """
    
    removal = "removal"
    """A derivation for which the entity is removed from accessibility usually through the use of the Delete operation. """
    
class ProvenanceParticipantRole(enum.Enum):
    
    enterer = "enterer"
    """A person entering the data into the originating system """
    
    performer = "performer"
    """A person, animal, organization or device that who actually and principally carries out the activity """
    
    author = "author"
    """A party that originates the resource and therefore has responsibility for the information given in the resource and ownership of this resource """
    
    verifier = "verifier"
    """A person who verifies the correctness and appropriateness of activity """
    
    legal = "legal"
    """The person authenticated the content and accepted legal responsibility for its content """
    
    attester = "attester"
    """A verifier who attests to the accuracy of the resource """
    
    informant = "informant"
    """A person who reported information that contributed to the resource """
    
    custodian = "custodian"
    """The entity that is accountable for maintaining a true an accurate copy of the original record """
    
    assembler = "assembler"
    """A device that operates independently of an author on custodian's algorithms for data extraction of existing information for purpose of generating a new artifact. """
    
    composer = "composer"
    """A device used by an author to record new information, which may also be used by the author to select existing information for aggregation with newly recorded information for the purpose of generating a new artifact. """
    
class ProvenanceParticipantType(enum.Enum):
    
    enterer = "enterer"
    """A person entering the data into the originating system """
    
    performer = "performer"
    """A person, animal, organization or device that who actually and principally carries out the activity """
    
    author = "author"
    """A party that originates the resource and therefore has responsibility for the information given in the resource and ownership of this resource """
    
    verifier = "verifier"
    """A person who verifies the correctness and appropriateness of activity """
    
    legal = "legal"
    """The person authenticated the content and accepted legal responsibility for its content """
    
    attester = "attester"
    """A verifier who attests to the accuracy of the resource """
    
    informant = "informant"
    """A person who reported information that contributed to the resource """
    
    custodian = "custodian"
    """The entity that is accountable for maintaining a true an accurate copy of the original record """
    
    assembler = "assembler"
    """A device that operates independently of an author on custodian's algorithms for data extraction of existing information for purpose of generating a new artifact. """
    
    composer = "composer"
    """A device used by an author to record new information, which may also be used by the author to select existing information for aggregation with newly recorded information for the purpose of generating a new artifact. """
    
class PublicationStatus(enum.Enum):
    
    draft = "draft"
    """This resource is still under development and is not yet considered to be ready for normal use. """
    
    active = "active"
    """This resource is ready for normal use. """
    
    retired = "retired"
    """This resource has been withdrawn or superseded and should no longer be used. """
    
    unknown = "unknown"
    """The authoring system does not know which of the status values currently applies for this resource.  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, it's just not known which one. """
    
class PushTypeAvailable(enum.Enum):
    
    specific = "specific"
    """specific """
    
    any = "any"
    """any """
    
    source = "source"
    """source """
    
class QualityOfEvidenceRating(enum.Enum):
    
    high = "high"
    """High quality evidence. """
    
    moderate = "moderate"
    """Moderate quality evidence. """
    
    low = "low"
    """Low quality evidence. """
    
    veryLow = "very-low"
    """Very low quality evidence. """
    
class QualityType(enum.Enum):
    
    indel = "indel"
    """INDEL Comparison. """
    
    snp = "snp"
    """SNP Comparison. """
    
    unknown = "unknown"
    """UNKNOWN Comparison. """
    
class QuantityComparator(enum.Enum):
    
    lt = "<"
    """The actual value is less than the given value. """
    
    lte = "<="
    """The actual value is less than or equal to the given value. """
    
    gte = ">="
    """The actual value is greater than or equal to the given value. """
    
    gt = ">"
    """The actual value is greater than the given value. """
    
class QuestionnaireItemOperator(enum.Enum):
    
    exists = "exists"
    """True if whether an answer exists is equal to the enableWhen answer (which must be a boolean). """
    
    eq = "="
    """True if whether at least one answer has a value that is equal to the enableWhen answer. """
    
    ne = "!="
    """True if whether at least no answer has a value that is equal to the enableWhen answer. """
    
    gt = ">"
    """True if whether at least no answer has a value that is greater than the enableWhen answer. """
    
    lt = "<"
    """True if whether at least no answer has a value that is less than the enableWhen answer. """
    
    gte = ">="
    """True if whether at least no answer has a value that is greater or equal to the enableWhen answer. """
    
    lte = "<="
    """True if whether at least no answer has a value that is less or equal to the enableWhen answer. """
    
class QuestionnaireItemType(enum.Enum):
    
    group = "group"
    """An item with no direct answer but should have at least one child item. """
    
    display = "display"
    """Text for display that will not capture an answer or have child items. """
    
    question = "question"
    """An item that defines a specific answer to be captured, and which may have child items. (the answer provided in the QuestionnaireResponse should be of the defined datatype). """
    
    boolean = "boolean"
    """Question with a yes/no answer (valueBoolean). """
    
    decimal = "decimal"
    """Question with is a real number answer (valueDecimal). """
    
    integer = "integer"
    """Question with an integer answer (valueInteger). """
    
    date = "date"
    """Question with a date answer (valueDate). """
    
    dateTime = "dateTime"
    """Question with a date and time answer (valueDateTime). """
    
    time = "time"
    """Question with a time (hour:minute:second) answer independent of date. (valueTime). """
    
    string = "string"
    """Question with a short (few words to short sentence) free-text entry answer (valueString). """
    
    text = "text"
    """Question with a long (potentially multi-paragraph) free-text entry answer (valueString). """
    
    url = "url"
    """Question with a URL (website, FTP site, etc.) answer (valueUri). """
    
    choice = "choice"
    """Question with a Coding drawn from a list of possible answers (specified in either the answerOption property, or via the valueset referenced in the answerValueSet property) as an answer (valueCoding). """
    
    openChoice = "open-choice"
    """Answer is a Coding drawn from a list of possible answers (as with the choice type) or a free-text entry in a string (valueCoding or valueString). """
    
    attachment = "attachment"
    """Question with binary content such as an image, PDF, etc. as an answer (valueAttachment). """
    
    reference = "reference"
    """Question with a reference to another resource (practitioner, organization, etc.) as an answer (valueReference). """
    
    quantity = "quantity"
    """Question with a combination of a numeric value and unit, potentially with a comparator (<, >, etc.) as an answer. (valueQuantity) There is an extension 'http://hl7.org/fhir/StructureDefinition/questionnaire-unit' that can be used to define what unit should be captured (or the unit that has a ucum conversion from the provided unit). """
    
class QuestionnaireItemUIControlCodes(enum.Enum):
    
    group = "group"
    """UI controls relevant to organizing groups of questions """
    
    list = "list"
    """Questions within the group should be listed sequentially """
    
    table = "table"
    """Questions within the group are rows in the table with possible answers as columns.  Used for 'choice' questions. """
    
    htable = "htable"
    """Questions within the group are columns in the table with possible answers as rows.  Used for 'choice' questions. """
    
    gtable = "gtable"
    """Questions within the group are columns in the table with each group repetition as a row.  Used for single-answer questions. """
    
    atable = "atable"
    """This table has one row - for the question.  Permitted answers are columns.  Used for choice questions. """
    
    header = "header"
    """The group is to be continuously visible at the top of the questionnaire """
    
    footer = "footer"
    """The group is to be continuously visible at the bottom of the questionnaire """
    
    text = "text"
    """UI controls relevant to rendering questionnaire text items """
    
    inline = "inline"
    """Text is displayed as a paragraph in a sequential position between sibling items (default behavior) """
    
    prompt = "prompt"
    """Text is displayed immediately below or within the answer-entry area of the containing question item (typically as a guide for what to enter) """
    
    unit = "unit"
    """Text is displayed adjacent (horizontally or vertically) to the answer space for the parent question, typically to indicate a unit of measure """
    
    lower = "lower"
    """Text is displayed to the left of the set of answer choices or a scaling control for the parent question item to indicate the meaning of the 'lower' bound.  E.g. 'Strongly disagree' """
    
    upper = "upper"
    """Text is displayed to the right of the set of answer choices or a scaling control for the parent question item to indicate the meaning of the 'upper' bound.  E.g. 'Strongly agree' """
    
    flyover = "flyover"
    """Text is temporarily visible over top of an item if the mouse is positioned over top of the text for the containing item """
    
    help = "help"
    """Text is displayed in a dialog box or similar control if invoked by pushing a button or some other UI-appropriate action to request 'help' for a question, group or the questionnaire as a whole (depending what the text is nested within) """
    
    question = "question"
    """UI controls relevant to capturing question data """
    
    autocomplete = "autocomplete"
    """A control which provides a list of potential matches based on text entered into a control.  Used for large choice sets where text-matching is an appropriate discovery mechanism. """
    
    dropDown = "drop-down"
    """A control where an item (or multiple items) can be selected from a list that is only displayed when the user is editing the field. """
    
    checkBox = "check-box"
    """A control where choices are listed with a box beside them.  The box can be toggled to select or de-select a given choice.  Multiple selections may be possible. """
    
    lookup = "lookup"
    """A control where editing an item spawns a separate dialog box or screen permitting a user to navigate, filter or otherwise discover an appropriate match.  Useful for large choice sets where text matching is not an appropriate discovery mechanism.  Such screens must generally be tuned for the specific choice list structure. """
    
    radioButton = "radio-button"
    """A control where choices are listed with a button beside them.  The button can be toggled to select or de-select a given choice.  Selecting one item deselects all others. """
    
    slider = "slider"
    """A control where an axis is displayed between the high and low values and the control can be visually manipulated to select a value anywhere on the axis. """
    
    spinner = "spinner"
    """A control where a list of numeric or other ordered values can be scrolled through via arrows. """
    
    textBox = "text-box"
    """A control where a user can type in their answer freely. """
    
class QuestionnaireItemUsageMode(enum.Enum):
    
    captureDisplay = "capture-display"
    """Render the item regardless of usage mode. """
    
    capture = "capture"
    """Render the item only when capturing data. """
    
    display = "display"
    """Render the item only when displaying a completed form. """
    
    displayNonEmpty = "display-non-empty"
    """Render the item only when displaying a completed form and the item has been answered (or has child items that have been answered). """
    
    captureDisplayNonEmpty = "capture-display-non-empty"
    """Render the item when capturing data or when displaying a completed form and the item has been answered (or has child items that have been answered). """
    
class QuestionnaireResponseStatus(enum.Enum):
    
    inProgress = "in-progress"
    """This QuestionnaireResponse has been partially filled out with answers but changes or additions are still expected to be made to it. """
    
    completed = "completed"
    """This QuestionnaireResponse has been filled out with answers and the current content is regarded as definitive. """
    
    amended = "amended"
    """This QuestionnaireResponse has been filled out with answers, then marked as complete, yet changes or additions have been made to it afterwards. """
    
    enteredInError = "entered-in-error"
    """This QuestionnaireResponse was entered in error and voided. """
    
    stopped = "stopped"
    """This QuestionnaireResponse has been partially filled out with answers but has been abandoned. It is unknown whether changes or additions are expected to be made to it. """
    
class QuestionnaireTextCategories(enum.Enum):
    
    instructions = "instructions"
    """The text provides guidance on how to populate or use a portion of the questionnaire (or the questionnaire as a whole). """
    
    security = "security"
    """The text provides guidance on how the information should be or will be handled from a security/confidentiality/access control perspective when completed """
    
    help = "help"
    """The text provides additional guidance on populating the containing item.  Help text isn't necessarily expected to be rendered as part of the form, but may instead be made available through fly-over, pop-up button, link to a "help" page, etc. """
    
class ReasonMedicationGivenCodes(enum.Enum):
    
    A = "a"
    """No reason known. """
    
    B = "b"
    """The administration was following an ordered protocol. """
    
    C = "c"
    """The administration was needed to treat an emergency. """
    
class ReferenceHandlingPolicy(enum.Enum):
    
    literal = "literal"
    """The server supports and populates Literal references (i.e. using Reference.reference) where they are known (this code does not guarantee that all references are literal; see 'enforced'). """
    
    logical = "logical"
    """The server allows logical references (i.e. using Reference.identifier). """
    
    resolves = "resolves"
    """The server will attempt to resolve logical references to literal references - i.e. converting Reference.identifier to Reference.reference (if resolution fails, the server may still accept resources; see logical). """
    
    enforced = "enforced"
    """The server enforces that references have integrity - e.g. it ensures that references can always be resolved. This is typically the case for clinical record systems, but often not the case for middleware/proxy systems. """
    
    local = "local"
    """The server does not support references that point to other servers. """
    
class ReferenceVersionRules(enum.Enum):
    
    either = "either"
    """The reference may be either version independent or version specific. """
    
    independent = "independent"
    """The reference must be version independent. """
    
    specific = "specific"
    """The reference must be version specific. """
    
class ReferralMethod(enum.Enum):
    
    fax = "fax"
    """Referrals may be accepted by fax. """
    
    phone = "phone"
    """Referrals may be accepted over the phone from a practitioner. """
    
    elec = "elec"
    """Referrals may be accepted via a secure messaging system. To determine the types of secure messaging systems supported, refer to the identifiers collection. Callers will need to understand the specific identifier system used to know that they are able to transmit messages. """
    
    semail = "semail"
    """Referrals may be accepted via a secure email. To send please encrypt with the services public key. """
    
    mail = "mail"
    """Referrals may be accepted via regular postage (or hand delivered). """
    
class RejectionCriterion(enum.Enum):
    
    hemolized = "hemolized"
    """blood specimen hemolized. """
    
    insufficient = "insufficient"
    """insufficient quantity of specimen. """
    
    broken = "broken"
    """specimen container broken. """
    
    clotted = "clotted"
    """specimen clotted. """
    
    wrongTemperature = "wrong-temperature"
    """specimen temperature inappropriate. """
    
class RelatedArtifactType(enum.Enum):
    
    documentation = "documentation"
    """Additional documentation for the knowledge resource. This would include additional instructions on usage as well as additional information on clinical context or appropriateness. """
    
    justification = "justification"
    """A summary of the justification for the knowledge resource including supporting evidence, relevant guidelines, or other clinically important information. This information is intended to provide a way to make the justification for the knowledge resource available to the consumer of interventions or results produced by the knowledge resource. """
    
    citation = "citation"
    """Bibliographic citation for papers, references, or other relevant material for the knowledge resource. This is intended to allow for citation of related material, but that was not necessarily specifically prepared in connection with this knowledge resource. """
    
    predecessor = "predecessor"
    """The previous version of the knowledge resource. """
    
    successor = "successor"
    """The next version of the knowledge resource. """
    
    derivedFrom = "derived-from"
    """The knowledge resource is derived from the related artifact. This is intended to capture the relationship in which a particular knowledge resource is based on the content of another artifact, but is modified to capture either a different set of overall requirements, or a more specific set of requirements such as those involved in a particular institution or clinical setting. """
    
    dependsOn = "depends-on"
    """The knowledge resource depends on the given related artifact. """
    
    composedOf = "composed-of"
    """The knowledge resource is composed of the given related artifact. """
    
class RepositoryType(enum.Enum):
    
    directlink = "directlink"
    """When URL is clicked, the resource can be seen directly (by webpage or by download link format). """
    
    openapi = "openapi"
    """When the API method (e.g. [base_url]/[parameter]) related with the URL of the website is executed, the resource can be seen directly (usually in JSON or XML format). """
    
    login = "login"
    """When logged into the website, the resource can be seen. """
    
    oauth = "oauth"
    """When logged in and  follow the API in the website related with URL, the resource can be seen. """
    
    other = "other"
    """Some other complicated or particular way to get resource from URL. """
    
class RequestIntent(enum.Enum):
    
    proposal = "proposal"
    """The request is a suggestion made by someone/something that does not have an intention to ensure it occurs and without providing an authorization to act. """
    
    plan = "plan"
    """The request represents an intention to ensure something occurs without providing an authorization for others to act. """
    
    directive = "directive"
    """The request represents a legally binding instruction authored by a Patient or RelatedPerson. """
    
    order = "order"
    """The request represents a request/demand and authorization for action by a Practitioner. """
    
    originalOrder = "original-order"
    """The request represents an original authorization for action. """
    
    reflexOrder = "reflex-order"
    """The request represents an automatically generated supplemental authorization for action based on a parent authorization together with initial results of the action taken against that parent authorization. """
    
    fillerOrder = "filler-order"
    """The request represents the view of an authorization instantiated by a fulfilling system representing the details of the fulfiller's intention to act upon a submitted order. """
    
    instanceOrder = "instance-order"
    """An order created in fulfillment of a broader order that represents the authorization for a single activity occurrence.  E.g. The administration of a single dose of a drug. """
    
    option = "option"
    """The request represents a component or option for a RequestGroup that establishes timing, conditionality and/or other constraints among a set of requests.  Refer to [[[RequestGroup]]] for additional information on how this status is used. """
    
class RequestPriority(enum.Enum):
    
    routine = "routine"
    """The request has normal priority. """
    
    urgent = "urgent"
    """The request should be actioned promptly - higher priority than routine. """
    
    asap = "asap"
    """The request should be actioned as soon as possible - higher priority than urgent. """
    
    stat = "stat"
    """The request should be actioned immediately - highest possible priority.  E.g. an emergency. """
    
class RequestResourceType(enum.Enum):
    
    appointment = "Appointment"
    """A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s). """
    
    appointmentResponse = "AppointmentResponse"
    """A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection. """
    
    carePlan = "CarePlan"
    """Healthcare plan for patient or group. """
    
    claim = "Claim"
    """Claim, Pre-determination or Pre-authorization. """
    
    communicationRequest = "CommunicationRequest"
    """A request for information to be sent to a receiver. """
    
    contract = "Contract"
    """Legal Agreement. """
    
    deviceRequest = "DeviceRequest"
    """Medical device request. """
    
    enrollmentRequest = "EnrollmentRequest"
    """Enrollment request. """
    
    immunizationRecommendation = "ImmunizationRecommendation"
    """Guidance or advice relating to an immunization. """
    
    medicationRequest = "MedicationRequest"
    """Ordering of medication for patient or group. """
    
    nutritionOrder = "NutritionOrder"
    """Diet, formula or nutritional supplement request. """
    
    serviceRequest = "ServiceRequest"
    """A record of a request for service such as diagnostic investigations, treatments, or operations to be performed. """
    
    supplyRequest = "SupplyRequest"
    """Request for a medication, substance or device. """
    
    task = "Task"
    """A task to be performed. """
    
    visionPrescription = "VisionPrescription"
    """Prescription for vision correction products for a patient. """
    
class RequestStatus(enum.Enum):
    
    draft = "draft"
    """The request has been created but is not yet complete or ready for action. """
    
    active = "active"
    """The request is in force and ready to be acted upon. """
    
    onHold = "on-hold"
    """The request (and any implicit authorization to act) has been temporarily withdrawn but is expected to resume in the future. """
    
    revoked = "revoked"
    """The request (and any implicit authorization to act) has been terminated prior to the known full completion of the intended actions.  No further activity should occur. """
    
    completed = "completed"
    """The activity described by the request has been fully performed.  No further activity will occur. """
    
    enteredInError = "entered-in-error"
    """This request should never have existed and should be considered 'void'.  (It is possible that real-world decisions were based on it.  If real-world activity has occurred, the status should be "revoked" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this request.  Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply,  but the authoring/source system does not know which. """
    
class ResearchElementType(enum.Enum):
    
    population = "population"
    """The element defines the population that forms the basis for research. """
    
    exposure = "exposure"
    """The element defines an exposure within the population that is being researched. """
    
    outcome = "outcome"
    """The element defines an outcome within the population that is being researched. """
    
class ResearchStudyObjectiveType(enum.Enum):
    
    primary = "primary"
    """The main question to be answered, and the one that drives any statistical planning for the study—e.g., calculation of the sample size to provide the appropriate power for statistical testing. """
    
    secondary = "secondary"
    """Question to be answered in the study that is of lesser importance than the primary objective. """
    
    exploratory = "exploratory"
    """Exploratory questions to be answered in the study. """
    
class ResearchStudyPhase(enum.Enum):
    
    NA = "n-a"
    """Trials without phases (for example, studies of devices or behavioral interventions). """
    
    earlyPhase1 = "early-phase-1"
    """Designation for optional exploratory trials conducted in accordance with the United States Food and Drug Administration's (FDA) 2006 Guidance on Exploratory Investigational New Drug (IND) Studies. Formerly called Phase 0. """
    
    phase1 = "phase-1"
    """Includes initial studies to determine the metabolism and pharmacologic actions of drugs in humans, the side effects associated with increasing doses, and to gain early evidence of effectiveness; may include healthy participants and/or patients. """
    
    phase1Phase2 = "phase-1-phase-2"
    """Trials that are a combination of phases 1 and 2. """
    
    phase2 = "phase-2"
    """Includes controlled clinical studies conducted to evaluate the effectiveness of the drug for a particular indication or indications in participants with the disease or condition under study and to determine the common short-term side effects and risks. """
    
    phase2Phase3 = "phase-2-phase-3"
    """Trials that are a combination of phases 2 and 3. """
    
    phase3 = "phase-3"
    """Includes trials conducted after preliminary evidence suggesting effectiveness of the drug has been obtained, and are intended to gather additional information to evaluate the overall benefit-risk relationship of the drug. """
    
    phase4 = "phase-4"
    """Studies of FDA-approved drugs to delineate additional information including the drug's risks, benefits, and optimal use. """
    
class ResearchStudyPrimaryPurposeType(enum.Enum):
    
    treatment = "treatment"
    """One or more interventions are being evaluated for treating a disease, syndrome, or condition. """
    
    prevention = "prevention"
    """One or more interventions are being assessed for preventing the development of a specific disease or health condition. """
    
    diagnostic = "diagnostic"
    """One or more interventions are being evaluated for identifying a disease or health condition. """
    
    supportiveCare = "supportive-care"
    """One or more interventions are evaluated for maximizing comfort, minimizing side effects, or mitigating against a decline in the participant's health or function. """
    
    screening = "screening"
    """One or more interventions are assessed or examined for identifying a condition, or risk factors for a condition, in people who are not yet known to have the condition or risk factor. """
    
    healthServicesResearch = "health-services-research"
    """One or more interventions for evaluating the delivery, processes, management, organization, or financing of healthcare. """
    
    basicScience = "basic-science"
    """One or more interventions for examining the basic mechanism of action (for example, physiology or biomechanics of an intervention). """
    
    deviceFeasibility = "device-feasibility"
    """An intervention of a device product is being evaluated to determine the feasibility of the product or to test a prototype device and not health outcomes. Such studies are conducted to confirm the design and operating specifications of a device before beginning a full clinical trial. """
    
class ResearchStudyReasonStopped(enum.Enum):
    
    accrualGoalMet = "accrual-goal-met"
    """The study prematurely ended because the accrual goal was met. """
    
    closedDueToToxicity = "closed-due-to-toxicity"
    """The study prematurely ended due to toxicity. """
    
    closedDueToLackOfStudyProgress = "closed-due-to-lack-of-study-progress"
    """The study prematurely ended due to lack of study progress. """
    
    temporarilyClosedPerStudyDesign = "temporarily-closed-per-study-design"
    """The study prematurely ended temporarily per study design. """
    
class ResearchStudyStatus(enum.Enum):
    
    active = "active"
    """Study is opened for accrual. """
    
    administrativelyCompleted = "administratively-completed"
    """Study is completed prematurely and will not resume; patients are no longer examined nor treated. """
    
    approved = "approved"
    """Protocol is approved by the review board. """
    
    closedToAccrual = "closed-to-accrual"
    """Study is closed for accrual; patients can be examined and treated. """
    
    closedToAccrualAndIntervention = "closed-to-accrual-and-intervention"
    """Study is closed to accrual and intervention, i.e. the study is closed to enrollment, all study subjects have completed treatment or intervention but are still being followed according to the primary objective of the study. """
    
    completed = "completed"
    """Study is closed to accrual and intervention, i.e. the study is closed to enrollment, all study subjects have completed treatment
or intervention but are still being followed according to the primary objective of the study. """
    
    disapproved = "disapproved"
    """Protocol was disapproved by the review board. """
    
    inReview = "in-review"
    """Protocol is submitted to the review board for approval. """
    
    temporarilyClosedToAccrual = "temporarily-closed-to-accrual"
    """Study is temporarily closed for accrual; can be potentially resumed in the future; patients can be examined and treated. """
    
    temporarilyClosedToAccrualAndIntervention = "temporarily-closed-to-accrual-and-intervention"
    """Study is temporarily closed for accrual and intervention and potentially can be resumed in the future. """
    
    withdrawn = "withdrawn"
    """Protocol was withdrawn by the lead organization. """
    
class ResearchSubjectStatus(enum.Enum):
    
    candidate = "candidate"
    """An identified person that can be considered for inclusion in a study. """
    
    eligible = "eligible"
    """A person that has met the eligibility criteria for inclusion in a study. """
    
    followUp = "follow-up"
    """A person is no longer receiving study intervention and/or being evaluated with tests and procedures according to the protocol, but they are being monitored on a protocol-prescribed schedule. """
    
    ineligible = "ineligible"
    """A person who did not meet one or more criteria required for participation in a study is considered to have failed screening or
is ineligible for the study. """
    
    notRegistered = "not-registered"
    """A person for whom registration was not completed. """
    
    offStudy = "off-study"
    """A person that has ended their participation on a study either because their treatment/observation is complete or through not
responding, withdrawal, non-compliance and/or adverse event. """
    
    onStudy = "on-study"
    """A person that is enrolled or registered on a study. """
    
    onStudyIntervention = "on-study-intervention"
    """The person is receiving the treatment or participating in an activity (e.g. yoga, diet, etc.) that the study is evaluating. """
    
    onStudyObservation = "on-study-observation"
    """The subject is being evaluated via tests and assessments according to the study calendar, but is not receiving any intervention. Note that this state is study-dependent and might not exist in all studies.  A synonym for this is "short-term follow-up". """
    
    pendingOnStudy = "pending-on-study"
    """A person is pre-registered for a study. """
    
    potentialCandidate = "potential-candidate"
    """A person that is potentially eligible for participation in the study. """
    
    screening = "screening"
    """A person who is being evaluated for eligibility for a study. """
    
    withdrawn = "withdrawn"
    """The person has withdrawn their participation in the study before registration. """
    
class ResourceSecurityCategory(enum.Enum):
    
    anonymous = "anonymous"
    """These resources tend to not contain any individual data, or business sensitive data. Most often these Resources will be available for anonymous access, meaning there is no access control based on the user or system requesting. However these Resources do tend to contain important information that must be authenticated back to the source publishing them, and protected from integrity failures in communication. For this reason server authenticated https (TLS) is recommended to provide authentication of the server and integrity protection in transit. This is normal web-server use of https. """
    
    business = "business"
    """These Resources tend to not contain any individual data, but do have data that describe business or service sensitive data. The use of the term Business is not intended to only mean an incorporated business, but rather the more broad concept of an organization, location, or other group that is not identifable as individuals. Often these resources will require some for of client authentication to assure that only authorized access is given. The client access control may be to individuals, or may be to system identity. For this purpose possible client authentication methods such as: mutual-authenticated-TLS, APIKey, App signed JWT, or App OAuth client-id JWT For example: a App that uses a Business protected Provider Directory to determine other business endpoint details. """
    
    individual = "individual"
    """These Resources do NOT contain Patient data, but do contain individual information about other participants. These other individuals are Practitioners, PractionerRole, CareTeam, or other users. These identities are needed to enable the practice of healthcare. These identities are identities under general privacy regulations, and thus must consider Privacy risk. Often access to these other identities are covered by business relationships. For this purpose access to these Resources will tend to be Role specific using methods such as RBAC or ABAC. """
    
    patient = "patient"
    """These Resources make up the bulk of FHIR and therefore are the most commonly understood. These Resources contain highly sesitive health information, or are closely linked to highly sensitive health information. These Resources will often use the security labels to differentiate various confidentiality levels within this broad group of Patient Sensitive data. Access to these Resources often requires a declared Purpose Of Use. Access to these Resources is often controlled by a Privacy Consent. """
    
    notClassified = "not-classified"
    """Some Resources can be used for a wide scope of use-cases that span very sensitive to very non-sensitive. These Resources do not fall into any of the above classifications, as their sensitivity is highly variable. These Resources will need special handling. These Resources often contain metadata that describes the content in a way that can be used for Access Control decisions. """
    
class ResourceType(enum.Enum):
    
    account = "Account"
    """A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc. """
    
    activityDefinition = "ActivityDefinition"
    """This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context. """
    
    adverseEvent = "AdverseEvent"
    """Actual or  potential/avoided event causing unintended physical injury resulting from or contributed to by medical care, a research study or other healthcare setting factors that requires additional monitoring, treatment, or hospitalization, or that results in death. """
    
    allergyIntolerance = "AllergyIntolerance"
    """Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance. """
    
    appointment = "Appointment"
    """A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s). """
    
    appointmentResponse = "AppointmentResponse"
    """A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection. """
    
    auditEvent = "AuditEvent"
    """A record of an event made for purposes of maintaining a security log. Typical uses include detection of intrusion attempts and monitoring for inappropriate usage. """
    
    basic = "Basic"
    """Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don't map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification. """
    
    binary = "Binary"
    """A resource that represents the data of a single raw artifact as digital content accessible in its native format.  A Binary resource can contain any content, whether text, image, pdf, zip archive, etc. """
    
    biologicallyDerivedProduct = "BiologicallyDerivedProduct"
    """A material substance originating from a biological entity intended to be transplanted or infused
into another (possibly the same) biological entity. """
    
    bodyStructure = "BodyStructure"
    """Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case. """
    
    bundle = "Bundle"
    """A container for a collection of resources. """
    
    capabilityStatement = "CapabilityStatement"
    """A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation. """
    
    carePlan = "CarePlan"
    """Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions. """
    
    careTeam = "CareTeam"
    """The Care Team includes all the people and organizations who plan to participate in the coordination and delivery of care for a patient. """
    
    catalogEntry = "CatalogEntry"
    """Catalog entries are wrappers that contextualize items included in a catalog. """
    
    chargeItem = "ChargeItem"
    """The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation. """
    
    chargeItemDefinition = "ChargeItemDefinition"
    """The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system. """
    
    claim = "Claim"
    """A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement. """
    
    claimResponse = "ClaimResponse"
    """This resource provides the adjudication details from the processing of a Claim resource. """
    
    clinicalImpression = "ClinicalImpression"
    """A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score. """
    
    codeSystem = "CodeSystem"
    """The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content. """
    
    communication = "Communication"
    """An occurrence of information being transmitted; e.g. an alert that was sent to a responsible provider, a public health agency that was notified about a reportable condition. """
    
    communicationRequest = "CommunicationRequest"
    """A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition. """
    
    compartmentDefinition = "CompartmentDefinition"
    """A compartment definition that defines how resources are accessed on a server. """
    
    composition = "Composition"
    """A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.). """
    
    conceptMap = "ConceptMap"
    """A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models. """
    
    condition = "Condition"
    """A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern. """
    
    consent = "Consent"
    """A record of a healthcare consumer’s  choices, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time. """
    
    contract = "Contract"
    """Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement. """
    
    coverage = "Coverage"
    """Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment. """
    
    coverageEligibilityRequest = "CoverageEligibilityRequest"
    """The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy. """
    
    coverageEligibilityResponse = "CoverageEligibilityResponse"
    """This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource. """
    
    detectedIssue = "DetectedIssue"
    """Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, etc. """
    
    device = "Device"
    """A type of a manufactured item that is used in the provision of healthcare without being substantially changed through that activity. The device may be a medical or non-medical device. """
    
    deviceDefinition = "DeviceDefinition"
    """The characteristics, operational status and capabilities of a medical-related component of a medical device. """
    
    deviceMetric = "DeviceMetric"
    """Describes a measurement, calculation or setting capability of a medical device. """
    
    deviceRequest = "DeviceRequest"
    """Represents a request for a patient to employ a medical device. The device may be an implantable device, or an external assistive device, such as a walker. """
    
    deviceUseStatement = "DeviceUseStatement"
    """A record of a device being used by a patient where the record is the result of a report from the patient or another clinician. """
    
    diagnosticReport = "DiagnosticReport"
    """The findings and interpretation of diagnostic  tests performed on patients, groups of patients, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting and provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. """
    
    documentManifest = "DocumentManifest"
    """A collection of documents compiled for a purpose together with metadata that applies to the collection. """
    
    documentReference = "DocumentReference"
    """A reference to a document of any kind for any purpose. Provides metadata about the document so that the document can be discovered and managed. The scope of a document is any seralized object with a mime-type, so includes formal patient centric documents (CDA), cliical notes, scanned paper, and non-patient specific documents like policy text. """
    
    domainResource = "DomainResource"
    """A resource that includes narrative, extensions, and contained resources. """
    
    effectEvidenceSynthesis = "EffectEvidenceSynthesis"
    """The EffectEvidenceSynthesis resource describes the difference in an outcome between exposures states in a population where the effect estimate is derived from a combination of research studies. """
    
    encounter = "Encounter"
    """An interaction between a patient and healthcare provider(s) for the purpose of providing healthcare service(s) or assessing the health status of a patient. """
    
    endpoint = "Endpoint"
    """The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b or a REST endpoint for another FHIR server. This may include any security context information. """
    
    enrollmentRequest = "EnrollmentRequest"
    """This resource provides the insurance enrollment details to the insurer regarding a specified coverage. """
    
    enrollmentResponse = "EnrollmentResponse"
    """This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource. """
    
    episodeOfCare = "EpisodeOfCare"
    """An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time. """
    
    eventDefinition = "EventDefinition"
    """The EventDefinition resource provides a reusable description of when a particular event can occur. """
    
    evidence = "Evidence"
    """The Evidence resource describes the conditional state (population and any exposures being compared within the population) and outcome (if specified) that the knowledge (evidence, assertion, recommendation) is about. """
    
    evidenceVariable = "EvidenceVariable"
    """The EvidenceVariable resource describes a "PICO" element that knowledge (evidence, assertion, recommendation) is about. """
    
    exampleScenario = "ExampleScenario"
    """Example of workflow instance. """
    
    explanationOfBenefit = "ExplanationOfBenefit"
    """This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided. """
    
    familyMemberHistory = "FamilyMemberHistory"
    """Significant health conditions for a person related to the patient relevant in the context of care for the patient. """
    
    flag = "Flag"
    """Prospective warnings of potential issues when providing care to the patient. """
    
    goal = "Goal"
    """Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc. """
    
    graphDefinition = "GraphDefinition"
    """A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set. """
    
    group = "Group"
    """Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization. """
    
    guidanceResponse = "GuidanceResponse"
    """A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken. """
    
    healthcareService = "HealthcareService"
    """The details of a healthcare service available at a location. """
    
    imagingStudy = "ImagingStudy"
    """Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities. """
    
    immunization = "Immunization"
    """Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party. """
    
    immunizationEvaluation = "ImmunizationEvaluation"
    """Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations. """
    
    immunizationRecommendation = "ImmunizationRecommendation"
    """A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification. """
    
    implementationGuide = "ImplementationGuide"
    """A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts. """
    
    insurancePlan = "InsurancePlan"
    """Details of a Health Insurance product/plan provided by an organization. """
    
    invoice = "Invoice"
    """Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose. """
    
    library = "Library"
    """The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets. """
    
    linkage = "Linkage"
    """Identifies two or more records (resource instances) that refer to the same real-world "occurrence". """
    
    list = "List"
    """A list is a curated collection of resources. """
    
    location = "Location"
    """Details and position information for a physical place where services are provided and resources and participants may be stored, found, contained, or accommodated. """
    
    measure = "Measure"
    """The Measure resource provides the definition of a quality measure. """
    
    measureReport = "MeasureReport"
    """The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation. """
    
    media = "Media"
    """A photo, video, or audio recording acquired or used in healthcare. The actual content may be inline or provided by direct reference. """
    
    medication = "Medication"
    """This resource is primarily used for the identification and definition of a medication for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use. """
    
    medicationAdministration = "MedicationAdministration"
    """Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion.  Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. """
    
    medicationDispense = "MedicationDispense"
    """Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order. """
    
    medicationKnowledge = "MedicationKnowledge"
    """Information about a medication that is used to support knowledge. """
    
    medicationRequest = "MedicationRequest"
    """An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns. """
    
    medicationStatement = "MedicationStatement"
    """A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains. 

The primary difference between a medication statement and a medication administration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medication statement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the medication statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information. """
    
    medicinalProduct = "MedicinalProduct"
    """Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use). """
    
    medicinalProductAuthorization = "MedicinalProductAuthorization"
    """The regulatory authorization of a medicinal product. """
    
    medicinalProductContraindication = "MedicinalProductContraindication"
    """The clinical particulars - indications, contraindications etc. of a medicinal product, including for regulatory purposes. """
    
    medicinalProductIndication = "MedicinalProductIndication"
    """Indication for the Medicinal Product. """
    
    medicinalProductIngredient = "MedicinalProductIngredient"
    """An ingredient of a manufactured item or pharmaceutical product. """
    
    medicinalProductInteraction = "MedicinalProductInteraction"
    """The interactions of the medicinal product with other medicinal products, or other forms of interactions. """
    
    medicinalProductManufactured = "MedicinalProductManufactured"
    """The manufactured item as contained in the packaged medicinal product. """
    
    medicinalProductPackaged = "MedicinalProductPackaged"
    """A medicinal product in a container or package. """
    
    medicinalProductPharmaceutical = "MedicinalProductPharmaceutical"
    """A pharmaceutical product described in terms of its composition and dose form. """
    
    medicinalProductUndesirableEffect = "MedicinalProductUndesirableEffect"
    """Describe the undesirable effects of the medicinal product. """
    
    messageDefinition = "MessageDefinition"
    """Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted. """
    
    messageHeader = "MessageHeader"
    """The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle. """
    
    molecularSequence = "MolecularSequence"
    """Raw data describing a biological sequence. """
    
    namingSystem = "NamingSystem"
    """A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc.  Represents a "System" used within the Identifier and Coding data types. """
    
    nutritionOrder = "NutritionOrder"
    """A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident. """
    
    observation = "Observation"
    """Measurements and simple assertions made about a patient, device or other subject. """
    
    observationDefinition = "ObservationDefinition"
    """Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service. """
    
    operationDefinition = "OperationDefinition"
    """A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction). """
    
    operationOutcome = "OperationOutcome"
    """A collection of error, warning, or information messages that result from a system action. """
    
    organization = "Organization"
    """A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc. """
    
    organizationAffiliation = "OrganizationAffiliation"
    """Defines an affiliation/assotiation/relationship between 2 distinct oganizations, that is not a part-of relationship/sub-division relationship. """
    
    parameters = "Parameters"
    """This resource is a non-persisted resource used to pass information into and back from an [operation](operations.html). It has no other use, and there is no RESTful endpoint associated with it. """
    
    patient = "Patient"
    """Demographics and other administrative information about an individual or animal receiving care or other health-related services. """
    
    paymentNotice = "PaymentNotice"
    """This resource provides the status of the payment for goods and services rendered, and the request and response resource references. """
    
    paymentReconciliation = "PaymentReconciliation"
    """This resource provides the details including amount of a payment and allocates the payment items being paid. """
    
    person = "Person"
    """Demographics and administrative information about a person independent of a specific health-related context. """
    
    planDefinition = "PlanDefinition"
    """This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical artifacts such as clinical decision support rules, order sets and protocols. """
    
    practitioner = "Practitioner"
    """A person who is directly or indirectly involved in the provisioning of healthcare. """
    
    practitionerRole = "PractitionerRole"
    """A specific set of Roles/Locations/specialties/services that a practitioner may perform at an organization for a period of time. """
    
    procedure = "Procedure"
    """An action that is or was performed on or for a patient. This can be a physical intervention like an operation, or less invasive like long term services, counseling, or hypnotherapy. """
    
    provenance = "Provenance"
    """Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies. """
    
    questionnaire = "Questionnaire"
    """A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection. """
    
    questionnaireResponse = "QuestionnaireResponse"
    """A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to. """
    
    relatedPerson = "RelatedPerson"
    """Information about a person that is involved in the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process. """
    
    requestGroup = "RequestGroup"
    """A group of related requests that can be used to capture intended activities that have inter-dependencies such as "give this medication after that one". """
    
    researchDefinition = "ResearchDefinition"
    """The ResearchDefinition resource describes the conditional state (population and any exposures being compared within the population) and outcome (if specified) that the knowledge (evidence, assertion, recommendation) is about. """
    
    researchElementDefinition = "ResearchElementDefinition"
    """The ResearchElementDefinition resource describes a "PICO" element that knowledge (evidence, assertion, recommendation) is about. """
    
    researchStudy = "ResearchStudy"
    """A process where a researcher or organization plans and then executes a series of steps intended to increase the field of healthcare-related knowledge.  This includes studies of safety, efficacy, comparative effectiveness and other information about medications, devices, therapies and other interventional and investigative techniques.  A ResearchStudy involves the gathering of information about human or animal subjects. """
    
    researchSubject = "ResearchSubject"
    """A physical entity which is the primary unit of operational and/or administrative interest in a study. """
    
    resource = "Resource"
    """This is the base resource type for everything. """
    
    riskAssessment = "RiskAssessment"
    """An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome. """
    
    riskEvidenceSynthesis = "RiskEvidenceSynthesis"
    """The RiskEvidenceSynthesis resource describes the likelihood of an outcome in a population plus exposure state where the risk estimate is derived from a combination of research studies. """
    
    schedule = "Schedule"
    """A container for slots of time that may be available for booking appointments. """
    
    searchParameter = "SearchParameter"
    """A search parameter that defines a named search item that can be used to search/filter on a resource. """
    
    serviceRequest = "ServiceRequest"
    """A record of a request for service such as diagnostic investigations, treatments, or operations to be performed. """
    
    slot = "Slot"
    """A slot of time on a schedule that may be available for booking appointments. """
    
    specimen = "Specimen"
    """A sample to be used for analysis. """
    
    specimenDefinition = "SpecimenDefinition"
    """A kind of specimen with associated set of requirements. """
    
    structureDefinition = "StructureDefinition"
    """A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types. """
    
    structureMap = "StructureMap"
    """A Map of relationships between 2 structures that can be used to transform data. """
    
    subscription = "Subscription"
    """The subscription resource is used to define a push-based subscription from a server to another system. Once a subscription is registered with the server, the server checks every resource that is created or updated, and if the resource matches the given criteria, it sends a message on the defined "channel" so that another system can take an appropriate action. """
    
    substance = "Substance"
    """A homogeneous material with a definite composition. """
    
    substanceNucleicAcid = "SubstanceNucleicAcid"
    """Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction. """
    
    substancePolymer = "SubstancePolymer"
    """Todo. """
    
    substanceProtein = "SubstanceProtein"
    """A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators. """
    
    substanceReferenceInformation = "SubstanceReferenceInformation"
    """Todo. """
    
    substanceSourceMaterial = "SubstanceSourceMaterial"
    """Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex. """
    
    substanceSpecification = "SubstanceSpecification"
    """The detailed description of a substance, typically at a level beyond what is used for prescribing. """
    
    supplyDelivery = "SupplyDelivery"
    """Record of delivery of what is supplied. """
    
    supplyRequest = "SupplyRequest"
    """A record of a request for a medication, substance or device used in the healthcare setting. """
    
    task = "Task"
    """A task to be performed. """
    
    terminologyCapabilities = "TerminologyCapabilities"
    """A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation. """
    
    testReport = "TestReport"
    """A summary of information based on the results of executing a TestScript. """
    
    testScript = "TestScript"
    """A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification. """
    
    valueSet = "ValueSet"
    """A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in [coded elements](terminologies.html). """
    
    verificationResult = "VerificationResult"
    """Describes validation requirements, source(s), status and dates for one or more elements. """
    
    visionPrescription = "VisionPrescription"
    """An authorization for the provision of glasses and/or contact lenses to a patient. """
    
class ResourceValidationMode(enum.Enum):
    
    create = "create"
    """The server checks the content, and then checks that the content would be acceptable as a create (e.g. that the content would not violate any uniqueness constraints). """
    
    update = "update"
    """The server checks the content, and then checks that it would accept it as an update against the nominated specific resource (e.g. that there are no changes to immutable fields the server does not allow to change and checking version integrity if appropriate). """
    
    delete = "delete"
    """The server ignores the content and checks that the nominated resource is allowed to be deleted (e.g. checking referential integrity rules). """
    
    profile = "profile"
    """The server checks an existing resource (must be nominated by id, not provided as a parameter) as valid against the nominated profile. """
    
class ResourceVersionPolicy(enum.Enum):
    
    noVersion = "no-version"
    """VersionId meta-property is not supported (server) or used (client). """
    
    versioned = "versioned"
    """VersionId meta-property is supported (server) or used (client). """
    
    versionedUpdate = "versioned-update"
    """VersionId must be correct for updates (server) or will be specified (If-match header) for updates (client). """
    
class ResponseType(enum.Enum):
    
    ok = "ok"
    """The message was accepted and processed without error. """
    
    transientError = "transient-error"
    """Some internal unexpected error occurred - wait and try again. Note - this is usually used for things like database unavailable, which may be expected to resolve, though human intervention may be required. """
    
    fatalError = "fatal-error"
    """The message was rejected because of a problem with the content. There is no point in re-sending without change. The response narrative SHALL describe the issue. """
    
class RestfulCapabilityMode(enum.Enum):
    
    client = "client"
    """The application acts as a client for this resource. """
    
    server = "server"
    """The application acts as a server for this resource. """
    
class RestfulSecurityService(enum.Enum):
    
    oAuth = "OAuth"
    """OAuth (unspecified version see oauth.net). """
    
    sMARTOnFHIR = "SMART-on-FHIR"
    """OAuth2 using SMART-on-FHIR profile (see http://docs.smarthealthit.org/). """
    
    NTLM = "NTLM"
    """Microsoft NTLM Authentication. """
    
    basic = "Basic"
    """Basic authentication defined in HTTP specification. """
    
    kerberos = "Kerberos"
    """see http://www.ietf.org/rfc/rfc4120.txt. """
    
    certificates = "Certificates"
    """SSL where client must have a certificate registered with the server. """
    
class RiskEstimateType(enum.Enum):
    
    proportion = "proportion"
    """dichotomous measure (present or absent) reported as a ratio compared to the denominator of 1 (A percentage is a proportion with denominator of 100). """
    
    derivedProportion = "derivedProportion"
    """A special use case where the proportion is derived from a formula rather than derived from summary evidence. """
    
    mean = "mean"
    """continuous numerical measure reported as an average. """
    
    median = "median"
    """continuous numerical measure reported as the middle of the range. """
    
    count = "count"
    """descriptive measure reported as total number of items. """
    
    descriptive = "descriptive"
    """descriptive measure reported as narrative. """
    
class RiskProbability(enum.Enum):
    
    negligible = "negligible"
    """The specified outcome is exceptionally unlikely. """
    
    low = "low"
    """The specified outcome is possible but unlikely. """
    
    moderate = "moderate"
    """The specified outcome has a reasonable likelihood of occurrence. """
    
    high = "high"
    """The specified outcome is more likely to occur than not. """
    
    certain = "certain"
    """The specified outcome is effectively guaranteed. """
    
class SNOMEDCTReasonMedicationNotGivenCodes(enum.Enum):
    
    A = "a"
    """No reason known. """
    
    B = "b"
    """The patient was not available when the dose was scheduled. """
    
    C = "c"
    """The patient was asleep when the dose was scheduled. """
    
    D = "d"
    """The patient was given the medication and immediately vomited it back. """
    
class SearchComparator(enum.Enum):
    
    eq = "eq"
    """the value for the parameter in the resource is equal to the provided value. """
    
    ne = "ne"
    """the value for the parameter in the resource is not equal to the provided value. """
    
    gt = "gt"
    """the value for the parameter in the resource is greater than the provided value. """
    
    lt = "lt"
    """the value for the parameter in the resource is less than the provided value. """
    
    ge = "ge"
    """the value for the parameter in the resource is greater or equal to the provided value. """
    
    le = "le"
    """the value for the parameter in the resource is less or equal to the provided value. """
    
    sa = "sa"
    """the value for the parameter in the resource starts after the provided value. """
    
    eb = "eb"
    """the value for the parameter in the resource ends before the provided value. """
    
    ap = "ap"
    """the value for the parameter in the resource is approximately the same to the provided value. """
    
class SearchEntryMode(enum.Enum):
    
    match = "match"
    """This resource matched the search specification. """
    
    include = "include"
    """This resource is returned because it is referred to from another resource in the search set. """
    
    outcome = "outcome"
    """An OperationOutcome that provides additional information about the processing of a search. """
    
class SearchModifierCode(enum.Enum):
    
    missing = "missing"
    """The search parameter returns resources that have a value or not. """
    
    exact = "exact"
    """The search parameter returns resources that have a value that exactly matches the supplied parameter (the whole string, including casing and accents). """
    
    contains = "contains"
    """The search parameter returns resources that include the supplied parameter value anywhere within the field being searched. """
    
    not_ = "not"
    """The search parameter returns resources that do not contain a match. """
    
    text = "text"
    """The search parameter is processed as a string that searches text associated with the code/value - either CodeableConcept.text, Coding.display, or Identifier.type.text. """
    
    in_ = "in"
    """The search parameter is a URI (relative or absolute) that identifies a value set, and the search parameter tests whether the coding is in the specified value set. """
    
    notIn = "not-in"
    """The search parameter is a URI (relative or absolute) that identifies a value set, and the search parameter tests whether the coding is not in the specified value set. """
    
    below = "below"
    """The search parameter tests whether the value in a resource is subsumed by the specified value (is-a, or hierarchical relationships). """
    
    above = "above"
    """The search parameter tests whether the value in a resource subsumes the specified value (is-a, or hierarchical relationships). """
    
    type = "type"
    """The search parameter only applies to the Resource Type specified as a modifier (e.g. the modifier is not actually :type, but :Patient etc.). """
    
    identifier = "identifier"
    """The search parameter applies to the identifier on the resource, not the reference. """
    
    ofType = "ofType"
    """The search parameter has the format system|code|value, where the system and code refer to an Identifier.type.coding.system and .code, and match if any of the type codes match. All 3 parts must be present. """
    
class SearchParamType(enum.Enum):
    
    number = "number"
    """Search parameter SHALL be a number (a whole number, or a decimal). """
    
    date = "date"
    """Search parameter is on a date/time. The date format is the standard XML format, though other formats may be supported. """
    
    string = "string"
    """Search parameter is a simple string, like a name part. Search is case-insensitive and accent-insensitive. May match just the start of a string. String parameters may contain spaces. """
    
    token = "token"
    """Search parameter on a coded element or identifier. May be used to search through the text, display, code and code/codesystem (for codes) and label, system and key (for identifier). Its value is either a string or a pair of namespace and value, separated by a "|", depending on the modifier used. """
    
    reference = "reference"
    """A reference to another resource (Reference or canonical). """
    
    composite = "composite"
    """A composite search parameter that combines a search on two values together. """
    
    quantity = "quantity"
    """A search parameter that searches on a quantity. """
    
    uri = "uri"
    """A search parameter that searches on a URI (RFC 3986). """
    
    special = "special"
    """Special logic applies to this parameter per the description of the search parameter. """
    
class SequenceStatus(enum.Enum):
    
    positive = "positive"
    """the variant is detected. """
    
    negative = "negative"
    """no variant is detected. """
    
    absent = "absent"
    """result of the variant is missing. """
    
class SequenceType(enum.Enum):
    
    aa = "aa"
    """Amino acid sequence. """
    
    dna = "dna"
    """DNA Sequence. """
    
    rna = "rna"
    """RNA Sequence. """
    
class ServiceProvisionConditions(enum.Enum):
    
    free = "free"
    """This service is available for no patient cost. """
    
    disc = "disc"
    """There are discounts available on this service for qualifying patients. """
    
    cost = "cost"
    """Fees apply for this service. """
    
class SlicingRules(enum.Enum):
    
    closed = "closed"
    """No additional content is allowed other than that described by the slices in this profile. """
    
    open = "open"
    """Additional content is allowed anywhere in the list. """
    
    openAtEnd = "openAtEnd"
    """Additional content is allowed, but only at the end of the list. Note that using this requires that the slices be ordered, which makes it hard to share uses. This should only be done where absolutely required. """
    
class SlotStatus(enum.Enum):
    
    busy = "busy"
    """Indicates that the time interval is busy because one  or more events have been scheduled for that interval. """
    
    free = "free"
    """Indicates that the time interval is free for scheduling. """
    
    busyUnavailable = "busy-unavailable"
    """Indicates that the time interval is busy and that the interval cannot be scheduled. """
    
    busyTentative = "busy-tentative"
    """Indicates that the time interval is busy because one or more events have been tentatively scheduled for that interval. """
    
    enteredInError = "entered-in-error"
    """This instance should not have been part of this patient's medical record. """
    
class SmartCapabilities(enum.Enum):
    
    launchEhr = "launch-ehr"
    """support for SMART’s EHR Launch mode. """
    
    launchStandalone = "launch-standalone"
    """support for SMART’s Standalone Launch mode. """
    
    clientPublic = "client-public"
    """support for SMART’s public client profile (no client authentication). """
    
    clientConfidentialSymmetric = "client-confidential-symmetric"
    """support for SMART’s confidential client profile (symmetric client secret authentication). """
    
    ssoOpenidConnect = "sso-openid-connect"
    """support for SMART’s OpenID Connect profile. """
    
    contextPassthroughBanner = "context-passthrough-banner"
    """support for “need patient banner” launch context (conveyed via need_patient_banner token parameter). """
    
    contextPassthroughStyle = "context-passthrough-style"
    """support for “SMART style URL” launch context (conveyed via smart_style_url token parameter). """
    
    contextEhrPatient = "context-ehr-patient"
    """support for patient-level launch context (requested by launch/patient scope, conveyed via patient token parameter). """
    
    contextEhrEncounter = "context-ehr-encounter"
    """support for encounter-level launch context (requested by launch/encounter scope, conveyed via encounter token parameter). """
    
    contextStandalonePatient = "context-standalone-patient"
    """support for patient-level launch context (requested by launch/patient scope, conveyed via patient token parameter). """
    
    contextStandaloneEncounter = "context-standalone-encounter"
    """support for encounter-level launch context (requested by launch/encounter scope, conveyed via encounter token parameter). """
    
    permissionOffline = "permission-offline"
    """support for refresh tokens (requested by offline_access scope). """
    
    permissionPatient = "permission-patient"
    """support for patient-level scopes (e.g. patient/Observation.read). """
    
    permissionUser = "permission-user"
    """support for user-level scopes (e.g. user/Appointment.read). """
    
class SortDirection(enum.Enum):
    
    ascending = "ascending"
    """Sort by the value ascending, so that lower values appear first. """
    
    descending = "descending"
    """Sort by the value descending, so that lower values appear last. """
    
class SpecialArrangements(enum.Enum):
    
    wheel = "wheel"
    """The patient requires a wheelchair to be made available for the encounter. """
    
    addBed = "add-bed"
    """An additional bed made available for a person accompanying the patient, for example a parent accompanying a child. """
    
    int = "int"
    """The patient is not fluent in the local language and requires an interpreter to be available. Refer to the Patient.Language property for the type of interpreter required. """
    
    att = "att"
    """A person who accompanies a patient to provide assistive services necessary for the patient's care during the encounter. """
    
    dog = "dog"
    """The patient has a guide dog and the location used for the encounter should be able to support the presence of the service animal. """
    
class SpecialValues(enum.Enum):
    
    true = "true"
    """Boolean true. """
    
    false = "false"
    """Boolean false. """
    
    trace = "trace"
    """The content is greater than zero, but too small to be quantified. """
    
    sufficient = "sufficient"
    """The specific quantity is not known, but is known to be non-zero and is not specified because it makes up the bulk of the material. """
    
    withdrawn = "withdrawn"
    """The value is no longer available. """
    
    nilKnown = "nil-known"
    """The are no known applicable values in this context. """
    
class SpecimenContainedPreference(enum.Enum):
    
    preferred = "preferred"
    """This type of contained specimen is preferred to collect this kind of specimen. """
    
    alternate = "alternate"
    """This type of conditioned specimen is an alternate. """
    
class SpecimenStatus(enum.Enum):
    
    available = "available"
    """The physical specimen is present and in good condition. """
    
    unavailable = "unavailable"
    """There is no physical specimen because it is either lost, destroyed or consumed. """
    
    unsatisfactory = "unsatisfactory"
    """The specimen cannot be used because of a quality issue such as a broken container, contamination, or too old. """
    
    enteredInError = "entered-in-error"
    """The specimen was entered in error and therefore nullified. """
    
class StandardsStatus(enum.Enum):
    
    draft = "draft"
    """This portion of the specification is not considered to be complete enough or sufficiently reviewed to be safe for implementation. It may have known issues or still be in the "in development" stage. It is included in the publication as a place-holder, to solicit feedback from the implementation community and/or to give implementers some insight as to functionality likely to be included in future versions of the specification. Content at this level should only be implemented by the brave or desperate and is very much "use at your own risk". The content that is Draft that will usually be elevated to Trial Use once review and correction is complete after it has been subjected to ballot. """
    
    normative = "normative"
    """This content has been subject to review and production implementation in a wide variety of environments. The content is considered to be stable and has been 'locked', subjecting it to FHIR Inter-version Compatibility Rules. While changes are possible, they are expected to be infrequent and are tightly constrained. Compatibility Rules. """
    
    trialUse = "trial-use"
    """This content has been well reviewed and is considered by the authors to be ready for use in production systems. It has been subjected to ballot and approved as an official standard. However, it has not yet seen widespread use in production across the full spectrum of environments it is intended to be used in. In some cases, there may be documented known issues that require implementation experience to determine appropriate resolutions for.

Future versions of FHIR may make significant changes to Trial Use content that are not compatible with previously published content. """
    
    informative = "informative"
    """This portion of the specification is provided for implementer assistance, and does not make rules that implementers are required to follow. Typical examples of this content in the FHIR specification are tables of contents, registries, examples, and implementer advice. """
    
    deprecated = "deprecated"
    """This portion of the specification is provided for implementer assistance, and does not make rules that implementers are required to follow. Typical examples of this content in the FHIR specification are tables of contents, registries, examples, and implementer advice. """
    
    external = "external"
    """This is content that is managed outside the FHIR Specification, but included for implementer convenience. """
    
class Status(enum.Enum):
    
    attested = "attested"
    """***TODO*** """
    
    validated = "validated"
    """***TODO*** """
    
    inProcess = "in-process"
    """***TODO*** """
    
    reqRevalid = "req-revalid"
    """***TODO*** """
    
    valFail = "val-fail"
    """***TODO*** """
    
    revalFail = "reval-fail"
    """***TODO*** """
    
class StrandType(enum.Enum):
    
    watson = "watson"
    """Watson strand of reference sequence. """
    
    crick = "crick"
    """Crick strand of reference sequence. """
    
class StrengthOfRecommendationRating(enum.Enum):
    
    strong = "strong"
    """Strong recommendation. """
    
    weak = "weak"
    """Weak recommendation. """
    
class StructureDefinitionKind(enum.Enum):
    
    primitiveType = "primitive-type"
    """A primitive type that has a value and an extension. These can be used throughout complex datatype, Resource and extension definitions. Only the base specification can define primitive types. """
    
    complexType = "complex-type"
    """A  complex structure that defines a set of data elements that is suitable for use in 'resources'. The base specification defines a number of complex types, and other specifications can define additional types. These structures do not have a maintained identity. """
    
    resource = "resource"
    """A 'resource' - a directed acyclic graph of elements that aggregrates other types into an identifiable entity. The base FHIR resources are defined by the FHIR specification itself but other 'resources' can be defined in additional specifications (though these will not be recognised as 'resources' by the FHIR specification (i.e. they do not get end-points etc, or act as the targets of references in FHIR defined resources - though other specificatiosn can treat them this way). """
    
    logical = "logical"
    """A pattern or a template that is not intended to be a real resource or complex type. """
    
class StructureMapContextType(enum.Enum):
    
    type = "type"
    """The context specifies a type. """
    
    variable = "variable"
    """The context specifies a variable. """
    
class StructureMapGroupTypeMode(enum.Enum):
    
    none = "none"
    """This group is not a default group for the types. """
    
    types = "types"
    """This group is a default mapping group for the specified types and for the primary source type. """
    
    typeAndTypes = "type-and-types"
    """This group is a default mapping group for the specified types. """
    
class StructureMapInputMode(enum.Enum):
    
    source = "source"
    """Names an input instance used a source for mapping. """
    
    target = "target"
    """Names an instance that is being populated. """
    
class StructureMapModelMode(enum.Enum):
    
    source = "source"
    """This structure describes an instance passed to the mapping engine that is used a source of data. """
    
    queried = "queried"
    """This structure describes an instance that the mapping engine may ask for that is used a source of data. """
    
    target = "target"
    """This structure describes an instance passed to the mapping engine that is used a target of data. """
    
    produced = "produced"
    """This structure describes an instance that the mapping engine may ask to create that is used a target of data. """
    
class StructureMapSourceListMode(enum.Enum):
    
    first = "first"
    """Only process this rule for the first in the list. """
    
    not_first = "not_first"
    """Process this rule for all but the first. """
    
    last = "last"
    """Only process this rule for the last in the list. """
    
    not_last = "not_last"
    """Process this rule for all but the last. """
    
    only_one = "only_one"
    """Only process this rule is there is only item. """
    
class StructureMapTargetListMode(enum.Enum):
    
    first = "first"
    """when the target list is being assembled, the items for this rule go first. If more than one rule defines a first item (for a given instance of mapping) then this is an error. """
    
    share = "share"
    """the target instance is shared with the target instances generated by another rule (up to the first common n items, then create new ones). """
    
    last = "last"
    """when the target list is being assembled, the items for this rule go last. If more than one rule defines a last item (for a given instance of mapping) then this is an error. """
    
    collate = "collate"
    """re-use the first item in the list, and keep adding content to it. """
    
class StructureMapTransform(enum.Enum):
    
    create = "create"
    """create(type : string) - type is passed through to the application on the standard API, and must be known by it. """
    
    copy = "copy"
    """copy(source). """
    
    truncate = "truncate"
    """truncate(source, length) - source must be stringy type. """
    
    escape = "escape"
    """escape(source, fmt1, fmt2) - change source from one kind of escaping to another (plain, java, xml, json). note that this is for when the string itself is escaped. """
    
    cast = "cast"
    """cast(source, type?) - case source from one type to another. target type can be left as implicit if there is one and only one target type known. """
    
    append = "append"
    """append(source...) - source is element or string. """
    
    translate = "translate"
    """translate(source, uri_of_map) - use the translate operation. """
    
    reference = "reference"
    """reference(source : object) - return a string that references the provided tree properly. """
    
    dateOp = "dateOp"
    """Perform a date operation. *Parameters to be documented*. """
    
    uuid = "uuid"
    """Generate a random UUID (in lowercase). No Parameters. """
    
    pointer = "pointer"
    """Return the appropriate string to put in a reference that refers to the resource provided as a parameter. """
    
    evaluate = "evaluate"
    """Execute the supplied FHIRPath expression and use the value returned by that. """
    
    cc = "cc"
    """Create a CodeableConcept. Parameters = (text) or (system. Code[, display]). """
    
    C = "c"
    """Create a Coding. Parameters = (system. Code[, display]). """
    
    qty = "qty"
    """Create a quantity. Parameters = (text) or (value, unit, [system, code]) where text is the natural representation e.g. [comparator]value[space]unit. """
    
    id = "id"
    """Create an identifier. Parameters = (system, value[, type]) where type is a code from the identifier type value set. """
    
    cp = "cp"
    """Create a contact details. Parameters = (value) or (system, value). If no system is provided, the system should be inferred from the content of the value. """
    
class StudyType(enum.Enum):
    
    RCT = "RCT"
    """randomized controlled trial. """
    
    CCT = "CCT"
    """controlled (but not randomized) trial. """
    
    cohort = "cohort"
    """observational study comparing cohorts. """
    
    caseControl = "case-control"
    """case-control study. """
    
    series = "series"
    """uncontrolled cohort or case series. """
    
    caseReport = "case-report"
    """a single case report. """
    
    mixed = "mixed"
    """a combination of 1 or more types of studies. """
    
class SubscriberRelationshipCodes(enum.Enum):
    
    child = "child"
    """The Beneficiary is a child of the Subscriber """
    
    parent = "parent"
    """The Beneficiary is a parent of the Subscriber """
    
    spouse = "spouse"
    """The Beneficiary is a spouse or equivalent of the Subscriber """
    
    common = "common"
    """The Beneficiary is a common law spouse or equivalent of the Subscriber """
    
    other = "other"
    """The Beneficiary has some other relationship the Subscriber """
    
    self = "self"
    """The Beneficiary is the Subscriber """
    
    injured = "injured"
    """The Beneficiary is covered under insurance of the subscriber due to an injury. """
    
class SubscriptionChannelType(enum.Enum):
    
    restHook = "rest-hook"
    """The channel is executed by making a post to the URI. If a payload is included, the URL is interpreted as the service base, and an update (PUT) is made. """
    
    websocket = "websocket"
    """The channel is executed by sending a packet across a web socket connection maintained by the client. The URL identifies the websocket, and the client binds to this URL. """
    
    email = "email"
    """The channel is executed by sending an email to the email addressed in the URI (which must be a mailto:). """
    
    sms = "sms"
    """The channel is executed by sending an SMS message to the phone number identified in the URL (tel:). """
    
    message = "message"
    """The channel is executed by sending a message (e.g. a Bundle with a MessageHeader resource etc.) to the application identified in the URI. """
    
class SubscriptionStatus(enum.Enum):
    
    requested = "requested"
    """The client has requested the subscription, and the server has not yet set it up. """
    
    active = "active"
    """The subscription is active. """
    
    error = "error"
    """The server has an error executing the notification. """
    
    off = "off"
    """Too many errors have occurred or the subscription has expired. """
    
class SubscriptionTag(enum.Enum):
    
    queued = "queued"
    """The message has been queued for processing on a destination systems. """
    
    delivered = "delivered"
    """The message has been delivered to its intended recipient. """
    
class SubstanceCategoryCodes(enum.Enum):
    
    allergen = "allergen"
    """A substance that causes an allergic reaction. """
    
    biological = "biological"
    """A substance that is produced by or extracted from a biological source. """
    
    body = "body"
    """A substance that comes directly from a human or an animal (e.g. blood, urine, feces, tears, etc.). """
    
    chemical = "chemical"
    """Any organic or inorganic substance of a particular molecular identity, including -- (i) any combination of such substances occurring in whole or in part as a result of a chemical reaction or occurring in nature and (ii) any element or uncombined radical (http://www.epa.gov/opptintr/import-export/pubs/importguide.pdf). """
    
    food = "food"
    """A food, dietary ingredient, or dietary supplement for human or animal. """
    
    drug = "drug"
    """A substance intended for use in the diagnosis, cure, mitigation, treatment, or prevention of disease in man or other animals (Federal Food Drug and Cosmetic Act). """
    
    material = "material"
    """A finished product which is not normally ingested, absorbed or injected (e.g. steel, iron, wood, plastic and paper). """
    
class SupplyDeliveryStatus(enum.Enum):
    
    inProgress = "in-progress"
    """Supply has been requested, but not delivered. """
    
    completed = "completed"
    """Supply has been delivered ("completed"). """
    
    abandoned = "abandoned"
    """Delivery was not completed. """
    
    enteredInError = "entered-in-error"
    """This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be "abandoned" rather than "entered-in-error".). """
    
class SupplyItemType(enum.Enum):
    
    medication = "medication"
    """Supply is a kind of medication. """
    
    device = "device"
    """What is supplied (or requested) is a device. """
    
class SupplyRequestReason(enum.Enum):
    
    patientCare = "patient-care"
    """The supply has been requested for use in direct patient care. """
    
    wardStock = "ward-stock"
    """The supply has been requested for creating or replenishing ward stock. """
    
class SupplyRequestStatus(enum.Enum):
    
    draft = "draft"
    """The request has been created but is not yet complete or ready for action. """
    
    active = "active"
    """The request is ready to be acted upon. """
    
    suspended = "suspended"
    """The authorization/request to act has been temporarily withdrawn but is expected to resume in the future. """
    
    cancelled = "cancelled"
    """The authorization/request to act has been terminated prior to the full completion of the intended actions.  No further activity should occur. """
    
    completed = "completed"
    """Activity against the request has been sufficiently completed to the satisfaction of the requester. """
    
    enteredInError = "entered-in-error"
    """This electronic record should never have existed, though it is possible that real-world decisions were based on it.  (If real-world activity has occurred, the status should be "cancelled" rather than "entered-in-error".). """
    
    unknown = "unknown"
    """The authoring/source system does not know which of the status values currently applies for this observation. Note: This concept is not to be used for "other" - one of the listed statuses is presumed to apply, but the authoring/source system does not know which. """
    
class SupplyType(enum.Enum):
    
    central = "central"
    """Supply is stored and requested from central supply. """
    
    nonstock = "nonstock"
    """Supply is not onsite and must be requested from an outside vendor using a non-stock requisition. """
    
class SurfaceCodes(enum.Enum):
    
    M = "M"
    """The surface of a tooth that is closest to the midline (middle) of the face. """
    
    O = "O"
    """The chewing surface of posterior teeth. """
    
    I = "I"
    """The biting edge of anterior teeth. """
    
    D = "D"
    """The surface of a tooth that faces away from the midline of the face. """
    
    B = "B"
    """The surface of a posterior tooth facing the cheeks. """
    
    V = "V"
    """The surface of a tooth facing the lips. """
    
    L = "L"
    """The surface of a tooth facing the tongue. """
    
    MO = "MO"
    """The Mesioclusal surfaces of a tooth. """
    
    DO = "DO"
    """The Distoclusal surfaces of a tooth. """
    
    DI = "DI"
    """The Distoincisal surfaces of a tooth. """
    
    MOD = "MOD"
    """The Mesioclusodistal surfaces of a tooth. """
    
class SynthesisType(enum.Enum):
    
    stdMA = "std-MA"
    """A meta-analysis of the summary data of estimates from individual studies or data sets. """
    
    IPDMA = "IPD-MA"
    """A meta-analysis of the individual participant data from individual studies or data sets. """
    
    indirectNMA = "indirect-NMA"
    """An indirect meta-analysis derived from 2 or more direct comparisons in a network meta-analysis. """
    
    combinedNMA = "combined-NMA"
    """An composite meta-analysis derived from direct comparisons and indirect comparisons in a network meta-analysis. """
    
    range = "range"
    """A range of results across a body of evidence. """
    
    classification = "classification"
    """An approach describing a body of evidence by categorically classifying individual studies (eg 3 studies showed beneft and 2 studied found no effect). """
    
class TaskCode(enum.Enum):
    
    approve = "approve"
    """Take what actions are needed to transition the focus resource from 'draft' to 'active' or 'in-progress', as appropriate for the resource type.  This may involve additing additional content, approval, validation, etc. """
    
    fulfill = "fulfill"
    """Act to perform the actions defined in the focus request.  This might result in a 'more assertive' request (order for a plan or proposal, filler order for a placer order), but is intend to eventually result in events.  The degree of fulfillment requested might be limited by Task.restriction. """
    
    abort = "abort"
    """Abort, cancel or withdraw the focal resource, as appropriate for the type of resource. """
    
    replace = "replace"
    """Replace the focal resource with the specified input resource """
    
    change = "change"
    """Update the focal resource of the owning system to reflect the content specified as the Task.focus """
    
    suspend = "suspend"
    """Transition the focal resource from 'active' or 'in-progress' to 'suspended' """
    
    resume = "resume"
    """Transition the focal resource from 'suspended' to 'active' or 'in-progress' as appropriate for the resource type. """
    
class TaskIntent(enum.Enum):
    
    unknown = "unknown"
    """The intent is not known.  When dealing with Task, it's not always known (or relevant) how the task was initiated - i.e. whether it was proposed, planned, ordered or just done spontaneously. """
    
class TaskStatus(enum.Enum):
    
    draft = "draft"
    """The task is not yet ready to be acted upon. """
    
    requested = "requested"
    """The task is ready to be acted upon and action is sought. """
    
    received = "received"
    """A potential performer has claimed ownership of the task and is evaluating whether to perform it. """
    
    accepted = "accepted"
    """The potential performer has agreed to execute the task but has not yet started work. """
    
    rejected = "rejected"
    """The potential performer who claimed ownership of the task has decided not to execute it prior to performing any action. """
    
    ready = "ready"
    """The task is ready to be performed, but no action has yet been taken.  Used in place of requested/received/accepted/rejected when request assignment and acceptance is a given. """
    
    cancelled = "cancelled"
    """The task was not completed. """
    
    inProgress = "in-progress"
    """The task has been started but is not yet complete. """
    
    onHold = "on-hold"
    """The task has been started but work has been paused. """
    
    failed = "failed"
    """The task was attempted but could not be completed due to some error. """
    
    completed = "completed"
    """The task has been completed. """
    
    enteredInError = "entered-in-error"
    """The task should never have existed and is retained only because of the possibility it may have used. """
    
class TemplateStatusCodeLifeCycle(enum.Enum):
    
    draft = "draft"
    """Design is under development (nascent). """
    
    pending = "pending"
    """Design is completed and is being reviewed. """
    
    active = "active"
    """Design has been deemed fit for the intended purpose and is published by the governance group. """
    
    review = "review"
    """Design is active, but is under review. The review may result in a change to the design. The change may necessitate a new version to be created. This in turn may result in the prior version of the template to be retired. Alternatively, the review may result in a change to the design that does not require a new version to be created, or it may result in no change to the design at all. """
    
    cancelled = "cancelled"
    """A drafted design is determined to be erroneous or not fit for intended purpose and is discontinued before ever being published in an active state. """
    
    rejected = "rejected"
    """A previously drafted design is determined to be erroneous or not fit for intended purpose and is discontinued before ever being published for consideration in a pending state. """
    
    retired = "retired"
    """A previously active design is discontinued from use. It should no longer be used for future designs, but for historical purposes may be used to process data previously recorded using this design. A newer design may or may not exist. The design is published in the retired state. """
    
    terminated = "terminated"
    """A design is determined to be erroneous or not fit for the intended purpose and should no longer be used, even for historical purposes. No new designs can be developed for this template. The associated template no longer needs to be published, but if published, is shown in the terminated state. """
    
class TestReportActionResult(enum.Enum):
    
    pass_ = "pass"
    """The action was successful. """
    
    skip = "skip"
    """The action was skipped. """
    
    fail = "fail"
    """The action failed. """
    
    warning = "warning"
    """The action passed but with warnings. """
    
    error = "error"
    """The action encountered a fatal error and the engine was unable to process. """
    
class TestReportParticipantType(enum.Enum):
    
    testEngine = "test-engine"
    """The test execution engine. """
    
    client = "client"
    """A FHIR Client. """
    
    server = "server"
    """A FHIR Server. """
    
class TestReportResult(enum.Enum):
    
    pass_ = "pass"
    """All test operations successfully passed all asserts. """
    
    fail = "fail"
    """One or more test operations failed one or more asserts. """
    
    pending = "pending"
    """One or more test operations is pending execution completion. """
    
class TestReportStatus(enum.Enum):
    
    completed = "completed"
    """All test operations have completed. """
    
    inProgress = "in-progress"
    """A test operations is currently executing. """
    
    waiting = "waiting"
    """A test operation is waiting for an external client request. """
    
    stopped = "stopped"
    """The test script execution was manually stopped. """
    
    enteredInError = "entered-in-error"
    """This test report was entered or created in error. """
    
class TestScriptOperationCode(enum.Enum):
    
    read = "read"
    """Read the current state of the resource. """
    
    vread = "vread"
    """Read the state of a specific version of the resource. """
    
    update = "update"
    """Update an existing resource by its id. """
    
    updateCreate = "updateCreate"
    """Update an existing resource by its id (or create it if it is new). """
    
    patch = "patch"
    """Patch an existing resource by its id. """
    
    delete = "delete"
    """Delete a resource. """
    
    deleteCondSingle = "deleteCondSingle"
    """Conditionally delete a single resource based on search parameters. """
    
    deleteCondMultiple = "deleteCondMultiple"
    """Conditionally delete one or more resources based on search parameters. """
    
    history = "history"
    """Retrieve the change history for a particular resource or resource type. """
    
    create = "create"
    """Create a new resource with a server assigned id. """
    
    search = "search"
    """Search based on some filter criteria. """
    
    batch = "batch"
    """Update, create or delete a set of resources as independent actions. """
    
    transaction = "transaction"
    """Update, create or delete a set of resources as a single transaction. """
    
    capabilities = "capabilities"
    """Get a capability statement for the system. """
    
    apply = "apply"
    """Realizes an ActivityDefinition in a specific context """
    
    closure = "closure"
    """Closure Table Maintenance """
    
    findMatches = "find-matches"
    """Finding Codes based on supplied properties """
    
    conforms = "conforms"
    """Compare two systems CapabilityStatements """
    
    dataRequirements = "data-requirements"
    """Aggregates and returns the parameters and data requirements for a resource and all its dependencies as a single module definition """
    
    document = "document"
    """Generate a Document """
    
    evaluate = "evaluate"
    """Request clinical decision support guidance based on a specific decision support module """
    
    evaluateMeasure = "evaluate-measure"
    """Invoke an eMeasure and obtain the results """
    
    everything = "everything"
    """Return all the related information as described in the Encounter or Patient """
    
    expand = "expand"
    """Value Set Expansion """
    
    find = "find"
    """Find a functional list """
    
    graphql = "graphql"
    """Invoke a GraphQL query """
    
    implements = "implements"
    """Test if a server implements a client's required operations """
    
    lastn = "lastn"
    """Last N Observations Query """
    
    lookup = "lookup"
    """Concept Look Up and Decomposition """
    
    match = "match"
    """Find patient matches using MPI based logic """
    
    meta = "meta"
    """Access a list of profiles, tags, and security labels """
    
    metaAdd = "meta-add"
    """Add profiles, tags, and security labels to a resource """
    
    metaDelete = "meta-delete"
    """Delete profiles, tags, and security labels for a resource """
    
    populate = "populate"
    """Populate Questionnaire """
    
    populatehtml = "populatehtml"
    """Generate HTML for Questionnaire """
    
    populatelink = "populatelink"
    """Generate a link to a Questionnaire completion webpage """
    
    processMessage = "process-message"
    """Process a message according to the defined event """
    
    questionnaire = "questionnaire"
    """Build Questionnaire """
    
    stats = "stats"
    """Observation Statistics """
    
    subset = "subset"
    """Fetch a subset of the CapabilityStatement resource """
    
    subsumes = "subsumes"
    """CodeSystem Subsumption Testing """
    
    transform = "transform"
    """Model Instance Transformation """
    
    translate = "translate"
    """Concept Translation """
    
    validate = "validate"
    """Validate a resource """
    
    validateCode = "validate-code"
    """ValueSet based Validation """
    
class TestScriptProfileDestinationType(enum.Enum):
    
    fHIRServer = "FHIR-Server"
    """General FHIR server used to respond to operations sent from a FHIR client. """
    
    fHIRSDCFormManager = "FHIR-SDC-FormManager"
    """A FHIR server acting as a Structured Data Capture Form Manager. """
    
    fHIRSDCFormProcessor = "FHIR-SDC-FormProcessor"
    """A FHIR server acting as a Structured Data Capture Form Processor. """
    
    fHIRSDCFormReceiver = "FHIR-SDC-FormReceiver"
    """A FHIR server acting as a Structured Data Capture Form Receiver. """
    
class TestScriptProfileOriginType(enum.Enum):
    
    fHIRClient = "FHIR-Client"
    """General FHIR client used to initiate operations against a FHIR server. """
    
    fHIRSDCFormFiller = "FHIR-SDC-FormFiller"
    """A FHIR client acting as a Structured Data Capture Form Filler. """
    
class TestScriptRequestMethodCode(enum.Enum):
    
    delete = "delete"
    """HTTP DELETE operation. """
    
    get = "get"
    """HTTP GET operation. """
    
    options = "options"
    """HTTP OPTIONS operation. """
    
    patch = "patch"
    """HTTP PATCH operation. """
    
    post = "post"
    """HTTP POST operation. """
    
    put = "put"
    """HTTP PUT operation. """
    
    head = "head"
    """HTTP HEAD operation. """
    
class TransactionMode(enum.Enum):
    
    notSupported = "not-supported"
    """Neither batch or transaction is supported. """
    
    batch = "batch"
    """Batches are  supported. """
    
    transaction = "transaction"
    """Transactions are supported. """
    
    both = "both"
    """Both batches and transactions are supported. """
    
class TriggerType(enum.Enum):
    
    namedEvent = "named-event"
    """The trigger occurs in response to a specific named event, and no other information about the trigger is specified. Named events are completely pre-coordinated, and the formal semantics of the trigger are not provided. """
    
    periodic = "periodic"
    """The trigger occurs at a specific time or periodically as described by a timing or schedule. A periodic event cannot have any data elements, but may have a name assigned as a shorthand for the event. """
    
    dataChanged = "data-changed"
    """The trigger occurs whenever data of a particular type is changed in any way, either added, modified, or removed. """
    
    dataAdded = "data-added"
    """The trigger occurs whenever data of a particular type is added. """
    
    dataModified = "data-modified"
    """The trigger occurs whenever data of a particular type is modified. """
    
    dataRemoved = "data-removed"
    """The trigger occurs whenever data of a particular type is removed. """
    
    dataAccessed = "data-accessed"
    """The trigger occurs whenever data of a particular type is accessed. """
    
    dataAccessEnded = "data-access-ended"
    """The trigger occurs whenever access to data of a particular type is completed. """
    
class TypeDerivationRule(enum.Enum):
    
    specialization = "specialization"
    """This definition defines a new type that adds additional elements to the base type. """
    
    constraint = "constraint"
    """This definition adds additional rules to an existing concrete type. """
    
class UDICodes(enum.Enum):
    
    gudid = "gudid"
    """GUDID (FDA) US Repository """
    
class UDIEntryType(enum.Enum):
    
    barcode = "barcode"
    """a barcodescanner captured the data from the device label. """
    
    rfid = "rfid"
    """An RFID chip reader captured the data from the device label. """
    
    manual = "manual"
    """The data was read from the label by a person and manually entered. (e.g.  via a keyboard). """
    
    card = "card"
    """The data originated from a patient's implant card and was read by an operator. """
    
    selfReported = "self-reported"
    """The data originated from a patient source and was not directly scanned or read from a label or card. """
    
    unknown = "unknown"
    """The method of data capture has not been determined. """
    
class UnitTypeCodes(enum.Enum):
    
    individual = "individual"
    """A single individual """
    
    family = "family"
    """A family, typically includes self, spouse(s) and children to a defined age """
    
class UnknownContentCode(enum.Enum):
    
    no = "no"
    """The application does not accept either unknown elements or extensions. """
    
    extensions = "extensions"
    """The application accepts unknown extensions, but not unknown elements. """
    
    elements = "elements"
    """The application accepts unknown elements, but not unknown extensions. """
    
    both = "both"
    """The application accepts unknown elements and extensions. """
    
class UsageContextType(enum.Enum):
    
    gender = "gender"
    """The gender of the patient. For this context type, appropriate values can be found in the http://hl7.org/fhir/ValueSet/administrative-gender value set. """
    
    age = "age"
    """The age of the patient. For this context type, the value could be a range that specifies the applicable ages or a code from an appropriate value set such as the MeSH value set http://terminology.hl7.org/ValueSet/v3-AgeGroupObservationValue. """
    
    focus = "focus"
    """The clinical concept(s) addressed by the artifact. For example, disease, diagnostic test interpretation, medication ordering as in http://hl7.org/fhir/ValueSet/condition-code. """
    
    user = "user"
    """The clinical specialty of the context in which the patient is being treated - For example, PCP, Patient, Cardiologist, Behavioral Professional, Oral Health Professional, Prescriber, etc... taken from a specialty value set such as the NUCC Health Care provider taxonomy value set http://hl7.org/fhir/ValueSet/provider-taxonomy. """
    
    workflow = "workflow"
    """The settings in which the artifact is intended for use. For example, admission, pre-op, etc. For example, the ActEncounterCode value set http://terminology.hl7.org/ValueSet/v3-ActEncounterCode. """
    
    task = "task"
    """The context for the clinical task(s) represented by this artifact. For example, this could be any task context represented by the HL7 ActTaskCode value set http://terminology.hl7.org/ValueSet/v3-ActTaskCode. General categories include: order entry, patient documentation and patient information review. """
    
    venue = "venue"
    """The venue in which an artifact could be used. For example, Outpatient, Inpatient, Home, Nursing home. The code value may originate from the HL7 ServiceDeliveryLocationRoleType value set (http://terminology.hl7.org/ValueSet/v3-ServiceDeliveryLocationRoleType). """
    
    species = "species"
    """The species to which an artifact applies. For example, SNOMED - 387961004 | Kingdom Animalia (organism). """
    
    program = "program"
    """A program/project of work for which this artifact is applicable. """
    
class Use(enum.Enum):
    
    claim = "claim"
    """The treatment is complete and this represents a Claim for the services. """
    
    preauthorization = "preauthorization"
    """The treatment is proposed and this represents a Pre-authorization for the services. """
    
    predetermination = "predetermination"
    """The treatment is proposed and this represents a Pre-determination for the services. """
    
class ValidationProcess(enum.Enum):
    
    editCheck = "edit-check"
    """editCheck """
    
    valueset = "valueset"
    """valueset """
    
    primary = "primary"
    """primary """
    
    multi = "multi"
    """multi """
    
    standalone = "standalone"
    """standalone """
    
    inContext = "in-context"
    """inContext """
    
class ValidationStatus(enum.Enum):
    
    successful = "successful"
    """successful """
    
    failed = "failed"
    """failed """
    
    unknown = "unknown"
    """The validations status has not been determined yet """
    
class ValidationType(enum.Enum):
    
    nothing = "nothing"
    """nothing """
    
    primary = "primary"
    """primary """
    
    multiple = "multiple"
    """multiple """
    
class VerificationresultCommunicationMethod(enum.Enum):
    
    manual = "manual"
    """The information is submitted/retrieved manually (e.g. by phone, fax, paper-based) """
    
    portal = "portal"
    """The information is submitted/retrieved via a portal """
    
    pull = "pull"
    """The information is retrieved (i.e. pulled) from a source (e.g. over an API) """
    
    push = "push"
    """The information is sent (i.e. pushed) from a source (e.g. over an API, asynchronously, secure messaging) """
    
class VisionBase(enum.Enum):
    
    up = "up"
    """top. """
    
    down = "down"
    """bottom. """
    
    in_ = "in"
    """inner edge. """
    
    out = "out"
    """outer edge. """
    
class VisionEyes(enum.Enum):
    
    right = "right"
    """Right Eye. """
    
    left = "left"
    """Left Eye. """
    
class XPathUsageType(enum.Enum):
    
    normal = "normal"
    """The search parameter is derived directly from the selected nodes based on the type definitions. """
    
    phonetic = "phonetic"
    """The search parameter is derived by a phonetic transform from the selected nodes. """
    
    nearby = "nearby"
    """The search parameter is based on a spatial transform of the selected nodes. """
    
    distance = "distance"
    """The search parameter is based on a spatial transform of the selected nodes, using physical distance from the middle. """
    
    other = "other"
    """The interpretation of the xpath statement is unknown (and can't be automated). """
    

class FHIRValidationError(Exception):
    """ Exception raised when one or more errors occurred during model
    validation.
    """

    def __init__(self, errors, path=None):
        """ Initializer.
        
        :param errors: List of Exception instances. Also accepts a string,
            which is converted to a TypeError.
        :param str path: The property path on the object where errors occurred
        """
        if not isinstance(errors, list):
            errors = [TypeError(errors)]
        msgs = "\n  ".join([str(e).replace("\n", "\n  ") for e in errors])
        message = "{}:\n  {}".format(path or "{root}", msgs)

        super(FHIRValidationError, self).__init__(message)

        self.errors = errors
        """ A list of validation errors encountered. Typically contains
        TypeError, KeyError, possibly AttributeError and others. """

        self.path = path
        """ The path on the object where the errors occurred. """

    def prefixed(self, path_prefix):
        """ Creates a new instance of the receiver, with the given path prefix
        applied. """
        path = (
            "{}.{}".format(path_prefix, self.path)
            if self.path is not None
            else path_prefix
        )
        return self.__class__(self.errors, path)


class FHIRAbstractBase(pydantic.BaseModel):
    """Abstract base class for all FHIR elements.
    """
class FHIRAbstractResource(FHIRAbstractBase):
    """ Extends the FHIRAbstractBase with server talking capabilities.
    """

    resource_type = "FHIRAbstractResource"
FHIRDate = str
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Create FHIR search params from NoSQL-like query structures.
#  2014, SMART Health IT.

try:
    from urllib import quote_plus
except Exception as e:
    from urllib.parse import quote_plus


class FHIRSearch(object):
    """ Create a FHIR search from NoSQL-like query structures.
    """

    def __init__(self, resource_type, struct=None):
        self.resource_type = resource_type
        """ The resource type class. """

        self.params = []
        """ FHIRSearchParam instances. """

        self.wants_expand = False
        """ Used internally; whether or not `params` must be expanded first. """

        if struct is not None:
            if dict != type(struct):
                raise Exception(
                    "Must pass a Python dictionary, but got a {}".format(type(struct))
                )
            self.wants_expand = True
            for key, val in struct.items():
                self.params.append(FHIRSearchParam(key, val))

    # MARK: Execution

    def construct(self):
        """ Constructs the URL with query string from the receiver's params.
        """
        if self.resource_type is None:
            raise Exception("Need resource_type set to construct a search query")

        parts = []
        if self.params is not None:
            for param in self.params:
                if self.wants_expand:
                    for expanded in param.handle():
                        parts.append(expanded.as_parameter())
                else:
                    parts.append(param.as_parameter())

        return "{}?{}".format(self.resource_type.resource_type, "&".join(parts))

    def perform(self, server):
        """ Construct the search URL and execute it against the given server.
        
        :param server: The server against which to perform the search
        :returns: A Bundle resource
        """
        if server is None:
            raise Exception("Need a server to perform search")

        from . import bundle

        res = server.request_json(self.construct())
        bundle = bundle.Bundle(res)
        bundle.origin_server = server
        return bundle

    def perform_resources(self, server):
        """ Performs the search by calling `perform`, then extracts all Bundle
        entries and returns a list of Resource instances.
        
        :param server: The server against which to perform the search
        :returns: A list of Resource instances
        """
        bundle = self.perform(server)
        resources = []
        if bundle is not None and bundle.entry is not None:
            for entry in bundle.entry:
                resources.append(entry.resource)

        return resources


class FHIRSearchParam(object):
    """ Holds one search parameter.
    
    The instance's `value` can either be a string value or a search construct
    dictionary. In the latter case the class's `handle` method must be called
    to arrive at search parameter instances that can be converted into a URL
    query.
    """

    def __init__(self, name, value):
        self.name = name
        self.value = value

    def copy(self):
        clone = object.__new__(self.__class__)
        clone.__dict__ = self.__dict__.copy()
        return clone

    def handle(self):
        """ Parses the receiver's value and returns a list of FHIRSearchParam
        instances. Needs only be called if the param needs to be handled, i.e.
        its value is a query structure.
        
        :returns: A list with one or more FHIRSearchParam instances, not
        altering the receiver
        """
        handler = FHIRSearchParamHandler.handler_for(self.name)(None, self.value)
        return handler.handle(self.copy())

    def as_parameter(self):
        """ Return a string that represents the reciever as "key=value".
        """
        return "{}={}".format(self.name, quote_plus(self.value, safe=",<=>"))


class FHIRSearchParamHandler(object):
    handles = None
    handlers = []

    @classmethod
    def announce_handler(cls, handler):
        cls.handlers.append(handler)

    @classmethod
    def handler_for(cls, key):
        for handler in cls.handlers:
            if handler.can_handle(key):
                return handler
        return cls

    @classmethod
    def can_handle(cls, key):
        if cls.handles is not None:
            return key in cls.handles
        return True  # base class handles everything else, so be sure to test it last!

    def __init__(self, key, value):
        self.key = key
        self.value = value
        self.modifier = []
        self.multiplier = []

    def handle(self, param):
        """ Applies all handlers to the given search parameter.
        :returns: A list of one or more new `FHIRSearchParam` instances
        """
        self.prepare()
        return self.expand(param)

    def prepare(self, parent=None):
        """ Creates sub-handlers as needed, then prepares the receiver.
        """
        if dict == type(self.value):
            for key, val in self.value.items():
                handler = FHIRSearchParamHandler.handler_for(key)(key, val)
                handler.prepare(self)

        if parent is not None:
            parent.multiplier.append(self)

    def expand(self, param):
        """ Executes the receiver's modifier and multiplier on itself, applying
        changes to the given search param instance.
        
        :returns: A list of one or more FHIRSearchParam instances
        """
        for handler in self.modifier:
            handler.expand(param)

        self.apply(param)

        # if we have multiplier, expand sequentially
        if len(self.multiplier) > 0:
            expanded = []
            for handler in self.multiplier:
                clone = param.copy()
                expanded.extend(handler.expand(clone))

            return expanded

        # no multiplier, just return the passed-in paramater
        return [param]

    def apply(self, param):
        if self.key is not None:
            param.name = "{}.{}".format(param.name, self.key)
        if 0 == len(self.multiplier):
            param.value = self.value


class FHIRSearchParamModifierHandler(FHIRSearchParamHandler):
    modifiers = {
        "$asc": ":asc",
        "$desc": ":desc",
        "$exact": ":exact",
        "$missing": ":missing",
        "$null": ":missing",
        "$text": ":text",
    }
    handles = modifiers.keys()

    def apply(self, param):
        if self.key not in self.__class__.modifiers:
            raise Exception(
                'Unknown modifier "{}" for "{}"'.format(self.key, param.name)
            )
        param.name += self.__class__.modifiers[self.key]
        param.value = self.value


class FHIRSearchParamOperatorHandler(FHIRSearchParamHandler):
    operators = {
        "$gt": ">",
        "$lt": "<",
        "$lte": "<=",
        "$gte": ">=",
    }
    handles = operators.keys()

    def apply(self, param):
        if self.key not in self.__class__.operators:
            raise Exception(
                'Unknown operator "{}" for "{}"'.format(self.key, parent.name)
            )
        param.value = self.__class__.operators[self.key] + self.value


class FHIRSearchParamMultiHandler(FHIRSearchParamHandler):
    handles = ["$and", "$or"]

    def prepare(self, parent):
        if list != type(self.value):
            raise Exception(
                'Expecting a list argument for "{}" but got {}'.format(
                    parent.key, self.value
                )
            )

        handlers = []
        for val in self.value:
            if dict == type(val):
                for kkey, vval in val.items():
                    handlers.append(
                        FHIRSearchParamHandler.handler_for(kkey)(kkey, vval)
                    )
            else:
                handlers.append(
                    FHIRSearchParamHandler.handler_for(parent.key)(None, val)
                )

        if "$and" == self.key:
            for handler in handlers:
                handler.prepare(parent)
        elif "$or" == self.key:
            ors = [h.value for h in handlers]
            handler = FHIRSearchParamHandler.handler_for(parent.key)(
                None, ",".join(ors)
            )
            handler.prepare(parent)
        else:
            raise Exception('I cannot handle "{}"'.format(self.key))


class FHIRSearchParamTypeHandler(FHIRSearchParamHandler):
    handles = ["$type"]

    def prepare(self, parent):
        parent.modifier.append(self)

    def apply(self, param):
        param.name = "{}:{}".format(param.name, self.value)


# announce all handlers
FHIRSearchParamHandler.announce_handler(FHIRSearchParamModifierHandler)
FHIRSearchParamHandler.announce_handler(FHIRSearchParamOperatorHandler)
FHIRSearchParamHandler.announce_handler(FHIRSearchParamMultiHandler)
FHIRSearchParamHandler.announce_handler(FHIRSearchParamTypeHandler)


class Resource(FHIRAbstractResource):
    """ Base Resource.
    
    This is the base resource type for everything.
    """
    
    resource_type = "Resource"
    
    # [<FHIRClassProperty self.name='id' >, <FHIRClassProperty self.name='meta' >, <FHIRClassProperty self.name='implicitRules' >, <FHIRClassProperty self.name='language' >]
  

    id: typing.Optional[str]

    """ Logical id of this artifact.
    Type `str`. """

    meta: typing.Optional["Meta"]

    """ Metadata about the resource.
    Type `Meta` (represented as `dict` in JSON). """

    implicitRules: typing.Optional[str]

    """ A set of rules under which this content was created.
    Type `str`. """

    language: typing.Optional[str]

    """ Language of the resource content.
    Type `str`. """




    

     
    



class Binary(Resource):
    """ Pure binary content defined by a format other than FHIR.
    
    A resource that represents the data of a single raw artifact as digital
    content accessible in its native format.  A Binary resource can contain any
    content, whether text, image, pdf, zip archive, etc.
    """
    
    resource_type = "Binary"
    
    # [<FHIRClassProperty self.name='contentType' >, <FHIRClassProperty self.name='securityContext' >, <FHIRClassProperty self.name='data' >]
  

    contentType: str

    """ MimeType of the binary content.
    Type `str`. """

    securityContext: typing.Optional["Reference"]

    """ Identifies another resource to use as proxy when enforcing access
        control.
    Type `Reference` (represented as `dict` in JSON). """

    data: typing.Optional[str]

    """ The actual content.
    Type `str`. """




    

     
    



class Bundle(Resource):
    """ Contains a collection of resources.
    
    A container for a collection of resources.
    """
    
    resource_type = "Bundle"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='timestamp' >, <FHIRClassProperty self.name='total' >, <FHIRClassProperty self.name='link' >, <FHIRClassProperty self.name='entry' >, <FHIRClassProperty self.name='signature' >]
  

    identifier: typing.Optional["Identifier"]

    """ Persistent identifier for the bundle.
    Type `Identifier` (represented as `dict` in JSON). """

    type: "str"

    """ document | message | transaction | transaction-response | batch |
        batch-response | history | searchset | collection.
    Type `str`. """

    timestamp: typing.Optional["FHIRDate"]

    """ When the bundle was assembled.
    Type `FHIRDate` (represented as `str` in JSON). """

    total: typing.Optional[int]

    """ If search, the total number of matches.
    Type `int`. """

    link: typing.Optional[typing.List["BundleLink"]]

    """ Links related to this Bundle.
    List of `BundleLink` items (represented as `dict` in JSON). """

    entry: typing.Optional[typing.List["BundleEntry"]]

    """ Entry in the bundle - will have a resource or information.
    List of `BundleEntry` items (represented as `dict` in JSON). """

    signature: typing.Optional["Signature"]

    """ Digital Signature.
    Type `Signature` (represented as `dict` in JSON). """




    

     
    



class DomainResource(Resource):
    """ A resource with narrative, extensions, and contained resources.
    
    A resource that includes narrative, extensions, and contained resources.
    """
    
    resource_type = "DomainResource"
    
    # [<FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='contained' >, <FHIRClassProperty self.name='extension' >, <FHIRClassProperty self.name='modifierExtension' >]
  

    text: typing.Optional["Narrative"]

    """ Text summary of the resource, for human interpretation.
    Type `Narrative` (represented as `dict` in JSON). """

    contained: typing.Optional[typing.List["Resource"]]

    """ Contained, inline Resources.
    List of `Resource` items (represented as `dict` in JSON). """

    extension: typing.Optional[typing.List["Extension"]]

    """ Additional content defined by implementations.
    List of `Extension` items (represented as `dict` in JSON). """

    modifierExtension: typing.Optional[typing.List["Extension"]]

    """ Extensions that cannot be ignored.
    List of `Extension` items (represented as `dict` in JSON). """




    

     
    



class Parameters(Resource):
    """ Operation Request or Response.
    
    This resource is a non-persisted resource used to pass information into and
    back from an [operation](operations.html). It has no other use, and there
    is no RESTful endpoint associated with it.
    """
    
    resource_type = "Parameters"
    
    # [<FHIRClassProperty self.name='parameter' >]
  

    parameter: typing.Optional[typing.List["ParametersParameter"]]

    """ Operation Parameter.
    List of `ParametersParameter` items (represented as `dict` in JSON). """




    

     
    



class Account(DomainResource):
    """ Tracks balance, charges, for patient or cost center.
    
    A financial tool for tracking value accrued for a particular purpose.  In
    the healthcare field, used to track charges for a patient, cost centers,
    etc.
    """
    
    resource_type = "Account"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='servicePeriod' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='owner' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='guarantor' >, <FHIRClassProperty self.name='partOf' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Account number.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | inactive | entered-in-error | on-hold | unknown.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ E.g. patient, expense, depreciation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Human-readable label.
    Type `str`. """

    subject: typing.Optional[typing.List["Reference"]]

    """ The entity that caused the expenses.
    List of `Reference` items (represented as `dict` in JSON). """

    servicePeriod: typing.Optional["Period"]

    """ Transaction window.
    Type `Period` (represented as `dict` in JSON). """

    coverage: typing.Optional[typing.List["AccountCoverage"]]

    """ The party(s) that are responsible for covering the payment of this
        account, and what order should they be applied to the account.
    List of `AccountCoverage` items (represented as `dict` in JSON). """

    owner: typing.Optional["Reference"]

    """ Entity managing the Account.
    Type `Reference` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Explanation of purpose/use.
    Type `str`. """

    guarantor: typing.Optional[typing.List["AccountGuarantor"]]

    """ The parties ultimately responsible for balancing the Account.
    List of `AccountGuarantor` items (represented as `dict` in JSON). """

    partOf: typing.Optional["Reference"]

    """ Reference to a parent Account.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ActivityDefinition(DomainResource):
    """ The definition of a specific activity to be taken, independent of any
    particular patient or context.
    
    This resource allows for the definition of some activity to be performed,
    independent of a particular patient, practitioner, or other performance
    context.
    """
    
    resource_type = "ActivityDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='library' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='timingTiming' >, <FHIRClassProperty self.name='timingDateTime' >, <FHIRClassProperty self.name='timingAge' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='timingRange' >, <FHIRClassProperty self.name='timingDuration' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='productReference' >, <FHIRClassProperty self.name='productCodeableConcept' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='dosage' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='specimenRequirement' >, <FHIRClassProperty self.name='observationRequirement' >, <FHIRClassProperty self.name='observationResultRequirement' >, <FHIRClassProperty self.name='transform' >, <FHIRClassProperty self.name='dynamicValue' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this activity definition, represented as a
        URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the activity definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the activity definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this activity definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this activity definition (human friendly).
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the activity definition.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ Type of individual the activity definition is intended for.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ Type of individual the activity definition is intended for.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the activity definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for activity definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this activity definition is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the activity definition.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the activity definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the activity definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the activity definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ E.g. Education, Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    library: typing.Optional[typing.List[str]]

    """ Logic used by the activity definition.
    List of `str` items. """

    kind: typing.Optional["str"]

    """ Kind of resource.
    Type `str`. """

    profile: typing.Optional[str]

    """ What profile the resource needs to conform to.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Detail type of activity.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intent: typing.Optional["str"]

    """ proposal | plan | directive | order | original-order | reflex-order
        | filler-order | instance-order | option.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    doNotPerform: typing.Optional[bool]

    """ True if the activity should not be performed.
    Type `bool`. """

    timingTiming: typing.Optional["Timing"]

    """ When activity is to occur.
    Type `Timing` (represented as `dict` in JSON). """

    timingDateTime: typing.Optional["FHIRDate"]

    """ When activity is to occur.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingAge: typing.Optional["Age"]

    """ When activity is to occur.
    Type `Age` (represented as `dict` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ When activity is to occur.
    Type `Period` (represented as `dict` in JSON). """

    timingRange: typing.Optional["Range"]

    """ When activity is to occur.
    Type `Range` (represented as `dict` in JSON). """

    timingDuration: typing.Optional["Duration"]

    """ When activity is to occur.
    Type `Duration` (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where it should happen.
    Type `Reference` (represented as `dict` in JSON). """

    participant: typing.Optional[typing.List["ActivityDefinitionParticipant"]]

    """ Who should participate in the action.
    List of `ActivityDefinitionParticipant` items (represented as `dict` in JSON). """

    productReference: typing.Optional["Reference"]

    """ What's administered/supplied.
    Type `Reference` (represented as `dict` in JSON). """

    productCodeableConcept: typing.Optional["CodeableConcept"]

    """ What's administered/supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ How much is administered/consumed/supplied.
    Type `Quantity` (represented as `dict` in JSON). """

    dosage: typing.Optional[typing.List["Dosage"]]

    """ Detailed dosage instructions.
    List of `Dosage` items (represented as `dict` in JSON). """

    bodySite: typing.Optional[typing.List["CodeableConcept"]]

    """ What part of body to perform on.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specimenRequirement: typing.Optional[typing.List["Reference"]]

    """ What specimens are required to perform this action.
    List of `Reference` items (represented as `dict` in JSON). """

    observationRequirement: typing.Optional[typing.List["Reference"]]

    """ What observations are required to perform this action.
    List of `Reference` items (represented as `dict` in JSON). """

    observationResultRequirement: typing.Optional[typing.List["Reference"]]

    """ What observations must be produced by this action.
    List of `Reference` items (represented as `dict` in JSON). """

    transform: typing.Optional[str]

    """ Transform to apply the template.
    Type `str`. """

    dynamicValue: typing.Optional[typing.List["ActivityDefinitionDynamicValue"]]

    """ Dynamic aspects of the definition.
    List of `ActivityDefinitionDynamicValue` items (represented as `dict` in JSON). """



#   {'path': 'ActivityDefinition.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'ActivityDefinition', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Type of individual the activity definition is intended for', 'formal': 'A code or group definition that describes the intended subject of the activity being defined.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))

#   {'path': 'ActivityDefinition.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingTiming', 'name': 'timingTiming', 'parent_name': 'ActivityDefinition', 'class_name': 'Timing', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When activity is to occur', 'formal': 'The period, timing or frequency upon which the described activity is to occur.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingTiming', 'timingDateTime', 'timingAge', 'timingPeriod', 'timingRange', 'timingDuration']), True))

#   {'path': 'ActivityDefinition.product[x]', 'choice_of_type': 'product', 'orig_name': 'productReference', 'name': 'productReference', 'parent_name': 'ActivityDefinition', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': "What's administered/supplied", 'formal': 'Identifies the food, drug or other product being consumed or supplied in the activity.', 'representation': None}

    _product_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['productReference', 'productCodeableConcept']), True))


    

     
    



class AdverseEvent(DomainResource):
    """ Medical care, research study or other healthcare event causing physical
    injury.
    
    Actual or  potential/avoided event causing unintended physical injury
    resulting from or contributed to by medical care, a research study or other
    healthcare setting factors that requires additional monitoring, treatment,
    or hospitalization, or that results in death.
    """
    
    resource_type = "AdverseEvent"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='actuality' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='event' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='detected' >, <FHIRClassProperty self.name='recordedDate' >, <FHIRClassProperty self.name='resultingCondition' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='seriousness' >, <FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='recorder' >, <FHIRClassProperty self.name='contributor' >, <FHIRClassProperty self.name='suspectEntity' >, <FHIRClassProperty self.name='subjectMedicalHistory' >, <FHIRClassProperty self.name='referenceDocument' >, <FHIRClassProperty self.name='study' >]
  

    identifier: typing.Optional["Identifier"]

    """ Business identifier for the event.
    Type `Identifier` (represented as `dict` in JSON). """

    actuality: "str"

    """ actual | potential.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ product-problem | product-quality | product-use-error | wrong-dose
        | incorrect-prescribing-information | wrong-technique | wrong-
        route-of-administration | wrong-rate | wrong-duration | wrong-time
        | expired-drug | medical-device-use-error | problem-different-
        manufacturer | unsafe-physical-environment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    event: typing.Optional["CodeableConcept"]

    """ Type of the event itself in relation to the subject.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Subject impacted by event.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the event occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    detected: typing.Optional["FHIRDate"]

    """ When the event was detected.
    Type `FHIRDate` (represented as `str` in JSON). """

    recordedDate: typing.Optional["FHIRDate"]

    """ When the event was recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    resultingCondition: typing.Optional[typing.List["Reference"]]

    """ Effect on the subject due to this event.
    List of `Reference` items (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Location where adverse event occurred.
    Type `Reference` (represented as `dict` in JSON). """

    seriousness: typing.Optional["CodeableConcept"]

    """ Seriousness of the event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    severity: typing.Optional["CodeableConcept"]

    """ mild | moderate | severe.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    outcome: typing.Optional["CodeableConcept"]

    """ resolved | recovering | ongoing | resolvedWithSequelae | fatal |
        unknown.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    recorder: typing.Optional["Reference"]

    """ Who recorded the adverse event.
    Type `Reference` (represented as `dict` in JSON). """

    contributor: typing.Optional[typing.List["Reference"]]

    """ Who  was involved in the adverse event or the potential adverse
        event.
    List of `Reference` items (represented as `dict` in JSON). """

    suspectEntity: typing.Optional[typing.List["AdverseEventSuspectEntity"]]

    """ The suspected agent causing the adverse event.
    List of `AdverseEventSuspectEntity` items (represented as `dict` in JSON). """

    subjectMedicalHistory: typing.Optional[typing.List["Reference"]]

    """ AdverseEvent.subjectMedicalHistory.
    List of `Reference` items (represented as `dict` in JSON). """

    referenceDocument: typing.Optional[typing.List["Reference"]]

    """ AdverseEvent.referenceDocument.
    List of `Reference` items (represented as `dict` in JSON). """

    study: typing.Optional[typing.List["Reference"]]

    """ AdverseEvent.study.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class AllergyIntolerance(DomainResource):
    """ Allergy or Intolerance (generally: Risk of adverse reaction to a substance).
    
    Risk of harmful or undesirable, physiological response which is unique to
    an individual and associated with exposure to a substance.
    """
    
    resource_type = "AllergyIntolerance"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='clinicalStatus' >, <FHIRClassProperty self.name='verificationStatus' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='criticality' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='onsetDateTime' >, <FHIRClassProperty self.name='onsetAge' >, <FHIRClassProperty self.name='onsetPeriod' >, <FHIRClassProperty self.name='onsetRange' >, <FHIRClassProperty self.name='onsetString' >, <FHIRClassProperty self.name='recordedDate' >, <FHIRClassProperty self.name='recorder' >, <FHIRClassProperty self.name='asserter' >, <FHIRClassProperty self.name='lastOccurrence' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='reaction' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    clinicalStatus: typing.Optional["CodeableConcept"]

    """ active | inactive | resolved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    verificationStatus: typing.Optional["CodeableConcept"]

    """ unconfirmed | confirmed | refuted | entered-in-error.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional["str"]

    """ allergy | intolerance - Underlying mechanism (if known).
    Type `str`. """

    category: typing.Optional[typing.List["str"]]

    """ food | medication | environment | biologic.
    List of `str` items. """

    criticality: typing.Optional["str"]

    """ low | high | unable-to-assess.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Code that identifies the allergy or intolerance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    patient: "Reference"

    """ Who the sensitivity is for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter when the allergy or intolerance was asserted.
    Type `Reference` (represented as `dict` in JSON). """

    onsetDateTime: typing.Optional["FHIRDate"]

    """ When allergy or intolerance was identified.
    Type `FHIRDate` (represented as `str` in JSON). """

    onsetAge: typing.Optional["Age"]

    """ When allergy or intolerance was identified.
    Type `Age` (represented as `dict` in JSON). """

    onsetPeriod: typing.Optional["Period"]

    """ When allergy or intolerance was identified.
    Type `Period` (represented as `dict` in JSON). """

    onsetRange: typing.Optional["Range"]

    """ When allergy or intolerance was identified.
    Type `Range` (represented as `dict` in JSON). """

    onsetString: typing.Optional[str]

    """ When allergy or intolerance was identified.
    Type `str`. """

    recordedDate: typing.Optional["FHIRDate"]

    """ Date first version of the resource instance was recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    recorder: typing.Optional["Reference"]

    """ Who recorded the sensitivity.
    Type `Reference` (represented as `dict` in JSON). """

    asserter: typing.Optional["Reference"]

    """ Source of the information about the allergy.
    Type `Reference` (represented as `dict` in JSON). """

    lastOccurrence: typing.Optional["FHIRDate"]

    """ Date(/time) of last known occurrence of a reaction.
    Type `FHIRDate` (represented as `str` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional text not captured in other fields.
    List of `Annotation` items (represented as `dict` in JSON). """

    reaction: typing.Optional[typing.List["AllergyIntoleranceReaction"]]

    """ Adverse Reaction Events linked to exposure to substance.
    List of `AllergyIntoleranceReaction` items (represented as `dict` in JSON). """



#   {'path': 'AllergyIntolerance.onset[x]', 'choice_of_type': 'onset', 'orig_name': 'onsetDateTime', 'name': 'onsetDateTime', 'parent_name': 'AllergyIntolerance', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When allergy or intolerance was identified', 'formal': 'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.', 'representation': None}

    _onset_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['onsetDateTime', 'onsetAge', 'onsetPeriod', 'onsetRange', 'onsetString']), True))


    

     
    



class Appointment(DomainResource):
    """ A booking of a healthcare event among patient(s), practitioner(s), related
    person(s) and/or device(s) for a specific date/time. This may result in one
    or more Encounter(s).
    """
    
    resource_type = "Appointment"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='cancelationReason' >, <FHIRClassProperty self.name='serviceCategory' >, <FHIRClassProperty self.name='serviceType' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='appointmentType' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='supportingInformation' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='minutesDuration' >, <FHIRClassProperty self.name='slot' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='patientInstruction' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='requestedPeriod' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ proposed | pending | booked | arrived | fulfilled | cancelled |
        noshow | entered-in-error | checked-in | waitlist.
    Type `str`. """

    cancelationReason: typing.Optional["CodeableConcept"]

    """ The coded reason for the appointment being cancelled.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    serviceCategory: typing.Optional[typing.List["CodeableConcept"]]

    """ A broad categorization of the service that is to be performed
        during this appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    serviceType: typing.Optional[typing.List["CodeableConcept"]]

    """ The specific service that is to be performed during this
        appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ The specialty of a practitioner that would be required to perform
        the service requested in this appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    appointmentType: typing.Optional["CodeableConcept"]

    """ The style of appointment or patient that has been booked in the
        slot (not service type).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Coded reason this appointment is scheduled.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Reason the appointment is to take place (resource).
    List of `Reference` items (represented as `dict` in JSON). """

    priority: typing.Optional[int]

    """ Used to make informed decisions if needing to re-prioritize.
    Type `int`. """

    description: typing.Optional[str]

    """ Shown on a subject line in a meeting request, or appointment list.
    Type `str`. """

    supportingInformation: typing.Optional[typing.List["Reference"]]

    """ Additional information to support the appointment.
    List of `Reference` items (represented as `dict` in JSON). """

    start: typing.Optional["FHIRDate"]

    """ When appointment is to take place.
    Type `FHIRDate` (represented as `str` in JSON). """

    end: typing.Optional["FHIRDate"]

    """ When appointment is to conclude.
    Type `FHIRDate` (represented as `str` in JSON). """

    minutesDuration: typing.Optional[int]

    """ Can be less than start/end (e.g. estimate).
    Type `int`. """

    slot: typing.Optional[typing.List["Reference"]]

    """ The slots that this appointment is filling.
    List of `Reference` items (represented as `dict` in JSON). """

    created: typing.Optional["FHIRDate"]

    """ The date that this appointment was initially created.
    Type `FHIRDate` (represented as `str` in JSON). """

    comment: typing.Optional[str]

    """ Additional comments.
    Type `str`. """

    patientInstruction: typing.Optional[str]

    """ Detailed information and instructions for the patient.
    Type `str`. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ The service request this appointment is allocated to assess.
    List of `Reference` items (represented as `dict` in JSON). """

    participant: typing.List["AppointmentParticipant"]

    """ Participants involved in appointment.
    List of `AppointmentParticipant` items (represented as `dict` in JSON). """

    requestedPeriod: typing.Optional[typing.List["Period"]]

    """ Potential date/time interval(s) requested to allocate the
        appointment within.
    List of `Period` items (represented as `dict` in JSON). """




    

     
    



class AppointmentResponse(DomainResource):
    """ A reply to an appointment request for a patient and/or practitioner(s),
    such as a confirmation or rejection.
    """
    
    resource_type = "AppointmentResponse"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='appointment' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='participantType' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='participantStatus' >, <FHIRClassProperty self.name='comment' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    appointment: "Reference"

    """ Appointment this response relates to.
    Type `Reference` (represented as `dict` in JSON). """

    start: typing.Optional["FHIRDate"]

    """ Time from appointment, or requested new start time.
    Type `FHIRDate` (represented as `str` in JSON). """

    end: typing.Optional["FHIRDate"]

    """ Time from appointment, or requested new end time.
    Type `FHIRDate` (represented as `str` in JSON). """

    participantType: typing.Optional[typing.List["CodeableConcept"]]

    """ Role of participant in the appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    actor: typing.Optional["Reference"]

    """ Person, Location, HealthcareService, or Device.
    Type `Reference` (represented as `dict` in JSON). """

    participantStatus: "str"

    """ accepted | declined | tentative | needs-action.
    Type `str`. """

    comment: typing.Optional[str]

    """ Additional comments.
    Type `str`. """




    

     
    



class AuditEvent(DomainResource):
    """ Event record kept for security purposes.
    
    A record of an event made for purposes of maintaining a security log.
    Typical uses include detection of intrusion attempts and monitoring for
    inappropriate usage.
    """
    
    resource_type = "AuditEvent"
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subtype' >, <FHIRClassProperty self.name='action' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='recorded' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='outcomeDesc' >, <FHIRClassProperty self.name='purposeOfEvent' >, <FHIRClassProperty self.name='agent' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='entity' >]
  

    type: "Coding"

    """ Type/identifier of event.
    Type `Coding` (represented as `dict` in JSON). """

    subtype: typing.Optional[typing.List["Coding"]]

    """ More specific type/id for the event.
    List of `Coding` items (represented as `dict` in JSON). """

    action: typing.Optional["str"]

    """ Type of action performed during the event.
    Type `str`. """

    period: typing.Optional["Period"]

    """ When the activity occurred.
    Type `Period` (represented as `dict` in JSON). """

    recorded: "FHIRDate"

    """ Time when the event was recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    outcome: typing.Optional[str]

    """ Whether the event succeeded or failed.
    Type `str`. """

    outcomeDesc: typing.Optional[str]

    """ Description of the event outcome.
    Type `str`. """

    purposeOfEvent: typing.Optional[typing.List["CodeableConcept"]]

    """ The purposeOfUse of the event.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    agent: typing.List["AuditEventAgent"]

    """ Actor involved in the event.
    List of `AuditEventAgent` items (represented as `dict` in JSON). """

    source: "AuditEventSource"

    """ Audit Event Reporter.
    Type `AuditEventSource` (represented as `dict` in JSON). """

    entity: typing.Optional[typing.List["AuditEventEntity"]]

    """ Data or objects used.
    List of `AuditEventEntity` items (represented as `dict` in JSON). """




    

     
    



class Basic(DomainResource):
    """ Resource for non-supported content.
    
    Basic is used for handling concepts not yet defined in FHIR, narrative-only
    resources that don't map to an existing resource, and custom resources not
    appropriate for inclusion in the FHIR specification.
    """
    
    resource_type = "Basic"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='author' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Kind of Resource.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Identifies the focus of this resource.
    Type `Reference` (represented as `dict` in JSON). """

    created: typing.Optional["FHIRDate"]

    """ When created.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional["Reference"]

    """ Who created.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class BiologicallyDerivedProduct(DomainResource):
    """ A material substance originating from a biological entity.
    
    A material substance originating from a biological entity intended to be
    transplanted or infused
    into another (possibly the same) biological entity.
    """
    
    resource_type = "BiologicallyDerivedProduct"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='productCategory' >, <FHIRClassProperty self.name='productCode' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='parent' >, <FHIRClassProperty self.name='collection' >, <FHIRClassProperty self.name='processing' >, <FHIRClassProperty self.name='manipulation' >, <FHIRClassProperty self.name='storage' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    productCategory: typing.Optional["str"]

    """ organ | tissue | fluid | cells | biologicalAgent.
    Type `str`. """

    productCode: typing.Optional["CodeableConcept"]

    """ What this biologically derived product is.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ available | unavailable.
    Type `str`. """

    request: typing.Optional[typing.List["Reference"]]

    """ Procedure request.
    List of `Reference` items (represented as `dict` in JSON). """

    quantity: typing.Optional[int]

    """ The amount of this biologically derived product.
    Type `int`. """

    parent: typing.Optional[typing.List["Reference"]]

    """ BiologicallyDerivedProduct parent.
    List of `Reference` items (represented as `dict` in JSON). """

    collection: typing.Optional["BiologicallyDerivedProductCollection"]

    """ How this product was collected.
    Type `BiologicallyDerivedProductCollection` (represented as `dict` in JSON). """

    processing: typing.Optional[typing.List["BiologicallyDerivedProductProcessing"]]

    """ Any processing of the product during collection.
    List of `BiologicallyDerivedProductProcessing` items (represented as `dict` in JSON). """

    manipulation: typing.Optional["BiologicallyDerivedProductManipulation"]

    """ Any manipulation of product post-collection.
    Type `BiologicallyDerivedProductManipulation` (represented as `dict` in JSON). """

    storage: typing.Optional[typing.List["BiologicallyDerivedProductStorage"]]

    """ Product storage.
    List of `BiologicallyDerivedProductStorage` items (represented as `dict` in JSON). """




    

     
    



class BodyStructure(DomainResource):
    """ Specific and identified anatomical structure.
    
    Record details about an anatomical structure.  This resource may be used
    when a coded concept does not provide the necessary detail needed for the
    use case.
    """
    
    resource_type = "BodyStructure"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='morphology' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='locationQualifier' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='image' >, <FHIRClassProperty self.name='patient' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Bodystructure identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this record is in active use.
    Type `bool`. """

    morphology: typing.Optional["CodeableConcept"]

    """ Kind of Structure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    location: typing.Optional["CodeableConcept"]

    """ Body site.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationQualifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Body site modifier.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Text description.
    Type `str`. """

    image: typing.Optional[typing.List["Attachment"]]

    """ Attached images.
    List of `Attachment` items (represented as `dict` in JSON). """

    patient: "Reference"

    """ Who this is about.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class CapabilityStatement(DomainResource):
    """ A statement of system capabilities.
    
    A Capability Statement documents a set of capabilities (behaviors) of a
    FHIR Server for a particular version of FHIR that may be used as a
    statement of actual server functionality or a statement of required or
    desired server implementation.
    """
    
    resource_type = "CapabilityStatement"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='instantiates' >, <FHIRClassProperty self.name='imports' >, <FHIRClassProperty self.name='software' >, <FHIRClassProperty self.name='implementation' >, <FHIRClassProperty self.name='fhirVersion' >, <FHIRClassProperty self.name='format' >, <FHIRClassProperty self.name='patchFormat' >, <FHIRClassProperty self.name='implementationGuide' >, <FHIRClassProperty self.name='rest' >, <FHIRClassProperty self.name='messaging' >, <FHIRClassProperty self.name='document' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this capability statement, represented as
        a URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the capability statement.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this capability statement (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this capability statement (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: "FHIRDate"

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the capability statement.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for capability statement (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this capability statement is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    kind: "str"

    """ instance | capability | requirements.
    Type `str`. """

    instantiates: typing.Optional[typing.List[str]]

    """ Canonical URL of another capability statement this implements.
    List of `str` items. """

    imports: typing.Optional[typing.List[str]]

    """ Canonical URL of another capability statement this adds to.
    List of `str` items. """

    software: typing.Optional["CapabilityStatementSoftware"]

    """ Software that is covered by this capability statement.
    Type `CapabilityStatementSoftware` (represented as `dict` in JSON). """

    implementation: typing.Optional["CapabilityStatementImplementation"]

    """ If this describes a specific instance.
    Type `CapabilityStatementImplementation` (represented as `dict` in JSON). """

    fhirVersion: str

    """ FHIR Version the system supports.
    Type `str`. """

    format: typing.List[str]

    """ formats supported (xml | json | ttl | mime type).
    List of `str` items. """

    patchFormat: typing.Optional[typing.List[str]]

    """ Patch formats supported.
    List of `str` items. """

    implementationGuide: typing.Optional[typing.List[str]]

    """ Implementation guides supported.
    List of `str` items. """

    rest: typing.Optional[typing.List["CapabilityStatementRest"]]

    """ If the endpoint is a RESTful one.
    List of `CapabilityStatementRest` items (represented as `dict` in JSON). """

    messaging: typing.Optional[typing.List["CapabilityStatementMessaging"]]

    """ If messaging is supported.
    List of `CapabilityStatementMessaging` items (represented as `dict` in JSON). """

    document: typing.Optional[typing.List["CapabilityStatementDocument"]]

    """ Document definition.
    List of `CapabilityStatementDocument` items (represented as `dict` in JSON). """




    

     
    



class CarePlan(DomainResource):
    """ Healthcare plan for patient or group.
    
    Describes the intention of how one or more practitioners intend to deliver
    care for a particular patient, group or community for a period of time,
    possibly limited to care for a specific condition or set of conditions.
    """
    
    resource_type = "CarePlan"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='contributor' >, <FHIRClassProperty self.name='careTeam' >, <FHIRClassProperty self.name='addresses' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='goal' >, <FHIRClassProperty self.name='activity' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this plan.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills CarePlan.
    List of `Reference` items (represented as `dict` in JSON). """

    replaces: typing.Optional[typing.List["Reference"]]

    """ CarePlan replaced by this CarePlan.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced CarePlan.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    intent: "str"

    """ proposal | plan | order | option.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of plan.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    title: typing.Optional[str]

    """ Human-friendly name for the care plan.
    Type `str`. """

    description: typing.Optional[str]

    """ Summary of nature of plan.
    Type `str`. """

    subject: "Reference"

    """ Who the care plan is for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time period plan covers.
    Type `Period` (represented as `dict` in JSON). """

    created: typing.Optional["FHIRDate"]

    """ Date record was first recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional["Reference"]

    """ Who is the designated responsible party.
    Type `Reference` (represented as `dict` in JSON). """

    contributor: typing.Optional[typing.List["Reference"]]

    """ Who provided the content of the care plan.
    List of `Reference` items (represented as `dict` in JSON). """

    careTeam: typing.Optional[typing.List["Reference"]]

    """ Who's involved in plan?.
    List of `Reference` items (represented as `dict` in JSON). """

    addresses: typing.Optional[typing.List["Reference"]]

    """ Health issues this plan addresses.
    List of `Reference` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["Reference"]]

    """ Information considered as part of plan.
    List of `Reference` items (represented as `dict` in JSON). """

    goal: typing.Optional[typing.List["Reference"]]

    """ Desired outcome of plan.
    List of `Reference` items (represented as `dict` in JSON). """

    activity: typing.Optional[typing.List["CarePlanActivity"]]

    """ Action to occur as part of plan.
    List of `CarePlanActivity` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments about the plan.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class CareTeam(DomainResource):
    """ Planned participants in the coordination and delivery of care for a patient
    or group.
    
    The Care Team includes all the people and organizations who plan to
    participate in the coordination and delivery of care for a patient.
    """
    
    resource_type = "CareTeam"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this team.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ proposed | active | suspended | inactive | entered-in-error.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of team.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Name of the team, such as crisis assessment team.
    Type `str`. """

    subject: typing.Optional["Reference"]

    """ Who care team is for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time period team covers.
    Type `Period` (represented as `dict` in JSON). """

    participant: typing.Optional[typing.List["CareTeamParticipant"]]

    """ Members of the team.
    List of `CareTeamParticipant` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why the care team exists.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why the care team exists.
    List of `Reference` items (represented as `dict` in JSON). """

    managingOrganization: typing.Optional[typing.List["Reference"]]

    """ Organization responsible for the care team.
    List of `Reference` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the care team (that applies to all members).
    List of `ContactPoint` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the CareTeam.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class CatalogEntry(DomainResource):
    """ An entry in a catalog.
    
    Catalog entries are wrappers that contextualize items included in a
    catalog.
    """
    
    resource_type = "CatalogEntry"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='orderable' >, <FHIRClassProperty self.name='referencedItem' >, <FHIRClassProperty self.name='additionalIdentifier' >, <FHIRClassProperty self.name='classification' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='validityPeriod' >, <FHIRClassProperty self.name='validTo' >, <FHIRClassProperty self.name='lastUpdated' >, <FHIRClassProperty self.name='additionalCharacteristic' >, <FHIRClassProperty self.name='additionalClassification' >, <FHIRClassProperty self.name='relatedEntry' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier of the catalog item.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ The type of item - medication, device, service, protocol or other.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    orderable: bool

    """ Whether the entry represents an orderable item.
    Type `bool`. """

    referencedItem: "Reference"

    """ The item that is being defined.
    Type `Reference` (represented as `dict` in JSON). """

    additionalIdentifier: typing.Optional[typing.List["Identifier"]]

    """ Any additional identifier(s) for the catalog item, in the same
        granularity or concept.
    List of `Identifier` items (represented as `dict` in JSON). """

    classification: typing.Optional[typing.List["CodeableConcept"]]

    """ Classification (category or class) of the item entry.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ draft | active | retired | unknown.
    Type `str`. """

    validityPeriod: typing.Optional["Period"]

    """ The time period in which this catalog entry is expected to be
        active.
    Type `Period` (represented as `dict` in JSON). """

    validTo: typing.Optional["FHIRDate"]

    """ The date until which this catalog entry is expected to be active.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastUpdated: typing.Optional["FHIRDate"]

    """ When was this catalog last updated.
    Type `FHIRDate` (represented as `str` in JSON). """

    additionalCharacteristic: typing.Optional[typing.List["CodeableConcept"]]

    """ Additional characteristics of the catalog entry.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    additionalClassification: typing.Optional[typing.List["CodeableConcept"]]

    """ Additional classification of the catalog entry.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    relatedEntry: typing.Optional[typing.List["CatalogEntryRelatedEntry"]]

    """ An item that this catalog entry is related to.
    List of `CatalogEntryRelatedEntry` items (represented as `dict` in JSON). """




    

     
    



class ChargeItem(DomainResource):
    """ Item containing charge code(s) associated with the provision of healthcare
    provider products.
    
    The resource ChargeItem describes the provision of healthcare provider
    products for a certain patient, therefore referring not only to the
    product, but containing in addition details of the provision, like date,
    time, amounts and participating organizations and persons. Main Usage of
    the ChargeItem is to enable the billing process and internal cost
    allocation.
    """
    
    resource_type = "ChargeItem"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='definitionUri' >, <FHIRClassProperty self.name='definitionCanonical' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='performingOrganization' >, <FHIRClassProperty self.name='requestingOrganization' >, <FHIRClassProperty self.name='costCenter' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='bodysite' >, <FHIRClassProperty self.name='factorOverride' >, <FHIRClassProperty self.name='priceOverride' >, <FHIRClassProperty self.name='overrideReason' >, <FHIRClassProperty self.name='enterer' >, <FHIRClassProperty self.name='enteredDate' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='service' >, <FHIRClassProperty self.name='productReference' >, <FHIRClassProperty self.name='productCodeableConcept' >, <FHIRClassProperty self.name='account' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='supportingInformation' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for item.
    List of `Identifier` items (represented as `dict` in JSON). """

    definitionUri: typing.Optional[typing.List[str]]

    """ Defining information about the code of this charge item.
    List of `str` items. """

    definitionCanonical: typing.Optional[typing.List[str]]

    """ Resource defining the code of this ChargeItem.
    List of `str` items. """

    status: "str"

    """ planned | billable | not-billable | aborted | billed | entered-in-
        error | unknown.
    Type `str`. """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced ChargeItem.
    List of `Reference` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ A code that identifies the charge, like a billing code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Individual service was done for/to.
    Type `Reference` (represented as `dict` in JSON). """

    context: typing.Optional["Reference"]

    """ Encounter / Episode associated with event.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When the charged service was applied.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When the charged service was applied.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ When the charged service was applied.
    Type `Timing` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["ChargeItemPerformer"]]

    """ Who performed charged service.
    List of `ChargeItemPerformer` items (represented as `dict` in JSON). """

    performingOrganization: typing.Optional["Reference"]

    """ Organization providing the charged service.
    Type `Reference` (represented as `dict` in JSON). """

    requestingOrganization: typing.Optional["Reference"]

    """ Organization requesting the charged service.
    Type `Reference` (represented as `dict` in JSON). """

    costCenter: typing.Optional["Reference"]

    """ Organization that has ownership of the (potential, future) revenue.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Quantity of which the charge item has been serviced.
    Type `Quantity` (represented as `dict` in JSON). """

    bodysite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical location, if relevant.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    factorOverride: typing.Optional[float]

    """ Factor overriding the associated rules.
    Type `float`. """

    priceOverride: typing.Optional["Money"]

    """ Price overriding the associated rules.
    Type `Money` (represented as `dict` in JSON). """

    overrideReason: typing.Optional[str]

    """ Reason for overriding the list price/factor.
    Type `str`. """

    enterer: typing.Optional["Reference"]

    """ Individual who was entering.
    Type `Reference` (represented as `dict` in JSON). """

    enteredDate: typing.Optional["FHIRDate"]

    """ Date the charge item was entered.
    Type `FHIRDate` (represented as `str` in JSON). """

    reason: typing.Optional[typing.List["CodeableConcept"]]

    """ Why was the charged  service rendered?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    service: typing.Optional[typing.List["Reference"]]

    """ Which rendered service is being charged?.
    List of `Reference` items (represented as `dict` in JSON). """

    productReference: typing.Optional["Reference"]

    """ Product charged.
    Type `Reference` (represented as `dict` in JSON). """

    productCodeableConcept: typing.Optional["CodeableConcept"]

    """ Product charged.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    account: typing.Optional[typing.List["Reference"]]

    """ Account to place this charge.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the ChargeItem.
    List of `Annotation` items (represented as `dict` in JSON). """

    supportingInformation: typing.Optional[typing.List["Reference"]]

    """ Further information supporting this charge.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'ChargeItem.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'ChargeItem', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the charged service was applied', 'formal': 'Date/time(s) or duration when the charged service was applied.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))

#   {'path': 'ChargeItem.product[x]', 'choice_of_type': 'product', 'orig_name': 'productReference', 'name': 'productReference', 'parent_name': 'ChargeItem', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': False, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Product charged', 'formal': 'Identifies the device, food, drug or other product being charged either by type code or reference to an instance.', 'representation': None}

    _product_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['productReference', 'productCodeableConcept']), True))


    

     
    



class ChargeItemDefinition(DomainResource):
    """ Definition of properties and rules about how the price and the
    applicability of a ChargeItem can be determined.
    
    The ChargeItemDefinition resource provides the properties that apply to the
    (billing) codes necessary to calculate costs and prices. The properties may
    differ largely depending on type and realm, therefore this resource gives
    only a rough structure and requires profiling for each type of billing code
    system.
    """
    
    resource_type = "ChargeItemDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='derivedFromUri' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='instance' >, <FHIRClassProperty self.name='applicability' >, <FHIRClassProperty self.name='propertyGroup' >]
  

    url: str

    """ Canonical identifier for this charge item definition, represented
        as a URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the charge item definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the charge item definition.
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this charge item definition (human friendly).
    Type `str`. """

    derivedFromUri: typing.Optional[typing.List[str]]

    """ Underlying externally-defined charge item definition.
    List of `str` items. """

    partOf: typing.Optional[typing.List[str]]

    """ A larger definition of which this particular definition is a
        component or step.
    List of `str` items. """

    replaces: typing.Optional[typing.List[str]]

    """ Completed or terminated request(s) whose function is taken by this
        new request.
    List of `str` items. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the charge item definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for charge item definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the charge item definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the charge item definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the charge item definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Billing codes or product types this definition applies to.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    instance: typing.Optional[typing.List["Reference"]]

    """ Instances this definition applies to.
    List of `Reference` items (represented as `dict` in JSON). """

    applicability: typing.Optional[typing.List["ChargeItemDefinitionApplicability"]]

    """ Whether or not the billing code is applicable.
    List of `ChargeItemDefinitionApplicability` items (represented as `dict` in JSON). """

    propertyGroup: typing.Optional[typing.List["ChargeItemDefinitionPropertyGroup"]]

    """ Group of properties which are applicable under the same conditions.
    List of `ChargeItemDefinitionPropertyGroup` items (represented as `dict` in JSON). """




    

     
    



class Claim(DomainResource):
    """ Claim, Pre-determination or Pre-authorization.
    
    A provider issued list of professional services and products which have
    been provided, or are to be provided, to a patient which is sent to an
    insurer for reimbursement.
    """
    
    resource_type = "Claim"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='billablePeriod' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='enterer' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='fundsReserve' >, <FHIRClassProperty self.name='related' >, <FHIRClassProperty self.name='prescription' >, <FHIRClassProperty self.name='originalPrescription' >, <FHIRClassProperty self.name='payee' >, <FHIRClassProperty self.name='referral' >, <FHIRClassProperty self.name='facility' >, <FHIRClassProperty self.name='careTeam' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='diagnosis' >, <FHIRClassProperty self.name='procedure' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='accident' >, <FHIRClassProperty self.name='item' >, <FHIRClassProperty self.name='total' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for claim.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    type: "CodeableConcept"

    """ Category or discipline.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional["CodeableConcept"]

    """ More granular claim type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    use: "str"

    """ claim | preauthorization | predetermination.
    Type `str`. """

    patient: "Reference"

    """ The recipient of the products and services.
    Type `Reference` (represented as `dict` in JSON). """

    billablePeriod: typing.Optional["Period"]

    """ Relevant time frame for the claim.
    Type `Period` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Resource creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    enterer: typing.Optional["Reference"]

    """ Author of the claim.
    Type `Reference` (represented as `dict` in JSON). """

    insurer: typing.Optional["Reference"]

    """ Target.
    Type `Reference` (represented as `dict` in JSON). """

    provider: "Reference"

    """ Party responsible for the claim.
    Type `Reference` (represented as `dict` in JSON). """

    priority: "CodeableConcept"

    """ Desired processing ugency.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fundsReserve: typing.Optional["CodeableConcept"]

    """ For whom to reserve funds.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    related: typing.Optional[typing.List["ClaimRelated"]]

    """ Prior or corollary claims.
    List of `ClaimRelated` items (represented as `dict` in JSON). """

    prescription: typing.Optional["Reference"]

    """ Prescription authorizing services and products.
    Type `Reference` (represented as `dict` in JSON). """

    originalPrescription: typing.Optional["Reference"]

    """ Original prescription if superseded by fulfiller.
    Type `Reference` (represented as `dict` in JSON). """

    payee: typing.Optional["ClaimPayee"]

    """ Recipient of benefits payable.
    Type `ClaimPayee` (represented as `dict` in JSON). """

    referral: typing.Optional["Reference"]

    """ Treatment referral.
    Type `Reference` (represented as `dict` in JSON). """

    facility: typing.Optional["Reference"]

    """ Servicing facility.
    Type `Reference` (represented as `dict` in JSON). """

    careTeam: typing.Optional[typing.List["ClaimCareTeam"]]

    """ Members of the care team.
    List of `ClaimCareTeam` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["ClaimSupportingInfo"]]

    """ Supporting information.
    List of `ClaimSupportingInfo` items (represented as `dict` in JSON). """

    diagnosis: typing.Optional[typing.List["ClaimDiagnosis"]]

    """ Pertinent diagnosis information.
    List of `ClaimDiagnosis` items (represented as `dict` in JSON). """

    procedure: typing.Optional[typing.List["ClaimProcedure"]]

    """ Clinical procedures performed.
    List of `ClaimProcedure` items (represented as `dict` in JSON). """

    insurance: typing.List["ClaimInsurance"]

    """ Patient insurance information.
    List of `ClaimInsurance` items (represented as `dict` in JSON). """

    accident: typing.Optional["ClaimAccident"]

    """ Details of the event.
    Type `ClaimAccident` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["ClaimItem"]]

    """ Product or service provided.
    List of `ClaimItem` items (represented as `dict` in JSON). """

    total: typing.Optional["Money"]

    """ Total claim cost.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class ClaimResponse(DomainResource):
    """ Response to a claim predetermination or preauthorization.
    
    This resource provides the adjudication details from the processing of a
    Claim resource.
    """
    
    resource_type = "ClaimResponse"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='requestor' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='disposition' >, <FHIRClassProperty self.name='preAuthRef' >, <FHIRClassProperty self.name='preAuthPeriod' >, <FHIRClassProperty self.name='payeeType' >, <FHIRClassProperty self.name='item' >, <FHIRClassProperty self.name='addItem' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='total' >, <FHIRClassProperty self.name='payment' >, <FHIRClassProperty self.name='fundsReserve' >, <FHIRClassProperty self.name='formCode' >, <FHIRClassProperty self.name='form' >, <FHIRClassProperty self.name='processNote' >, <FHIRClassProperty self.name='communicationRequest' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='error' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for a claim response.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    type: "CodeableConcept"

    """ More granular claim type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional["CodeableConcept"]

    """ More granular claim type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    use: "str"

    """ claim | preauthorization | predetermination.
    Type `str`. """

    patient: "Reference"

    """ The recipient of the products and services.
    Type `Reference` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Response creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    insurer: "Reference"

    """ Party responsible for reimbursement.
    Type `Reference` (represented as `dict` in JSON). """

    requestor: typing.Optional["Reference"]

    """ Party responsible for the claim.
    Type `Reference` (represented as `dict` in JSON). """

    request: typing.Optional["Reference"]

    """ Id of resource triggering adjudication.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: "str"

    """ queued | complete | error | partial.
    Type `str`. """

    disposition: typing.Optional[str]

    """ Disposition Message.
    Type `str`. """

    preAuthRef: typing.Optional[str]

    """ Preauthorization reference.
    Type `str`. """

    preAuthPeriod: typing.Optional["Period"]

    """ Preauthorization reference effective period.
    Type `Period` (represented as `dict` in JSON). """

    payeeType: typing.Optional["CodeableConcept"]

    """ Party to be paid any benefits payable.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["ClaimResponseItem"]]

    """ Adjudication for claim line items.
    List of `ClaimResponseItem` items (represented as `dict` in JSON). """

    addItem: typing.Optional[typing.List["ClaimResponseAddItem"]]

    """ Insurer added line items.
    List of `ClaimResponseAddItem` items (represented as `dict` in JSON). """

    adjudication: typing.Optional[typing.List["ClaimResponseItemAdjudication"]]

    """ Header-level adjudication.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """

    total: typing.Optional[typing.List["ClaimResponseTotal"]]

    """ Adjudication totals.
    List of `ClaimResponseTotal` items (represented as `dict` in JSON). """

    payment: typing.Optional["ClaimResponsePayment"]

    """ Payment Details.
    Type `ClaimResponsePayment` (represented as `dict` in JSON). """

    fundsReserve: typing.Optional["CodeableConcept"]

    """ Funds reserved status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    formCode: typing.Optional["CodeableConcept"]

    """ Printed form identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    form: typing.Optional["Attachment"]

    """ Printed reference or actual form.
    Type `Attachment` (represented as `dict` in JSON). """

    processNote: typing.Optional[typing.List["ClaimResponseProcessNote"]]

    """ Note concerning adjudication.
    List of `ClaimResponseProcessNote` items (represented as `dict` in JSON). """

    communicationRequest: typing.Optional[typing.List["Reference"]]

    """ Request for additional information.
    List of `Reference` items (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["ClaimResponseInsurance"]]

    """ Patient insurance information.
    List of `ClaimResponseInsurance` items (represented as `dict` in JSON). """

    error: typing.Optional[typing.List["ClaimResponseError"]]

    """ Processing errors.
    List of `ClaimResponseError` items (represented as `dict` in JSON). """




    

     
    



class ClinicalImpression(DomainResource):
    """ A clinical assessment performed when planning treatments and management
    strategies for a patient.
    
    A record of a clinical assessment performed to determine what problem(s)
    may affect the patient and before planning the treatments or management
    strategies that are best to manage a patient's condition. Assessments are
    often 1:1 with a clinical consultation / encounter,  but this varies
    greatly depending on the clinical workflow. This resource is called
    "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion
    with the recording of assessment tools such as Apgar score.
    """
    
    resource_type = "ClinicalImpression"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='effectiveDateTime' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='assessor' >, <FHIRClassProperty self.name='previous' >, <FHIRClassProperty self.name='problem' >, <FHIRClassProperty self.name='investigation' >, <FHIRClassProperty self.name='protocol' >, <FHIRClassProperty self.name='summary' >, <FHIRClassProperty self.name='finding' >, <FHIRClassProperty self.name='prognosisCodeableConcept' >, <FHIRClassProperty self.name='prognosisReference' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ in-progress | completed | entered-in-error.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Kind of assessment performed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Why/how the assessment was performed.
    Type `str`. """

    subject: "Reference"

    """ Patient or group assessed.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    effectiveDateTime: typing.Optional["FHIRDate"]

    """ Time of assessment.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ Time of assessment.
    Type `Period` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the assessment was documented.
    Type `FHIRDate` (represented as `str` in JSON). """

    assessor: typing.Optional["Reference"]

    """ The clinician performing the assessment.
    Type `Reference` (represented as `dict` in JSON). """

    previous: typing.Optional["Reference"]

    """ Reference to last assessment.
    Type `Reference` (represented as `dict` in JSON). """

    problem: typing.Optional[typing.List["Reference"]]

    """ Relevant impressions of patient state.
    List of `Reference` items (represented as `dict` in JSON). """

    investigation: typing.Optional[typing.List["ClinicalImpressionInvestigation"]]

    """ One or more sets of investigations (signs, symptoms, etc.).
    List of `ClinicalImpressionInvestigation` items (represented as `dict` in JSON). """

    protocol: typing.Optional[typing.List[str]]

    """ Clinical Protocol followed.
    List of `str` items. """

    summary: typing.Optional[str]

    """ Summary of the assessment.
    Type `str`. """

    finding: typing.Optional[typing.List["ClinicalImpressionFinding"]]

    """ Possible or likely findings and diagnoses.
    List of `ClinicalImpressionFinding` items (represented as `dict` in JSON). """

    prognosisCodeableConcept: typing.Optional[typing.List["CodeableConcept"]]

    """ Estimate of likely outcome.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    prognosisReference: typing.Optional[typing.List["Reference"]]

    """ RiskAssessment expressing likely outcome.
    List of `Reference` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["Reference"]]

    """ Information supporting the clinical impression.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the ClinicalImpression.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'ClinicalImpression.effective[x]', 'choice_of_type': 'effective', 'orig_name': 'effectiveDateTime', 'name': 'effectiveDateTime', 'parent_name': 'ClinicalImpression', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time of assessment', 'formal': 'The point in time or period over which the subject was assessed.', 'representation': None}

    _effective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['effectiveDateTime', 'effectivePeriod']), True))


    

     
    



class CodeSystem(DomainResource):
    """ Declares the existence of and describes a code system or code system
    supplement.
    
    The CodeSystem resource is used to declare the existence of and describe a
    code system or code system supplement and its key properties, and
    optionally define a part or all of its content.
    """
    
    resource_type = "CodeSystem"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='caseSensitive' >, <FHIRClassProperty self.name='valueSet' >, <FHIRClassProperty self.name='hierarchyMeaning' >, <FHIRClassProperty self.name='compositional' >, <FHIRClassProperty self.name='versionNeeded' >, <FHIRClassProperty self.name='content' >, <FHIRClassProperty self.name='supplements' >, <FHIRClassProperty self.name='count' >, <FHIRClassProperty self.name='filter' >, <FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='concept' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this code system, represented as a URI
        (globally unique) (Coding.system).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the code system (business identifier).
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the code system (Coding.version).
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this code system (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this code system (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the code system.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for code system (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this code system is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    caseSensitive: typing.Optional[bool]

    """ If code comparison is case sensitive.
    Type `bool`. """

    valueSet: typing.Optional[str]

    """ Canonical reference to the value set with entire code system.
    Type `str`. """

    hierarchyMeaning: typing.Optional["str"]

    """ grouped-by | is-a | part-of | classified-with.
    Type `str`. """

    compositional: typing.Optional[bool]

    """ If code system defines a compositional grammar.
    Type `bool`. """

    versionNeeded: typing.Optional[bool]

    """ If definitions are not stable.
    Type `bool`. """

    content: "str"

    """ not-present | example | fragment | complete | supplement.
    Type `str`. """

    supplements: typing.Optional[str]

    """ Canonical URL of Code System this adds designations and properties
        to.
    Type `str`. """

    count: typing.Optional[int]

    """ Total concepts in the code system.
    Type `int`. """

    filter: typing.Optional[typing.List["CodeSystemFilter"]]

    """ Filter that can be used in a value set.
    List of `CodeSystemFilter` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List["CodeSystemProperty"]]

    """ Additional information supplied about each concept.
    List of `CodeSystemProperty` items (represented as `dict` in JSON). """

    concept: typing.Optional[typing.List["CodeSystemConcept"]]

    """ Concepts in the code system.
    List of `CodeSystemConcept` items (represented as `dict` in JSON). """




    

     
    



class Communication(DomainResource):
    """ A record of information transmitted from a sender to a receiver.
    
    An occurrence of information being transmitted; e.g. an alert that was sent
    to a responsible provider, a public health agency that was notified about a
    reportable condition.
    """
    
    resource_type = "Communication"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='inResponseTo' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='medium' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='about' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='sent' >, <FHIRClassProperty self.name='received' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='sender' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='payload' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Request fulfilled by this communication.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of this action.
    List of `Reference` items (represented as `dict` in JSON). """

    inResponseTo: typing.Optional[typing.List["Reference"]]

    """ Reply to.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ preparation | in-progress | not-done | on-hold | stopped |
        completed | entered-in-error | unknown.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Message category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    medium: typing.Optional[typing.List["CodeableConcept"]]

    """ A channel of communication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Focus of message.
    Type `Reference` (represented as `dict` in JSON). """

    topic: typing.Optional["CodeableConcept"]

    """ Description of the purpose/content.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    about: typing.Optional[typing.List["Reference"]]

    """ Resources that pertain to this communication.
    List of `Reference` items (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    sent: typing.Optional["FHIRDate"]

    """ When sent.
    Type `FHIRDate` (represented as `str` in JSON). """

    received: typing.Optional["FHIRDate"]

    """ When received.
    Type `FHIRDate` (represented as `str` in JSON). """

    recipient: typing.Optional[typing.List["Reference"]]

    """ Message recipient.
    List of `Reference` items (represented as `dict` in JSON). """

    sender: typing.Optional["Reference"]

    """ Message sender.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Indication for message.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why was communication done?.
    List of `Reference` items (represented as `dict` in JSON). """

    payload: typing.Optional[typing.List["CommunicationPayload"]]

    """ Message payload.
    List of `CommunicationPayload` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the communication.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class CommunicationRequest(DomainResource):
    """ A request for information to be sent to a receiver.
    
    A request to convey information; e.g. the CDS system proposes that an alert
    be sent to a responsible provider, the CDS system proposes that the public
    health agency be notified about a reportable condition.
    """
    
    resource_type = "CommunicationRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='groupIdentifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='medium' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='about' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='payload' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='sender' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills plan or proposal.
    List of `Reference` items (represented as `dict` in JSON). """

    replaces: typing.Optional[typing.List["Reference"]]

    """ Request(s) replaced by this request.
    List of `Reference` items (represented as `dict` in JSON). """

    groupIdentifier: typing.Optional["Identifier"]

    """ Composite request this is part of.
    Type `Identifier` (represented as `dict` in JSON). """

    status: "str"

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Message category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    doNotPerform: typing.Optional[bool]

    """ True if request is prohibiting action.
    Type `bool`. """

    medium: typing.Optional[typing.List["CodeableConcept"]]

    """ A channel of communication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Focus of message.
    Type `Reference` (represented as `dict` in JSON). """

    about: typing.Optional[typing.List["Reference"]]

    """ Resources that pertain to this communication request.
    List of `Reference` items (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    payload: typing.Optional[typing.List["CommunicationRequestPayload"]]

    """ Message payload.
    List of `CommunicationRequestPayload` items (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When scheduled.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When scheduled.
    Type `Period` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ When request transitioned to being actionable.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Who/what is requesting service.
    Type `Reference` (represented as `dict` in JSON). """

    recipient: typing.Optional[typing.List["Reference"]]

    """ Message recipient.
    List of `Reference` items (represented as `dict` in JSON). """

    sender: typing.Optional["Reference"]

    """ Message sender.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why is communication needed?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why is communication needed?.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about communication request.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'CommunicationRequest.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'CommunicationRequest', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When scheduled', 'formal': 'The time when this communication is to occur.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod']), True))


    

     
    



class CompartmentDefinition(DomainResource):
    """ Compartment Definition for a resource.
    
    A compartment definition that defines how resources are accessed on a
    server.
    """
    
    resource_type = "CompartmentDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='search' >, <FHIRClassProperty self.name='resource' >]
  

    url: str

    """ Canonical identifier for this compartment definition, represented
        as a URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the compartment definition.
    Type `str`. """

    name: str

    """ Name for this compartment definition (computer friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the compartment definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this compartment definition is defined.
    Type `str`. """

    code: "str"

    """ Patient | Encounter | RelatedPerson | Practitioner | Device.
    Type `str`. """

    search: bool

    """ Whether the search syntax is supported.
    Type `bool`. """

    resource: typing.Optional[typing.List["CompartmentDefinitionResource"]]

    """ How a resource is related to the compartment.
    List of `CompartmentDefinitionResource` items (represented as `dict` in JSON). """




    

     
    



class Composition(DomainResource):
    """ A set of resources composed into a single coherent clinical statement with
    clinical attestation.
    
    A set of healthcare-related information that is assembled together into a
    single logical package that provides a single coherent statement of
    meaning, establishes its own context and that has clinical attestation with
    regard to who is making the statement. A Composition defines the structure
    and narrative content necessary for a document. However, a Composition
    alone does not constitute a document. Rather, the Composition must be the
    first entry in a Bundle where Bundle.type=document, and any other resources
    referenced from Composition must be included as subsequent entries in the
    Bundle (for example Patient, Practitioner, Encounter, etc.).
    """
    
    resource_type = "Composition"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='confidentiality' >, <FHIRClassProperty self.name='attester' >, <FHIRClassProperty self.name='custodian' >, <FHIRClassProperty self.name='relatesTo' >, <FHIRClassProperty self.name='event' >, <FHIRClassProperty self.name='section' >]
  

    identifier: typing.Optional["Identifier"]

    """ Version-independent identifier for the Composition.
    Type `Identifier` (represented as `dict` in JSON). """

    status: "str"

    """ preliminary | final | amended | entered-in-error.
    Type `str`. """

    type: "CodeableConcept"

    """ Kind of composition (LOINC if possible).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Categorization of Composition.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who and/or what the composition is about.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Context of the Composition.
    Type `Reference` (represented as `dict` in JSON). """

    date: "FHIRDate"

    """ Composition editing time.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.List["Reference"]

    """ Who and/or what authored the composition.
    List of `Reference` items (represented as `dict` in JSON). """

    title: str

    """ Human Readable name/title.
    Type `str`. """

    confidentiality: typing.Optional[str]

    """ As defined by affinity domain.
    Type `str`. """

    attester: typing.Optional[typing.List["CompositionAttester"]]

    """ Attests to accuracy of composition.
    List of `CompositionAttester` items (represented as `dict` in JSON). """

    custodian: typing.Optional["Reference"]

    """ Organization which maintains the composition.
    Type `Reference` (represented as `dict` in JSON). """

    relatesTo: typing.Optional[typing.List["CompositionRelatesTo"]]

    """ Relationships to other compositions/documents.
    List of `CompositionRelatesTo` items (represented as `dict` in JSON). """

    event: typing.Optional[typing.List["CompositionEvent"]]

    """ The clinical service(s) being documented.
    List of `CompositionEvent` items (represented as `dict` in JSON). """

    section: typing.Optional[typing.List["CompositionSection"]]

    """ Composition is broken into sections.
    List of `CompositionSection` items (represented as `dict` in JSON). """




    

     
    



class ConceptMap(DomainResource):
    """ A map from one set of concepts to one or more other concepts.
    
    A statement of relationships from one set of concepts to one or more other
    concepts - either concepts in code systems, or data element/data element
    concepts, or classes in class models.
    """
    
    resource_type = "ConceptMap"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='sourceUri' >, <FHIRClassProperty self.name='sourceCanonical' >, <FHIRClassProperty self.name='targetUri' >, <FHIRClassProperty self.name='targetCanonical' >, <FHIRClassProperty self.name='group' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this concept map, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional["Identifier"]

    """ Additional identifier for the concept map.
    Type `Identifier` (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the concept map.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this concept map (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this concept map (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the concept map.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for concept map (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this concept map is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    sourceUri: typing.Optional[str]

    """ The source value set that contains the concepts that are being
        mapped.
    Type `str`. """

    sourceCanonical: typing.Optional[str]

    """ The source value set that contains the concepts that are being
        mapped.
    Type `str`. """

    targetUri: typing.Optional[str]

    """ The target value set which provides context for the mappings.
    Type `str`. """

    targetCanonical: typing.Optional[str]

    """ The target value set which provides context for the mappings.
    Type `str`. """

    group: typing.Optional[typing.List["ConceptMapGroup"]]

    """ Same source and target systems.
    List of `ConceptMapGroup` items (represented as `dict` in JSON). """



#   {'path': 'ConceptMap.source[x]', 'choice_of_type': 'source', 'orig_name': 'sourceUri', 'name': 'sourceUri', 'parent_name': 'ConceptMap', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The source value set that contains the concepts that are being mapped', 'formal': 'Identifier for the source value set that contains the concepts that are being mapped and provides context for the mappings.', 'representation': None}

    _source_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['sourceUri', 'sourceCanonical']), True))

#   {'path': 'ConceptMap.target[x]', 'choice_of_type': 'target', 'orig_name': 'targetUri', 'name': 'targetUri', 'parent_name': 'ConceptMap', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The target value set which provides context for the mappings', 'formal': 'The target value set provides context for the mappings. Note that the mapping is made between concepts, not between value sets, but the value set provides important context about how the concept mapping choices are made.', 'representation': None}

    _target_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['targetUri', 'targetCanonical']), True))


    

     
    



class Condition(DomainResource):
    """ Detailed information about conditions, problems or diagnoses.
    
    A clinical condition, problem, diagnosis, or other event, situation, issue,
    or clinical concept that has risen to a level of concern.
    """
    
    resource_type = "Condition"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='clinicalStatus' >, <FHIRClassProperty self.name='verificationStatus' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='onsetDateTime' >, <FHIRClassProperty self.name='onsetAge' >, <FHIRClassProperty self.name='onsetPeriod' >, <FHIRClassProperty self.name='onsetRange' >, <FHIRClassProperty self.name='onsetString' >, <FHIRClassProperty self.name='abatementDateTime' >, <FHIRClassProperty self.name='abatementAge' >, <FHIRClassProperty self.name='abatementPeriod' >, <FHIRClassProperty self.name='abatementRange' >, <FHIRClassProperty self.name='abatementString' >, <FHIRClassProperty self.name='recordedDate' >, <FHIRClassProperty self.name='recorder' >, <FHIRClassProperty self.name='asserter' >, <FHIRClassProperty self.name='stage' >, <FHIRClassProperty self.name='evidence' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this condition.
    List of `Identifier` items (represented as `dict` in JSON). """

    clinicalStatus: typing.Optional["CodeableConcept"]

    """ active | recurrence | relapse | inactive | remission | resolved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    verificationStatus: typing.Optional["CodeableConcept"]

    """ unconfirmed | provisional | differential | confirmed | refuted |
        entered-in-error.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ problem-list-item | encounter-diagnosis.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    severity: typing.Optional["CodeableConcept"]

    """ Subjective severity of condition.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Identification of the condition, problem or diagnosis.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    bodySite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical location, if relevant.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who has the condition?.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    onsetDateTime: typing.Optional["FHIRDate"]

    """ Estimated or actual date,  date-time, or age.
    Type `FHIRDate` (represented as `str` in JSON). """

    onsetAge: typing.Optional["Age"]

    """ Estimated or actual date,  date-time, or age.
    Type `Age` (represented as `dict` in JSON). """

    onsetPeriod: typing.Optional["Period"]

    """ Estimated or actual date,  date-time, or age.
    Type `Period` (represented as `dict` in JSON). """

    onsetRange: typing.Optional["Range"]

    """ Estimated or actual date,  date-time, or age.
    Type `Range` (represented as `dict` in JSON). """

    onsetString: typing.Optional[str]

    """ Estimated or actual date,  date-time, or age.
    Type `str`. """

    abatementDateTime: typing.Optional["FHIRDate"]

    """ When in resolution/remission.
    Type `FHIRDate` (represented as `str` in JSON). """

    abatementAge: typing.Optional["Age"]

    """ When in resolution/remission.
    Type `Age` (represented as `dict` in JSON). """

    abatementPeriod: typing.Optional["Period"]

    """ When in resolution/remission.
    Type `Period` (represented as `dict` in JSON). """

    abatementRange: typing.Optional["Range"]

    """ When in resolution/remission.
    Type `Range` (represented as `dict` in JSON). """

    abatementString: typing.Optional[str]

    """ When in resolution/remission.
    Type `str`. """

    recordedDate: typing.Optional["FHIRDate"]

    """ Date record was first recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    recorder: typing.Optional["Reference"]

    """ Who recorded the condition.
    Type `Reference` (represented as `dict` in JSON). """

    asserter: typing.Optional["Reference"]

    """ Person who asserts this condition.
    Type `Reference` (represented as `dict` in JSON). """

    stage: typing.Optional[typing.List["ConditionStage"]]

    """ Stage/grade, usually assessed formally.
    List of `ConditionStage` items (represented as `dict` in JSON). """

    evidence: typing.Optional[typing.List["ConditionEvidence"]]

    """ Supporting evidence.
    List of `ConditionEvidence` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional information about the Condition.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'Condition.onset[x]', 'choice_of_type': 'onset', 'orig_name': 'onsetDateTime', 'name': 'onsetDateTime', 'parent_name': 'Condition', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Estimated or actual date,  date-time, or age', 'formal': 'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.', 'representation': None}

    _onset_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['onsetDateTime', 'onsetAge', 'onsetPeriod', 'onsetRange', 'onsetString']), True))

#   {'path': 'Condition.abatement[x]', 'choice_of_type': 'abatement', 'orig_name': 'abatementDateTime', 'name': 'abatementDateTime', 'parent_name': 'Condition', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When in resolution/remission', 'formal': 'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.', 'representation': None}

    _abatement_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['abatementDateTime', 'abatementAge', 'abatementPeriod', 'abatementRange', 'abatementString']), True))


    

     
    



class Consent(DomainResource):
    """ A healthcare consumer's  choices to permit or deny recipients or roles to
    perform actions for specific purposes and periods of time.
    
    A record of a healthcare consumer’s  choices, which permits or denies
    identified recipient(s) or recipient role(s) to perform one or more actions
    within a given policy context, for specific purposes and periods of time.
    """
    
    resource_type = "Consent"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='scope' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='dateTime' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='sourceAttachment' >, <FHIRClassProperty self.name='sourceReference' >, <FHIRClassProperty self.name='policy' >, <FHIRClassProperty self.name='policyRule' >, <FHIRClassProperty self.name='verification' >, <FHIRClassProperty self.name='provision' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifier for this record (external references).
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ draft | proposed | active | rejected | inactive | entered-in-error.
    Type `str`. """

    scope: "CodeableConcept"

    """ Which of the four areas this resource covers (extensible).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.List["CodeableConcept"]

    """ Classification of the consent statement - for indexing/retrieval.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    patient: typing.Optional["Reference"]

    """ Who the consent applies to.
    Type `Reference` (represented as `dict` in JSON). """

    dateTime: typing.Optional["FHIRDate"]

    """ When this Consent was created or indexed.
    Type `FHIRDate` (represented as `str` in JSON). """

    performer: typing.Optional[typing.List["Reference"]]

    """ Who is agreeing to the policy and rules.
    List of `Reference` items (represented as `dict` in JSON). """

    organization: typing.Optional[typing.List["Reference"]]

    """ Custodian of the consent.
    List of `Reference` items (represented as `dict` in JSON). """

    sourceAttachment: typing.Optional["Attachment"]

    """ Source from which this consent is taken.
    Type `Attachment` (represented as `dict` in JSON). """

    sourceReference: typing.Optional["Reference"]

    """ Source from which this consent is taken.
    Type `Reference` (represented as `dict` in JSON). """

    policy: typing.Optional[typing.List["ConsentPolicy"]]

    """ Policies covered by this consent.
    List of `ConsentPolicy` items (represented as `dict` in JSON). """

    policyRule: typing.Optional["CodeableConcept"]

    """ Regulation that this consents to.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    verification: typing.Optional[typing.List["ConsentVerification"]]

    """ Consent Verified by patient or family.
    List of `ConsentVerification` items (represented as `dict` in JSON). """

    provision: typing.Optional["ConsentProvision"]

    """ Constraints to the base Consent.policyRule.
    Type `ConsentProvision` (represented as `dict` in JSON). """



#   {'path': 'Consent.source[x]', 'choice_of_type': 'source', 'orig_name': 'sourceAttachment', 'name': 'sourceAttachment', 'parent_name': 'Consent', 'class_name': 'Attachment', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Source from which this consent is taken', 'formal': 'The source on which this consent statement is based. The source might be a scanned original paper form, or a reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.', 'representation': None}

    _source_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['sourceAttachment', 'sourceReference']), True))


    

     
    



class Contract(DomainResource):
    """ Legal Agreement.
    
    Legally enforceable, formally recorded unilateral or bilateral directive
    i.e., a policy or agreement.
    """
    
    resource_type = "Contract"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='legalState' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='contentDerivative' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='applies' >, <FHIRClassProperty self.name='expirationType' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='domain' >, <FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='scope' >, <FHIRClassProperty self.name='topicCodeableConcept' >, <FHIRClassProperty self.name='topicReference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='contentDefinition' >, <FHIRClassProperty self.name='term' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='relevantHistory' >, <FHIRClassProperty self.name='signer' >, <FHIRClassProperty self.name='friendly' >, <FHIRClassProperty self.name='legal' >, <FHIRClassProperty self.name='rule' >, <FHIRClassProperty self.name='legallyBindingAttachment' >, <FHIRClassProperty self.name='legallyBindingReference' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Contract number.
    List of `Identifier` items (represented as `dict` in JSON). """

    url: typing.Optional[str]

    """ Basal definition.
    Type `str`. """

    version: typing.Optional[str]

    """ Business edition.
    Type `str`. """

    status: typing.Optional["str"]

    """ amended | appended | cancelled | disputed | entered-in-error |
        executable | executed | negotiable | offered | policy | rejected |
        renewed | revoked | resolved | terminated.
    Type `str`. """

    legalState: typing.Optional["CodeableConcept"]

    """ Negotiation status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional["Reference"]

    """ Source Contract Definition.
    Type `Reference` (represented as `dict` in JSON). """

    instantiatesUri: typing.Optional[str]

    """ External Contract Definition.
    Type `str`. """

    contentDerivative: typing.Optional["CodeableConcept"]

    """ Content derived from the basal information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    issued: typing.Optional["FHIRDate"]

    """ When this Contract was issued.
    Type `FHIRDate` (represented as `str` in JSON). """

    applies: typing.Optional["Period"]

    """ Effective time.
    Type `Period` (represented as `dict` in JSON). """

    expirationType: typing.Optional["CodeableConcept"]

    """ Contract cessation cause.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional[typing.List["Reference"]]

    """ Contract Target Entity.
    List of `Reference` items (represented as `dict` in JSON). """

    authority: typing.Optional[typing.List["Reference"]]

    """ Authority under which this Contract has standing.
    List of `Reference` items (represented as `dict` in JSON). """

    domain: typing.Optional[typing.List["Reference"]]

    """ A sphere of control governed by an authoritative jurisdiction,
        organization, or person.
    List of `Reference` items (represented as `dict` in JSON). """

    site: typing.Optional[typing.List["Reference"]]

    """ Specific Location.
    List of `Reference` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Computer friendly designation.
    Type `str`. """

    title: typing.Optional[str]

    """ Human Friendly name.
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate Friendly name.
    Type `str`. """

    alias: typing.Optional[typing.List[str]]

    """ Acronym or short name.
    List of `str` items. """

    author: typing.Optional["Reference"]

    """ Source of Contract.
    Type `Reference` (represented as `dict` in JSON). """

    scope: typing.Optional["CodeableConcept"]

    """ Range of Legal Concerns.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    topicCodeableConcept: typing.Optional["CodeableConcept"]

    """ Focus of contract interest.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    topicReference: typing.Optional["Reference"]

    """ Focus of contract interest.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Legal instrument category.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional[typing.List["CodeableConcept"]]

    """ Subtype within the context of type.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    contentDefinition: typing.Optional["ContractContentDefinition"]

    """ Contract precursor content.
    Type `ContractContentDefinition` (represented as `dict` in JSON). """

    term: typing.Optional[typing.List["ContractTerm"]]

    """ Contract Term List.
    List of `ContractTerm` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["Reference"]]

    """ Extra Information.
    List of `Reference` items (represented as `dict` in JSON). """

    relevantHistory: typing.Optional[typing.List["Reference"]]

    """ Key event in Contract History.
    List of `Reference` items (represented as `dict` in JSON). """

    signer: typing.Optional[typing.List["ContractSigner"]]

    """ Contract Signatory.
    List of `ContractSigner` items (represented as `dict` in JSON). """

    friendly: typing.Optional[typing.List["ContractFriendly"]]

    """ Contract Friendly Language.
    List of `ContractFriendly` items (represented as `dict` in JSON). """

    legal: typing.Optional[typing.List["ContractLegal"]]

    """ Contract Legal Language.
    List of `ContractLegal` items (represented as `dict` in JSON). """

    rule: typing.Optional[typing.List["ContractRule"]]

    """ Computable Contract Language.
    List of `ContractRule` items (represented as `dict` in JSON). """

    legallyBindingAttachment: typing.Optional["Attachment"]

    """ Binding Contract.
    Type `Attachment` (represented as `dict` in JSON). """

    legallyBindingReference: typing.Optional["Reference"]

    """ Binding Contract.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Contract.topic[x]', 'choice_of_type': 'topic', 'orig_name': 'topicCodeableConcept', 'name': 'topicCodeableConcept', 'parent_name': 'Contract', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Focus of contract interest', 'formal': 'Narrows the range of legal concerns to focus on the achievement of specific contractual objectives.', 'representation': None}

    _topic_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['topicCodeableConcept', 'topicReference']), True))

#   {'path': 'Contract.legallyBinding[x]', 'choice_of_type': 'legallyBinding', 'orig_name': 'legallyBindingAttachment', 'name': 'legallyBindingAttachment', 'parent_name': 'Contract', 'class_name': 'Attachment', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Binding Contract', 'formal': 'Legally binding Contract: This is the signed and legally recognized representation of the Contract, which is considered the "source of truth" and which would be the basis for legal action related to enforcement of this Contract.', 'representation': None}

    _legallyBinding_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['legallyBindingAttachment', 'legallyBindingReference']), True))


    

     
    



class Coverage(DomainResource):
    """ Insurance or medical plan or a payment agreement.
    
    Financial instrument which may be used to reimburse or pay for health care
    products and services. Includes both insurance and self-payment.
    """
    
    resource_type = "Coverage"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='policyHolder' >, <FHIRClassProperty self.name='subscriber' >, <FHIRClassProperty self.name='subscriberId' >, <FHIRClassProperty self.name='beneficiary' >, <FHIRClassProperty self.name='dependent' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='payor' >, <FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='order' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='costToBeneficiary' >, <FHIRClassProperty self.name='subrogation' >, <FHIRClassProperty self.name='contract' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for the coverage.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Coverage category such as medical or accident.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    policyHolder: typing.Optional["Reference"]

    """ Owner of the policy.
    Type `Reference` (represented as `dict` in JSON). """

    subscriber: typing.Optional["Reference"]

    """ Subscriber to the policy.
    Type `Reference` (represented as `dict` in JSON). """

    subscriberId: typing.Optional[str]

    """ ID assigned to the subscriber.
    Type `str`. """

    beneficiary: "Reference"

    """ Plan beneficiary.
    Type `Reference` (represented as `dict` in JSON). """

    dependent: typing.Optional[str]

    """ Dependent number.
    Type `str`. """

    relationship: typing.Optional["CodeableConcept"]

    """ Beneficiary relationship to the subscriber.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Coverage start and end dates.
    Type `Period` (represented as `dict` in JSON). """

    payor: typing.List["Reference"]

    """ Issuer of the policy.
    List of `Reference` items (represented as `dict` in JSON). """

    class_: typing.Optional[typing.List["CoverageClass"]]

    """ Additional coverage classifications.
    List of `CoverageClass` items (represented as `dict` in JSON). """

    order: typing.Optional[int]

    """ Relative order of the coverage.
    Type `int`. """

    network: typing.Optional[str]

    """ Insurer network.
    Type `str`. """

    costToBeneficiary: typing.Optional[typing.List["CoverageCostToBeneficiary"]]

    """ Patient payments for services/products.
    List of `CoverageCostToBeneficiary` items (represented as `dict` in JSON). """

    subrogation: typing.Optional[bool]

    """ Reimbursement to insurer.
    Type `bool`. """

    contract: typing.Optional[typing.List["Reference"]]

    """ Contract details.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class CoverageEligibilityRequest(DomainResource):
    """ CoverageEligibilityRequest resource.
    
    The CoverageEligibilityRequest provides patient and insurance coverage
    information to an insurer for them to respond, in the form of an
    CoverageEligibilityResponse, with information regarding whether the stated
    coverage is valid and in-force and optionally to provide the insurance
    details of the policy.
    """
    
    resource_type = "CoverageEligibilityRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='enterer' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='facility' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='item' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for coverage eligiblity request.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    priority: typing.Optional["CodeableConcept"]

    """ Desired processing priority.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    purpose: typing.List["str"]

    """ auth-requirements | benefits | discovery | validation.
    List of `str` items. """

    patient: "Reference"

    """ Intended recipient of products and services.
    Type `Reference` (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Estimated date or dates of service.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Estimated date or dates of service.
    Type `Period` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    enterer: typing.Optional["Reference"]

    """ Author.
    Type `Reference` (represented as `dict` in JSON). """

    provider: typing.Optional["Reference"]

    """ Party responsible for the request.
    Type `Reference` (represented as `dict` in JSON). """

    insurer: "Reference"

    """ Coverage issuer.
    Type `Reference` (represented as `dict` in JSON). """

    facility: typing.Optional["Reference"]

    """ Servicing facility.
    Type `Reference` (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["CoverageEligibilityRequestSupportingInfo"]]

    """ Supporting information.
    List of `CoverageEligibilityRequestSupportingInfo` items (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["CoverageEligibilityRequestInsurance"]]

    """ Patient insurance information.
    List of `CoverageEligibilityRequestInsurance` items (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["CoverageEligibilityRequestItem"]]

    """ Item to be evaluated for eligibiity.
    List of `CoverageEligibilityRequestItem` items (represented as `dict` in JSON). """



#   {'path': 'CoverageEligibilityRequest.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'CoverageEligibilityRequest', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Estimated date or dates of service', 'formal': 'The date or dates when the enclosed suite of services were performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))


    

     
    



class CoverageEligibilityResponse(DomainResource):
    """ CoverageEligibilityResponse resource.
    
    This resource provides eligibility and plan details from the processing of
    an CoverageEligibilityRequest resource.
    """
    
    resource_type = "CoverageEligibilityResponse"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='requestor' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='disposition' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='preAuthRef' >, <FHIRClassProperty self.name='form' >, <FHIRClassProperty self.name='error' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for coverage eligiblity request.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    purpose: typing.List["str"]

    """ auth-requirements | benefits | discovery | validation.
    List of `str` items. """

    patient: "Reference"

    """ Intended recipient of products and services.
    Type `Reference` (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Estimated date or dates of service.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Estimated date or dates of service.
    Type `Period` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Response creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    requestor: typing.Optional["Reference"]

    """ Party responsible for the request.
    Type `Reference` (represented as `dict` in JSON). """

    request: "Reference"

    """ Eligibility request reference.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: "str"

    """ queued | complete | error | partial.
    Type `str`. """

    disposition: typing.Optional[str]

    """ Disposition Message.
    Type `str`. """

    insurer: "Reference"

    """ Coverage issuer.
    Type `Reference` (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["CoverageEligibilityResponseInsurance"]]

    """ Patient insurance information.
    List of `CoverageEligibilityResponseInsurance` items (represented as `dict` in JSON). """

    preAuthRef: typing.Optional[str]

    """ Preauthorization reference.
    Type `str`. """

    form: typing.Optional["CodeableConcept"]

    """ Printed form identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    error: typing.Optional[typing.List["CoverageEligibilityResponseError"]]

    """ Processing errors.
    List of `CoverageEligibilityResponseError` items (represented as `dict` in JSON). """



#   {'path': 'CoverageEligibilityResponse.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'CoverageEligibilityResponse', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Estimated date or dates of service', 'formal': 'The date or dates when the enclosed suite of services were performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))


    

     
    



class DetectedIssue(DomainResource):
    """ Clinical issue with action.
    
    Indicates an actual or potential clinical issue with or between one or more
    active or proposed clinical actions for a patient; e.g. Drug-drug
    interaction, Ineffective treatment frequency, Procedure-condition conflict,
    etc.
    """
    
    resource_type = "DetectedIssue"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='identifiedDateTime' >, <FHIRClassProperty self.name='identifiedPeriod' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='implicated' >, <FHIRClassProperty self.name='evidence' >, <FHIRClassProperty self.name='detail' >, <FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='mitigation' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique id for the detected issue.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ registered | preliminary | final | amended +.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Issue Category, e.g. drug-drug, duplicate therapy, etc..
    Type `CodeableConcept` (represented as `dict` in JSON). """

    severity: typing.Optional["str"]

    """ high | moderate | low.
    Type `str`. """

    patient: typing.Optional["Reference"]

    """ Associated patient.
    Type `Reference` (represented as `dict` in JSON). """

    identifiedDateTime: typing.Optional["FHIRDate"]

    """ When identified.
    Type `FHIRDate` (represented as `str` in JSON). """

    identifiedPeriod: typing.Optional["Period"]

    """ When identified.
    Type `Period` (represented as `dict` in JSON). """

    author: typing.Optional["Reference"]

    """ The provider or device that identified the issue.
    Type `Reference` (represented as `dict` in JSON). """

    implicated: typing.Optional[typing.List["Reference"]]

    """ Problem resource.
    List of `Reference` items (represented as `dict` in JSON). """

    evidence: typing.Optional[typing.List["DetectedIssueEvidence"]]

    """ Supporting evidence.
    List of `DetectedIssueEvidence` items (represented as `dict` in JSON). """

    detail: typing.Optional[str]

    """ Description and context.
    Type `str`. """

    reference: typing.Optional[str]

    """ Authority for issue.
    Type `str`. """

    mitigation: typing.Optional[typing.List["DetectedIssueMitigation"]]

    """ Step taken to address.
    List of `DetectedIssueMitigation` items (represented as `dict` in JSON). """



#   {'path': 'DetectedIssue.identified[x]', 'choice_of_type': 'identified', 'orig_name': 'identifiedDateTime', 'name': 'identifiedDateTime', 'parent_name': 'DetectedIssue', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When identified', 'formal': 'The date or period when the detected issue was initially identified.', 'representation': None}

    _identified_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['identifiedDateTime', 'identifiedPeriod']), True))


    

     
    



class Device(DomainResource):
    """ Item used in healthcare.
    
    A type of a manufactured item that is used in the provision of healthcare
    without being substantially changed through that activity. The device may
    be a medical or non-medical device.
    """
    
    resource_type = "Device"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='udiCarrier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='distinctIdentifier' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='manufactureDate' >, <FHIRClassProperty self.name='expirationDate' >, <FHIRClassProperty self.name='lotNumber' >, <FHIRClassProperty self.name='serialNumber' >, <FHIRClassProperty self.name='deviceName' >, <FHIRClassProperty self.name='modelNumber' >, <FHIRClassProperty self.name='partNumber' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='specialization' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='owner' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='safety' >, <FHIRClassProperty self.name='parent' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Instance identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    definition: typing.Optional["Reference"]

    """ The reference to the definition for the device.
    Type `Reference` (represented as `dict` in JSON). """

    udiCarrier: typing.Optional[typing.List["DeviceUdiCarrier"]]

    """ Unique Device Identifier (UDI) Barcode string.
    List of `DeviceUdiCarrier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | inactive | entered-in-error | unknown.
    Type `str`. """

    statusReason: typing.Optional[typing.List["CodeableConcept"]]

    """ online | paused | standby | offline | not-ready | transduc-discon |
        hw-discon | off.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    distinctIdentifier: typing.Optional[str]

    """ The distinct identification string.
    Type `str`. """

    manufacturer: typing.Optional[str]

    """ Name of device manufacturer.
    Type `str`. """

    manufactureDate: typing.Optional["FHIRDate"]

    """ Date when the device was made.
    Type `FHIRDate` (represented as `str` in JSON). """

    expirationDate: typing.Optional["FHIRDate"]

    """ Date and time of expiry of this device (if applicable).
    Type `FHIRDate` (represented as `str` in JSON). """

    lotNumber: typing.Optional[str]

    """ Lot number of manufacture.
    Type `str`. """

    serialNumber: typing.Optional[str]

    """ Serial number assigned by the manufacturer.
    Type `str`. """

    deviceName: typing.Optional[typing.List["DeviceDeviceName"]]

    """ The name of the device as given by the manufacturer.
    List of `DeviceDeviceName` items (represented as `dict` in JSON). """

    modelNumber: typing.Optional[str]

    """ The model number for the device.
    Type `str`. """

    partNumber: typing.Optional[str]

    """ The part number of the device.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ The kind or type of device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    specialization: typing.Optional[typing.List["DeviceSpecialization"]]

    """ The capabilities supported on a  device, the standards to which the
        device conforms for a particular purpose, and used for the
        communication.
    List of `DeviceSpecialization` items (represented as `dict` in JSON). """

    version: typing.Optional[typing.List["DeviceVersion"]]

    """ The actual design of the device or software version running on the
        device.
    List of `DeviceVersion` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List["DeviceProperty"]]

    """ The actual configuration settings of a device as it actually
        operates, e.g., regulation status, time properties.
    List of `DeviceProperty` items (represented as `dict` in JSON). """

    patient: typing.Optional["Reference"]

    """ Patient to whom Device is affixed.
    Type `Reference` (represented as `dict` in JSON). """

    owner: typing.Optional["Reference"]

    """ Organization responsible for device.
    Type `Reference` (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["ContactPoint"]]

    """ Details for human/organization for support.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where the device is found.
    Type `Reference` (represented as `dict` in JSON). """

    url: typing.Optional[str]

    """ Network address to contact device.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Device notes and comments.
    List of `Annotation` items (represented as `dict` in JSON). """

    safety: typing.Optional[typing.List["CodeableConcept"]]

    """ Safety Characteristics of Device.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    parent: typing.Optional["Reference"]

    """ The parent device.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class DeviceDefinition(DomainResource):
    """ An instance of a medical-related component of a medical device.
    
    The characteristics, operational status and capabilities of a medical-
    related component of a medical device.
    """
    
    resource_type = "DeviceDefinition"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='udiDeviceIdentifier' >, <FHIRClassProperty self.name='manufacturerString' >, <FHIRClassProperty self.name='manufacturerReference' >, <FHIRClassProperty self.name='deviceName' >, <FHIRClassProperty self.name='modelNumber' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='specialization' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='safety' >, <FHIRClassProperty self.name='shelfLifeStorage' >, <FHIRClassProperty self.name='physicalCharacteristics' >, <FHIRClassProperty self.name='languageCode' >, <FHIRClassProperty self.name='capability' >, <FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='owner' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='onlineInformation' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='parentDevice' >, <FHIRClassProperty self.name='material' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Instance identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    udiDeviceIdentifier: typing.Optional[typing.List["DeviceDefinitionUdiDeviceIdentifier"]]

    """ Unique Device Identifier (UDI) Barcode string.
    List of `DeviceDefinitionUdiDeviceIdentifier` items (represented as `dict` in JSON). """

    manufacturerString: typing.Optional[str]

    """ Name of device manufacturer.
    Type `str`. """

    manufacturerReference: typing.Optional["Reference"]

    """ Name of device manufacturer.
    Type `Reference` (represented as `dict` in JSON). """

    deviceName: typing.Optional[typing.List["DeviceDefinitionDeviceName"]]

    """ A name given to the device to identify it.
    List of `DeviceDefinitionDeviceName` items (represented as `dict` in JSON). """

    modelNumber: typing.Optional[str]

    """ The model number for the device.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ What kind of device or device system this is.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    specialization: typing.Optional[typing.List["DeviceDefinitionSpecialization"]]

    """ The capabilities supported on a  device, the standards to which the
        device conforms for a particular purpose, and used for the
        communication.
    List of `DeviceDefinitionSpecialization` items (represented as `dict` in JSON). """

    version: typing.Optional[typing.List[str]]

    """ Available versions.
    List of `str` items. """

    safety: typing.Optional[typing.List["CodeableConcept"]]

    """ Safety characteristics of the device.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    shelfLifeStorage: typing.Optional[typing.List["ProductShelfLife"]]

    """ Shelf Life and storage information.
    List of `ProductShelfLife` items (represented as `dict` in JSON). """

    physicalCharacteristics: typing.Optional["ProdCharacteristic"]

    """ Dimensions, color etc..
    Type `ProdCharacteristic` (represented as `dict` in JSON). """

    languageCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Language code for the human-readable text strings produced by the
        device (all supported).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    capability: typing.Optional[typing.List["DeviceDefinitionCapability"]]

    """ Device capabilities.
    List of `DeviceDefinitionCapability` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List["DeviceDefinitionProperty"]]

    """ The actual configuration settings of a device as it actually
        operates, e.g., regulation status, time properties.
    List of `DeviceDefinitionProperty` items (represented as `dict` in JSON). """

    owner: typing.Optional["Reference"]

    """ Organization responsible for device.
    Type `Reference` (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["ContactPoint"]]

    """ Details for human/organization for support.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    url: typing.Optional[str]

    """ Network address to contact device.
    Type `str`. """

    onlineInformation: typing.Optional[str]

    """ Access to on-line information.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Device notes and comments.
    List of `Annotation` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ The quantity of the device present in the packaging (e.g. the
        number of devices present in a pack, or the number of devices in
        the same package of the medicinal product).
    Type `Quantity` (represented as `dict` in JSON). """

    parentDevice: typing.Optional["Reference"]

    """ The parent device it can be part of.
    Type `Reference` (represented as `dict` in JSON). """

    material: typing.Optional[typing.List["DeviceDefinitionMaterial"]]

    """ A substance used to create the material(s) of which the device is
        made.
    List of `DeviceDefinitionMaterial` items (represented as `dict` in JSON). """



#   {'path': 'DeviceDefinition.manufacturer[x]', 'choice_of_type': 'manufacturer', 'orig_name': 'manufacturerString', 'name': 'manufacturerString', 'parent_name': 'DeviceDefinition', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Name of device manufacturer', 'formal': 'A name of the manufacturer.', 'representation': None}

    _manufacturer_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['manufacturerString', 'manufacturerReference']), True))


    

     
    



class DeviceMetric(DomainResource):
    """ Measurement, calculation or setting capability of a medical device.
    
    Describes a measurement, calculation or setting capability of a medical
    device.
    """
    
    resource_type = "DeviceMetric"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='parent' >, <FHIRClassProperty self.name='operationalStatus' >, <FHIRClassProperty self.name='color' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='measurementPeriod' >, <FHIRClassProperty self.name='calibration' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Instance identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: "CodeableConcept"

    """ Identity of metric, for example Heart Rate or PEEP Setting.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unit: typing.Optional["CodeableConcept"]

    """ Unit of Measure for the Metric.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional["Reference"]

    """ Describes the link to the source Device.
    Type `Reference` (represented as `dict` in JSON). """

    parent: typing.Optional["Reference"]

    """ Describes the link to the parent Device.
    Type `Reference` (represented as `dict` in JSON). """

    operationalStatus: typing.Optional["str"]

    """ on | off | standby | entered-in-error.
    Type `str`. """

    color: typing.Optional["str"]

    """ black | red | green | yellow | blue | magenta | cyan | white.
    Type `str`. """

    category: "str"

    """ measurement | setting | calculation | unspecified.
    Type `str`. """

    measurementPeriod: typing.Optional["Timing"]

    """ Describes the measurement repetition time.
    Type `Timing` (represented as `dict` in JSON). """

    calibration: typing.Optional[typing.List["DeviceMetricCalibration"]]

    """ Describes the calibrations that have been performed or that are
        required to be performed.
    List of `DeviceMetricCalibration` items (represented as `dict` in JSON). """




    

     
    



class DeviceRequest(DomainResource):
    """ Medical device request.
    
    Represents a request for a patient to employ a medical device. The device
    may be an implantable device, or an external assistive device, such as a
    walker.
    """
    
    resource_type = "DeviceRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='priorRequest' >, <FHIRClassProperty self.name='groupIdentifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='codeReference' >, <FHIRClassProperty self.name='codeCodeableConcept' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='performerType' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='relevantHistory' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Request identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ What request fulfills.
    List of `Reference` items (represented as `dict` in JSON). """

    priorRequest: typing.Optional[typing.List["Reference"]]

    """ What request replaces.
    List of `Reference` items (represented as `dict` in JSON). """

    groupIdentifier: typing.Optional["Identifier"]

    """ Identifier of composite request.
    Type `Identifier` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    intent: "str"

    """ proposal | plan | directive | order | original-order | reflex-order
        | filler-order | instance-order | option.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    codeReference: typing.Optional["Reference"]

    """ Device requested.
    Type `Reference` (represented as `dict` in JSON). """

    codeCodeableConcept: typing.Optional["CodeableConcept"]

    """ Device requested.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    parameter: typing.Optional[typing.List["DeviceRequestParameter"]]

    """ Device details.
    List of `DeviceRequestParameter` items (represented as `dict` in JSON). """

    subject: "Reference"

    """ Focus of request.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter motivating request.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ Desired time or schedule for use.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ Desired time or schedule for use.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ Desired time or schedule for use.
    Type `Timing` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ When recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Who/what is requesting diagnostics.
    Type `Reference` (represented as `dict` in JSON). """

    performerType: typing.Optional["CodeableConcept"]

    """ Filler role.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Requested Filler.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Coded Reason for request.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Linked Reason for request.
    List of `Reference` items (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["Reference"]]

    """ Associated insurance coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["Reference"]]

    """ Additional clinical information.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Notes or comments.
    List of `Annotation` items (represented as `dict` in JSON). """

    relevantHistory: typing.Optional[typing.List["Reference"]]

    """ Request provenance.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'DeviceRequest.code[x]', 'choice_of_type': 'code', 'orig_name': 'codeReference', 'name': 'codeReference', 'parent_name': 'DeviceRequest', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Device requested', 'formal': 'The details of the device to be used.', 'representation': None}

    _code_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['codeReference', 'codeCodeableConcept']), False))

#   {'path': 'DeviceRequest.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'DeviceRequest', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Desired time or schedule for use', 'formal': 'The timing schedule for the use of the device. The Schedule data type allows many different expressions, for example. "Every 8 hours"; "Three times a day"; "1/2 an hour before breakfast for 10 days from 23-Dec 2011:"; "15 Oct 2013, 17 Oct 2013 and 1 Nov 2013".', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))


    

     
    



class DeviceUseStatement(DomainResource):
    """ Record of use of a device.
    
    A record of a device being used by a patient where the record is the result
    of a report from the patient or another clinician.
    """
    
    resource_type = "DeviceUseStatement"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='derivedFrom' >, <FHIRClassProperty self.name='timingTiming' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='timingDateTime' >, <FHIRClassProperty self.name='recordedOn' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifier for this record.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills plan, proposal or order.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ active | completed | entered-in-error +.
    Type `str`. """

    subject: "Reference"

    """ Patient using device.
    Type `Reference` (represented as `dict` in JSON). """

    derivedFrom: typing.Optional[typing.List["Reference"]]

    """ Supporting information.
    List of `Reference` items (represented as `dict` in JSON). """

    timingTiming: typing.Optional["Timing"]

    """ How often  the device was used.
    Type `Timing` (represented as `dict` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ How often  the device was used.
    Type `Period` (represented as `dict` in JSON). """

    timingDateTime: typing.Optional["FHIRDate"]

    """ How often  the device was used.
    Type `FHIRDate` (represented as `str` in JSON). """

    recordedOn: typing.Optional["FHIRDate"]

    """ When statement was recorded.
    Type `FHIRDate` (represented as `str` in JSON). """

    source: typing.Optional["Reference"]

    """ Who made the statement.
    Type `Reference` (represented as `dict` in JSON). """

    device: "Reference"

    """ Reference to device used.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why device was used.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why was DeviceUseStatement performed?.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Target body site.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Addition details (comments, instructions).
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'DeviceUseStatement.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingTiming', 'name': 'timingTiming', 'parent_name': 'DeviceUseStatement', 'class_name': 'Timing', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'How often  the device was used', 'formal': 'How often the device was used.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingTiming', 'timingPeriod', 'timingDateTime']), True))


    

     
    



class DiagnosticReport(DomainResource):
    """ A Diagnostic report - a combination of request information, atomic results,
    images, interpretation, as well as formatted reports.
    
    The findings and interpretation of diagnostic  tests performed on patients,
    groups of patients, devices, and locations, and/or specimens derived from
    these. The report includes clinical context such as requesting and provider
    information, and some mix of atomic results, images, textual and coded
    interpretations, and formatted representation of diagnostic reports.
    """
    
    resource_type = "DiagnosticReport"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='effectiveDateTime' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='resultsInterpreter' >, <FHIRClassProperty self.name='specimen' >, <FHIRClassProperty self.name='result' >, <FHIRClassProperty self.name='imagingStudy' >, <FHIRClassProperty self.name='media' >, <FHIRClassProperty self.name='conclusion' >, <FHIRClassProperty self.name='conclusionCode' >, <FHIRClassProperty self.name='presentedForm' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier for report.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ What was requested.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ registered | partial | preliminary | final +.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Service category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Name/Code for this diagnostic report.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ The subject of the report - usually, but not always, the patient.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Health care event when test ordered.
    Type `Reference` (represented as `dict` in JSON). """

    effectiveDateTime: typing.Optional["FHIRDate"]

    """ Clinically relevant time/time-period for report.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ Clinically relevant time/time-period for report.
    Type `Period` (represented as `dict` in JSON). """

    issued: typing.Optional["FHIRDate"]

    """ DateTime this version was made.
    Type `FHIRDate` (represented as `str` in JSON). """

    performer: typing.Optional[typing.List["Reference"]]

    """ Responsible Diagnostic Service.
    List of `Reference` items (represented as `dict` in JSON). """

    resultsInterpreter: typing.Optional[typing.List["Reference"]]

    """ Primary result interpreter.
    List of `Reference` items (represented as `dict` in JSON). """

    specimen: typing.Optional[typing.List["Reference"]]

    """ Specimens this report is based on.
    List of `Reference` items (represented as `dict` in JSON). """

    result: typing.Optional[typing.List["Reference"]]

    """ Observations.
    List of `Reference` items (represented as `dict` in JSON). """

    imagingStudy: typing.Optional[typing.List["Reference"]]

    """ Reference to full details of imaging associated with the diagnostic
        report.
    List of `Reference` items (represented as `dict` in JSON). """

    media: typing.Optional[typing.List["DiagnosticReportMedia"]]

    """ Key images associated with this report.
    List of `DiagnosticReportMedia` items (represented as `dict` in JSON). """

    conclusion: typing.Optional[str]

    """ Clinical conclusion (interpretation) of test results.
    Type `str`. """

    conclusionCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Codes for the clinical conclusion of test results.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    presentedForm: typing.Optional[typing.List["Attachment"]]

    """ Entire report as issued.
    List of `Attachment` items (represented as `dict` in JSON). """



#   {'path': 'DiagnosticReport.effective[x]', 'choice_of_type': 'effective', 'orig_name': 'effectiveDateTime', 'name': 'effectiveDateTime', 'parent_name': 'DiagnosticReport', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Clinically relevant time/time-period for report', 'formal': 'The time or time-period the observed values are related to. When the subject of the report is a patient, this is usually either the time of the procedure or of specimen collection(s), but very often the source of the date/time is not known, only the date/time itself.', 'representation': None}

    _effective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['effectiveDateTime', 'effectivePeriod']), True))


    

     
    



class DocumentManifest(DomainResource):
    """ A list that defines a set of documents.
    
    A collection of documents compiled for a purpose together with metadata
    that applies to the collection.
    """
    
    resource_type = "DocumentManifest"
    
    # [<FHIRClassProperty self.name='masterIdentifier' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='content' >, <FHIRClassProperty self.name='related' >]
  

    masterIdentifier: typing.Optional["Identifier"]

    """ Unique Identifier for the set of documents.
    Type `Identifier` (represented as `dict` in JSON). """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Other identifiers for the manifest.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ current | superseded | entered-in-error.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Kind of document set.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ The subject of the set of documents.
    Type `Reference` (represented as `dict` in JSON). """

    created: typing.Optional["FHIRDate"]

    """ When this document manifest created.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional[typing.List["Reference"]]

    """ Who and/or what authored the DocumentManifest.
    List of `Reference` items (represented as `dict` in JSON). """

    recipient: typing.Optional[typing.List["Reference"]]

    """ Intended to get notified about this set of documents.
    List of `Reference` items (represented as `dict` in JSON). """

    source: typing.Optional[str]

    """ The source system/application/software.
    Type `str`. """

    description: typing.Optional[str]

    """ Human-readable description (title).
    Type `str`. """

    content: typing.List["Reference"]

    """ Items in manifest.
    List of `Reference` items (represented as `dict` in JSON). """

    related: typing.Optional[typing.List["DocumentManifestRelated"]]

    """ Related things.
    List of `DocumentManifestRelated` items (represented as `dict` in JSON). """




    

     
    



class DocumentReference(DomainResource):
    """ A reference to a document.
    
    A reference to a document of any kind for any purpose. Provides metadata
    about the document so that the document can be discovered and managed. The
    scope of a document is any seralized object with a mime-type, so includes
    formal patient centric documents (CDA), cliical notes, scanned paper, and
    non-patient specific documents like policy text.
    """
    
    resource_type = "DocumentReference"
    
    # [<FHIRClassProperty self.name='masterIdentifier' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='docStatus' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='authenticator' >, <FHIRClassProperty self.name='custodian' >, <FHIRClassProperty self.name='relatesTo' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='securityLabel' >, <FHIRClassProperty self.name='content' >, <FHIRClassProperty self.name='context' >]
  

    masterIdentifier: typing.Optional["Identifier"]

    """ Master Version Specific Identifier.
    Type `Identifier` (represented as `dict` in JSON). """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Other identifiers for the document.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ current | superseded | entered-in-error.
    Type `str`. """

    docStatus: typing.Optional["str"]

    """ preliminary | final | amended | entered-in-error.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Kind of document (LOINC if possible).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Categorization of document.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who/what is the subject of the document.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When this document reference was created.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional[typing.List["Reference"]]

    """ Who and/or what authored the document.
    List of `Reference` items (represented as `dict` in JSON). """

    authenticator: typing.Optional["Reference"]

    """ Who/what authenticated the document.
    Type `Reference` (represented as `dict` in JSON). """

    custodian: typing.Optional["Reference"]

    """ Organization which maintains the document.
    Type `Reference` (represented as `dict` in JSON). """

    relatesTo: typing.Optional[typing.List["DocumentReferenceRelatesTo"]]

    """ Relationships to other documents.
    List of `DocumentReferenceRelatesTo` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Human-readable description.
    Type `str`. """

    securityLabel: typing.Optional[typing.List["CodeableConcept"]]

    """ Document security-tags.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    content: typing.List["DocumentReferenceContent"]

    """ Document referenced.
    List of `DocumentReferenceContent` items (represented as `dict` in JSON). """

    context: typing.Optional["DocumentReferenceContext"]

    """ Clinical context of document.
    Type `DocumentReferenceContext` (represented as `dict` in JSON). """




    

     
    



class EffectEvidenceSynthesis(DomainResource):
    """ A quantified estimate of effect based on a body of evidence.
    
    The EffectEvidenceSynthesis resource describes the difference in an outcome
    between exposures states in a population where the effect estimate is
    derived from a combination of research studies.
    """
    
    resource_type = "EffectEvidenceSynthesis"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='synthesisType' >, <FHIRClassProperty self.name='studyType' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='exposure' >, <FHIRClassProperty self.name='exposureAlternative' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='sampleSize' >, <FHIRClassProperty self.name='resultsByExposure' >, <FHIRClassProperty self.name='effectEstimate' >, <FHIRClassProperty self.name='certainty' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this effect evidence synthesis,
        represented as a URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the effect evidence synthesis.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the effect evidence synthesis.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this effect evidence synthesis (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this effect evidence synthesis (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the effect evidence synthesis.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for effect evidence synthesis (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the effect evidence synthesis was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the effect evidence synthesis was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the effect evidence synthesis is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the EffectEvidenceSynthesis, such as Education,
        Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    synthesisType: typing.Optional["CodeableConcept"]

    """ Type of synthesis.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    studyType: typing.Optional["CodeableConcept"]

    """ Type of study.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    population: "Reference"

    """ What population?.
    Type `Reference` (represented as `dict` in JSON). """

    exposure: "Reference"

    """ What exposure?.
    Type `Reference` (represented as `dict` in JSON). """

    exposureAlternative: "Reference"

    """ What comparison exposure?.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: "Reference"

    """ What outcome?.
    Type `Reference` (represented as `dict` in JSON). """

    sampleSize: typing.Optional["EffectEvidenceSynthesisSampleSize"]

    """ What sample size was involved?.
    Type `EffectEvidenceSynthesisSampleSize` (represented as `dict` in JSON). """

    resultsByExposure: typing.Optional[typing.List["EffectEvidenceSynthesisResultsByExposure"]]

    """ What was the result per exposure?.
    List of `EffectEvidenceSynthesisResultsByExposure` items (represented as `dict` in JSON). """

    effectEstimate: typing.Optional[typing.List["EffectEvidenceSynthesisEffectEstimate"]]

    """ What was the estimated effect.
    List of `EffectEvidenceSynthesisEffectEstimate` items (represented as `dict` in JSON). """

    certainty: typing.Optional[typing.List["EffectEvidenceSynthesisCertainty"]]

    """ How certain is the effect.
    List of `EffectEvidenceSynthesisCertainty` items (represented as `dict` in JSON). """




    

     
    



class Encounter(DomainResource):
    """ An interaction during which services are provided to the patient.
    
    An interaction between a patient and healthcare provider(s) for the purpose
    of providing healthcare service(s) or assessing the health status of a
    patient.
    """
    
    resource_type = "Encounter"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusHistory' >, <FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='classHistory' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='serviceType' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='episodeOfCare' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='appointment' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='length' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='diagnosis' >, <FHIRClassProperty self.name='account' >, <FHIRClassProperty self.name='hospitalization' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='serviceProvider' >, <FHIRClassProperty self.name='partOf' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifier(s) by which this encounter is known.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ planned | arrived | triaged | in-progress | onleave | finished |
        cancelled +.
    Type `str`. """

    statusHistory: typing.Optional[typing.List["EncounterStatusHistory"]]

    """ List of past encounter statuses.
    List of `EncounterStatusHistory` items (represented as `dict` in JSON). """

    class_: "Coding"

    """ Classification of patient encounter.
    Type `Coding` (represented as `dict` in JSON). """

    classHistory: typing.Optional[typing.List["EncounterClassHistory"]]

    """ List of past encounter classes.
    List of `EncounterClassHistory` items (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Specific type of encounter.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    serviceType: typing.Optional["CodeableConcept"]

    """ Specific type of service.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    priority: typing.Optional["CodeableConcept"]

    """ Indicates the urgency of the encounter.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ The patient or group present at the encounter.
    Type `Reference` (represented as `dict` in JSON). """

    episodeOfCare: typing.Optional[typing.List["Reference"]]

    """ Episode(s) of care that this encounter should be recorded against.
    List of `Reference` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ The ServiceRequest that initiated this encounter.
    List of `Reference` items (represented as `dict` in JSON). """

    participant: typing.Optional[typing.List["EncounterParticipant"]]

    """ List of participants involved in the encounter.
    List of `EncounterParticipant` items (represented as `dict` in JSON). """

    appointment: typing.Optional[typing.List["Reference"]]

    """ The appointment that scheduled this encounter.
    List of `Reference` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ The start and end time of the encounter.
    Type `Period` (represented as `dict` in JSON). """

    length: typing.Optional["Duration"]

    """ Quantity of time the encounter lasted (less time absent).
    Type `Duration` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Coded reason the encounter takes place.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Reason the encounter takes place (reference).
    List of `Reference` items (represented as `dict` in JSON). """

    diagnosis: typing.Optional[typing.List["EncounterDiagnosis"]]

    """ The list of diagnosis relevant to this encounter.
    List of `EncounterDiagnosis` items (represented as `dict` in JSON). """

    account: typing.Optional[typing.List["Reference"]]

    """ The set of accounts that may be used for billing for this Encounter.
    List of `Reference` items (represented as `dict` in JSON). """

    hospitalization: typing.Optional["EncounterHospitalization"]

    """ Details about the admission to a healthcare service.
    Type `EncounterHospitalization` (represented as `dict` in JSON). """

    location: typing.Optional[typing.List["EncounterLocation"]]

    """ List of locations where the patient has been.
    List of `EncounterLocation` items (represented as `dict` in JSON). """

    serviceProvider: typing.Optional["Reference"]

    """ The organization (facility) responsible for this encounter.
    Type `Reference` (represented as `dict` in JSON). """

    partOf: typing.Optional["Reference"]

    """ Another Encounter this encounter is part of.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class Endpoint(DomainResource):
    """ The technical details of an endpoint that can be used for electronic
    services.
    
    The technical details of an endpoint that can be used for electronic
    services, such as for web services providing XDS.b or a REST endpoint for
    another FHIR server. This may include any security context information.
    """
    
    resource_type = "Endpoint"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='connectionType' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='payloadType' >, <FHIRClassProperty self.name='payloadMimeType' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='header' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifies this endpoint across multiple systems.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | suspended | error | off | entered-in-error | test.
    Type `str`. """

    connectionType: "Coding"

    """ Protocol/Profile/Standard to be used with this endpoint connection.
    Type `Coding` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ A name that this endpoint can be identified by.
    Type `str`. """

    managingOrganization: typing.Optional["Reference"]

    """ Organization that manages this endpoint (might not be the
        organization that exposes the endpoint).
    Type `Reference` (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details for source (e.g. troubleshooting).
    List of `ContactPoint` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Interval the endpoint is expected to be operational.
    Type `Period` (represented as `dict` in JSON). """

    payloadType: typing.List["CodeableConcept"]

    """ The type of content that may be used at this endpoint (e.g. XDS
        Discharge summaries).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    payloadMimeType: typing.Optional[typing.List[str]]

    """ Mimetype to send. If not specified, the content could be anything
        (including no payload, if the connectionType defined this).
    List of `str` items. """

    address: str

    """ The technical base address for connecting to this endpoint.
    Type `str`. """

    header: typing.Optional[typing.List[str]]

    """ Usage depends on the channel type.
    List of `str` items. """




    

     
    



class EnrollmentRequest(DomainResource):
    """ Enroll in coverage.
    
    This resource provides the insurance enrollment details to the insurer
    regarding a specified coverage.
    """
    
    resource_type = "EnrollmentRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='candidate' >, <FHIRClassProperty self.name='coverage' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    created: typing.Optional["FHIRDate"]

    """ Creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    insurer: typing.Optional["Reference"]

    """ Target.
    Type `Reference` (represented as `dict` in JSON). """

    provider: typing.Optional["Reference"]

    """ Responsible practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    candidate: typing.Optional["Reference"]

    """ The subject to be enrolled.
    Type `Reference` (represented as `dict` in JSON). """

    coverage: typing.Optional["Reference"]

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class EnrollmentResponse(DomainResource):
    """ EnrollmentResponse resource.
    
    This resource provides enrollment and plan details from the processing of
    an EnrollmentRequest resource.
    """
    
    resource_type = "EnrollmentResponse"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='disposition' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='requestProvider' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    request: typing.Optional["Reference"]

    """ Claim reference.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: typing.Optional["str"]

    """ queued | complete | error | partial.
    Type `str`. """

    disposition: typing.Optional[str]

    """ Disposition Message.
    Type `str`. """

    created: typing.Optional["FHIRDate"]

    """ Creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    organization: typing.Optional["Reference"]

    """ Insurer.
    Type `Reference` (represented as `dict` in JSON). """

    requestProvider: typing.Optional["Reference"]

    """ Responsible practitioner.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class EpisodeOfCare(DomainResource):
    """ An association of a Patient with an Organization and  Healthcare
    Provider(s) for a period of time that the Organization assumes some level
    of responsibility.
    
    An association between a patient and an organization / healthcare
    provider(s) during which time encounters may occur. The managing
    organization assumes a level of responsibility for the patient during this
    time.
    """
    
    resource_type = "EpisodeOfCare"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusHistory' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='diagnosis' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='referralRequest' >, <FHIRClassProperty self.name='careManager' >, <FHIRClassProperty self.name='team' >, <FHIRClassProperty self.name='account' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier(s) relevant for this EpisodeOfCare.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ planned | waitlist | active | onhold | finished | cancelled |
        entered-in-error.
    Type `str`. """

    statusHistory: typing.Optional[typing.List["EpisodeOfCareStatusHistory"]]

    """ Past list of status codes (the current status may be included to
        cover the start date of the status).
    List of `EpisodeOfCareStatusHistory` items (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Type/class  - e.g. specialist referral, disease management.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    diagnosis: typing.Optional[typing.List["EpisodeOfCareDiagnosis"]]

    """ The list of diagnosis relevant to this episode of care.
    List of `EpisodeOfCareDiagnosis` items (represented as `dict` in JSON). """

    patient: "Reference"

    """ The patient who is the focus of this episode of care.
    Type `Reference` (represented as `dict` in JSON). """

    managingOrganization: typing.Optional["Reference"]

    """ Organization that assumes care.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Interval during responsibility is assumed.
    Type `Period` (represented as `dict` in JSON). """

    referralRequest: typing.Optional[typing.List["Reference"]]

    """ Originating Referral Request(s).
    List of `Reference` items (represented as `dict` in JSON). """

    careManager: typing.Optional["Reference"]

    """ Care manager/care coordinator for the patient.
    Type `Reference` (represented as `dict` in JSON). """

    team: typing.Optional[typing.List["Reference"]]

    """ Other practitioners facilitating this episode of care.
    List of `Reference` items (represented as `dict` in JSON). """

    account: typing.Optional[typing.List["Reference"]]

    """ The set of accounts that may be used for billing for this
        EpisodeOfCare.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class EventDefinition(DomainResource):
    """ A description of when an event can occur.
    
    The EventDefinition resource provides a reusable description of when a
    particular event can occur.
    """
    
    resource_type = "EventDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='trigger' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this event definition, represented as a
        URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the event definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the event definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this event definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this event definition (human friendly).
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the event definition.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ Type of individual the event definition is focused on.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ Type of individual the event definition is focused on.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the event definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for event definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this event definition is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the event definition.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the event definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the event definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the event definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ E.g. Education, Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    trigger: typing.List["TriggerDefinition"]

    """ "when" the event occurs (multiple = 'or').
    List of `TriggerDefinition` items (represented as `dict` in JSON). """



#   {'path': 'EventDefinition.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'EventDefinition', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Type of individual the event definition is focused on', 'formal': 'A code or group definition that describes the intended subject of the event definition.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class Evidence(DomainResource):
    """ A research context or question.
    
    The Evidence resource describes the conditional state (population and any
    exposures being compared within the population) and outcome (if specified)
    that the knowledge (evidence, assertion, recommendation) is about.
    """
    
    resource_type = "Evidence"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='shortTitle' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='exposureBackground' >, <FHIRClassProperty self.name='exposureVariant' >, <FHIRClassProperty self.name='outcome' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this evidence, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the evidence.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the evidence.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this evidence (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this evidence (human friendly).
    Type `str`. """

    shortTitle: typing.Optional[str]

    """ Title for use in informal contexts.
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the Evidence.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the evidence.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for evidence (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the evidence was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the evidence was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the evidence is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the Evidence, such as Education, Treatment,
        Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    exposureBackground: "Reference"

    """ What population?.
    Type `Reference` (represented as `dict` in JSON). """

    exposureVariant: typing.Optional[typing.List["Reference"]]

    """ What exposure?.
    List of `Reference` items (represented as `dict` in JSON). """

    outcome: typing.Optional[typing.List["Reference"]]

    """ What outcome?.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class EvidenceVariable(DomainResource):
    """ A population, intervention, or exposure definition.
    
    The EvidenceVariable resource describes a "PICO" element that knowledge
    (evidence, assertion, recommendation) is about.
    """
    
    resource_type = "EvidenceVariable"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='shortTitle' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='characteristic' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this evidence variable, represented as a
        URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the evidence variable.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the evidence variable.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this evidence variable (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this evidence variable (human friendly).
    Type `str`. """

    shortTitle: typing.Optional[str]

    """ Title for use in informal contexts.
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the EvidenceVariable.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the evidence variable.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for evidence variable (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the evidence variable was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the evidence variable was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the evidence variable is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the EvidenceVariable, such as Education, Treatment,
        Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    type: typing.Optional["str"]

    """ dichotomous | continuous | descriptive.
    Type `str`. """

    characteristic: typing.List["EvidenceVariableCharacteristic"]

    """ What defines the members of the evidence element.
    List of `EvidenceVariableCharacteristic` items (represented as `dict` in JSON). """




    

     
    



class ExampleScenario(DomainResource):
    """ Example of workflow instance.
    """
    
    resource_type = "ExampleScenario"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='instance' >, <FHIRClassProperty self.name='process' >, <FHIRClassProperty self.name='workflow' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this example scenario, represented as a
        URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the example scenario.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the example scenario.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this example scenario (computer friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for example scenario (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    purpose: typing.Optional[str]

    """ The purpose of the example, e.g. to illustrate a scenario.
    Type `str`. """

    actor: typing.Optional[typing.List["ExampleScenarioActor"]]

    """ Actor participating in the resource.
    List of `ExampleScenarioActor` items (represented as `dict` in JSON). """

    instance: typing.Optional[typing.List["ExampleScenarioInstance"]]

    """ Each resource and each version that is present in the workflow.
    List of `ExampleScenarioInstance` items (represented as `dict` in JSON). """

    process: typing.Optional[typing.List["ExampleScenarioProcess"]]

    """ Each major process - a group of operations.
    List of `ExampleScenarioProcess` items (represented as `dict` in JSON). """

    workflow: typing.Optional[typing.List[str]]

    """ Another nested workflow.
    List of `str` items. """




    

     
    



class ExplanationOfBenefit(DomainResource):
    """ Explanation of Benefit resource.
    
    This resource provides: the claim details; adjudication details from the
    processing of a Claim; and optionally account balance information, for
    informing the subscriber of the benefits provided.
    """
    
    resource_type = "ExplanationOfBenefit"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='billablePeriod' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='enterer' >, <FHIRClassProperty self.name='insurer' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='fundsReserveRequested' >, <FHIRClassProperty self.name='fundsReserve' >, <FHIRClassProperty self.name='related' >, <FHIRClassProperty self.name='prescription' >, <FHIRClassProperty self.name='originalPrescription' >, <FHIRClassProperty self.name='payee' >, <FHIRClassProperty self.name='referral' >, <FHIRClassProperty self.name='facility' >, <FHIRClassProperty self.name='claim' >, <FHIRClassProperty self.name='claimResponse' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='disposition' >, <FHIRClassProperty self.name='preAuthRef' >, <FHIRClassProperty self.name='preAuthRefPeriod' >, <FHIRClassProperty self.name='careTeam' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='diagnosis' >, <FHIRClassProperty self.name='procedure' >, <FHIRClassProperty self.name='precedence' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='accident' >, <FHIRClassProperty self.name='item' >, <FHIRClassProperty self.name='addItem' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='total' >, <FHIRClassProperty self.name='payment' >, <FHIRClassProperty self.name='formCode' >, <FHIRClassProperty self.name='form' >, <FHIRClassProperty self.name='processNote' >, <FHIRClassProperty self.name='benefitPeriod' >, <FHIRClassProperty self.name='benefitBalance' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for the resource.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    type: "CodeableConcept"

    """ Category or discipline.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional["CodeableConcept"]

    """ More granular claim type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    use: "str"

    """ claim | preauthorization | predetermination.
    Type `str`. """

    patient: "Reference"

    """ The recipient of the products and services.
    Type `Reference` (represented as `dict` in JSON). """

    billablePeriod: typing.Optional["Period"]

    """ Relevant time frame for the claim.
    Type `Period` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Response creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    enterer: typing.Optional["Reference"]

    """ Author of the claim.
    Type `Reference` (represented as `dict` in JSON). """

    insurer: "Reference"

    """ Party responsible for reimbursement.
    Type `Reference` (represented as `dict` in JSON). """

    provider: "Reference"

    """ Party responsible for the claim.
    Type `Reference` (represented as `dict` in JSON). """

    priority: typing.Optional["CodeableConcept"]

    """ Desired processing urgency.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fundsReserveRequested: typing.Optional["CodeableConcept"]

    """ For whom to reserve funds.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fundsReserve: typing.Optional["CodeableConcept"]

    """ Funds reserved status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    related: typing.Optional[typing.List["ExplanationOfBenefitRelated"]]

    """ Prior or corollary claims.
    List of `ExplanationOfBenefitRelated` items (represented as `dict` in JSON). """

    prescription: typing.Optional["Reference"]

    """ Prescription authorizing services or products.
    Type `Reference` (represented as `dict` in JSON). """

    originalPrescription: typing.Optional["Reference"]

    """ Original prescription if superceded by fulfiller.
    Type `Reference` (represented as `dict` in JSON). """

    payee: typing.Optional["ExplanationOfBenefitPayee"]

    """ Recipient of benefits payable.
    Type `ExplanationOfBenefitPayee` (represented as `dict` in JSON). """

    referral: typing.Optional["Reference"]

    """ Treatment Referral.
    Type `Reference` (represented as `dict` in JSON). """

    facility: typing.Optional["Reference"]

    """ Servicing Facility.
    Type `Reference` (represented as `dict` in JSON). """

    claim: typing.Optional["Reference"]

    """ Claim reference.
    Type `Reference` (represented as `dict` in JSON). """

    claimResponse: typing.Optional["Reference"]

    """ Claim response reference.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: "str"

    """ queued | complete | error | partial.
    Type `str`. """

    disposition: typing.Optional[str]

    """ Disposition Message.
    Type `str`. """

    preAuthRef: typing.Optional[typing.List[str]]

    """ Preauthorization reference.
    List of `str` items. """

    preAuthRefPeriod: typing.Optional[typing.List["Period"]]

    """ Preauthorization in-effect period.
    List of `Period` items (represented as `dict` in JSON). """

    careTeam: typing.Optional[typing.List["ExplanationOfBenefitCareTeam"]]

    """ Care Team members.
    List of `ExplanationOfBenefitCareTeam` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["ExplanationOfBenefitSupportingInfo"]]

    """ Supporting information.
    List of `ExplanationOfBenefitSupportingInfo` items (represented as `dict` in JSON). """

    diagnosis: typing.Optional[typing.List["ExplanationOfBenefitDiagnosis"]]

    """ Pertinent diagnosis information.
    List of `ExplanationOfBenefitDiagnosis` items (represented as `dict` in JSON). """

    procedure: typing.Optional[typing.List["ExplanationOfBenefitProcedure"]]

    """ Clinical procedures performed.
    List of `ExplanationOfBenefitProcedure` items (represented as `dict` in JSON). """

    precedence: typing.Optional[int]

    """ Precedence (primary, secondary, etc.).
    Type `int`. """

    insurance: typing.List["ExplanationOfBenefitInsurance"]

    """ Patient insurance information.
    List of `ExplanationOfBenefitInsurance` items (represented as `dict` in JSON). """

    accident: typing.Optional["ExplanationOfBenefitAccident"]

    """ Details of the event.
    Type `ExplanationOfBenefitAccident` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["ExplanationOfBenefitItem"]]

    """ Product or service provided.
    List of `ExplanationOfBenefitItem` items (represented as `dict` in JSON). """

    addItem: typing.Optional[typing.List["ExplanationOfBenefitAddItem"]]

    """ Insurer added line items.
    List of `ExplanationOfBenefitAddItem` items (represented as `dict` in JSON). """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Header-level adjudication.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """

    total: typing.Optional[typing.List["ExplanationOfBenefitTotal"]]

    """ Adjudication totals.
    List of `ExplanationOfBenefitTotal` items (represented as `dict` in JSON). """

    payment: typing.Optional["ExplanationOfBenefitPayment"]

    """ Payment Details.
    Type `ExplanationOfBenefitPayment` (represented as `dict` in JSON). """

    formCode: typing.Optional["CodeableConcept"]

    """ Printed form identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    form: typing.Optional["Attachment"]

    """ Printed reference or actual form.
    Type `Attachment` (represented as `dict` in JSON). """

    processNote: typing.Optional[typing.List["ExplanationOfBenefitProcessNote"]]

    """ Note concerning adjudication.
    List of `ExplanationOfBenefitProcessNote` items (represented as `dict` in JSON). """

    benefitPeriod: typing.Optional["Period"]

    """ When the benefits are applicable.
    Type `Period` (represented as `dict` in JSON). """

    benefitBalance: typing.Optional[typing.List["ExplanationOfBenefitBenefitBalance"]]

    """ Balance by Benefit Category.
    List of `ExplanationOfBenefitBenefitBalance` items (represented as `dict` in JSON). """




    

     
    



class FamilyMemberHistory(DomainResource):
    """ Information about patient's relatives, relevant for patient.
    
    Significant health conditions for a person related to the patient relevant
    in the context of care for the patient.
    """
    
    resource_type = "FamilyMemberHistory"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='dataAbsentReason' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='sex' >, <FHIRClassProperty self.name='bornPeriod' >, <FHIRClassProperty self.name='bornDate' >, <FHIRClassProperty self.name='bornString' >, <FHIRClassProperty self.name='ageAge' >, <FHIRClassProperty self.name='ageRange' >, <FHIRClassProperty self.name='ageString' >, <FHIRClassProperty self.name='estimatedAge' >, <FHIRClassProperty self.name='deceasedBoolean' >, <FHIRClassProperty self.name='deceasedAge' >, <FHIRClassProperty self.name='deceasedRange' >, <FHIRClassProperty self.name='deceasedDate' >, <FHIRClassProperty self.name='deceasedString' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='condition' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Id(s) for this record.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    status: "str"

    """ partial | completed | entered-in-error | health-unknown.
    Type `str`. """

    dataAbsentReason: typing.Optional["CodeableConcept"]

    """ subject-unknown | withheld | unable-to-obtain | deferred.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    patient: "Reference"

    """ Patient history is about.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When history was recorded or last updated.
    Type `FHIRDate` (represented as `str` in JSON). """

    name: typing.Optional[str]

    """ The family member described.
    Type `str`. """

    relationship: "CodeableConcept"

    """ Relationship to the subject.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    sex: typing.Optional["CodeableConcept"]

    """ male | female | other | unknown.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    bornPeriod: typing.Optional["Period"]

    """ (approximate) date of birth.
    Type `Period` (represented as `dict` in JSON). """

    bornDate: typing.Optional["FHIRDate"]

    """ (approximate) date of birth.
    Type `FHIRDate` (represented as `str` in JSON). """

    bornString: typing.Optional[str]

    """ (approximate) date of birth.
    Type `str`. """

    ageAge: typing.Optional["Age"]

    """ (approximate) age.
    Type `Age` (represented as `dict` in JSON). """

    ageRange: typing.Optional["Range"]

    """ (approximate) age.
    Type `Range` (represented as `dict` in JSON). """

    ageString: typing.Optional[str]

    """ (approximate) age.
    Type `str`. """

    estimatedAge: typing.Optional[bool]

    """ Age is estimated?.
    Type `bool`. """

    deceasedBoolean: typing.Optional[bool]

    """ Dead? How old/when?.
    Type `bool`. """

    deceasedAge: typing.Optional["Age"]

    """ Dead? How old/when?.
    Type `Age` (represented as `dict` in JSON). """

    deceasedRange: typing.Optional["Range"]

    """ Dead? How old/when?.
    Type `Range` (represented as `dict` in JSON). """

    deceasedDate: typing.Optional["FHIRDate"]

    """ Dead? How old/when?.
    Type `FHIRDate` (represented as `str` in JSON). """

    deceasedString: typing.Optional[str]

    """ Dead? How old/when?.
    Type `str`. """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why was family member history performed?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why was family member history performed?.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ General note about related person.
    List of `Annotation` items (represented as `dict` in JSON). """

    condition: typing.Optional[typing.List["FamilyMemberHistoryCondition"]]

    """ Condition that the related person had.
    List of `FamilyMemberHistoryCondition` items (represented as `dict` in JSON). """



#   {'path': 'FamilyMemberHistory.born[x]', 'choice_of_type': 'born', 'orig_name': 'bornPeriod', 'name': 'bornPeriod', 'parent_name': 'FamilyMemberHistory', 'class_name': 'Period', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': '(approximate) date of birth', 'formal': 'The actual or approximate date of birth of the relative.', 'representation': None}

    _born_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['bornPeriod', 'bornDate', 'bornString']), True))

#   {'path': 'FamilyMemberHistory.age[x]', 'choice_of_type': 'age', 'orig_name': 'ageAge', 'name': 'ageAge', 'parent_name': 'FamilyMemberHistory', 'class_name': 'Age', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': '(approximate) age', 'formal': 'The age of the relative at the time the family member history is recorded.', 'representation': None}

    _age_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['ageAge', 'ageRange', 'ageString']), True))

#   {'path': 'FamilyMemberHistory.deceased[x]', 'choice_of_type': 'deceased', 'orig_name': 'deceasedBoolean', 'name': 'deceasedBoolean', 'parent_name': 'FamilyMemberHistory', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Dead? How old/when?', 'formal': 'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.', 'representation': None}

    _deceased_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['deceasedBoolean', 'deceasedAge', 'deceasedRange', 'deceasedDate', 'deceasedString']), True))


    

     
    



class Flag(DomainResource):
    """ Key information to flag to healthcare providers.
    
    Prospective warnings of potential issues when providing care to the
    patient.
    """
    
    resource_type = "Flag"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='author' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | inactive | entered-in-error.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Clinical, administrative, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Coded or textual message to display to user.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who/What is flag about?.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time period when flag is active.
    Type `Period` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Alert relevant during encounter.
    Type `Reference` (represented as `dict` in JSON). """

    author: typing.Optional["Reference"]

    """ Flag creator.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class Goal(DomainResource):
    """ Describes the intended objective(s) for a patient, group or organization.
    
    Describes the intended objective(s) for a patient, group or organization
    care, for example, weight loss, restoring an activity of daily living,
    obtaining herd immunity via immunization, meeting a process improvement
    objective, etc.
    """
    
    resource_type = "Goal"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='lifecycleStatus' >, <FHIRClassProperty self.name='achievementStatus' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='startDate' >, <FHIRClassProperty self.name='startCodeableConcept' >, <FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='statusDate' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='expressedBy' >, <FHIRClassProperty self.name='addresses' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='outcomeCode' >, <FHIRClassProperty self.name='outcomeReference' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this goal.
    List of `Identifier` items (represented as `dict` in JSON). """

    lifecycleStatus: "str"

    """ proposed | planned | accepted | active | on-hold | completed |
        cancelled | entered-in-error | rejected.
    Type `str`. """

    achievementStatus: typing.Optional["CodeableConcept"]

    """ in-progress | improving | worsening | no-change | achieved |
        sustaining | not-achieved | no-progress | not-attainable.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ E.g. Treatment, dietary, behavioral, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    priority: typing.Optional["CodeableConcept"]

    """ high-priority | medium-priority | low-priority.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: "CodeableConcept"

    """ Code or text describing goal.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who this goal is intended for.
    Type `Reference` (represented as `dict` in JSON). """

    startDate: typing.Optional["FHIRDate"]

    """ When goal pursuit begins.
    Type `FHIRDate` (represented as `str` in JSON). """

    startCodeableConcept: typing.Optional["CodeableConcept"]

    """ When goal pursuit begins.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    target: typing.Optional[typing.List["GoalTarget"]]

    """ Target outcome for the goal.
    List of `GoalTarget` items (represented as `dict` in JSON). """

    statusDate: typing.Optional["FHIRDate"]

    """ When goal status took effect.
    Type `FHIRDate` (represented as `str` in JSON). """

    statusReason: typing.Optional[str]

    """ Reason for current status.
    Type `str`. """

    expressedBy: typing.Optional["Reference"]

    """ Who's responsible for creating Goal?.
    Type `Reference` (represented as `dict` in JSON). """

    addresses: typing.Optional[typing.List["Reference"]]

    """ Issues addressed by this goal.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments about the goal.
    List of `Annotation` items (represented as `dict` in JSON). """

    outcomeCode: typing.Optional[typing.List["CodeableConcept"]]

    """ What result was achieved regarding the goal?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    outcomeReference: typing.Optional[typing.List["Reference"]]

    """ Observation that resulted from goal.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'Goal.start[x]', 'choice_of_type': 'start', 'orig_name': 'startDate', 'name': 'startDate', 'parent_name': 'Goal', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When goal pursuit begins', 'formal': 'The date or event after which the goal should begin being pursued.', 'representation': None}

    _start_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['startDate', 'startCodeableConcept']), True))


    

     
    



class GraphDefinition(DomainResource):
    """ Definition of a graph of resources.
    
    A formal computable definition of a graph of resources - that is, a
    coherent set of resources that form a graph by following references. The
    Graph Definition resource defines a set and makes rules about the set.
    """
    
    resource_type = "GraphDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='link' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this graph definition, represented as a
        URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the graph definition.
    Type `str`. """

    name: str

    """ Name for this graph definition (computer friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the graph definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for graph definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this graph definition is defined.
    Type `str`. """

    start: "str"

    """ Type of resource at which the graph starts.
    Type `str`. """

    profile: typing.Optional[str]

    """ Profile on base resource.
    Type `str`. """

    link: typing.Optional[typing.List["GraphDefinitionLink"]]

    """ Links this graph makes rules about.
    List of `GraphDefinitionLink` items (represented as `dict` in JSON). """




    

     
    



class Group(DomainResource):
    """ Group of multiple entities.
    
    Represents a defined collection of entities that may be discussed or acted
    upon collectively but which are not expected to act collectively, and are
    not formally or legally recognized; i.e. a collection of entities that
    isn't an Organization.
    """
    
    resource_type = "Group"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='actual' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='managingEntity' >, <FHIRClassProperty self.name='characteristic' >, <FHIRClassProperty self.name='member' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique id.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this group's record is in active use.
    Type `bool`. """

    type: "str"

    """ person | animal | practitioner | device | medication | substance.
    Type `str`. """

    actual: bool

    """ Descriptive or actual.
    Type `bool`. """

    code: typing.Optional["CodeableConcept"]

    """ Kind of Group members.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Label for Group.
    Type `str`. """

    quantity: typing.Optional[int]

    """ Number of members.
    Type `int`. """

    managingEntity: typing.Optional["Reference"]

    """ Entity that is the custodian of the Group's definition.
    Type `Reference` (represented as `dict` in JSON). """

    characteristic: typing.Optional[typing.List["GroupCharacteristic"]]

    """ Include / Exclude group members by Trait.
    List of `GroupCharacteristic` items (represented as `dict` in JSON). """

    member: typing.Optional[typing.List["GroupMember"]]

    """ Who or what is in group.
    List of `GroupMember` items (represented as `dict` in JSON). """




    

     
    



class GuidanceResponse(DomainResource):
    """ The formal response to a guidance request.
    
    A guidance response is the formal response to a guidance request, including
    any output parameters returned by the evaluation, as well as the
    description of any proposed actions to be taken.
    """
    
    resource_type = "GuidanceResponse"
    
    # [<FHIRClassProperty self.name='requestIdentifier' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='moduleUri' >, <FHIRClassProperty self.name='moduleCanonical' >, <FHIRClassProperty self.name='moduleCodeableConcept' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='evaluationMessage' >, <FHIRClassProperty self.name='outputParameters' >, <FHIRClassProperty self.name='result' >, <FHIRClassProperty self.name='dataRequirement' >]
  

    requestIdentifier: typing.Optional["Identifier"]

    """ The identifier of the request associated with this response, if any.
    Type `Identifier` (represented as `dict` in JSON). """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    moduleUri: typing.Optional[str]

    """ What guidance was requested.
    Type `str`. """

    moduleCanonical: typing.Optional[str]

    """ What guidance was requested.
    Type `str`. """

    moduleCodeableConcept: typing.Optional["CodeableConcept"]

    """ What guidance was requested.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: "str"

    """ success | data-requested | data-required | in-progress | failure |
        entered-in-error.
    Type `str`. """

    subject: typing.Optional["Reference"]

    """ Patient the request was performed for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter during which the response was returned.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When the guidance response was processed.
    Type `FHIRDate` (represented as `str` in JSON). """

    performer: typing.Optional["Reference"]

    """ Device returning the guidance.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why guidance is needed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why guidance is needed.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional notes about the response.
    List of `Annotation` items (represented as `dict` in JSON). """

    evaluationMessage: typing.Optional[typing.List["Reference"]]

    """ Messages resulting from the evaluation of the artifact or artifacts.
    List of `Reference` items (represented as `dict` in JSON). """

    outputParameters: typing.Optional["Reference"]

    """ The output parameters of the evaluation, if any.
    Type `Reference` (represented as `dict` in JSON). """

    result: typing.Optional["Reference"]

    """ Proposed actions, if any.
    Type `Reference` (represented as `dict` in JSON). """

    dataRequirement: typing.Optional[typing.List["DataRequirement"]]

    """ Additional required data.
    List of `DataRequirement` items (represented as `dict` in JSON). """



#   {'path': 'GuidanceResponse.module[x]', 'choice_of_type': 'module', 'orig_name': 'moduleUri', 'name': 'moduleUri', 'parent_name': 'GuidanceResponse', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What guidance was requested', 'formal': 'An identifier, CodeableConcept or canonical reference to the guidance that was requested.', 'representation': None}

    _module_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['moduleUri', 'moduleCanonical', 'moduleCodeableConcept']), False))


    

     
    



class HealthcareService(DomainResource):
    """ The details of a healthcare service available at a location.
    """
    
    resource_type = "HealthcareService"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='providedBy' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='extraDetails' >, <FHIRClassProperty self.name='photo' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='coverageArea' >, <FHIRClassProperty self.name='serviceProvisionCode' >, <FHIRClassProperty self.name='eligibility' >, <FHIRClassProperty self.name='program' >, <FHIRClassProperty self.name='characteristic' >, <FHIRClassProperty self.name='communication' >, <FHIRClassProperty self.name='referralMethod' >, <FHIRClassProperty self.name='appointmentRequired' >, <FHIRClassProperty self.name='availableTime' >, <FHIRClassProperty self.name='notAvailable' >, <FHIRClassProperty self.name='availabilityExceptions' >, <FHIRClassProperty self.name='endpoint' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifiers for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this HealthcareService record is in active use.
    Type `bool`. """

    providedBy: typing.Optional["Reference"]

    """ Organization that provides this service.
    Type `Reference` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Broad category of service being performed or delivered.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of service that may be delivered or performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ Specialties handled by the HealthcareService.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    location: typing.Optional[typing.List["Reference"]]

    """ Location(s) where service may be provided.
    List of `Reference` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Description of service as presented to a consumer while searching.
    Type `str`. """

    comment: typing.Optional[str]

    """ Additional description and/or any specific issues not covered
        elsewhere.
    Type `str`. """

    extraDetails: typing.Optional[str]

    """ Extra details about the service that can't be placed in the other
        fields.
    Type `str`. """

    photo: typing.Optional["Attachment"]

    """ Facilitates quick identification of the service.
    Type `Attachment` (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contacts related to the healthcare service.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    coverageArea: typing.Optional[typing.List["Reference"]]

    """ Location(s) service is intended for/available to.
    List of `Reference` items (represented as `dict` in JSON). """

    serviceProvisionCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Conditions under which service is available/offered.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    eligibility: typing.Optional[typing.List["HealthcareServiceEligibility"]]

    """ Specific eligibility requirements required to use the service.
    List of `HealthcareServiceEligibility` items (represented as `dict` in JSON). """

    program: typing.Optional[typing.List["CodeableConcept"]]

    """ Programs that this service is applicable to.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    characteristic: typing.Optional[typing.List["CodeableConcept"]]

    """ Collection of characteristics (attributes).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    communication: typing.Optional[typing.List["CodeableConcept"]]

    """ The language that this service is offered in.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    referralMethod: typing.Optional[typing.List["CodeableConcept"]]

    """ Ways that the service accepts referrals.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    appointmentRequired: typing.Optional[bool]

    """ If an appointment is required for access to this service.
    Type `bool`. """

    availableTime: typing.Optional[typing.List["HealthcareServiceAvailableTime"]]

    """ Times the Service Site is available.
    List of `HealthcareServiceAvailableTime` items (represented as `dict` in JSON). """

    notAvailable: typing.Optional[typing.List["HealthcareServiceNotAvailable"]]

    """ Not available during this time due to provided reason.
    List of `HealthcareServiceNotAvailable` items (represented as `dict` in JSON). """

    availabilityExceptions: typing.Optional[str]

    """ Description of availability exceptions.
    Type `str`. """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoints providing access to electronic services
        operated for the healthcare service.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class ImagingStudy(DomainResource):
    """ A set of images produced in single study (one or more series of references
    images).
    
    Representation of the content produced in a DICOM imaging study. A study
    comprises a set of series, each of which includes a set of Service-Object
    Pair Instances (SOP Instances - images or other data) acquired or produced
    in a common context.  A series is of only one modality (e.g. X-ray, CT, MR,
    ultrasound), but a study may have multiple series of different modalities.
    """
    
    resource_type = "ImagingStudy"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='modality' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='started' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='referrer' >, <FHIRClassProperty self.name='interpreter' >, <FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='numberOfSeries' >, <FHIRClassProperty self.name='numberOfInstances' >, <FHIRClassProperty self.name='procedureReference' >, <FHIRClassProperty self.name='procedureCode' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='series' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifiers for the whole study.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ registered | available | cancelled | entered-in-error | unknown.
    Type `str`. """

    modality: typing.Optional[typing.List["Coding"]]

    """ All series modality if actual acquisition modalities.
    List of `Coding` items (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who or what is the subject of the study.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter with which this imaging study is associated.
    Type `Reference` (represented as `dict` in JSON). """

    started: typing.Optional["FHIRDate"]

    """ When the study was started.
    Type `FHIRDate` (represented as `str` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Request fulfilled.
    List of `Reference` items (represented as `dict` in JSON). """

    referrer: typing.Optional["Reference"]

    """ Referring physician.
    Type `Reference` (represented as `dict` in JSON). """

    interpreter: typing.Optional[typing.List["Reference"]]

    """ Who interpreted images.
    List of `Reference` items (represented as `dict` in JSON). """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Study access endpoint.
    List of `Reference` items (represented as `dict` in JSON). """

    numberOfSeries: typing.Optional[int]

    """ Number of Study Related Series.
    Type `int`. """

    numberOfInstances: typing.Optional[int]

    """ Number of Study Related Instances.
    Type `int`. """

    procedureReference: typing.Optional["Reference"]

    """ The performed Procedure reference.
    Type `Reference` (represented as `dict` in JSON). """

    procedureCode: typing.Optional[typing.List["CodeableConcept"]]

    """ The performed procedure code.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where ImagingStudy occurred.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why the study was requested.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why was study performed.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ User-defined comments.
    List of `Annotation` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Institution-generated description.
    Type `str`. """

    series: typing.Optional[typing.List["ImagingStudySeries"]]

    """ Each study has one or more series of instances.
    List of `ImagingStudySeries` items (represented as `dict` in JSON). """




    

     
    



class Immunization(DomainResource):
    """ Immunization event information.
    
    Describes the event of a patient being administered a vaccine or a record
    of an immunization as reported by a patient, a clinician or another party.
    """
    
    resource_type = "Immunization"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='vaccineCode' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrenceString' >, <FHIRClassProperty self.name='recorded' >, <FHIRClassProperty self.name='primarySource' >, <FHIRClassProperty self.name='reportOrigin' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='lotNumber' >, <FHIRClassProperty self.name='expirationDate' >, <FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='route' >, <FHIRClassProperty self.name='doseQuantity' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='isSubpotent' >, <FHIRClassProperty self.name='subpotentReason' >, <FHIRClassProperty self.name='education' >, <FHIRClassProperty self.name='programEligibility' >, <FHIRClassProperty self.name='fundingSource' >, <FHIRClassProperty self.name='reaction' >, <FHIRClassProperty self.name='protocolApplied' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ completed | entered-in-error | not-done.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason not done.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    vaccineCode: "CodeableConcept"

    """ Vaccine product administered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    patient: "Reference"

    """ Who was immunized.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter immunization was part of.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ Vaccine administration date.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrenceString: typing.Optional[str]

    """ Vaccine administration date.
    Type `str`. """

    recorded: typing.Optional["FHIRDate"]

    """ When the immunization was first captured in the subject's record.
    Type `FHIRDate` (represented as `str` in JSON). """

    primarySource: typing.Optional[bool]

    """ Indicates context the data was recorded in.
    Type `bool`. """

    reportOrigin: typing.Optional["CodeableConcept"]

    """ Indicates the source of a secondarily reported record.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where immunization occurred.
    Type `Reference` (represented as `dict` in JSON). """

    manufacturer: typing.Optional["Reference"]

    """ Vaccine manufacturer.
    Type `Reference` (represented as `dict` in JSON). """

    lotNumber: typing.Optional[str]

    """ Vaccine lot number.
    Type `str`. """

    expirationDate: typing.Optional["FHIRDate"]

    """ Vaccine expiration date.
    Type `FHIRDate` (represented as `str` in JSON). """

    site: typing.Optional["CodeableConcept"]

    """ Body site vaccine  was administered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    route: typing.Optional["CodeableConcept"]

    """ How vaccine entered body.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    doseQuantity: typing.Optional["Quantity"]

    """ Amount of vaccine administered.
    Type `Quantity` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["ImmunizationPerformer"]]

    """ Who performed event.
    List of `ImmunizationPerformer` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional immunization notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why immunization occurred.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why immunization occurred.
    List of `Reference` items (represented as `dict` in JSON). """

    isSubpotent: typing.Optional[bool]

    """ Dose potency.
    Type `bool`. """

    subpotentReason: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason for being subpotent.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    education: typing.Optional[typing.List["ImmunizationEducation"]]

    """ Educational material presented to patient.
    List of `ImmunizationEducation` items (represented as `dict` in JSON). """

    programEligibility: typing.Optional[typing.List["CodeableConcept"]]

    """ Patient eligibility for a vaccination program.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    fundingSource: typing.Optional["CodeableConcept"]

    """ Funding source for the vaccine.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reaction: typing.Optional[typing.List["ImmunizationReaction"]]

    """ Details of a reaction that follows immunization.
    List of `ImmunizationReaction` items (represented as `dict` in JSON). """

    protocolApplied: typing.Optional[typing.List["ImmunizationProtocolApplied"]]

    """ Protocol followed by the provider.
    List of `ImmunizationProtocolApplied` items (represented as `dict` in JSON). """



#   {'path': 'Immunization.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'Immunization', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Vaccine administration date', 'formal': 'Date vaccine administered or was to be administered.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrenceString']), False))


    

     
    



class ImmunizationEvaluation(DomainResource):
    """ Immunization evaluation information.
    
    Describes a comparison of an immunization event against published
    recommendations to determine if the administration is "valid" in relation
    to those  recommendations.
    """
    
    resource_type = "ImmunizationEvaluation"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='targetDisease' >, <FHIRClassProperty self.name='immunizationEvent' >, <FHIRClassProperty self.name='doseStatus' >, <FHIRClassProperty self.name='doseStatusReason' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='series' >, <FHIRClassProperty self.name='doseNumberPositiveInt' >, <FHIRClassProperty self.name='doseNumberString' >, <FHIRClassProperty self.name='seriesDosesPositiveInt' >, <FHIRClassProperty self.name='seriesDosesString' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ completed | entered-in-error.
    Type `str`. """

    patient: "Reference"

    """ Who this evaluation is for.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date evaluation was performed.
    Type `FHIRDate` (represented as `str` in JSON). """

    authority: typing.Optional["Reference"]

    """ Who is responsible for publishing the recommendations.
    Type `Reference` (represented as `dict` in JSON). """

    targetDisease: "CodeableConcept"

    """ Evaluation target disease.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    immunizationEvent: "Reference"

    """ Immunization being evaluated.
    Type `Reference` (represented as `dict` in JSON). """

    doseStatus: "CodeableConcept"

    """ Status of the dose relative to published recommendations.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    doseStatusReason: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason for the dose status.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Evaluation notes.
    Type `str`. """

    series: typing.Optional[str]

    """ Name of vaccine series.
    Type `str`. """

    doseNumberPositiveInt: typing.Optional[int]

    """ Dose number within series.
    Type `int`. """

    doseNumberString: typing.Optional[str]

    """ Dose number within series.
    Type `str`. """

    seriesDosesPositiveInt: typing.Optional[int]

    """ Recommended number of doses for immunity.
    Type `int`. """

    seriesDosesString: typing.Optional[str]

    """ Recommended number of doses for immunity.
    Type `str`. """



#   {'path': 'ImmunizationEvaluation.doseNumber[x]', 'choice_of_type': 'doseNumber', 'orig_name': 'doseNumberPositiveInt', 'name': 'doseNumberPositiveInt', 'parent_name': 'ImmunizationEvaluation', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Dose number within series', 'formal': 'Nominal position in a series.', 'representation': None}

    _doseNumber_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['doseNumberPositiveInt', 'doseNumberString']), True))

#   {'path': 'ImmunizationEvaluation.seriesDoses[x]', 'choice_of_type': 'seriesDoses', 'orig_name': 'seriesDosesPositiveInt', 'name': 'seriesDosesPositiveInt', 'parent_name': 'ImmunizationEvaluation', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Recommended number of doses for immunity', 'formal': 'The recommended number of doses to achieve immunity.', 'representation': None}

    _seriesDoses_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['seriesDosesPositiveInt', 'seriesDosesString']), True))


    

     
    



class ImmunizationRecommendation(DomainResource):
    """ Guidance or advice relating to an immunization.
    
    A patient's point-in-time set of recommendations (i.e. forecasting)
    according to a published schedule with optional supporting justification.
    """
    
    resource_type = "ImmunizationRecommendation"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='recommendation' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    patient: "Reference"

    """ Who this profile is for.
    Type `Reference` (represented as `dict` in JSON). """

    date: "FHIRDate"

    """ Date recommendation(s) created.
    Type `FHIRDate` (represented as `str` in JSON). """

    authority: typing.Optional["Reference"]

    """ Who is responsible for protocol.
    Type `Reference` (represented as `dict` in JSON). """

    recommendation: typing.List["ImmunizationRecommendationRecommendation"]

    """ Vaccine administration recommendations.
    List of `ImmunizationRecommendationRecommendation` items (represented as `dict` in JSON). """




    

     
    



class ImplementationGuide(DomainResource):
    """ A set of rules about how FHIR is used.
    
    A set of rules of how a particular interoperability or standards problem is
    solved - typically through the use of FHIR resources. This resource is used
    to gather all the parts of an implementation guide into a logical whole and
    to publish a computable definition of all the parts.
    """
    
    resource_type = "ImplementationGuide"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='packageId' >, <FHIRClassProperty self.name='license' >, <FHIRClassProperty self.name='fhirVersion' >, <FHIRClassProperty self.name='dependsOn' >, <FHIRClassProperty self.name='global_' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='manifest' >]
  

    url: str

    """ Canonical identifier for this implementation guide, represented as
        a URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the implementation guide.
    Type `str`. """

    name: str

    """ Name for this implementation guide (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this implementation guide (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the implementation guide.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for implementation guide (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    packageId: str

    """ NPM Package name for IG.
    Type `str`. """

    license: typing.Optional[str]

    """ SPDX license code for this IG (or not-open-source).
    Type `str`. """

    fhirVersion: typing.List[str]

    """ FHIR Version(s) this Implementation Guide targets.
    List of `str` items. """

    dependsOn: typing.Optional[typing.List["ImplementationGuideDependsOn"]]

    """ Another Implementation guide this depends on.
    List of `ImplementationGuideDependsOn` items (represented as `dict` in JSON). """

    global_: typing.Optional[typing.List["ImplementationGuideGlobal"]]

    """ Profiles that apply globally.
    List of `ImplementationGuideGlobal` items (represented as `dict` in JSON). """

    definition: typing.Optional["ImplementationGuideDefinition"]

    """ Information needed to build the IG.
    Type `ImplementationGuideDefinition` (represented as `dict` in JSON). """

    manifest: typing.Optional["ImplementationGuideManifest"]

    """ Information about an assembled IG.
    Type `ImplementationGuideManifest` (represented as `dict` in JSON). """




    

     
    



class InsurancePlan(DomainResource):
    """ Details of a Health Insurance product/plan provided by an organization.
    """
    
    resource_type = "InsurancePlan"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='ownedBy' >, <FHIRClassProperty self.name='administeredBy' >, <FHIRClassProperty self.name='coverageArea' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='plan' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for Product.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ draft | active | retired | unknown.
    Type `str`. """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Kind of product.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Official name.
    Type `str`. """

    alias: typing.Optional[typing.List[str]]

    """ Alternate names.
    List of `str` items. """

    period: typing.Optional["Period"]

    """ When the product is available.
    Type `Period` (represented as `dict` in JSON). """

    ownedBy: typing.Optional["Reference"]

    """ Plan issuer.
    Type `Reference` (represented as `dict` in JSON). """

    administeredBy: typing.Optional["Reference"]

    """ Product administrator.
    Type `Reference` (represented as `dict` in JSON). """

    coverageArea: typing.Optional[typing.List["Reference"]]

    """ Where product applies.
    List of `Reference` items (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["InsurancePlanContact"]]

    """ Contact for the product.
    List of `InsurancePlanContact` items (represented as `dict` in JSON). """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoint.
    List of `Reference` items (represented as `dict` in JSON). """

    network: typing.Optional[typing.List["Reference"]]

    """ What networks are Included.
    List of `Reference` items (represented as `dict` in JSON). """

    coverage: typing.Optional[typing.List["InsurancePlanCoverage"]]

    """ Coverage details.
    List of `InsurancePlanCoverage` items (represented as `dict` in JSON). """

    plan: typing.Optional[typing.List["InsurancePlanPlan"]]

    """ Plan details.
    List of `InsurancePlanPlan` items (represented as `dict` in JSON). """




    

     
    



class Invoice(DomainResource):
    """ Invoice containing ChargeItems from an Account.
    
    Invoice containing collected ChargeItems from an Account with calculated
    individual and total price for Billing purpose.
    """
    
    resource_type = "Invoice"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='cancelledReason' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='issuer' >, <FHIRClassProperty self.name='account' >, <FHIRClassProperty self.name='lineItem' >, <FHIRClassProperty self.name='totalPriceComponent' >, <FHIRClassProperty self.name='totalNet' >, <FHIRClassProperty self.name='totalGross' >, <FHIRClassProperty self.name='paymentTerms' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for item.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ draft | issued | balanced | cancelled | entered-in-error.
    Type `str`. """

    cancelledReason: typing.Optional[str]

    """ Reason for cancellation of this Invoice.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Type of Invoice.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Recipient(s) of goods and services.
    Type `Reference` (represented as `dict` in JSON). """

    recipient: typing.Optional["Reference"]

    """ Recipient of this invoice.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Invoice date / posting date.
    Type `FHIRDate` (represented as `str` in JSON). """

    participant: typing.Optional[typing.List["InvoiceParticipant"]]

    """ Participant in creation of this Invoice.
    List of `InvoiceParticipant` items (represented as `dict` in JSON). """

    issuer: typing.Optional["Reference"]

    """ Issuing Organization of Invoice.
    Type `Reference` (represented as `dict` in JSON). """

    account: typing.Optional["Reference"]

    """ Account that is being balanced.
    Type `Reference` (represented as `dict` in JSON). """

    lineItem: typing.Optional[typing.List["InvoiceLineItem"]]

    """ Line items of this Invoice.
    List of `InvoiceLineItem` items (represented as `dict` in JSON). """

    totalPriceComponent: typing.Optional[typing.List["InvoiceLineItemPriceComponent"]]

    """ Components of Invoice total.
    List of `InvoiceLineItemPriceComponent` items (represented as `dict` in JSON). """

    totalNet: typing.Optional["Money"]

    """ Net total of this Invoice.
    Type `Money` (represented as `dict` in JSON). """

    totalGross: typing.Optional["Money"]

    """ Gross total of this Invoice.
    Type `Money` (represented as `dict` in JSON). """

    paymentTerms: typing.Optional[str]

    """ Payment details.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the invoice.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class Library(DomainResource):
    """ Represents a library of quality improvement components.
    
    The Library resource is a general-purpose container for knowledge asset
    definitions. It can be used to describe and expose existing knowledge
    assets such as logic libraries and information model descriptions, as well
    as to describe a collection of knowledge assets.
    """
    
    resource_type = "Library"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='dataRequirement' >, <FHIRClassProperty self.name='content' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this library, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the library.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the library.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this library (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this library (human friendly).
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the library.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    type: "CodeableConcept"

    """ logic-library | model-definition | asset-collection | module-
        definition.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ Type of individual the library content is focused on.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ Type of individual the library content is focused on.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the library.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for library (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this library is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the library.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the library was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the library was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the library is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ E.g. Education, Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    parameter: typing.Optional[typing.List["ParameterDefinition"]]

    """ Parameters defined by the library.
    List of `ParameterDefinition` items (represented as `dict` in JSON). """

    dataRequirement: typing.Optional[typing.List["DataRequirement"]]

    """ What data is referenced by this library.
    List of `DataRequirement` items (represented as `dict` in JSON). """

    content: typing.Optional[typing.List["Attachment"]]

    """ Contents of the library, either embedded or referenced.
    List of `Attachment` items (represented as `dict` in JSON). """



#   {'path': 'Library.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'Library', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Type of individual the library content is focused on', 'formal': 'A code or group definition that describes the intended subject of the contents of the library.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class Linkage(DomainResource):
    """ Links records for 'same' item.
    
    Identifies two or more records (resource instances) that refer to the same
    real-world "occurrence".
    """
    
    resource_type = "Linkage"
    
    # [<FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='item' >]
  

    active: typing.Optional[bool]

    """ Whether this linkage assertion is active or not.
    Type `bool`. """

    author: typing.Optional["Reference"]

    """ Who is responsible for linkages.
    Type `Reference` (represented as `dict` in JSON). """

    item: typing.List["LinkageItem"]

    """ Item to be linked.
    List of `LinkageItem` items (represented as `dict` in JSON). """




    

     
    



class List(DomainResource):
    """ A list is a curated collection of resources.
    """
    
    resource_type = "List"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='orderedBy' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='entry' >, <FHIRClassProperty self.name='emptyReason' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ current | retired | entered-in-error.
    Type `str`. """

    mode: "str"

    """ working | snapshot | changes.
    Type `str`. """

    title: typing.Optional[str]

    """ Descriptive name for the list.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ What the purpose of this list is.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ If all resources have the same subject.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Context in which list created.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the list was prepared.
    Type `FHIRDate` (represented as `str` in JSON). """

    source: typing.Optional["Reference"]

    """ Who and/or what defined the list contents (aka Author).
    Type `Reference` (represented as `dict` in JSON). """

    orderedBy: typing.Optional["CodeableConcept"]

    """ What order the list has.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments about the list.
    List of `Annotation` items (represented as `dict` in JSON). """

    entry: typing.Optional[typing.List["ListEntry"]]

    """ Entries in the list.
    List of `ListEntry` items (represented as `dict` in JSON). """

    emptyReason: typing.Optional["CodeableConcept"]

    """ Why list is empty.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class Location(DomainResource):
    """ Details and position information for a physical place.
    
    Details and position information for a physical place where services are
    provided and resources and participants may be stored, found, contained, or
    accommodated.
    """
    
    resource_type = "Location"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='operationalStatus' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='physicalType' >, <FHIRClassProperty self.name='position' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='hoursOfOperation' >, <FHIRClassProperty self.name='availabilityExceptions' >, <FHIRClassProperty self.name='endpoint' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique code or number identifying the location to its users.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | suspended | inactive.
    Type `str`. """

    operationalStatus: typing.Optional["Coding"]

    """ The operational status of the location (typically only for a
        bed/room).
    Type `Coding` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Name of the location as used by humans.
    Type `str`. """

    alias: typing.Optional[typing.List[str]]

    """ A list of alternate names that the location is known as, or was
        known as, in the past.
    List of `str` items. """

    description: typing.Optional[str]

    """ Additional details about the location that could be displayed as
        further information to identify the location beyond its name.
    Type `str`. """

    mode: typing.Optional["str"]

    """ instance | kind.
    Type `str`. """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of function performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details of the location.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional["Address"]

    """ Physical location.
    Type `Address` (represented as `dict` in JSON). """

    physicalType: typing.Optional["CodeableConcept"]

    """ Physical form of the location.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    position: typing.Optional["LocationPosition"]

    """ The absolute geographic location.
    Type `LocationPosition` (represented as `dict` in JSON). """

    managingOrganization: typing.Optional["Reference"]

    """ Organization responsible for provisioning and upkeep.
    Type `Reference` (represented as `dict` in JSON). """

    partOf: typing.Optional["Reference"]

    """ Another Location this one is physically a part of.
    Type `Reference` (represented as `dict` in JSON). """

    hoursOfOperation: typing.Optional[typing.List["LocationHoursOfOperation"]]

    """ What days/times during a week is this location usually open.
    List of `LocationHoursOfOperation` items (represented as `dict` in JSON). """

    availabilityExceptions: typing.Optional[str]

    """ Description of availability exceptions.
    Type `str`. """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoints providing access to services operated for the
        location.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class Measure(DomainResource):
    """ A quality measure definition.
    
    The Measure resource provides the definition of a quality measure.
    """
    
    resource_type = "Measure"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='library' >, <FHIRClassProperty self.name='disclaimer' >, <FHIRClassProperty self.name='scoring' >, <FHIRClassProperty self.name='compositeScoring' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='riskAdjustment' >, <FHIRClassProperty self.name='rateAggregation' >, <FHIRClassProperty self.name='rationale' >, <FHIRClassProperty self.name='clinicalRecommendationStatement' >, <FHIRClassProperty self.name='improvementNotation' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='guidance' >, <FHIRClassProperty self.name='group' >, <FHIRClassProperty self.name='supplementalData' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this measure, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the measure.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the measure.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this measure (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this measure (human friendly).
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the measure.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the measure.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for measure (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this measure is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the measure.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the measure was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the measure was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the measure is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the measure, such as Education, Treatment,
        Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    library: typing.Optional[typing.List[str]]

    """ Logic used by the measure.
    List of `str` items. """

    disclaimer: typing.Optional[str]

    """ Disclaimer for use of the measure or its referenced content.
    Type `str`. """

    scoring: typing.Optional["CodeableConcept"]

    """ proportion | ratio | continuous-variable | cohort.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    compositeScoring: typing.Optional["CodeableConcept"]

    """ opportunity | all-or-nothing | linear | weighted.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ process | outcome | structure | patient-reported-outcome |
        composite.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    riskAdjustment: typing.Optional[str]

    """ How risk adjustment is applied for this measure.
    Type `str`. """

    rateAggregation: typing.Optional[str]

    """ How is rate aggregation performed for this measure.
    Type `str`. """

    rationale: typing.Optional[str]

    """ Detailed description of why the measure exists.
    Type `str`. """

    clinicalRecommendationStatement: typing.Optional[str]

    """ Summary of clinical guidelines.
    Type `str`. """

    improvementNotation: typing.Optional["CodeableConcept"]

    """ increase | decrease.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    definition: typing.Optional[typing.List[str]]

    """ Defined terms used in the measure documentation.
    List of `str` items. """

    guidance: typing.Optional[str]

    """ Additional guidance for implementers.
    Type `str`. """

    group: typing.Optional[typing.List["MeasureGroup"]]

    """ Population criteria group.
    List of `MeasureGroup` items (represented as `dict` in JSON). """

    supplementalData: typing.Optional[typing.List["MeasureSupplementalData"]]

    """ What other data should be reported with the measure.
    List of `MeasureSupplementalData` items (represented as `dict` in JSON). """



#   {'path': 'Measure.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'Measure', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device', 'formal': 'The intended subjects for the measure. If this element is not provided, a Patient subject is assumed, but the subject of the measure can be anything.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class MeasureReport(DomainResource):
    """ Results of a measure evaluation.
    
    The MeasureReport resource contains the results of the calculation of a
    measure; and optionally a reference to the resources involved in that
    calculation.
    """
    
    resource_type = "MeasureReport"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='measure' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='reporter' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='improvementNotation' >, <FHIRClassProperty self.name='group' >, <FHIRClassProperty self.name='evaluatedResource' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the MeasureReport.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ complete | pending | error.
    Type `str`. """

    type: "str"

    """ individual | subject-list | summary | data-collection.
    Type `str`. """

    measure: str

    """ What measure was calculated.
    Type `str`. """

    subject: typing.Optional["Reference"]

    """ What individual(s) the report is for.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the report was generated.
    Type `FHIRDate` (represented as `str` in JSON). """

    reporter: typing.Optional["Reference"]

    """ Who is reporting the data.
    Type `Reference` (represented as `dict` in JSON). """

    period: "Period"

    """ What period the report covers.
    Type `Period` (represented as `dict` in JSON). """

    improvementNotation: typing.Optional["CodeableConcept"]

    """ increase | decrease.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    group: typing.Optional[typing.List["MeasureReportGroup"]]

    """ Measure results for each group.
    List of `MeasureReportGroup` items (represented as `dict` in JSON). """

    evaluatedResource: typing.Optional[typing.List["Reference"]]

    """ What data was used to calculate the measure score.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class Media(DomainResource):
    """ A photo, video, or audio recording acquired or used in healthcare. The
    actual content may be inline or provided by direct reference.
    """
    
    resource_type = "Media"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='modality' >, <FHIRClassProperty self.name='view' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='createdDateTime' >, <FHIRClassProperty self.name='createdPeriod' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='operator' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='deviceName' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='height' >, <FHIRClassProperty self.name='width' >, <FHIRClassProperty self.name='frames' >, <FHIRClassProperty self.name='duration' >, <FHIRClassProperty self.name='content' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifier(s) for the image.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Procedure that caused this media to be created.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ preparation | in-progress | not-done | on-hold | stopped |
        completed | entered-in-error | unknown.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Classification of media as image, video, or audio.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modality: typing.Optional["CodeableConcept"]

    """ The type of acquisition equipment/process.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    view: typing.Optional["CodeableConcept"]

    """ Imaging view, e.g. Lateral or Antero-posterior.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who/What this Media is a record of.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter associated with media.
    Type `Reference` (represented as `dict` in JSON). """

    createdDateTime: typing.Optional["FHIRDate"]

    """ When Media was collected.
    Type `FHIRDate` (represented as `str` in JSON). """

    createdPeriod: typing.Optional["Period"]

    """ When Media was collected.
    Type `Period` (represented as `dict` in JSON). """

    issued: typing.Optional["FHIRDate"]

    """ Date/Time this version was made available.
    Type `FHIRDate` (represented as `str` in JSON). """

    operator: typing.Optional["Reference"]

    """ The person who generated the image.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why was event performed?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Observed body part.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    deviceName: typing.Optional[str]

    """ Name of the device/manufacturer.
    Type `str`. """

    device: typing.Optional["Reference"]

    """ Observing Device.
    Type `Reference` (represented as `dict` in JSON). """

    height: typing.Optional[int]

    """ Height of the image in pixels (photo/video).
    Type `int`. """

    width: typing.Optional[int]

    """ Width of the image in pixels (photo/video).
    Type `int`. """

    frames: typing.Optional[int]

    """ Number of frames if > 1 (photo).
    Type `int`. """

    duration: typing.Optional[float]

    """ Length in seconds (audio / video).
    Type `float`. """

    content: "Attachment"

    """ Actual Media - reference or data.
    Type `Attachment` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the media.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'Media.created[x]', 'choice_of_type': 'created', 'orig_name': 'createdDateTime', 'name': 'createdDateTime', 'parent_name': 'Media', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When Media was collected', 'formal': 'The date and time(s) at which the media was collected.', 'representation': None}

    _created_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['createdDateTime', 'createdPeriod']), True))


    

     
    



class Medication(DomainResource):
    """ Definition of a Medication.
    
    This resource is primarily used for the identification and definition of a
    medication for the purposes of prescribing, dispensing, and administering a
    medication as well as for making statements about medication use.
    """
    
    resource_type = "Medication"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='form' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='ingredient' >, <FHIRClassProperty self.name='batch' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier for this medication.
    List of `Identifier` items (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Codes that identify this medication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | inactive | entered-in-error.
    Type `str`. """

    manufacturer: typing.Optional["Reference"]

    """ Manufacturer of the item.
    Type `Reference` (represented as `dict` in JSON). """

    form: typing.Optional["CodeableConcept"]

    """ powder | tablets | capsule +.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Ratio"]

    """ Amount of drug in package.
    Type `Ratio` (represented as `dict` in JSON). """

    ingredient: typing.Optional[typing.List["MedicationIngredient"]]

    """ Active or inactive ingredient.
    List of `MedicationIngredient` items (represented as `dict` in JSON). """

    batch: typing.Optional["MedicationBatch"]

    """ Details about packaged medications.
    Type `MedicationBatch` (represented as `dict` in JSON). """




    

     
    



class MedicationAdministration(DomainResource):
    """ Administration of medication to a patient.
    
    Describes the event of a patient consuming or otherwise being administered
    a medication.  This may be as simple as swallowing a tablet or it may be a
    long running infusion.  Related resources tie this event to the authorizing
    prescription, and the specific encounter between patient and health care
    practitioner.
    """
    
    resource_type = "MedicationAdministration"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiates' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='supportingInformation' >, <FHIRClassProperty self.name='effectiveDateTime' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='dosage' >, <FHIRClassProperty self.name='eventHistory' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiates: typing.Optional[typing.List[str]]

    """ Instantiates protocol or definition.
    List of `str` items. """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ in-progress | not-done | on-hold | completed | entered-in-error |
        stopped | unknown.
    Type `str`. """

    statusReason: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason administration not performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Type of medication usage.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ What was administered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ What was administered.
    Type `Reference` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who received medication.
    Type `Reference` (represented as `dict` in JSON). """

    context: typing.Optional["Reference"]

    """ Encounter or Episode of Care administered as part of.
    Type `Reference` (represented as `dict` in JSON). """

    supportingInformation: typing.Optional[typing.List["Reference"]]

    """ Additional information to support administration.
    List of `Reference` items (represented as `dict` in JSON). """

    effectiveDateTime: typing.Optional["FHIRDate"]

    """ Start and end time of administration.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ Start and end time of administration.
    Type `Period` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["MedicationAdministrationPerformer"]]

    """ Who performed the medication administration and what they did.
    List of `MedicationAdministrationPerformer` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason administration performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Condition or observation that supports why the medication was
        administered.
    List of `Reference` items (represented as `dict` in JSON). """

    request: typing.Optional["Reference"]

    """ Request administration performed against.
    Type `Reference` (represented as `dict` in JSON). """

    device: typing.Optional[typing.List["Reference"]]

    """ Device used to administer.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Information about the administration.
    List of `Annotation` items (represented as `dict` in JSON). """

    dosage: typing.Optional["MedicationAdministrationDosage"]

    """ Details of how medication was taken.
    Type `MedicationAdministrationDosage` (represented as `dict` in JSON). """

    eventHistory: typing.Optional[typing.List["Reference"]]

    """ A list of events of interest in the lifecycle.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'MedicationAdministration.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicationAdministration', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What was administered', 'formal': 'Identifies the medication that was administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.', 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))

#   {'path': 'MedicationAdministration.effective[x]', 'choice_of_type': 'effective', 'orig_name': 'effectiveDateTime', 'name': 'effectiveDateTime', 'parent_name': 'MedicationAdministration', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Start and end time of administration', 'formal': "A specific date/time or interval of time during which the administration took place (or did not take place, when the 'notGiven' attribute is true). For many administrations, such as swallowing a tablet the use of dateTime is more appropriate.", 'representation': None}

    _effective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['effectiveDateTime', 'effectivePeriod']), False))


    

     
    



class MedicationDispense(DomainResource):
    """ Dispensing a medication to a named patient.
    
    Indicates that a medication product is to be or has been dispensed for a
    named person/patient.  This includes a description of the medication
    product (supply) provided and the instructions for administering the
    medication.  The medication dispense is the result of a pharmacy system
    responding to a medication order.
    """
    
    resource_type = "MedicationDispense"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReasonCodeableConcept' >, <FHIRClassProperty self.name='statusReasonReference' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='supportingInformation' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='authorizingPrescription' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='daysSupply' >, <FHIRClassProperty self.name='whenPrepared' >, <FHIRClassProperty self.name='whenHandedOver' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='receiver' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='dosageInstruction' >, <FHIRClassProperty self.name='substitution' >, <FHIRClassProperty self.name='detectedIssue' >, <FHIRClassProperty self.name='eventHistory' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Event that dispense is part of.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ preparation | in-progress | cancelled | on-hold | completed |
        entered-in-error | stopped | declined | unknown.
    Type `str`. """

    statusReasonCodeableConcept: typing.Optional["CodeableConcept"]

    """ Why a dispense was not performed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    statusReasonReference: typing.Optional["Reference"]

    """ Why a dispense was not performed.
    Type `Reference` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Type of medication dispense.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ What medication was supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ What medication was supplied.
    Type `Reference` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who the dispense is for.
    Type `Reference` (represented as `dict` in JSON). """

    context: typing.Optional["Reference"]

    """ Encounter / Episode associated with event.
    Type `Reference` (represented as `dict` in JSON). """

    supportingInformation: typing.Optional[typing.List["Reference"]]

    """ Information that supports the dispensing of the medication.
    List of `Reference` items (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["MedicationDispensePerformer"]]

    """ Who performed event.
    List of `MedicationDispensePerformer` items (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where the dispense occurred.
    Type `Reference` (represented as `dict` in JSON). """

    authorizingPrescription: typing.Optional[typing.List["Reference"]]

    """ Medication order that authorizes the dispense.
    List of `Reference` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Trial fill, partial fill, emergency fill, etc..
    Type `CodeableConcept` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Amount dispensed.
    Type `Quantity` (represented as `dict` in JSON). """

    daysSupply: typing.Optional["Quantity"]

    """ Amount of medication expressed as a timing amount.
    Type `Quantity` (represented as `dict` in JSON). """

    whenPrepared: typing.Optional["FHIRDate"]

    """ When product was packaged and reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    whenHandedOver: typing.Optional["FHIRDate"]

    """ When product was given out.
    Type `FHIRDate` (represented as `str` in JSON). """

    destination: typing.Optional["Reference"]

    """ Where the medication was sent.
    Type `Reference` (represented as `dict` in JSON). """

    receiver: typing.Optional[typing.List["Reference"]]

    """ Who collected the medication.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Information about the dispense.
    List of `Annotation` items (represented as `dict` in JSON). """

    dosageInstruction: typing.Optional[typing.List["Dosage"]]

    """ How the medication is to be used by the patient or administered by
        the caregiver.
    List of `Dosage` items (represented as `dict` in JSON). """

    substitution: typing.Optional["MedicationDispenseSubstitution"]

    """ Whether a substitution was performed on the dispense.
    Type `MedicationDispenseSubstitution` (represented as `dict` in JSON). """

    detectedIssue: typing.Optional[typing.List["Reference"]]

    """ Clinical issue with action.
    List of `Reference` items (represented as `dict` in JSON). """

    eventHistory: typing.Optional[typing.List["Reference"]]

    """ A list of relevant lifecycle events.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'MedicationDispense.statusReason[x]', 'choice_of_type': 'statusReason', 'orig_name': 'statusReasonCodeableConcept', 'name': 'statusReasonCodeableConcept', 'parent_name': 'MedicationDispense', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Why a dispense was not performed', 'formal': 'Indicates the reason why a dispense was not performed.', 'representation': None}

    _statusReason_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['statusReasonCodeableConcept', 'statusReasonReference']), True))

#   {'path': 'MedicationDispense.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicationDispense', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What medication was supplied', 'formal': 'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.', 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))


    

     
    



class MedicationKnowledge(DomainResource):
    """ Definition of Medication Knowledge.
    
    Information about a medication that is used to support knowledge.
    """
    
    resource_type = "MedicationKnowledge"
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='doseForm' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='synonym' >, <FHIRClassProperty self.name='relatedMedicationKnowledge' >, <FHIRClassProperty self.name='associatedMedication' >, <FHIRClassProperty self.name='productType' >, <FHIRClassProperty self.name='monograph' >, <FHIRClassProperty self.name='ingredient' >, <FHIRClassProperty self.name='preparationInstruction' >, <FHIRClassProperty self.name='intendedRoute' >, <FHIRClassProperty self.name='cost' >, <FHIRClassProperty self.name='monitoringProgram' >, <FHIRClassProperty self.name='administrationGuidelines' >, <FHIRClassProperty self.name='medicineClassification' >, <FHIRClassProperty self.name='packaging' >, <FHIRClassProperty self.name='drugCharacteristic' >, <FHIRClassProperty self.name='contraindication' >, <FHIRClassProperty self.name='regulatory' >, <FHIRClassProperty self.name='kinetics' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Code that identifies this medication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | inactive | entered-in-error.
    Type `str`. """

    manufacturer: typing.Optional["Reference"]

    """ Manufacturer of the item.
    Type `Reference` (represented as `dict` in JSON). """

    doseForm: typing.Optional["CodeableConcept"]

    """ powder | tablets | capsule +.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Quantity"]

    """ Amount of drug in package.
    Type `Quantity` (represented as `dict` in JSON). """

    synonym: typing.Optional[typing.List[str]]

    """ Additional names for a medication.
    List of `str` items. """

    relatedMedicationKnowledge: typing.Optional[typing.List["MedicationKnowledgeRelatedMedicationKnowledge"]]

    """ Associated or related medication information.
    List of `MedicationKnowledgeRelatedMedicationKnowledge` items (represented as `dict` in JSON). """

    associatedMedication: typing.Optional[typing.List["Reference"]]

    """ A medication resource that is associated with this medication.
    List of `Reference` items (represented as `dict` in JSON). """

    productType: typing.Optional[typing.List["CodeableConcept"]]

    """ Category of the medication or product.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    monograph: typing.Optional[typing.List["MedicationKnowledgeMonograph"]]

    """ Associated documentation about the medication.
    List of `MedicationKnowledgeMonograph` items (represented as `dict` in JSON). """

    ingredient: typing.Optional[typing.List["MedicationKnowledgeIngredient"]]

    """ Active or inactive ingredient.
    List of `MedicationKnowledgeIngredient` items (represented as `dict` in JSON). """

    preparationInstruction: typing.Optional[str]

    """ The instructions for preparing the medication.
    Type `str`. """

    intendedRoute: typing.Optional[typing.List["CodeableConcept"]]

    """ The intended or approved route of administration.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    cost: typing.Optional[typing.List["MedicationKnowledgeCost"]]

    """ The pricing of the medication.
    List of `MedicationKnowledgeCost` items (represented as `dict` in JSON). """

    monitoringProgram: typing.Optional[typing.List["MedicationKnowledgeMonitoringProgram"]]

    """ Program under which a medication is reviewed.
    List of `MedicationKnowledgeMonitoringProgram` items (represented as `dict` in JSON). """

    administrationGuidelines: typing.Optional[typing.List["MedicationKnowledgeAdministrationGuidelines"]]

    """ Guidelines for administration of the medication.
    List of `MedicationKnowledgeAdministrationGuidelines` items (represented as `dict` in JSON). """

    medicineClassification: typing.Optional[typing.List["MedicationKnowledgeMedicineClassification"]]

    """ Categorization of the medication within a formulary or
        classification system.
    List of `MedicationKnowledgeMedicineClassification` items (represented as `dict` in JSON). """

    packaging: typing.Optional["MedicationKnowledgePackaging"]

    """ Details about packaged medications.
    Type `MedicationKnowledgePackaging` (represented as `dict` in JSON). """

    drugCharacteristic: typing.Optional[typing.List["MedicationKnowledgeDrugCharacteristic"]]

    """ Specifies descriptive properties of the medicine.
    List of `MedicationKnowledgeDrugCharacteristic` items (represented as `dict` in JSON). """

    contraindication: typing.Optional[typing.List["Reference"]]

    """ Potential clinical issue with or between medication(s).
    List of `Reference` items (represented as `dict` in JSON). """

    regulatory: typing.Optional[typing.List["MedicationKnowledgeRegulatory"]]

    """ Regulatory information about a medication.
    List of `MedicationKnowledgeRegulatory` items (represented as `dict` in JSON). """

    kinetics: typing.Optional[typing.List["MedicationKnowledgeKinetics"]]

    """ The time course of drug absorption, distribution, metabolism and
        excretion of a medication from the body.
    List of `MedicationKnowledgeKinetics` items (represented as `dict` in JSON). """




    

     
    



class MedicationRequest(DomainResource):
    """ Ordering of medication for patient or group.
    
    An order or request for both supply of the medication and the instructions
    for administration of the medication to a patient. The resource is called
    "MedicationRequest" rather than "MedicationPrescription" or
    "MedicationOrder" to generalize the use across inpatient and outpatient
    settings, including care plans, etc., and to harmonize with workflow
    patterns.
    """
    
    resource_type = "MedicationRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='reportedBoolean' >, <FHIRClassProperty self.name='reportedReference' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='supportingInformation' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='performerType' >, <FHIRClassProperty self.name='recorder' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='groupIdentifier' >, <FHIRClassProperty self.name='courseOfTherapyType' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='dosageInstruction' >, <FHIRClassProperty self.name='dispenseRequest' >, <FHIRClassProperty self.name='substitution' >, <FHIRClassProperty self.name='priorPrescription' >, <FHIRClassProperty self.name='detectedIssue' >, <FHIRClassProperty self.name='eventHistory' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External ids for this request.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | on-hold | cancelled | completed | entered-in-error |
        stopped | draft | unknown.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intent: "str"

    """ proposal | plan | order | original-order | reflex-order | filler-
        order | instance-order | option.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of medication usage.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    doNotPerform: typing.Optional[bool]

    """ True if request is prohibiting action.
    Type `bool`. """

    reportedBoolean: typing.Optional[bool]

    """ Reported rather than primary record.
    Type `bool`. """

    reportedReference: typing.Optional["Reference"]

    """ Reported rather than primary record.
    Type `Reference` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Medication to be taken.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ Medication to be taken.
    Type `Reference` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who or group medication request is for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of encounter/admission/stay.
    Type `Reference` (represented as `dict` in JSON). """

    supportingInformation: typing.Optional[typing.List["Reference"]]

    """ Information to support ordering of the medication.
    List of `Reference` items (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ When request was initially authored.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Who/What requested the Request.
    Type `Reference` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Intended performer of administration.
    Type `Reference` (represented as `dict` in JSON). """

    performerType: typing.Optional["CodeableConcept"]

    """ Desired kind of performer of the medication administration.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    recorder: typing.Optional["Reference"]

    """ Person who entered the request.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason or indication for ordering or not ordering the medication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Condition or observation that supports why the prescription is
        being written.
    List of `Reference` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ What request fulfills.
    List of `Reference` items (represented as `dict` in JSON). """

    groupIdentifier: typing.Optional["Identifier"]

    """ Composite request this is part of.
    Type `Identifier` (represented as `dict` in JSON). """

    courseOfTherapyType: typing.Optional["CodeableConcept"]

    """ Overall pattern of medication administration.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["Reference"]]

    """ Associated insurance coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Information about the prescription.
    List of `Annotation` items (represented as `dict` in JSON). """

    dosageInstruction: typing.Optional[typing.List["Dosage"]]

    """ How the medication should be taken.
    List of `Dosage` items (represented as `dict` in JSON). """

    dispenseRequest: typing.Optional["MedicationRequestDispenseRequest"]

    """ Medication supply authorization.
    Type `MedicationRequestDispenseRequest` (represented as `dict` in JSON). """

    substitution: typing.Optional["MedicationRequestSubstitution"]

    """ Any restrictions on medication substitution.
    Type `MedicationRequestSubstitution` (represented as `dict` in JSON). """

    priorPrescription: typing.Optional["Reference"]

    """ An order/prescription that is being replaced.
    Type `Reference` (represented as `dict` in JSON). """

    detectedIssue: typing.Optional[typing.List["Reference"]]

    """ Clinical Issue with action.
    List of `Reference` items (represented as `dict` in JSON). """

    eventHistory: typing.Optional[typing.List["Reference"]]

    """ A list of events of interest in the lifecycle.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'MedicationRequest.reported[x]', 'choice_of_type': 'reported', 'orig_name': 'reportedBoolean', 'name': 'reportedBoolean', 'parent_name': 'MedicationRequest', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Reported rather than primary record', 'formal': "Indicates if this record was captured as a secondary 'reported' record rather than as an original primary source-of-truth record.  It may also indicate the source of the report.", 'representation': None}

    _reported_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['reportedBoolean', 'reportedReference']), True))

#   {'path': 'MedicationRequest.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicationRequest', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Medication to be taken', 'formal': 'Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.', 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))


    

     
    



class MedicationStatement(DomainResource):
    """ Record of medication being taken by a patient.
    
    A record of a medication that is being consumed by a patient.   A
    MedicationStatement may indicate that the patient may be taking the
    medication now or has taken the medication in the past or will be taking
    the medication in the future.  The source of this information can be the
    patient, significant other (such as a family member or spouse), or a
    clinician.  A common scenario where this information is captured is during
    the history taking process during a patient visit or stay.   The medication
    information may come from sources such as the patient's memory, from a
    prescription bottle,  or from a list of medications the patient, clinician
    or other party maintains.
    
    The primary difference between a medication statement and a medication
    administration is that the medication administration has complete
    administration information and is based on actual administration
    information from the person who administered the medication.  A medication
    statement is often, if not always, less specific.  There is no required
    date/time when the medication was administered, in fact we only know that a
    source has reported the patient is taking this medication, where details
    such as time, quantity, or rate or even medication product may be
    incomplete or missing or less precise.  As stated earlier, the medication
    statement information may come from the patient's memory, from a
    prescription bottle or from a list of medications the patient, clinician or
    other party maintains.  Medication administration is more formal and is not
    missing detailed information.
    """
    
    resource_type = "MedicationStatement"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='effectiveDateTime' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='dateAsserted' >, <FHIRClassProperty self.name='informationSource' >, <FHIRClassProperty self.name='derivedFrom' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='dosage' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfils plan, proposal or order.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ active | completed | entered-in-error | intended | stopped | on-
        hold | unknown | not-taken.
    Type `str`. """

    statusReason: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason for current status.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Type of medication usage.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ What medication was taken.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ What medication was taken.
    Type `Reference` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who is/was taking  the medication.
    Type `Reference` (represented as `dict` in JSON). """

    context: typing.Optional["Reference"]

    """ Encounter / Episode associated with MedicationStatement.
    Type `Reference` (represented as `dict` in JSON). """

    effectiveDateTime: typing.Optional["FHIRDate"]

    """ The date/time or interval when the medication is/was/will be taken.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ The date/time or interval when the medication is/was/will be taken.
    Type `Period` (represented as `dict` in JSON). """

    dateAsserted: typing.Optional["FHIRDate"]

    """ When the statement was asserted?.
    Type `FHIRDate` (represented as `str` in JSON). """

    informationSource: typing.Optional["Reference"]

    """ Person or organization that provided the information about the
        taking of this medication.
    Type `Reference` (represented as `dict` in JSON). """

    derivedFrom: typing.Optional[typing.List["Reference"]]

    """ Additional supporting information.
    List of `Reference` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason for why the medication is being/was taken.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Condition or observation that supports why the medication is
        being/was taken.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Further information about the statement.
    List of `Annotation` items (represented as `dict` in JSON). """

    dosage: typing.Optional[typing.List["Dosage"]]

    """ Details of how medication is/was taken or should be taken.
    List of `Dosage` items (represented as `dict` in JSON). """



#   {'path': 'MedicationStatement.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicationStatement', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What medication was taken', 'formal': 'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.', 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))

#   {'path': 'MedicationStatement.effective[x]', 'choice_of_type': 'effective', 'orig_name': 'effectiveDateTime', 'name': 'effectiveDateTime', 'parent_name': 'MedicationStatement', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The date/time or interval when the medication is/was/will be taken', 'formal': 'The interval of time during which it is being asserted that the patient is/was/will be taking the medication (or was not taking, when the MedicationStatement.taken element is No).', 'representation': None}

    _effective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['effectiveDateTime', 'effectivePeriod']), True))


    

     
    



class MedicinalProduct(DomainResource):
    """ Detailed definition of a medicinal product, typically for uses other than
    direct patient care (e.g. regulatory use).
    """
    
    resource_type = "MedicinalProduct"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='domain' >, <FHIRClassProperty self.name='combinedPharmaceuticalDoseForm' >, <FHIRClassProperty self.name='legalStatusOfSupply' >, <FHIRClassProperty self.name='additionalMonitoringIndicator' >, <FHIRClassProperty self.name='specialMeasures' >, <FHIRClassProperty self.name='paediatricUseIndicator' >, <FHIRClassProperty self.name='productClassification' >, <FHIRClassProperty self.name='marketingStatus' >, <FHIRClassProperty self.name='pharmaceuticalProduct' >, <FHIRClassProperty self.name='packagedMedicinalProduct' >, <FHIRClassProperty self.name='attachedDocument' >, <FHIRClassProperty self.name='masterFile' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='clinicalTrial' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='crossReference' >, <FHIRClassProperty self.name='manufacturingBusinessOperation' >, <FHIRClassProperty self.name='specialDesignation' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier for this product. Could be an MPID.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Regulatory type, e.g. Investigational or Authorized.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    domain: typing.Optional["Coding"]

    """ If this medicine applies to human or veterinary uses.
    Type `Coding` (represented as `dict` in JSON). """

    combinedPharmaceuticalDoseForm: typing.Optional["CodeableConcept"]

    """ The dose form for a single part product, or combined form of a
        multiple part product.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    legalStatusOfSupply: typing.Optional["CodeableConcept"]

    """ The legal status of supply of the medicinal product as classified
        by the regulator.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additionalMonitoringIndicator: typing.Optional["CodeableConcept"]

    """ Whether the Medicinal Product is subject to additional monitoring
        for regulatory reasons.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    specialMeasures: typing.Optional[typing.List[str]]

    """ Whether the Medicinal Product is subject to special measures for
        regulatory reasons.
    List of `str` items. """

    paediatricUseIndicator: typing.Optional["CodeableConcept"]

    """ If authorised for use in children.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productClassification: typing.Optional[typing.List["CodeableConcept"]]

    """ Allows the product to be classified by various systems.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    marketingStatus: typing.Optional[typing.List["MarketingStatus"]]

    """ Marketing status of the medicinal product, in contrast to marketing
        authorizaton.
    List of `MarketingStatus` items (represented as `dict` in JSON). """

    pharmaceuticalProduct: typing.Optional[typing.List["Reference"]]

    """ Pharmaceutical aspects of product.
    List of `Reference` items (represented as `dict` in JSON). """

    packagedMedicinalProduct: typing.Optional[typing.List["Reference"]]

    """ Package representation for the product.
    List of `Reference` items (represented as `dict` in JSON). """

    attachedDocument: typing.Optional[typing.List["Reference"]]

    """ Supporting documentation, typically for regulatory submission.
    List of `Reference` items (represented as `dict` in JSON). """

    masterFile: typing.Optional[typing.List["Reference"]]

    """ A master file for to the medicinal product (e.g. Pharmacovigilance
        System Master File).
    List of `Reference` items (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["Reference"]]

    """ A product specific contact, person (in a role), or an organization.
    List of `Reference` items (represented as `dict` in JSON). """

    clinicalTrial: typing.Optional[typing.List["Reference"]]

    """ Clinical trials or studies that this product is involved in.
    List of `Reference` items (represented as `dict` in JSON). """

    name: typing.List["MedicinalProductName"]

    """ The product's name, including full name and possibly coded parts.
    List of `MedicinalProductName` items (represented as `dict` in JSON). """

    crossReference: typing.Optional[typing.List["Identifier"]]

    """ Reference to another product, e.g. for linking authorised to
        investigational product.
    List of `Identifier` items (represented as `dict` in JSON). """

    manufacturingBusinessOperation: typing.Optional[typing.List["MedicinalProductManufacturingBusinessOperation"]]

    """ An operation applied to the product, for manufacturing or
        adminsitrative purpose.
    List of `MedicinalProductManufacturingBusinessOperation` items (represented as `dict` in JSON). """

    specialDesignation: typing.Optional[typing.List["MedicinalProductSpecialDesignation"]]

    """ Indicates if the medicinal product has an orphan designation for
        the treatment of a rare disease.
    List of `MedicinalProductSpecialDesignation` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductAuthorization(DomainResource):
    """ The regulatory authorization of a medicinal product.
    """
    
    resource_type = "MedicinalProductAuthorization"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusDate' >, <FHIRClassProperty self.name='restoreDate' >, <FHIRClassProperty self.name='validityPeriod' >, <FHIRClassProperty self.name='dataExclusivityPeriod' >, <FHIRClassProperty self.name='dateOfFirstAuthorization' >, <FHIRClassProperty self.name='internationalBirthDate' >, <FHIRClassProperty self.name='legalBasis' >, <FHIRClassProperty self.name='jurisdictionalAuthorization' >, <FHIRClassProperty self.name='holder' >, <FHIRClassProperty self.name='regulator' >, <FHIRClassProperty self.name='procedure' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier for the marketing authorization, as assigned by
        a regulator.
    List of `Identifier` items (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ The medicinal product that is being authorized.
    Type `Reference` (represented as `dict` in JSON). """

    country: typing.Optional[typing.List["CodeableConcept"]]

    """ The country in which the marketing authorization has been granted.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Jurisdiction within a country.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ The status of the marketing authorization.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    statusDate: typing.Optional["FHIRDate"]

    """ The date at which the given status has become applicable.
    Type `FHIRDate` (represented as `str` in JSON). """

    restoreDate: typing.Optional["FHIRDate"]

    """ The date when a suspended the marketing or the marketing
        authorization of the product is anticipated to be restored.
    Type `FHIRDate` (represented as `str` in JSON). """

    validityPeriod: typing.Optional["Period"]

    """ The beginning of the time period in which the marketing
        authorization is in the specific status shall be specified A
        complete date consisting of day, month and year shall be specified
        using the ISO 8601 date format.
    Type `Period` (represented as `dict` in JSON). """

    dataExclusivityPeriod: typing.Optional["Period"]

    """ A period of time after authorization before generic product
        applicatiosn can be submitted.
    Type `Period` (represented as `dict` in JSON). """

    dateOfFirstAuthorization: typing.Optional["FHIRDate"]

    """ The date when the first authorization was granted by a Medicines
        Regulatory Agency.
    Type `FHIRDate` (represented as `str` in JSON). """

    internationalBirthDate: typing.Optional["FHIRDate"]

    """ Date of first marketing authorization for a company's new medicinal
        product in any country in the World.
    Type `FHIRDate` (represented as `str` in JSON). """

    legalBasis: typing.Optional["CodeableConcept"]

    """ The legal framework against which this authorization is granted.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    jurisdictionalAuthorization: typing.Optional[typing.List["MedicinalProductAuthorizationJurisdictionalAuthorization"]]

    """ Authorization in areas within a country.
    List of `MedicinalProductAuthorizationJurisdictionalAuthorization` items (represented as `dict` in JSON). """

    holder: typing.Optional["Reference"]

    """ Marketing Authorization Holder.
    Type `Reference` (represented as `dict` in JSON). """

    regulator: typing.Optional["Reference"]

    """ Medicines Regulatory Agency.
    Type `Reference` (represented as `dict` in JSON). """

    procedure: typing.Optional["MedicinalProductAuthorizationProcedure"]

    """ The regulatory procedure for granting or amending a marketing
        authorization.
    Type `MedicinalProductAuthorizationProcedure` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductContraindication(DomainResource):
    """ MedicinalProductContraindication.
    
    The clinical particulars - indications, contraindications etc. of a
    medicinal product, including for regulatory purposes.
    """
    
    resource_type = "MedicinalProductContraindication"
    
    # [<FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='disease' >, <FHIRClassProperty self.name='diseaseStatus' >, <FHIRClassProperty self.name='comorbidity' >, <FHIRClassProperty self.name='therapeuticIndication' >, <FHIRClassProperty self.name='otherTherapy' >, <FHIRClassProperty self.name='population' >]
  

    subject: typing.Optional[typing.List["Reference"]]

    """ The medication for which this is an indication.
    List of `Reference` items (represented as `dict` in JSON). """

    disease: typing.Optional["CodeableConcept"]

    """ The disease, symptom or procedure for the contraindication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diseaseStatus: typing.Optional["CodeableConcept"]

    """ The status of the disease or symptom for the contraindication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    comorbidity: typing.Optional[typing.List["CodeableConcept"]]

    """ A comorbidity (concurrent condition) or coinfection.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    therapeuticIndication: typing.Optional[typing.List["Reference"]]

    """ Information about the use of the medicinal product in relation to
        other therapies as part of the indication.
    List of `Reference` items (represented as `dict` in JSON). """

    otherTherapy: typing.Optional[typing.List["MedicinalProductContraindicationOtherTherapy"]]

    """ Information about the use of the medicinal product in relation to
        other therapies described as part of the indication.
    List of `MedicinalProductContraindicationOtherTherapy` items (represented as `dict` in JSON). """

    population: typing.Optional[typing.List["Population"]]

    """ The population group to which this applies.
    List of `Population` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductIndication(DomainResource):
    """ MedicinalProductIndication.
    
    Indication for the Medicinal Product.
    """
    
    resource_type = "MedicinalProductIndication"
    
    # [<FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='diseaseSymptomProcedure' >, <FHIRClassProperty self.name='diseaseStatus' >, <FHIRClassProperty self.name='comorbidity' >, <FHIRClassProperty self.name='intendedEffect' >, <FHIRClassProperty self.name='duration' >, <FHIRClassProperty self.name='otherTherapy' >, <FHIRClassProperty self.name='undesirableEffect' >, <FHIRClassProperty self.name='population' >]
  

    subject: typing.Optional[typing.List["Reference"]]

    """ The medication for which this is an indication.
    List of `Reference` items (represented as `dict` in JSON). """

    diseaseSymptomProcedure: typing.Optional["CodeableConcept"]

    """ The disease, symptom or procedure that is the indication for
        treatment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diseaseStatus: typing.Optional["CodeableConcept"]

    """ The status of the disease or symptom for which the indication
        applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    comorbidity: typing.Optional[typing.List["CodeableConcept"]]

    """ Comorbidity (concurrent condition) or co-infection as part of the
        indication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    intendedEffect: typing.Optional["CodeableConcept"]

    """ The intended effect, aim or strategy to be achieved by the
        indication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    duration: typing.Optional["Quantity"]

    """ Timing or duration information as part of the indication.
    Type `Quantity` (represented as `dict` in JSON). """

    otherTherapy: typing.Optional[typing.List["MedicinalProductIndicationOtherTherapy"]]

    """ Information about the use of the medicinal product in relation to
        other therapies described as part of the indication.
    List of `MedicinalProductIndicationOtherTherapy` items (represented as `dict` in JSON). """

    undesirableEffect: typing.Optional[typing.List["Reference"]]

    """ Describe the undesirable effects of the medicinal product.
    List of `Reference` items (represented as `dict` in JSON). """

    population: typing.Optional[typing.List["Population"]]

    """ The population group to which this applies.
    List of `Population` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductIngredient(DomainResource):
    """ An ingredient of a manufactured item or pharmaceutical product.
    """
    
    resource_type = "MedicinalProductIngredient"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='allergenicIndicator' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='specifiedSubstance' >, <FHIRClassProperty self.name='substance' >]
  

    identifier: typing.Optional["Identifier"]

    """ Identifier for the ingredient.
    Type `Identifier` (represented as `dict` in JSON). """

    role: "CodeableConcept"

    """ Ingredient role e.g. Active ingredient, excipient.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    allergenicIndicator: typing.Optional[bool]

    """ If the ingredient is a known or suspected allergen.
    Type `bool`. """

    manufacturer: typing.Optional[typing.List["Reference"]]

    """ Manufacturer of this Ingredient.
    List of `Reference` items (represented as `dict` in JSON). """

    specifiedSubstance: typing.Optional[typing.List["MedicinalProductIngredientSpecifiedSubstance"]]

    """ A specified substance that comprises this ingredient.
    List of `MedicinalProductIngredientSpecifiedSubstance` items (represented as `dict` in JSON). """

    substance: typing.Optional["MedicinalProductIngredientSubstance"]

    """ The ingredient substance.
    Type `MedicinalProductIngredientSubstance` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductInteraction(DomainResource):
    """ MedicinalProductInteraction.
    
    The interactions of the medicinal product with other medicinal products, or
    other forms of interactions.
    """
    
    resource_type = "MedicinalProductInteraction"
    
    # [<FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='interactant' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='effect' >, <FHIRClassProperty self.name='incidence' >, <FHIRClassProperty self.name='management' >]
  

    subject: typing.Optional[typing.List["Reference"]]

    """ The medication for which this is a described interaction.
    List of `Reference` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ The interaction described.
    Type `str`. """

    interactant: typing.Optional[typing.List["MedicinalProductInteractionInteractant"]]

    """ The specific medication, food or laboratory test that interacts.
    List of `MedicinalProductInteractionInteractant` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ The type of the interaction e.g. drug-drug interaction, drug-food
        interaction, drug-lab test interaction.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    effect: typing.Optional["CodeableConcept"]

    """ The effect of the interaction, for example "reduced gastric
        absorption of primary medication".
    Type `CodeableConcept` (represented as `dict` in JSON). """

    incidence: typing.Optional["CodeableConcept"]

    """ The incidence of the interaction, e.g. theoretical, observed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    management: typing.Optional["CodeableConcept"]

    """ Actions for managing the interaction.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductManufactured(DomainResource):
    """ The manufactured item as contained in the packaged medicinal product.
    """
    
    resource_type = "MedicinalProductManufactured"
    
    # [<FHIRClassProperty self.name='manufacturedDoseForm' >, <FHIRClassProperty self.name='unitOfPresentation' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='ingredient' >, <FHIRClassProperty self.name='physicalCharacteristics' >, <FHIRClassProperty self.name='otherCharacteristics' >]
  

    manufacturedDoseForm: "CodeableConcept"

    """ Dose form as manufactured and before any transformation into the
        pharmaceutical product.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unitOfPresentation: typing.Optional["CodeableConcept"]

    """ The “real world” units in which the quantity of the manufactured
        item is described.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    quantity: "Quantity"

    """ The quantity or "count number" of the manufactured item.
    Type `Quantity` (represented as `dict` in JSON). """

    manufacturer: typing.Optional[typing.List["Reference"]]

    """ Manufacturer of the item (Note that this should be named
        "manufacturer" but it currently causes technical issues).
    List of `Reference` items (represented as `dict` in JSON). """

    ingredient: typing.Optional[typing.List["Reference"]]

    """ Ingredient.
    List of `Reference` items (represented as `dict` in JSON). """

    physicalCharacteristics: typing.Optional["ProdCharacteristic"]

    """ Dimensions, color etc..
    Type `ProdCharacteristic` (represented as `dict` in JSON). """

    otherCharacteristics: typing.Optional[typing.List["CodeableConcept"]]

    """ Other codeable characteristics.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPackaged(DomainResource):
    """ A medicinal product in a container or package.
    """
    
    resource_type = "MedicinalProductPackaged"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='legalStatusOfSupply' >, <FHIRClassProperty self.name='marketingStatus' >, <FHIRClassProperty self.name='marketingAuthorization' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='batchIdentifier' >, <FHIRClassProperty self.name='packageItem' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    subject: typing.Optional[typing.List["Reference"]]

    """ The product with this is a pack for.
    List of `Reference` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Textual description.
    Type `str`. """

    legalStatusOfSupply: typing.Optional["CodeableConcept"]

    """ The legal status of supply of the medicinal product as classified
        by the regulator.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    marketingStatus: typing.Optional[typing.List["MarketingStatus"]]

    """ Marketing information.
    List of `MarketingStatus` items (represented as `dict` in JSON). """

    marketingAuthorization: typing.Optional["Reference"]

    """ Manufacturer of this Package Item.
    Type `Reference` (represented as `dict` in JSON). """

    manufacturer: typing.Optional[typing.List["Reference"]]

    """ Manufacturer of this Package Item.
    List of `Reference` items (represented as `dict` in JSON). """

    batchIdentifier: typing.Optional[typing.List["MedicinalProductPackagedBatchIdentifier"]]

    """ Batch numbering.
    List of `MedicinalProductPackagedBatchIdentifier` items (represented as `dict` in JSON). """

    packageItem: typing.List["MedicinalProductPackagedPackageItem"]

    """ A packaging item, as a contained for medicine, possibly with other
        packaging items within.
    List of `MedicinalProductPackagedPackageItem` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPharmaceutical(DomainResource):
    """ A pharmaceutical product described in terms of its composition and dose
    form.
    """
    
    resource_type = "MedicinalProductPharmaceutical"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='administrableDoseForm' >, <FHIRClassProperty self.name='unitOfPresentation' >, <FHIRClassProperty self.name='ingredient' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='characteristics' >, <FHIRClassProperty self.name='routeOfAdministration' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ An identifier for the pharmaceutical medicinal product.
    List of `Identifier` items (represented as `dict` in JSON). """

    administrableDoseForm: "CodeableConcept"

    """ The administrable dose form, after necessary reconstitution.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unitOfPresentation: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    ingredient: typing.Optional[typing.List["Reference"]]

    """ Ingredient.
    List of `Reference` items (represented as `dict` in JSON). """

    device: typing.Optional[typing.List["Reference"]]

    """ Accompanying device.
    List of `Reference` items (represented as `dict` in JSON). """

    characteristics: typing.Optional[typing.List["MedicinalProductPharmaceuticalCharacteristics"]]

    """ Characteristics e.g. a products onset of action.
    List of `MedicinalProductPharmaceuticalCharacteristics` items (represented as `dict` in JSON). """

    routeOfAdministration: typing.List["MedicinalProductPharmaceuticalRouteOfAdministration"]

    """ The path by which the pharmaceutical product is taken into or makes
        contact with the body.
    List of `MedicinalProductPharmaceuticalRouteOfAdministration` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductUndesirableEffect(DomainResource):
    """ MedicinalProductUndesirableEffect.
    
    Describe the undesirable effects of the medicinal product.
    """
    
    resource_type = "MedicinalProductUndesirableEffect"
    
    # [<FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='symptomConditionEffect' >, <FHIRClassProperty self.name='classification' >, <FHIRClassProperty self.name='frequencyOfOccurrence' >, <FHIRClassProperty self.name='population' >]
  

    subject: typing.Optional[typing.List["Reference"]]

    """ The medication for which this is an indication.
    List of `Reference` items (represented as `dict` in JSON). """

    symptomConditionEffect: typing.Optional["CodeableConcept"]

    """ The symptom, condition or undesirable effect.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    classification: typing.Optional["CodeableConcept"]

    """ Classification of the effect.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    frequencyOfOccurrence: typing.Optional["CodeableConcept"]

    """ The frequency of occurrence of the effect.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    population: typing.Optional[typing.List["Population"]]

    """ The population group to which this applies.
    List of `Population` items (represented as `dict` in JSON). """




    

     
    



class MessageDefinition(DomainResource):
    """ A resource that defines a type of message that can be exchanged between
    systems.
    
    Defines the characteristics of a message that can be shared between
    systems, including the type of event that initiates the message, the
    content to be transmitted and what response(s), if any, are permitted.
    """
    
    resource_type = "MessageDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='base' >, <FHIRClassProperty self.name='parent' >, <FHIRClassProperty self.name='eventCoding' >, <FHIRClassProperty self.name='eventUri' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='responseRequired' >, <FHIRClassProperty self.name='allowedResponse' >, <FHIRClassProperty self.name='graph' >]
  

    url: typing.Optional[str]

    """ Business Identifier for a given MessageDefinition.
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Primary key for the message definition on a given server.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the message definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this message definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this message definition (human friendly).
    Type `str`. """

    replaces: typing.Optional[typing.List[str]]

    """ Takes the place of.
    List of `str` items. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: "FHIRDate"

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the message definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for message definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this message definition is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    base: typing.Optional[str]

    """ Definition this one is based on.
    Type `str`. """

    parent: typing.Optional[typing.List[str]]

    """ Protocol/workflow this is part of.
    List of `str` items. """

    eventCoding: typing.Optional["Coding"]

    """ Event code  or link to the EventDefinition.
    Type `Coding` (represented as `dict` in JSON). """

    eventUri: typing.Optional[str]

    """ Event code  or link to the EventDefinition.
    Type `str`. """

    category: typing.Optional["str"]

    """ consequence | currency | notification.
    Type `str`. """

    focus: typing.Optional[typing.List["MessageDefinitionFocus"]]

    """ Resource(s) that are the subject of the event.
    List of `MessageDefinitionFocus` items (represented as `dict` in JSON). """

    responseRequired: typing.Optional["str"]

    """ always | on-error | never | on-success.
    Type `str`. """

    allowedResponse: typing.Optional[typing.List["MessageDefinitionAllowedResponse"]]

    """ Responses to this message.
    List of `MessageDefinitionAllowedResponse` items (represented as `dict` in JSON). """

    graph: typing.Optional[typing.List[str]]

    """ Canonical reference to a GraphDefinition.
    List of `str` items. """



#   {'path': 'MessageDefinition.event[x]', 'choice_of_type': 'event', 'orig_name': 'eventCoding', 'name': 'eventCoding', 'parent_name': 'MessageDefinition', 'class_name': 'Coding', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Event code  or link to the EventDefinition', 'formal': 'Event code or link to the EventDefinition.', 'representation': None}

    _event_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['eventCoding', 'eventUri']), False))


    

     
    



class MessageHeader(DomainResource):
    """ A resource that describes a message that is exchanged between systems.
    
    The header for a message exchange that is either requesting or responding
    to an action.  The reference(s) that are the subject of the action as well
    as other information related to the action are typically transmitted in a
    bundle in which the MessageHeader resource instance is the first resource
    in the bundle.
    """
    
    resource_type = "MessageHeader"
    
    # [<FHIRClassProperty self.name='eventCoding' >, <FHIRClassProperty self.name='eventUri' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='sender' >, <FHIRClassProperty self.name='enterer' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='response' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='definition' >]
  

    eventCoding: typing.Optional["Coding"]

    """ Code for the event this message represents or link to event
        definition.
    Type `Coding` (represented as `dict` in JSON). """

    eventUri: typing.Optional[str]

    """ Code for the event this message represents or link to event
        definition.
    Type `str`. """

    destination: typing.Optional[typing.List["MessageHeaderDestination"]]

    """ Message destination application(s).
    List of `MessageHeaderDestination` items (represented as `dict` in JSON). """

    sender: typing.Optional["Reference"]

    """ Real world sender of the message.
    Type `Reference` (represented as `dict` in JSON). """

    enterer: typing.Optional["Reference"]

    """ The source of the data entry.
    Type `Reference` (represented as `dict` in JSON). """

    author: typing.Optional["Reference"]

    """ The source of the decision.
    Type `Reference` (represented as `dict` in JSON). """

    source: "MessageHeaderSource"

    """ Message source application.
    Type `MessageHeaderSource` (represented as `dict` in JSON). """

    responsible: typing.Optional["Reference"]

    """ Final responsibility for event.
    Type `Reference` (represented as `dict` in JSON). """

    reason: typing.Optional["CodeableConcept"]

    """ Cause of event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    response: typing.Optional["MessageHeaderResponse"]

    """ If this is a reply to prior message.
    Type `MessageHeaderResponse` (represented as `dict` in JSON). """

    focus: typing.Optional[typing.List["Reference"]]

    """ The actual content of the message.
    List of `Reference` items (represented as `dict` in JSON). """

    definition: typing.Optional[str]

    """ Link to the definition for this message.
    Type `str`. """



#   {'path': 'MessageHeader.event[x]', 'choice_of_type': 'event', 'orig_name': 'eventCoding', 'name': 'eventCoding', 'parent_name': 'MessageHeader', 'class_name': 'Coding', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Code for the event this message represents or link to event definition', 'formal': 'Code that identifies the event this message represents and connects it with its definition. Events defined as part of the FHIR specification have the system value "http://terminology.hl7.org/CodeSystem/message-events".  Alternatively uri to the EventDefinition.', 'representation': None}

    _event_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['eventCoding', 'eventUri']), False))


    

     
    



class MolecularSequence(DomainResource):
    """ Information about a biological sequence.
    
    Raw data describing a biological sequence.
    """
    
    resource_type = "MolecularSequence"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='coordinateSystem' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='specimen' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='referenceSeq' >, <FHIRClassProperty self.name='variant' >, <FHIRClassProperty self.name='observedSeq' >, <FHIRClassProperty self.name='quality' >, <FHIRClassProperty self.name='readCoverage' >, <FHIRClassProperty self.name='repository' >, <FHIRClassProperty self.name='pointer' >, <FHIRClassProperty self.name='structureVariant' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique ID for this particular sequence. This is a FHIR-defined id.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: typing.Optional["str"]

    """ aa | dna | rna.
    Type `str`. """

    coordinateSystem: int

    """ Base number of coordinate system (0 for 0-based numbering or
        coordinates, inclusive start, exclusive end, 1 for 1-based
        numbering, inclusive start, inclusive end).
    Type `int`. """

    patient: typing.Optional["Reference"]

    """ Who and/or what this is about.
    Type `Reference` (represented as `dict` in JSON). """

    specimen: typing.Optional["Reference"]

    """ Specimen used for sequencing.
    Type `Reference` (represented as `dict` in JSON). """

    device: typing.Optional["Reference"]

    """ The method for sequencing.
    Type `Reference` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Who should be responsible for test result.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ The number of copies of the sequence of interest.  (RNASeq).
    Type `Quantity` (represented as `dict` in JSON). """

    referenceSeq: typing.Optional["MolecularSequenceReferenceSeq"]

    """ A sequence used as reference.
    Type `MolecularSequenceReferenceSeq` (represented as `dict` in JSON). """

    variant: typing.Optional[typing.List["MolecularSequenceVariant"]]

    """ Variant in sequence.
    List of `MolecularSequenceVariant` items (represented as `dict` in JSON). """

    observedSeq: typing.Optional[str]

    """ Sequence that was observed.
    Type `str`. """

    quality: typing.Optional[typing.List["MolecularSequenceQuality"]]

    """ An set of value as quality of sequence.
    List of `MolecularSequenceQuality` items (represented as `dict` in JSON). """

    readCoverage: typing.Optional[int]

    """ Average number of reads representing a given nucleotide in the
        reconstructed sequence.
    Type `int`. """

    repository: typing.Optional[typing.List["MolecularSequenceRepository"]]

    """ External repository which contains detailed report related with
        observedSeq in this resource.
    List of `MolecularSequenceRepository` items (represented as `dict` in JSON). """

    pointer: typing.Optional[typing.List["Reference"]]

    """ Pointer to next atomic sequence.
    List of `Reference` items (represented as `dict` in JSON). """

    structureVariant: typing.Optional[typing.List["MolecularSequenceStructureVariant"]]

    """ Structural variant.
    List of `MolecularSequenceStructureVariant` items (represented as `dict` in JSON). """




    

     
    



class NamingSystem(DomainResource):
    """ System of unique identification.
    
    A curated namespace that issues unique symbols within that namespace for
    the identification of concepts, people, devices, etc.  Represents a
    "System" used within the Identifier and Coding data types.
    """
    
    resource_type = "NamingSystem"
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='uniqueId' >]
  

    name: str

    """ Name for this naming system (computer friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    kind: "str"

    """ codesystem | identifier | root.
    Type `str`. """

    date: "FHIRDate"

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    responsible: typing.Optional[str]

    """ Who maintains system namespace?.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ e.g. driver,  provider,  patient, bank etc..
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the naming system.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for naming system (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    usage: typing.Optional[str]

    """ How/where is it used.
    Type `str`. """

    uniqueId: typing.List["NamingSystemUniqueId"]

    """ Unique identifiers used for system.
    List of `NamingSystemUniqueId` items (represented as `dict` in JSON). """




    

     
    



class NutritionOrder(DomainResource):
    """ Diet, formula or nutritional supplement request.
    
    A request to supply a diet, formula feeding (enteral) or oral nutritional
    supplement to a patient/resident.
    """
    
    resource_type = "NutritionOrder"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='instantiates' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='dateTime' >, <FHIRClassProperty self.name='orderer' >, <FHIRClassProperty self.name='allergyIntolerance' >, <FHIRClassProperty self.name='foodPreferenceModifier' >, <FHIRClassProperty self.name='excludeFoodModifier' >, <FHIRClassProperty self.name='oralDiet' >, <FHIRClassProperty self.name='supplement' >, <FHIRClassProperty self.name='enteralFormula' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifiers assigned to this order.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    instantiates: typing.Optional[typing.List[str]]

    """ Instantiates protocol or definition.
    List of `str` items. """

    status: "str"

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    intent: "str"

    """ proposal | plan | directive | order | original-order | reflex-order
        | filler-order | instance-order | option.
    Type `str`. """

    patient: "Reference"

    """ The person who requires the diet, formula or nutritional supplement.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ The encounter associated with this nutrition order.
    Type `Reference` (represented as `dict` in JSON). """

    dateTime: "FHIRDate"

    """ Date and time the nutrition order was requested.
    Type `FHIRDate` (represented as `str` in JSON). """

    orderer: typing.Optional["Reference"]

    """ Who ordered the diet, formula or nutritional supplement.
    Type `Reference` (represented as `dict` in JSON). """

    allergyIntolerance: typing.Optional[typing.List["Reference"]]

    """ List of the patient's food and nutrition-related allergies and
        intolerances.
    List of `Reference` items (represented as `dict` in JSON). """

    foodPreferenceModifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Order-specific modifier about the type of food that should be given.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    excludeFoodModifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Order-specific modifier about the type of food that should not be
        given.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    oralDiet: typing.Optional["NutritionOrderOralDiet"]

    """ Oral diet components.
    Type `NutritionOrderOralDiet` (represented as `dict` in JSON). """

    supplement: typing.Optional[typing.List["NutritionOrderSupplement"]]

    """ Supplement components.
    List of `NutritionOrderSupplement` items (represented as `dict` in JSON). """

    enteralFormula: typing.Optional["NutritionOrderEnteralFormula"]

    """ Enteral formula components.
    Type `NutritionOrderEnteralFormula` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class Observation(DomainResource):
    """ Measurements and simple assertions.
    
    Measurements and simple assertions made about a patient, device or other
    subject.
    """
    
    resource_type = "Observation"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='effectiveDateTime' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='effectiveTiming' >, <FHIRClassProperty self.name='effectiveInstant' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='dataAbsentReason' >, <FHIRClassProperty self.name='interpretation' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='specimen' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='referenceRange' >, <FHIRClassProperty self.name='hasMember' >, <FHIRClassProperty self.name='derivedFrom' >, <FHIRClassProperty self.name='component' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for observation.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills plan, proposal or order.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ registered | preliminary | final | amended +.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Classification of  type of observation.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Type of observation (code / type).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who and/or what the observation is about.
    Type `Reference` (represented as `dict` in JSON). """

    focus: typing.Optional[typing.List["Reference"]]

    """ What the observation is about, when it is not about the subject of
        record.
    List of `Reference` items (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Healthcare event during which this observation is made.
    Type `Reference` (represented as `dict` in JSON). """

    effectiveDateTime: typing.Optional["FHIRDate"]

    """ Clinically relevant time/time-period for observation.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ Clinically relevant time/time-period for observation.
    Type `Period` (represented as `dict` in JSON). """

    effectiveTiming: typing.Optional["Timing"]

    """ Clinically relevant time/time-period for observation.
    Type `Timing` (represented as `dict` in JSON). """

    effectiveInstant: typing.Optional["FHIRDate"]

    """ Clinically relevant time/time-period for observation.
    Type `FHIRDate` (represented as `str` in JSON). """

    issued: typing.Optional["FHIRDate"]

    """ Date/Time this version was made available.
    Type `FHIRDate` (represented as `str` in JSON). """

    performer: typing.Optional[typing.List["Reference"]]

    """ Who is responsible for the observation.
    List of `Reference` items (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Actual result.
    Type `Quantity` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Actual result.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueString: typing.Optional[str]

    """ Actual result.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Actual result.
    Type `bool`. """

    valueInteger: typing.Optional[int]

    """ Actual result.
    Type `int`. """

    valueRange: typing.Optional["Range"]

    """ Actual result.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Actual result.
    Type `Ratio` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Actual result.
    Type `SampledData` (represented as `dict` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ Actual result.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Actual result.
    Type `FHIRDate` (represented as `str` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Actual result.
    Type `Period` (represented as `dict` in JSON). """

    dataAbsentReason: typing.Optional["CodeableConcept"]

    """ Why the result is missing.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    interpretation: typing.Optional[typing.List["CodeableConcept"]]

    """ High, low, normal, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments about the observation.
    List of `Annotation` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Observed body part.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ How it was done.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    specimen: typing.Optional["Reference"]

    """ Specimen used for this observation.
    Type `Reference` (represented as `dict` in JSON). """

    device: typing.Optional["Reference"]

    """ (Measurement) Device.
    Type `Reference` (represented as `dict` in JSON). """

    referenceRange: typing.Optional[typing.List["ObservationReferenceRange"]]

    """ Provides guide for interpretation.
    List of `ObservationReferenceRange` items (represented as `dict` in JSON). """

    hasMember: typing.Optional[typing.List["Reference"]]

    """ Related resource that belongs to the Observation group.
    List of `Reference` items (represented as `dict` in JSON). """

    derivedFrom: typing.Optional[typing.List["Reference"]]

    """ Related measurements the observation is made from.
    List of `Reference` items (represented as `dict` in JSON). """

    component: typing.Optional[typing.List["ObservationComponent"]]

    """ Component results.
    List of `ObservationComponent` items (represented as `dict` in JSON). """



#   {'path': 'Observation.effective[x]', 'choice_of_type': 'effective', 'orig_name': 'effectiveDateTime', 'name': 'effectiveDateTime', 'parent_name': 'Observation', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Clinically relevant time/time-period for observation', 'formal': 'The time or time-period the observed value is asserted as being true. For biological subjects - e.g. human patients - this is usually called the "physiologically relevant time". This is usually either the time of the procedure or of specimen collection, but very often the source of the date/time is not known, only the date/time itself.', 'representation': None}

    _effective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['effectiveDateTime', 'effectivePeriod', 'effectiveTiming', 'effectiveInstant']), True))

#   {'path': 'Observation.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueQuantity', 'name': 'valueQuantity', 'parent_name': 'Observation', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Actual result', 'formal': 'The information determined as a result of making the observation, if the information has a simple value.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueQuantity', 'valueCodeableConcept', 'valueString', 'valueBoolean', 'valueInteger', 'valueRange', 'valueRatio', 'valueSampledData', 'valueTime', 'valueDateTime', 'valuePeriod']), True))


    

     
    



class ObservationDefinition(DomainResource):
    """ Definition of an observation.
    
    Set of definitional characteristics for a kind of observation or
    measurement produced or consumed by an orderable health care service.
    """
    
    resource_type = "ObservationDefinition"
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='permittedDataType' >, <FHIRClassProperty self.name='multipleResultsAllowed' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='preferredReportName' >, <FHIRClassProperty self.name='quantitativeDetails' >, <FHIRClassProperty self.name='qualifiedInterval' >, <FHIRClassProperty self.name='validCodedValueSet' >, <FHIRClassProperty self.name='normalCodedValueSet' >, <FHIRClassProperty self.name='abnormalCodedValueSet' >, <FHIRClassProperty self.name='criticalCodedValueSet' >]
  

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Category of observation.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Type of observation (code / type).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier for this ObservationDefinition instance.
    List of `Identifier` items (represented as `dict` in JSON). """

    permittedDataType: typing.Optional[typing.List["str"]]

    """ Quantity | CodeableConcept | string | boolean | integer | Range |
        Ratio | SampledData | time | dateTime | Period.
    List of `str` items. """

    multipleResultsAllowed: typing.Optional[bool]

    """ Multiple results allowed.
    Type `bool`. """

    method: typing.Optional["CodeableConcept"]

    """ Method used to produce the observation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    preferredReportName: typing.Optional[str]

    """ Preferred report name.
    Type `str`. """

    quantitativeDetails: typing.Optional["ObservationDefinitionQuantitativeDetails"]

    """ Characteristics of quantitative results.
    Type `ObservationDefinitionQuantitativeDetails` (represented as `dict` in JSON). """

    qualifiedInterval: typing.Optional[typing.List["ObservationDefinitionQualifiedInterval"]]

    """ Qualified range for continuous and ordinal observation results.
    List of `ObservationDefinitionQualifiedInterval` items (represented as `dict` in JSON). """

    validCodedValueSet: typing.Optional["Reference"]

    """ Value set of valid coded values for the observations conforming to
        this ObservationDefinition.
    Type `Reference` (represented as `dict` in JSON). """

    normalCodedValueSet: typing.Optional["Reference"]

    """ Value set of normal coded values for the observations conforming to
        this ObservationDefinition.
    Type `Reference` (represented as `dict` in JSON). """

    abnormalCodedValueSet: typing.Optional["Reference"]

    """ Value set of abnormal coded values for the observations conforming
        to this ObservationDefinition.
    Type `Reference` (represented as `dict` in JSON). """

    criticalCodedValueSet: typing.Optional["Reference"]

    """ Value set of critical coded values for the observations conforming
        to this ObservationDefinition.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class OperationDefinition(DomainResource):
    """ Definition of an operation or a named query.
    
    A formal computable definition of an operation (on the RESTful interface)
    or a named query (using the search interaction).
    """
    
    resource_type = "OperationDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='affectsState' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='base' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='instance' >, <FHIRClassProperty self.name='inputProfile' >, <FHIRClassProperty self.name='outputProfile' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='overload' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this operation definition, represented as
        a URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the operation definition.
    Type `str`. """

    name: str

    """ Name for this operation definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this operation definition (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    kind: "str"

    """ operation | query.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the operation definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for operation definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this operation definition is defined.
    Type `str`. """

    affectsState: typing.Optional[bool]

    """ Whether content is changed by the operation.
    Type `bool`. """

    code: str

    """ Name used to invoke the operation.
    Type `str`. """

    comment: typing.Optional[str]

    """ Additional information about use.
    Type `str`. """

    base: typing.Optional[str]

    """ Marks this as a profile of the base.
    Type `str`. """

    resource: typing.Optional[typing.List["str"]]

    """ Types this operation applies to.
    List of `str` items. """

    system: bool

    """ Invoke at the system level?.
    Type `bool`. """

    type: bool

    """ Invoke at the type level?.
    Type `bool`. """

    instance: bool

    """ Invoke on an instance?.
    Type `bool`. """

    inputProfile: typing.Optional[str]

    """ Validation information for in parameters.
    Type `str`. """

    outputProfile: typing.Optional[str]

    """ Validation information for out parameters.
    Type `str`. """

    parameter: typing.Optional[typing.List["OperationDefinitionParameter"]]

    """ Parameters for the operation/query.
    List of `OperationDefinitionParameter` items (represented as `dict` in JSON). """

    overload: typing.Optional[typing.List["OperationDefinitionOverload"]]

    """ Define overloaded variants for when  generating code.
    List of `OperationDefinitionOverload` items (represented as `dict` in JSON). """




    

     
    



class OperationOutcome(DomainResource):
    """ Information about the success/failure of an action.
    
    A collection of error, warning, or information messages that result from a
    system action.
    """
    
    resource_type = "OperationOutcome"
    
    # [<FHIRClassProperty self.name='issue' >]
  

    issue: typing.List["OperationOutcomeIssue"]

    """ A single issue associated with the action.
    List of `OperationOutcomeIssue` items (represented as `dict` in JSON). """




    

     
    



class Organization(DomainResource):
    """ A grouping of people or organizations with a common purpose.
    
    A formally or informally recognized grouping of people or organizations
    formed for the purpose of achieving some form of collective action.
    Includes companies, institutions, corporations, departments, community
    groups, healthcare practice groups, payer/insurer, etc.
    """
    
    resource_type = "Organization"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='endpoint' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifies this organization  across multiple systems.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether the organization's record is still in active use.
    Type `bool`. """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Kind of organization.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Name used for the organization.
    Type `str`. """

    alias: typing.Optional[typing.List[str]]

    """ A list of alternate names that the organization is known as, or was
        known as in the past.
    List of `str` items. """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the organization.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional[typing.List["Address"]]

    """ An address for the organization.
    List of `Address` items (represented as `dict` in JSON). """

    partOf: typing.Optional["Reference"]

    """ The organization of which this organization forms a part.
    Type `Reference` (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["OrganizationContact"]]

    """ Contact for the organization for a certain purpose.
    List of `OrganizationContact` items (represented as `dict` in JSON). """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoints providing access to services operated for the
        organization.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class OrganizationAffiliation(DomainResource):
    """ Defines an affiliation/assotiation/relationship between 2 distinct
    oganizations, that is not a part-of relationship/sub-division relationship.
    """
    
    resource_type = "OrganizationAffiliation"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='participatingOrganization' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='healthcareService' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='endpoint' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifiers that are specific to this role.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this organization affiliation record is in active use.
    Type `bool`. """

    period: typing.Optional["Period"]

    """ The period during which the participatingOrganization is affiliated
        with the primary organization.
    Type `Period` (represented as `dict` in JSON). """

    organization: typing.Optional["Reference"]

    """ Organization where the role is available.
    Type `Reference` (represented as `dict` in JSON). """

    participatingOrganization: typing.Optional["Reference"]

    """ Organization that provides/performs the role (e.g. providing
        services or is a member of).
    Type `Reference` (represented as `dict` in JSON). """

    network: typing.Optional[typing.List["Reference"]]

    """ Health insurance provider network in which the
        participatingOrganization provides the role's services (if defined)
        at the indicated locations (if defined).
    List of `Reference` items (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Definition of the role the participatingOrganization plays.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ Specific specialty of the participatingOrganization in the context
        of the role.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    location: typing.Optional[typing.List["Reference"]]

    """ The location(s) at which the role occurs.
    List of `Reference` items (represented as `dict` in JSON). """

    healthcareService: typing.Optional[typing.List["Reference"]]

    """ Healthcare services provided through the role.
    List of `Reference` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details at the participatingOrganization relevant to this
        Affiliation.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoints providing access to services operated for this
        role.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class Patient(DomainResource):
    """ Information about an individual or animal receiving health care services.
    
    Demographics and other administrative information about an individual or
    animal receiving care or other health-related services.
    """
    
    resource_type = "Patient"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='birthDate' >, <FHIRClassProperty self.name='deceasedBoolean' >, <FHIRClassProperty self.name='deceasedDateTime' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='maritalStatus' >, <FHIRClassProperty self.name='multipleBirthBoolean' >, <FHIRClassProperty self.name='multipleBirthInteger' >, <FHIRClassProperty self.name='photo' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='communication' >, <FHIRClassProperty self.name='generalPractitioner' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='link' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ An identifier for this patient.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this patient's record is in active use.
    Type `bool`. """

    name: typing.Optional[typing.List["HumanName"]]

    """ A name associated with the patient.
    List of `HumanName` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the individual.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    birthDate: typing.Optional["FHIRDate"]

    """ The date of birth for the individual.
    Type `FHIRDate` (represented as `str` in JSON). """

    deceasedBoolean: typing.Optional[bool]

    """ Indicates if the individual is deceased or not.
    Type `bool`. """

    deceasedDateTime: typing.Optional["FHIRDate"]

    """ Indicates if the individual is deceased or not.
    Type `FHIRDate` (represented as `str` in JSON). """

    address: typing.Optional[typing.List["Address"]]

    """ An address for the individual.
    List of `Address` items (represented as `dict` in JSON). """

    maritalStatus: typing.Optional["CodeableConcept"]

    """ Marital (civil) status of a patient.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    multipleBirthBoolean: typing.Optional[bool]

    """ Whether patient is part of a multiple birth.
    Type `bool`. """

    multipleBirthInteger: typing.Optional[int]

    """ Whether patient is part of a multiple birth.
    Type `int`. """

    photo: typing.Optional[typing.List["Attachment"]]

    """ Image of the patient.
    List of `Attachment` items (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["PatientContact"]]

    """ A contact party (e.g. guardian, partner, friend) for the patient.
    List of `PatientContact` items (represented as `dict` in JSON). """

    communication: typing.Optional[typing.List["PatientCommunication"]]

    """ A language which may be used to communicate with the patient about
        his or her health.
    List of `PatientCommunication` items (represented as `dict` in JSON). """

    generalPractitioner: typing.Optional[typing.List["Reference"]]

    """ Patient's nominated primary care provider.
    List of `Reference` items (represented as `dict` in JSON). """

    managingOrganization: typing.Optional["Reference"]

    """ Organization that is the custodian of the patient record.
    Type `Reference` (represented as `dict` in JSON). """

    link: typing.Optional[typing.List["PatientLink"]]

    """ Link to another patient resource that concerns the same actual
        person.
    List of `PatientLink` items (represented as `dict` in JSON). """



#   {'path': 'Patient.deceased[x]', 'choice_of_type': 'deceased', 'orig_name': 'deceasedBoolean', 'name': 'deceasedBoolean', 'parent_name': 'Patient', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Indicates if the individual is deceased or not', 'formal': None, 'representation': None}

    _deceased_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['deceasedBoolean', 'deceasedDateTime']), True))

#   {'path': 'Patient.multipleBirth[x]', 'choice_of_type': 'multipleBirth', 'orig_name': 'multipleBirthBoolean', 'name': 'multipleBirthBoolean', 'parent_name': 'Patient', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Whether patient is part of a multiple birth', 'formal': 'Indicates whether the patient is part of a multiple (boolean) or indicates the actual birth order (integer).', 'representation': None}

    _multipleBirth_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['multipleBirthBoolean', 'multipleBirthInteger']), True))


    

     
    



class PaymentNotice(DomainResource):
    """ PaymentNotice request.
    
    This resource provides the status of the payment for goods and services
    rendered, and the request and response resource references.
    """
    
    resource_type = "PaymentNotice"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='response' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='payment' >, <FHIRClassProperty self.name='paymentDate' >, <FHIRClassProperty self.name='payee' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='paymentStatus' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for the payment noctice.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    request: typing.Optional["Reference"]

    """ Request reference.
    Type `Reference` (represented as `dict` in JSON). """

    response: typing.Optional["Reference"]

    """ Response reference.
    Type `Reference` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    provider: typing.Optional["Reference"]

    """ Responsible practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    payment: "Reference"

    """ Payment reference.
    Type `Reference` (represented as `dict` in JSON). """

    paymentDate: typing.Optional["FHIRDate"]

    """ Payment or clearing date.
    Type `FHIRDate` (represented as `str` in JSON). """

    payee: typing.Optional["Reference"]

    """ Party being paid.
    Type `Reference` (represented as `dict` in JSON). """

    recipient: "Reference"

    """ Party being notified.
    Type `Reference` (represented as `dict` in JSON). """

    amount: "Money"

    """ Monetary amount of the payment.
    Type `Money` (represented as `dict` in JSON). """

    paymentStatus: typing.Optional["CodeableConcept"]

    """ Issued or cleared Status of the payment.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class PaymentReconciliation(DomainResource):
    """ PaymentReconciliation resource.
    
    This resource provides the details including amount of a payment and
    allocates the payment items being paid.
    """
    
    resource_type = "PaymentReconciliation"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='paymentIssuer' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='requestor' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='disposition' >, <FHIRClassProperty self.name='paymentDate' >, <FHIRClassProperty self.name='paymentAmount' >, <FHIRClassProperty self.name='paymentIdentifier' >, <FHIRClassProperty self.name='detail' >, <FHIRClassProperty self.name='formCode' >, <FHIRClassProperty self.name='processNote' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for a payment reconciliation.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    period: typing.Optional["Period"]

    """ Period covered.
    Type `Period` (represented as `dict` in JSON). """

    created: "FHIRDate"

    """ Creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    paymentIssuer: typing.Optional["Reference"]

    """ Party generating payment.
    Type `Reference` (represented as `dict` in JSON). """

    request: typing.Optional["Reference"]

    """ Reference to requesting resource.
    Type `Reference` (represented as `dict` in JSON). """

    requestor: typing.Optional["Reference"]

    """ Responsible practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: typing.Optional["str"]

    """ queued | complete | error | partial.
    Type `str`. """

    disposition: typing.Optional[str]

    """ Disposition message.
    Type `str`. """

    paymentDate: "FHIRDate"

    """ When payment issued.
    Type `FHIRDate` (represented as `str` in JSON). """

    paymentAmount: "Money"

    """ Total amount of Payment.
    Type `Money` (represented as `dict` in JSON). """

    paymentIdentifier: typing.Optional["Identifier"]

    """ Business identifier for the payment.
    Type `Identifier` (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["PaymentReconciliationDetail"]]

    """ Settlement particulars.
    List of `PaymentReconciliationDetail` items (represented as `dict` in JSON). """

    formCode: typing.Optional["CodeableConcept"]

    """ Printed form identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    processNote: typing.Optional[typing.List["PaymentReconciliationProcessNote"]]

    """ Note concerning processing.
    List of `PaymentReconciliationProcessNote` items (represented as `dict` in JSON). """




    

     
    



class Person(DomainResource):
    """ A generic person record.
    
    Demographics and administrative information about a person independent of a
    specific health-related context.
    """
    
    resource_type = "Person"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='birthDate' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='photo' >, <FHIRClassProperty self.name='managingOrganization' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='link' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ A human identifier for this person.
    List of `Identifier` items (represented as `dict` in JSON). """

    name: typing.Optional[typing.List["HumanName"]]

    """ A name associated with the person.
    List of `HumanName` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the person.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    birthDate: typing.Optional["FHIRDate"]

    """ The date on which the person was born.
    Type `FHIRDate` (represented as `str` in JSON). """

    address: typing.Optional[typing.List["Address"]]

    """ One or more addresses for the person.
    List of `Address` items (represented as `dict` in JSON). """

    photo: typing.Optional["Attachment"]

    """ Image of the person.
    Type `Attachment` (represented as `dict` in JSON). """

    managingOrganization: typing.Optional["Reference"]

    """ The organization that is the custodian of the person record.
    Type `Reference` (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ This person's record is in active use.
    Type `bool`. """

    link: typing.Optional[typing.List["PersonLink"]]

    """ Link to a resource that concerns the same actual person.
    List of `PersonLink` items (represented as `dict` in JSON). """




    

     
    



class PlanDefinition(DomainResource):
    """ The definition of a plan for a series of actions, independent of any
    specific patient or context.
    
    This resource allows for the definition of various types of plans as a
    sharable, consumable, and executable artifact. The resource is general
    enough to support the description of a broad range of clinical artifacts
    such as clinical decision support rules, order sets and protocols.
    """
    
    resource_type = "PlanDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='library' >, <FHIRClassProperty self.name='goal' >, <FHIRClassProperty self.name='action' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this plan definition, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the plan definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the plan definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this plan definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this plan definition (human friendly).
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the plan definition.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ order-set | clinical-protocol | eca-rule | workflow-definition.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ Type of individual the plan definition is focused on.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ Type of individual the plan definition is focused on.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the plan definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for plan definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this plan definition is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the plan.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the plan definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the plan definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the plan definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ E.g. Education, Treatment, Assessment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations.
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    library: typing.Optional[typing.List[str]]

    """ Logic used by the plan definition.
    List of `str` items. """

    goal: typing.Optional[typing.List["PlanDefinitionGoal"]]

    """ What the plan is trying to accomplish.
    List of `PlanDefinitionGoal` items (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["PlanDefinitionAction"]]

    """ Action defined by the plan.
    List of `PlanDefinitionAction` items (represented as `dict` in JSON). """



#   {'path': 'PlanDefinition.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'PlanDefinition', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Type of individual the plan definition is focused on', 'formal': 'A code or group definition that describes the intended subject of the plan definition.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class Practitioner(DomainResource):
    """ A person with a  formal responsibility in the provisioning of healthcare or
    related services.
    
    A person who is directly or indirectly involved in the provisioning of
    healthcare.
    """
    
    resource_type = "Practitioner"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='birthDate' >, <FHIRClassProperty self.name='photo' >, <FHIRClassProperty self.name='qualification' >, <FHIRClassProperty self.name='communication' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ An identifier for the person as this agent.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this practitioner's record is in active use.
    Type `bool`. """

    name: typing.Optional[typing.List["HumanName"]]

    """ The name(s) associated with the practitioner.
    List of `HumanName` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the practitioner (that apply to all roles).
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional[typing.List["Address"]]

    """ Address(es) of the practitioner that are not role specific
        (typically home address).
    List of `Address` items (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    birthDate: typing.Optional["FHIRDate"]

    """ The date  on which the practitioner was born.
    Type `FHIRDate` (represented as `str` in JSON). """

    photo: typing.Optional[typing.List["Attachment"]]

    """ Image of the person.
    List of `Attachment` items (represented as `dict` in JSON). """

    qualification: typing.Optional[typing.List["PractitionerQualification"]]

    """ Certification, licenses, or training pertaining to the provision of
        care.
    List of `PractitionerQualification` items (represented as `dict` in JSON). """

    communication: typing.Optional[typing.List["CodeableConcept"]]

    """ A language the practitioner can use in patient communication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class PractitionerRole(DomainResource):
    """ Roles/organizations the practitioner is associated with.
    
    A specific set of Roles/Locations/specialties/services that a practitioner
    may perform at an organization for a period of time.
    """
    
    resource_type = "PractitionerRole"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='practitioner' >, <FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='healthcareService' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='availableTime' >, <FHIRClassProperty self.name='notAvailable' >, <FHIRClassProperty self.name='availabilityExceptions' >, <FHIRClassProperty self.name='endpoint' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifiers that are specific to a role/location.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this practitioner role record is in active use.
    Type `bool`. """

    period: typing.Optional["Period"]

    """ The period during which the practitioner is authorized to perform
        in these role(s).
    Type `Period` (represented as `dict` in JSON). """

    practitioner: typing.Optional["Reference"]

    """ Practitioner that is able to provide the defined services for the
        organization.
    Type `Reference` (represented as `dict` in JSON). """

    organization: typing.Optional["Reference"]

    """ Organization where the roles are available.
    Type `Reference` (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Roles which this practitioner may perform.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ Specific specialty of the practitioner.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    location: typing.Optional[typing.List["Reference"]]

    """ The location(s) at which this practitioner provides care.
    List of `Reference` items (represented as `dict` in JSON). """

    healthcareService: typing.Optional[typing.List["Reference"]]

    """ The list of healthcare services that this worker provides for this
        role's Organization/Location(s).
    List of `Reference` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details that are specific to the role/location/service.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    availableTime: typing.Optional[typing.List["PractitionerRoleAvailableTime"]]

    """ Times the Service Site is available.
    List of `PractitionerRoleAvailableTime` items (represented as `dict` in JSON). """

    notAvailable: typing.Optional[typing.List["PractitionerRoleNotAvailable"]]

    """ Not available during this time due to provided reason.
    List of `PractitionerRoleNotAvailable` items (represented as `dict` in JSON). """

    availabilityExceptions: typing.Optional[str]

    """ Description of availability exceptions.
    Type `str`. """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Technical endpoints providing access to services operated for the
        practitioner with this role.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class Procedure(DomainResource):
    """ An action that is being or was performed on a patient.
    
    An action that is or was performed on or for a patient. This can be a
    physical intervention like an operation, or less invasive like long term
    services, counseling, or hypnotherapy.
    """
    
    resource_type = "Procedure"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='performedDateTime' >, <FHIRClassProperty self.name='performedPeriod' >, <FHIRClassProperty self.name='performedString' >, <FHIRClassProperty self.name='performedAge' >, <FHIRClassProperty self.name='performedRange' >, <FHIRClassProperty self.name='recorder' >, <FHIRClassProperty self.name='asserter' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='report' >, <FHIRClassProperty self.name='complication' >, <FHIRClassProperty self.name='complicationDetail' >, <FHIRClassProperty self.name='followUp' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='focalDevice' >, <FHIRClassProperty self.name='usedReference' >, <FHIRClassProperty self.name='usedCode' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Identifiers for this procedure.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ A request for this procedure.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ preparation | in-progress | not-done | on-hold | stopped |
        completed | entered-in-error | unknown.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Classification of the procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Identification of the procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who the procedure was performed on.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    performedDateTime: typing.Optional["FHIRDate"]

    """ When the procedure was performed.
    Type `FHIRDate` (represented as `str` in JSON). """

    performedPeriod: typing.Optional["Period"]

    """ When the procedure was performed.
    Type `Period` (represented as `dict` in JSON). """

    performedString: typing.Optional[str]

    """ When the procedure was performed.
    Type `str`. """

    performedAge: typing.Optional["Age"]

    """ When the procedure was performed.
    Type `Age` (represented as `dict` in JSON). """

    performedRange: typing.Optional["Range"]

    """ When the procedure was performed.
    Type `Range` (represented as `dict` in JSON). """

    recorder: typing.Optional["Reference"]

    """ Who recorded the procedure.
    Type `Reference` (represented as `dict` in JSON). """

    asserter: typing.Optional["Reference"]

    """ Person who asserts this procedure.
    Type `Reference` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["ProcedurePerformer"]]

    """ The people who performed the procedure.
    List of `ProcedurePerformer` items (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where the procedure happened.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Coded reason procedure performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ The justification that the procedure was performed.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional[typing.List["CodeableConcept"]]

    """ Target body sites.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    outcome: typing.Optional["CodeableConcept"]

    """ The result of procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    report: typing.Optional[typing.List["Reference"]]

    """ Any report resulting from the procedure.
    List of `Reference` items (represented as `dict` in JSON). """

    complication: typing.Optional[typing.List["CodeableConcept"]]

    """ Complication following the procedure.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    complicationDetail: typing.Optional[typing.List["Reference"]]

    """ A condition that is a result of the procedure.
    List of `Reference` items (represented as `dict` in JSON). """

    followUp: typing.Optional[typing.List["CodeableConcept"]]

    """ Instructions for follow up.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional information about the procedure.
    List of `Annotation` items (represented as `dict` in JSON). """

    focalDevice: typing.Optional[typing.List["ProcedureFocalDevice"]]

    """ Manipulated, implanted, or removed device.
    List of `ProcedureFocalDevice` items (represented as `dict` in JSON). """

    usedReference: typing.Optional[typing.List["Reference"]]

    """ Items used during procedure.
    List of `Reference` items (represented as `dict` in JSON). """

    usedCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Coded items used during the procedure.
    List of `CodeableConcept` items (represented as `dict` in JSON). """



#   {'path': 'Procedure.performed[x]', 'choice_of_type': 'performed', 'orig_name': 'performedDateTime', 'name': 'performedDateTime', 'parent_name': 'Procedure', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the procedure was performed', 'formal': 'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.', 'representation': None}

    _performed_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['performedDateTime', 'performedPeriod', 'performedString', 'performedAge', 'performedRange']), True))


    

     
    



class Provenance(DomainResource):
    """ Who, What, When for a set of resources.
    
    Provenance of a resource is a record that describes entities and processes
    involved in producing and delivering or otherwise influencing that
    resource. Provenance provides a critical foundation for assessing
    authenticity, enabling trust, and allowing reproducibility. Provenance
    assertions are a form of contextual metadata and can themselves become
    important records with their own provenance. Provenance statement indicates
    clinical significance in terms of confidence in authenticity, reliability,
    and trustworthiness, integrity, and stage in lifecycle (e.g. Document
    Completion - has the artifact been legally authenticated), all of which may
    impact security, privacy, and trust policies.
    """
    
    resource_type = "Provenance"
    
    # [<FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='occurredPeriod' >, <FHIRClassProperty self.name='occurredDateTime' >, <FHIRClassProperty self.name='recorded' >, <FHIRClassProperty self.name='policy' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='activity' >, <FHIRClassProperty self.name='agent' >, <FHIRClassProperty self.name='entity' >, <FHIRClassProperty self.name='signature' >]
  

    target: typing.List["Reference"]

    """ Target Reference(s) (usually version specific).
    List of `Reference` items (represented as `dict` in JSON). """

    occurredPeriod: typing.Optional["Period"]

    """ When the activity occurred.
    Type `Period` (represented as `dict` in JSON). """

    occurredDateTime: typing.Optional["FHIRDate"]

    """ When the activity occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    recorded: "FHIRDate"

    """ When the activity was recorded / updated.
    Type `FHIRDate` (represented as `str` in JSON). """

    policy: typing.Optional[typing.List[str]]

    """ Policy or plan the activity was defined by.
    List of `str` items. """

    location: typing.Optional["Reference"]

    """ Where the activity occurred, if relevant.
    Type `Reference` (represented as `dict` in JSON). """

    reason: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason the activity is occurring.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    activity: typing.Optional["CodeableConcept"]

    """ Activity that occurred.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    agent: typing.List["ProvenanceAgent"]

    """ Actor involved.
    List of `ProvenanceAgent` items (represented as `dict` in JSON). """

    entity: typing.Optional[typing.List["ProvenanceEntity"]]

    """ An entity used in this activity.
    List of `ProvenanceEntity` items (represented as `dict` in JSON). """

    signature: typing.Optional[typing.List["Signature"]]

    """ Signature on target.
    List of `Signature` items (represented as `dict` in JSON). """



#   {'path': 'Provenance.occurred[x]', 'choice_of_type': 'occurred', 'orig_name': 'occurredPeriod', 'name': 'occurredPeriod', 'parent_name': 'Provenance', 'class_name': 'Period', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the activity occurred', 'formal': 'The period during which the activity occurred.', 'representation': None}

    _occurred_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurredPeriod', 'occurredDateTime']), True))


    

     
    



class Questionnaire(DomainResource):
    """ A structured set of questions.
    
    A structured set of questions intended to guide the collection of answers
    from end-users. Questionnaires provide detailed control over order,
    presentation, phraseology and grouping to allow coherent, consistent data
    collection.
    """
    
    resource_type = "Questionnaire"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='derivedFrom' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectType' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='item' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this questionnaire, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the questionnaire.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the questionnaire.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this questionnaire (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this questionnaire (human friendly).
    Type `str`. """

    derivedFrom: typing.Optional[typing.List[str]]

    """ Instantiates protocol or definition.
    List of `str` items. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectType: typing.Optional[typing.List["str"]]

    """ Resource that can be subject of QuestionnaireResponse.
    List of `str` items. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the questionnaire.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for questionnaire (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this questionnaire is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the questionnaire was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the questionnaire was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the questionnaire is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["Coding"]]

    """ Concept that represents the overall questionnaire.
    List of `Coding` items (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["QuestionnaireItem"]]

    """ Questions and sections within the Questionnaire.
    List of `QuestionnaireItem` items (represented as `dict` in JSON). """




    

     
    



class QuestionnaireResponse(DomainResource):
    """ A structured set of questions and their answers.
    
    A structured set of questions and their answers. The questions are ordered
    and grouped into coherent subsets, corresponding to the structure of the
    grouping of the questionnaire being responded to.
    """
    
    resource_type = "QuestionnaireResponse"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='questionnaire' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='authored' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='item' >]
  

    identifier: typing.Optional["Identifier"]

    """ Unique id for this set of answers.
    Type `Identifier` (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Request fulfilled by this QuestionnaireResponse.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of this action.
    List of `Reference` items (represented as `dict` in JSON). """

    questionnaire: typing.Optional[str]

    """ Form being answered.
    Type `str`. """

    status: "str"

    """ in-progress | completed | amended | entered-in-error | stopped.
    Type `str`. """

    subject: typing.Optional["Reference"]

    """ The subject of the questions.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    authored: typing.Optional["FHIRDate"]

    """ Date the answers were gathered.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional["Reference"]

    """ Person who received and recorded the answers.
    Type `Reference` (represented as `dict` in JSON). """

    source: typing.Optional["Reference"]

    """ The person who answered the questions.
    Type `Reference` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["QuestionnaireResponseItem"]]

    """ Groups and questions.
    List of `QuestionnaireResponseItem` items (represented as `dict` in JSON). """




    

     
    



class RelatedPerson(DomainResource):
    """ A person that is related to a patient, but who is not a direct target of
    care.
    
    Information about a person that is involved in the care for a patient, but
    who is not the target of healthcare, nor has a formal responsibility in the
    care process.
    """
    
    resource_type = "RelatedPerson"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='birthDate' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='photo' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='communication' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ A human identifier for this person.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this related person's record is in active use.
    Type `bool`. """

    patient: "Reference"

    """ The patient this person is related to.
    Type `Reference` (represented as `dict` in JSON). """

    relationship: typing.Optional[typing.List["CodeableConcept"]]

    """ The nature of the relationship.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    name: typing.Optional[typing.List["HumanName"]]

    """ A name associated with the person.
    List of `HumanName` items (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the person.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    birthDate: typing.Optional["FHIRDate"]

    """ The date on which the related person was born.
    Type `FHIRDate` (represented as `str` in JSON). """

    address: typing.Optional[typing.List["Address"]]

    """ Address where the related person can be contacted or visited.
    List of `Address` items (represented as `dict` in JSON). """

    photo: typing.Optional[typing.List["Attachment"]]

    """ Image of the person.
    List of `Attachment` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Period of time that this relationship is considered valid.
    Type `Period` (represented as `dict` in JSON). """

    communication: typing.Optional[typing.List["RelatedPersonCommunication"]]

    """ A language which may be used to communicate with about the
        patient's health.
    List of `RelatedPersonCommunication` items (represented as `dict` in JSON). """




    

     
    



class RequestGroup(DomainResource):
    """ A group of related requests.
    
    A group of related requests that can be used to capture intended activities
    that have inter-dependencies such as "give this medication after that one".
    """
    
    resource_type = "RequestGroup"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='groupIdentifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='action' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills plan, proposal, or order.
    List of `Reference` items (represented as `dict` in JSON). """

    replaces: typing.Optional[typing.List["Reference"]]

    """ Request(s) replaced by this request.
    List of `Reference` items (represented as `dict` in JSON). """

    groupIdentifier: typing.Optional["Identifier"]

    """ Composite request this is part of.
    Type `Identifier` (represented as `dict` in JSON). """

    status: "str"

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    intent: "str"

    """ proposal | plan | directive | order | original-order | reflex-order
        | filler-order | instance-order | option.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ What's being requested/ordered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Who the request group is about.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Created as part of.
    Type `Reference` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ When the request group was authored.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional["Reference"]

    """ Device or practitioner that authored the request group.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why the request group is needed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why the request group is needed.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Additional notes about the response.
    List of `Annotation` items (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["RequestGroupAction"]]

    """ Proposed actions, if any.
    List of `RequestGroupAction` items (represented as `dict` in JSON). """




    

     
    



class ResearchDefinition(DomainResource):
    """ A research context or question.
    
    The ResearchDefinition resource describes the conditional state (population
    and any exposures being compared within the population) and outcome (if
    specified) that the knowledge (evidence, assertion, recommendation) is
    about.
    """
    
    resource_type = "ResearchDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='shortTitle' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='library' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='exposure' >, <FHIRClassProperty self.name='exposureAlternative' >, <FHIRClassProperty self.name='outcome' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this research definition, represented as a
        URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the research definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the research definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this research definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this research definition (human friendly).
    Type `str`. """

    shortTitle: typing.Optional[str]

    """ Title for use in informal contexts.
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the ResearchDefinition.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the research definition.
    Type `str`. """

    comment: typing.Optional[typing.List[str]]

    """ Used for footnotes or explanatory notes.
    List of `str` items. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for research definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this research definition is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the ResearchDefinition.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the research definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the research definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the research definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the ResearchDefinition, such as Education,
        Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    library: typing.Optional[typing.List[str]]

    """ Logic used by the ResearchDefinition.
    List of `str` items. """

    population: "Reference"

    """ What population?.
    Type `Reference` (represented as `dict` in JSON). """

    exposure: typing.Optional["Reference"]

    """ What exposure?.
    Type `Reference` (represented as `dict` in JSON). """

    exposureAlternative: typing.Optional["Reference"]

    """ What alternative exposure state?.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: typing.Optional["Reference"]

    """ What outcome?.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'ResearchDefinition.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'ResearchDefinition', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device', 'formal': 'The intended subjects for the ResearchDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchDefinition can be anything.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class ResearchElementDefinition(DomainResource):
    """ A population, intervention, or exposure definition.
    
    The ResearchElementDefinition resource describes a "PICO" element that
    knowledge (evidence, assertion, recommendation) is about.
    """
    
    resource_type = "ResearchElementDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='shortTitle' >, <FHIRClassProperty self.name='subtitle' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='library' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='variableType' >, <FHIRClassProperty self.name='characteristic' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this research element definition,
        represented as a URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the research element definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the research element definition.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this research element definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this research element definition (human friendly).
    Type `str`. """

    shortTitle: typing.Optional[str]

    """ Title for use in informal contexts.
    Type `str`. """

    subtitle: typing.Optional[str]

    """ Subordinate title of the ResearchElementDefinition.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the research element definition.
    Type `str`. """

    comment: typing.Optional[typing.List[str]]

    """ Used for footnotes or explanatory notes.
    List of `str` items. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for research element definition (if
        applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this research element definition is defined.
    Type `str`. """

    usage: typing.Optional[str]

    """ Describes the clinical usage of the ResearchElementDefinition.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the research element definition was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the research element definition was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the research element definition is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the ResearchElementDefinition, such as Education,
        Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    library: typing.Optional[typing.List[str]]

    """ Logic used by the ResearchElementDefinition.
    List of `str` items. """

    type: "str"

    """ population | exposure | outcome.
    Type `str`. """

    variableType: typing.Optional["str"]

    """ dichotomous | continuous | descriptive.
    Type `str`. """

    characteristic: typing.List["ResearchElementDefinitionCharacteristic"]

    """ What defines the members of the research element.
    List of `ResearchElementDefinitionCharacteristic` items (represented as `dict` in JSON). """



#   {'path': 'ResearchElementDefinition.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'ResearchElementDefinition', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device', 'formal': 'The intended subjects for the ResearchElementDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchElementDefinition can be anything.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class ResearchStudy(DomainResource):
    """ Investigation to increase healthcare-related patient-independent knowledge.
    
    A process where a researcher or organization plans and then executes a
    series of steps intended to increase the field of healthcare-related
    knowledge.  This includes studies of safety, efficacy, comparative
    effectiveness and other information about medications, devices, therapies
    and other interventional and investigative techniques.  A ResearchStudy
    involves the gathering of information about human or animal subjects.
    """
    
    resource_type = "ResearchStudy"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='protocol' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='primaryPurposeType' >, <FHIRClassProperty self.name='phase' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='keyword' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='enrollment' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='sponsor' >, <FHIRClassProperty self.name='principalInvestigator' >, <FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='reasonStopped' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='arm' >, <FHIRClassProperty self.name='objective' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for study.
    List of `Identifier` items (represented as `dict` in JSON). """

    title: typing.Optional[str]

    """ Name for this study.
    Type `str`. """

    protocol: typing.Optional[typing.List["Reference"]]

    """ Steps followed in executing study.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of larger study.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ active | administratively-completed | approved | closed-to-accrual
        | closed-to-accrual-and-intervention | completed | disapproved |
        in-review | temporarily-closed-to-accrual | temporarily-closed-to-
        accrual-and-intervention | withdrawn.
    Type `str`. """

    primaryPurposeType: typing.Optional["CodeableConcept"]

    """ treatment | prevention | diagnostic | supportive-care | screening |
        health-services-research | basic-science | device-feasibility.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    phase: typing.Optional["CodeableConcept"]

    """ n-a | early-phase-1 | phase-1 | phase-1-phase-2 | phase-2 |
        phase-2-phase-3 | phase-3 | phase-4.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Classifications for the study.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    focus: typing.Optional[typing.List["CodeableConcept"]]

    """ Drugs, devices, etc. under study.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    condition: typing.Optional[typing.List["CodeableConcept"]]

    """ Condition being studied.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the study.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ References and dependencies.
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    keyword: typing.Optional[typing.List["CodeableConcept"]]

    """ Used to search for the study.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    location: typing.Optional[typing.List["CodeableConcept"]]

    """ Geographic region(s) for study.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ What this is study doing.
    Type `str`. """

    enrollment: typing.Optional[typing.List["Reference"]]

    """ Inclusion & exclusion criteria.
    List of `Reference` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ When the study began and ended.
    Type `Period` (represented as `dict` in JSON). """

    sponsor: typing.Optional["Reference"]

    """ Organization that initiates and is legally responsible for the
        study.
    Type `Reference` (represented as `dict` in JSON). """

    principalInvestigator: typing.Optional["Reference"]

    """ Researcher who oversees multiple aspects of the study.
    Type `Reference` (represented as `dict` in JSON). """

    site: typing.Optional[typing.List["Reference"]]

    """ Facility where study activities are conducted.
    List of `Reference` items (represented as `dict` in JSON). """

    reasonStopped: typing.Optional["CodeableConcept"]

    """ accrual-goal-met | closed-due-to-toxicity | closed-due-to-lack-of-
        study-progress | temporarily-closed-per-study-design.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the study.
    List of `Annotation` items (represented as `dict` in JSON). """

    arm: typing.Optional[typing.List["ResearchStudyArm"]]

    """ Defined path through the study for a subject.
    List of `ResearchStudyArm` items (represented as `dict` in JSON). """

    objective: typing.Optional[typing.List["ResearchStudyObjective"]]

    """ A goal for the study.
    List of `ResearchStudyObjective` items (represented as `dict` in JSON). """




    

     
    



class ResearchSubject(DomainResource):
    """ Physical entity which is the primary unit of interest in the study.
    
    A physical entity which is the primary unit of operational and/or
    administrative interest in a study.
    """
    
    resource_type = "ResearchSubject"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='study' >, <FHIRClassProperty self.name='individual' >, <FHIRClassProperty self.name='assignedArm' >, <FHIRClassProperty self.name='actualArm' >, <FHIRClassProperty self.name='consent' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for research subject in a study.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ candidate | eligible | follow-up | ineligible | not-registered |
        off-study | on-study | on-study-intervention | on-study-observation
        | pending-on-study | potential-candidate | screening | withdrawn.
    Type `str`. """

    period: typing.Optional["Period"]

    """ Start and end of participation.
    Type `Period` (represented as `dict` in JSON). """

    study: "Reference"

    """ Study subject is part of.
    Type `Reference` (represented as `dict` in JSON). """

    individual: "Reference"

    """ Who is part of study.
    Type `Reference` (represented as `dict` in JSON). """

    assignedArm: typing.Optional[str]

    """ What path should be followed.
    Type `str`. """

    actualArm: typing.Optional[str]

    """ What path was followed.
    Type `str`. """

    consent: typing.Optional["Reference"]

    """ Agreement to participate in study.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class RiskAssessment(DomainResource):
    """ Potential outcomes for a subject with likelihood.
    
    An assessment of the likely outcome(s) for a patient or other subject as
    well as the likelihood of each outcome.
    """
    
    resource_type = "RiskAssessment"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='parent' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='basis' >, <FHIRClassProperty self.name='prediction' >, <FHIRClassProperty self.name='mitigation' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier for the assessment.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional["Reference"]

    """ Request fulfilled by this assessment.
    Type `Reference` (represented as `dict` in JSON). """

    parent: typing.Optional["Reference"]

    """ Part of this occurrence.
    Type `Reference` (represented as `dict` in JSON). """

    status: "str"

    """ registered | preliminary | final | amended +.
    Type `str`. """

    method: typing.Optional["CodeableConcept"]

    """ Evaluation mechanism.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Type of assessment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Who/what does assessment apply to?.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Where was assessment performed?.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When was assessment made?.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When was assessment made?.
    Type `Period` (represented as `dict` in JSON). """

    condition: typing.Optional["Reference"]

    """ Condition assessed.
    Type `Reference` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Who did assessment?.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why the assessment was necessary?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why the assessment was necessary?.
    List of `Reference` items (represented as `dict` in JSON). """

    basis: typing.Optional[typing.List["Reference"]]

    """ Information used in assessment.
    List of `Reference` items (represented as `dict` in JSON). """

    prediction: typing.Optional[typing.List["RiskAssessmentPrediction"]]

    """ Outcome predicted.
    List of `RiskAssessmentPrediction` items (represented as `dict` in JSON). """

    mitigation: typing.Optional[str]

    """ How to reduce risk.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments on the risk assessment.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'RiskAssessment.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'RiskAssessment', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When was assessment made?', 'formal': 'The date (and possibly time) the risk assessment was performed.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod']), True))


    

     
    



class RiskEvidenceSynthesis(DomainResource):
    """ A quantified estimate of risk based on a body of evidence.
    
    The RiskEvidenceSynthesis resource describes the likelihood of an outcome
    in a population plus exposure state where the risk estimate is derived from
    a combination of research studies.
    """
    
    resource_type = "RiskEvidenceSynthesis"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='approvalDate' >, <FHIRClassProperty self.name='lastReviewDate' >, <FHIRClassProperty self.name='effectivePeriod' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='editor' >, <FHIRClassProperty self.name='reviewer' >, <FHIRClassProperty self.name='endorser' >, <FHIRClassProperty self.name='relatedArtifact' >, <FHIRClassProperty self.name='synthesisType' >, <FHIRClassProperty self.name='studyType' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='exposure' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='sampleSize' >, <FHIRClassProperty self.name='riskEstimate' >, <FHIRClassProperty self.name='certainty' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this risk evidence synthesis, represented
        as a URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the risk evidence synthesis.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the risk evidence synthesis.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this risk evidence synthesis (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this risk evidence synthesis (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the risk evidence synthesis.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for risk evidence synthesis (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    approvalDate: typing.Optional["FHIRDate"]

    """ When the risk evidence synthesis was approved by publisher.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastReviewDate: typing.Optional["FHIRDate"]

    """ When the risk evidence synthesis was last reviewed.
    Type `FHIRDate` (represented as `str` in JSON). """

    effectivePeriod: typing.Optional["Period"]

    """ When the risk evidence synthesis is expected to be used.
    Type `Period` (represented as `dict` in JSON). """

    topic: typing.Optional[typing.List["CodeableConcept"]]

    """ The category of the EffectEvidenceSynthesis, such as Education,
        Treatment, Assessment, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["ContactDetail"]]

    """ Who authored the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    editor: typing.Optional[typing.List["ContactDetail"]]

    """ Who edited the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    reviewer: typing.Optional[typing.List["ContactDetail"]]

    """ Who reviewed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    endorser: typing.Optional[typing.List["ContactDetail"]]

    """ Who endorsed the content.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    relatedArtifact: typing.Optional[typing.List["RelatedArtifact"]]

    """ Additional documentation, citations, etc..
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    synthesisType: typing.Optional["CodeableConcept"]

    """ Type of synthesis.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    studyType: typing.Optional["CodeableConcept"]

    """ Type of study.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    population: "Reference"

    """ What population?.
    Type `Reference` (represented as `dict` in JSON). """

    exposure: typing.Optional["Reference"]

    """ What exposure?.
    Type `Reference` (represented as `dict` in JSON). """

    outcome: "Reference"

    """ What outcome?.
    Type `Reference` (represented as `dict` in JSON). """

    sampleSize: typing.Optional["RiskEvidenceSynthesisSampleSize"]

    """ What sample size was involved?.
    Type `RiskEvidenceSynthesisSampleSize` (represented as `dict` in JSON). """

    riskEstimate: typing.Optional["RiskEvidenceSynthesisRiskEstimate"]

    """ What was the estimated risk.
    Type `RiskEvidenceSynthesisRiskEstimate` (represented as `dict` in JSON). """

    certainty: typing.Optional[typing.List["RiskEvidenceSynthesisCertainty"]]

    """ How certain is the risk.
    List of `RiskEvidenceSynthesisCertainty` items (represented as `dict` in JSON). """




    

     
    



class Schedule(DomainResource):
    """ A container for slots of time that may be available for booking
    appointments.
    """
    
    resource_type = "Schedule"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='active' >, <FHIRClassProperty self.name='serviceCategory' >, <FHIRClassProperty self.name='serviceType' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='planningHorizon' >, <FHIRClassProperty self.name='comment' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    active: typing.Optional[bool]

    """ Whether this schedule is in active use.
    Type `bool`. """

    serviceCategory: typing.Optional[typing.List["CodeableConcept"]]

    """ High-level category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    serviceType: typing.Optional[typing.List["CodeableConcept"]]

    """ Specific service.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of specialty needed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    actor: typing.List["Reference"]

    """ Resource(s) that availability information is being provided for.
    List of `Reference` items (represented as `dict` in JSON). """

    planningHorizon: typing.Optional["Period"]

    """ Period of time covered by schedule.
    Type `Period` (represented as `dict` in JSON). """

    comment: typing.Optional[str]

    """ Comments on availability.
    Type `str`. """




    

     
    



class SearchParameter(DomainResource):
    """ Search parameter for a resource.
    
    A search parameter that defines a named search item that can be used to
    search/filter on a resource.
    """
    
    resource_type = "SearchParameter"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='derivedFrom' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='base' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='xpath' >, <FHIRClassProperty self.name='xpathUsage' >, <FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='multipleOr' >, <FHIRClassProperty self.name='multipleAnd' >, <FHIRClassProperty self.name='comparator' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='chain' >, <FHIRClassProperty self.name='component' >]
  

    url: str

    """ Canonical identifier for this search parameter, represented as a
        URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the search parameter.
    Type `str`. """

    name: str

    """ Name for this search parameter (computer friendly).
    Type `str`. """

    derivedFrom: typing.Optional[str]

    """ Original definition for the search parameter.
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: str

    """ Natural language description of the search parameter.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for search parameter (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this search parameter is defined.
    Type `str`. """

    code: str

    """ Code used in URL.
    Type `str`. """

    base: typing.List["str"]

    """ The resource type(s) this search parameter applies to.
    List of `str` items. """

    type: "str"

    """ number | date | string | token | reference | composite | quantity |
        uri | special.
    Type `str`. """

    expression: typing.Optional[str]

    """ FHIRPath expression that extracts the values.
    Type `str`. """

    xpath: typing.Optional[str]

    """ XPath that extracts the values.
    Type `str`. """

    xpathUsage: typing.Optional["str"]

    """ normal | phonetic | nearby | distance | other.
    Type `str`. """

    target: typing.Optional[typing.List["str"]]

    """ Types of resource (if a resource reference).
    List of `str` items. """

    multipleOr: typing.Optional[bool]

    """ Allow multiple values per parameter (or).
    Type `bool`. """

    multipleAnd: typing.Optional[bool]

    """ Allow multiple parameters (and).
    Type `bool`. """

    comparator: typing.Optional[typing.List["str"]]

    """ eq | ne | gt | lt | ge | le | sa | eb | ap.
    List of `str` items. """

    modifier: typing.Optional[typing.List["str"]]

    """ missing | exact | contains | not | text | in | not-in | below |
        above | type | identifier | ofType.
    List of `str` items. """

    chain: typing.Optional[typing.List[str]]

    """ Chained names supported.
    List of `str` items. """

    component: typing.Optional[typing.List["SearchParameterComponent"]]

    """ For Composite resources to define the parts.
    List of `SearchParameterComponent` items (represented as `dict` in JSON). """




    

     
    



class ServiceRequest(DomainResource):
    """ A request for a service to be performed.
    
    A record of a request for service such as diagnostic investigations,
    treatments, or operations to be performed.
    """
    
    resource_type = "ServiceRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='replaces' >, <FHIRClassProperty self.name='requisition' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='orderDetail' >, <FHIRClassProperty self.name='quantityQuantity' >, <FHIRClassProperty self.name='quantityRatio' >, <FHIRClassProperty self.name='quantityRange' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='asNeededBoolean' >, <FHIRClassProperty self.name='asNeededCodeableConcept' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='performerType' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='locationCode' >, <FHIRClassProperty self.name='locationReference' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='supportingInfo' >, <FHIRClassProperty self.name='specimen' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='patientInstruction' >, <FHIRClassProperty self.name='relevantHistory' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifiers assigned to this order.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ What request fulfills.
    List of `Reference` items (represented as `dict` in JSON). """

    replaces: typing.Optional[typing.List["Reference"]]

    """ What request replaces.
    List of `Reference` items (represented as `dict` in JSON). """

    requisition: typing.Optional["Identifier"]

    """ Composite Request ID.
    Type `Identifier` (represented as `dict` in JSON). """

    status: "str"

    """ draft | active | on-hold | revoked | completed | entered-in-error |
        unknown.
    Type `str`. """

    intent: "str"

    """ proposal | plan | directive | order | original-order | reflex-order
        | filler-order | instance-order | option.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ Classification of service.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    doNotPerform: typing.Optional[bool]

    """ True if service/procedure should not be performed.
    Type `bool`. """

    code: typing.Optional["CodeableConcept"]

    """ What is being requested/ordered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    orderDetail: typing.Optional[typing.List["CodeableConcept"]]

    """ Additional order information.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantityQuantity: typing.Optional["Quantity"]

    """ Service amount.
    Type `Quantity` (represented as `dict` in JSON). """

    quantityRatio: typing.Optional["Ratio"]

    """ Service amount.
    Type `Ratio` (represented as `dict` in JSON). """

    quantityRange: typing.Optional["Range"]

    """ Service amount.
    Type `Range` (represented as `dict` in JSON). """

    subject: "Reference"

    """ Individual or Entity the service is ordered for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Encounter in which the request was created.
    Type `Reference` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When service should occur.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When service should occur.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ When service should occur.
    Type `Timing` (represented as `dict` in JSON). """

    asNeededBoolean: typing.Optional[bool]

    """ Preconditions for service.
    Type `bool`. """

    asNeededCodeableConcept: typing.Optional["CodeableConcept"]

    """ Preconditions for service.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ Date request signed.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Who/what is requesting service.
    Type `Reference` (represented as `dict` in JSON). """

    performerType: typing.Optional["CodeableConcept"]

    """ Performer role.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["Reference"]]

    """ Requested performer.
    List of `Reference` items (represented as `dict` in JSON). """

    locationCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Requested location.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    locationReference: typing.Optional[typing.List["Reference"]]

    """ Requested location.
    List of `Reference` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Explanation/Justification for procedure or service.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Explanation/Justification for service or service.
    List of `Reference` items (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["Reference"]]

    """ Associated insurance coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    supportingInfo: typing.Optional[typing.List["Reference"]]

    """ Additional clinical information.
    List of `Reference` items (represented as `dict` in JSON). """

    specimen: typing.Optional[typing.List["Reference"]]

    """ Procedure Samples.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional[typing.List["CodeableConcept"]]

    """ Location on Body.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments.
    List of `Annotation` items (represented as `dict` in JSON). """

    patientInstruction: typing.Optional[str]

    """ Patient or consumer-oriented instructions.
    Type `str`. """

    relevantHistory: typing.Optional[typing.List["Reference"]]

    """ Request provenance.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'ServiceRequest.quantity[x]', 'choice_of_type': 'quantity', 'orig_name': 'quantityQuantity', 'name': 'quantityQuantity', 'parent_name': 'ServiceRequest', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Service amount', 'formal': 'An amount of service being requested which can be a quantity ( for example $1,500 home modification), a ratio ( for example, 20 half day visits per month), or a range (2.0 to 1.8 Gy per fraction).', 'representation': None}

    _quantity_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['quantityQuantity', 'quantityRatio', 'quantityRange']), True))

#   {'path': 'ServiceRequest.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'ServiceRequest', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When service should occur', 'formal': 'The date/time at which the requested service should occur.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))

#   {'path': 'ServiceRequest.asNeeded[x]', 'choice_of_type': 'asNeeded', 'orig_name': 'asNeededBoolean', 'name': 'asNeededBoolean', 'parent_name': 'ServiceRequest', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Preconditions for service', 'formal': 'If a CodeableConcept is present, it indicates the pre-condition for performing the service.  For example "pain", "on flare-up", etc.', 'representation': None}

    _asNeeded_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['asNeededBoolean', 'asNeededCodeableConcept']), True))


    

     
    



class Slot(DomainResource):
    """ A slot of time on a schedule that may be available for booking appointments.
    """
    
    resource_type = "Slot"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='serviceCategory' >, <FHIRClassProperty self.name='serviceType' >, <FHIRClassProperty self.name='specialty' >, <FHIRClassProperty self.name='appointmentType' >, <FHIRClassProperty self.name='schedule' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='overbooked' >, <FHIRClassProperty self.name='comment' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Ids for this item.
    List of `Identifier` items (represented as `dict` in JSON). """

    serviceCategory: typing.Optional[typing.List["CodeableConcept"]]

    """ A broad categorization of the service that is to be performed
        during this appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    serviceType: typing.Optional[typing.List["CodeableConcept"]]

    """ The type of appointments that can be booked into this slot (ideally
        this would be an identifiable service - which is at a location,
        rather than the location itself). If provided then this overrides
        the value provided on the availability resource.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialty: typing.Optional[typing.List["CodeableConcept"]]

    """ The specialty of a practitioner that would be required to perform
        the service requested in this appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    appointmentType: typing.Optional["CodeableConcept"]

    """ The style of appointment or patient that may be booked in the slot
        (not service type).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    schedule: "Reference"

    """ The schedule resource that this slot defines an interval of status
        information.
    Type `Reference` (represented as `dict` in JSON). """

    status: "str"

    """ busy | free | busy-unavailable | busy-tentative | entered-in-error.
    Type `str`. """

    start: "FHIRDate"

    """ Date/Time that the slot is to begin.
    Type `FHIRDate` (represented as `str` in JSON). """

    end: "FHIRDate"

    """ Date/Time that the slot is to conclude.
    Type `FHIRDate` (represented as `str` in JSON). """

    overbooked: typing.Optional[bool]

    """ This slot has already been overbooked, appointments are unlikely to
        be accepted for this time.
    Type `bool`. """

    comment: typing.Optional[str]

    """ Comments on the slot to describe any extended information. Such as
        custom constraints on the slot.
    Type `str`. """




    

     
    



class Specimen(DomainResource):
    """ Sample for analysis.
    
    A sample to be used for analysis.
    """
    
    resource_type = "Specimen"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='accessionIdentifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='receivedTime' >, <FHIRClassProperty self.name='parent' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='collection' >, <FHIRClassProperty self.name='processing' >, <FHIRClassProperty self.name='container' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='note' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External Identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    accessionIdentifier: typing.Optional["Identifier"]

    """ Identifier assigned by the lab.
    Type `Identifier` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ available | unavailable | unsatisfactory | entered-in-error.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Kind of material that forms the specimen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional["Reference"]

    """ Where the specimen came from. This may be from patient(s), from a
        location (e.g., the source of an environmental sample), or a
        sampling of a substance or a device.
    Type `Reference` (represented as `dict` in JSON). """

    receivedTime: typing.Optional["FHIRDate"]

    """ The time when specimen was received for processing.
    Type `FHIRDate` (represented as `str` in JSON). """

    parent: typing.Optional[typing.List["Reference"]]

    """ Specimen from which this specimen originated.
    List of `Reference` items (represented as `dict` in JSON). """

    request: typing.Optional[typing.List["Reference"]]

    """ Why the specimen was collected.
    List of `Reference` items (represented as `dict` in JSON). """

    collection: typing.Optional["SpecimenCollection"]

    """ Collection details.
    Type `SpecimenCollection` (represented as `dict` in JSON). """

    processing: typing.Optional[typing.List["SpecimenProcessing"]]

    """ Processing and processing step details.
    List of `SpecimenProcessing` items (represented as `dict` in JSON). """

    container: typing.Optional[typing.List["SpecimenContainer"]]

    """ Direct container of specimen (tube/slide, etc.).
    List of `SpecimenContainer` items (represented as `dict` in JSON). """

    condition: typing.Optional[typing.List["CodeableConcept"]]

    """ State of the specimen.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class SpecimenDefinition(DomainResource):
    """ Kind of specimen.
    
    A kind of specimen with associated set of requirements.
    """
    
    resource_type = "SpecimenDefinition"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='typeCollected' >, <FHIRClassProperty self.name='patientPreparation' >, <FHIRClassProperty self.name='timeAspect' >, <FHIRClassProperty self.name='collection' >, <FHIRClassProperty self.name='typeTested' >]
  

    identifier: typing.Optional["Identifier"]

    """ Business identifier of a kind of specimen.
    Type `Identifier` (represented as `dict` in JSON). """

    typeCollected: typing.Optional["CodeableConcept"]

    """ Kind of material to collect.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    patientPreparation: typing.Optional[typing.List["CodeableConcept"]]

    """ Patient preparation for collection.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    timeAspect: typing.Optional[str]

    """ Time aspect for collection.
    Type `str`. """

    collection: typing.Optional[typing.List["CodeableConcept"]]

    """ Specimen collection procedure.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    typeTested: typing.Optional[typing.List["SpecimenDefinitionTypeTested"]]

    """ Specimen in container intended for testing by lab.
    List of `SpecimenDefinitionTypeTested` items (represented as `dict` in JSON). """




    

     
    



class StructureDefinition(DomainResource):
    """ Structural Definition.
    
    A definition of a FHIR structure. This resource is used to describe the
    underlying resources, data types defined in FHIR, and also for describing
    extensions and constraints on resources and data types.
    """
    
    resource_type = "StructureDefinition"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='keyword' >, <FHIRClassProperty self.name='fhirVersion' >, <FHIRClassProperty self.name='mapping' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='abstract' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='contextInvariant' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='baseDefinition' >, <FHIRClassProperty self.name='derivation' >, <FHIRClassProperty self.name='snapshot' >, <FHIRClassProperty self.name='differential' >]
  

    url: str

    """ Canonical identifier for this structure definition, represented as
        a URI (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the structure definition.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the structure definition.
    Type `str`. """

    name: str

    """ Name for this structure definition (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this structure definition (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the structure definition.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for structure definition (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this structure definition is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    keyword: typing.Optional[typing.List["Coding"]]

    """ Assist with indexing and finding.
    List of `Coding` items (represented as `dict` in JSON). """

    fhirVersion: typing.Optional[str]

    """ FHIR Version this StructureDefinition targets.
    Type `str`. """

    mapping: typing.Optional[typing.List["StructureDefinitionMapping"]]

    """ External specification that the content is mapped to.
    List of `StructureDefinitionMapping` items (represented as `dict` in JSON). """

    kind: "str"

    """ primitive-type | complex-type | resource | logical.
    Type `str`. """

    abstract: bool

    """ Whether the structure is abstract.
    Type `bool`. """

    context: typing.Optional[typing.List["StructureDefinitionContext"]]

    """ If an extension, where it can be used in instances.
    List of `StructureDefinitionContext` items (represented as `dict` in JSON). """

    contextInvariant: typing.Optional[typing.List[str]]

    """ FHIRPath invariants - when the extension can be used.
    List of `str` items. """

    type: str

    """ Type defined or constrained by this structure.
    Type `str`. """

    baseDefinition: typing.Optional[str]

    """ Definition that this type is constrained/specialized from.
    Type `str`. """

    derivation: typing.Optional["str"]

    """ specialization | constraint - How relates to base definition.
    Type `str`. """

    snapshot: typing.Optional["StructureDefinitionSnapshot"]

    """ Snapshot view of the structure.
    Type `StructureDefinitionSnapshot` (represented as `dict` in JSON). """

    differential: typing.Optional["StructureDefinitionDifferential"]

    """ Differential view of the structure.
    Type `StructureDefinitionDifferential` (represented as `dict` in JSON). """




    

     
    



class StructureMap(DomainResource):
    """ A Map of relationships between 2 structures that can be used to transform
    data.
    """
    
    resource_type = "StructureMap"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='structure' >, <FHIRClassProperty self.name='import_' >, <FHIRClassProperty self.name='group' >]
  

    url: str

    """ Canonical identifier for this structure map, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the structure map.
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the structure map.
    Type `str`. """

    name: str

    """ Name for this structure map (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this structure map (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the structure map.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for structure map (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this structure map is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    structure: typing.Optional[typing.List["StructureMapStructure"]]

    """ Structure Definition used by this map.
    List of `StructureMapStructure` items (represented as `dict` in JSON). """

    import_: typing.Optional[typing.List[str]]

    """ Other maps used by this map (canonical URLs).
    List of `str` items. """

    group: typing.List["StructureMapGroup"]

    """ Named sections for reader convenience.
    List of `StructureMapGroup` items (represented as `dict` in JSON). """




    

     
    



class Subscription(DomainResource):
    """ Server push subscription criteria.
    
    The subscription resource is used to define a push-based subscription from
    a server to another system. Once a subscription is registered with the
    server, the server checks every resource that is created or updated, and if
    the resource matches the given criteria, it sends a message on the defined
    "channel" so that another system can take an appropriate action.
    """
    
    resource_type = "Subscription"
    
    # [<FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='criteria' >, <FHIRClassProperty self.name='error' >, <FHIRClassProperty self.name='channel' >]
  

    status: "str"

    """ requested | active | error | off.
    Type `str`. """

    contact: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details for source (e.g. troubleshooting).
    List of `ContactPoint` items (represented as `dict` in JSON). """

    end: typing.Optional["FHIRDate"]

    """ When to automatically delete the subscription.
    Type `FHIRDate` (represented as `str` in JSON). """

    reason: str

    """ Description of why this subscription was created.
    Type `str`. """

    criteria: str

    """ Rule for server push.
    Type `str`. """

    error: typing.Optional[str]

    """ Latest error note.
    Type `str`. """

    channel: "SubscriptionChannel"

    """ The channel on which to report matches to the criteria.
    Type `SubscriptionChannel` (represented as `dict` in JSON). """




    

     
    



class Substance(DomainResource):
    """ A homogeneous material with a definite composition.
    """
    
    resource_type = "Substance"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='instance' >, <FHIRClassProperty self.name='ingredient' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Unique identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ active | inactive | entered-in-error.
    Type `str`. """

    category: typing.Optional[typing.List["CodeableConcept"]]

    """ What class/type of substance this is.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ What substance this is.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Textual description of the substance, comments.
    Type `str`. """

    instance: typing.Optional[typing.List["SubstanceInstance"]]

    """ If this describes a specific package/container of the substance.
    List of `SubstanceInstance` items (represented as `dict` in JSON). """

    ingredient: typing.Optional[typing.List["SubstanceIngredient"]]

    """ Composition information about the substance.
    List of `SubstanceIngredient` items (represented as `dict` in JSON). """




    

     
    



class SubstanceNucleicAcid(DomainResource):
    """ Nucleic acids are defined by three distinct elements: the base, sugar and
    linkage. Individual substance/moiety IDs will be created for each of these
    elements. The nucleotide sequence will be always entered in the 5’-3’
    direction.
    """
    
    resource_type = "SubstanceNucleicAcid"
    
    # [<FHIRClassProperty self.name='sequenceType' >, <FHIRClassProperty self.name='numberOfSubunits' >, <FHIRClassProperty self.name='areaOfHybridisation' >, <FHIRClassProperty self.name='oligoNucleotideType' >, <FHIRClassProperty self.name='subunit' >]
  

    sequenceType: typing.Optional["CodeableConcept"]

    """ The type of the sequence shall be specified based on a controlled
        vocabulary.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    numberOfSubunits: typing.Optional[int]

    """ The number of linear sequences of nucleotides linked through
        phosphodiester bonds shall be described. Subunits would be strands
        of nucleic acids that are tightly associated typically through
        Watson-Crick base pairing. NOTE: If not specified in the reference
        source, the assumption is that there is 1 subunit.
    Type `int`. """

    areaOfHybridisation: typing.Optional[str]

    """ The area of hybridisation shall be described if applicable for
        double stranded RNA or DNA. The number associated with the subunit
        followed by the number associated to the residue shall be specified
        in increasing order. The underscore “” shall be used as separator
        as follows: “Subunitnumber Residue”.
    Type `str`. """

    oligoNucleotideType: typing.Optional["CodeableConcept"]

    """ (TBC).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subunit: typing.Optional[typing.List["SubstanceNucleicAcidSubunit"]]

    """ Subunits are listed in order of decreasing length; sequences of the
        same length will be ordered by molecular weight; subunits that have
        identical sequences will be repeated multiple times.
    List of `SubstanceNucleicAcidSubunit` items (represented as `dict` in JSON). """




    

     
    



class SubstancePolymer(DomainResource):
    """ Todo.
    """
    
    resource_type = "SubstancePolymer"
    
    # [<FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='geometry' >, <FHIRClassProperty self.name='copolymerConnectivity' >, <FHIRClassProperty self.name='modification' >, <FHIRClassProperty self.name='monomerSet' >, <FHIRClassProperty self.name='repeat' >]
  

    class_: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    geometry: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    copolymerConnectivity: typing.Optional[typing.List["CodeableConcept"]]

    """ Todo.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    modification: typing.Optional[typing.List[str]]

    """ Todo.
    List of `str` items. """

    monomerSet: typing.Optional[typing.List["SubstancePolymerMonomerSet"]]

    """ Todo.
    List of `SubstancePolymerMonomerSet` items (represented as `dict` in JSON). """

    repeat: typing.Optional[typing.List["SubstancePolymerRepeat"]]

    """ Todo.
    List of `SubstancePolymerRepeat` items (represented as `dict` in JSON). """




    

     
    



class SubstanceProtein(DomainResource):
    """ A SubstanceProtein is defined as a single unit of a linear amino acid
    sequence, or a combination of subunits that are either covalently linked or
    have a defined invariant stoichiometric relationship. This includes all
    synthetic, recombinant and purified SubstanceProteins of defined sequence,
    whether the use is therapeutic or prophylactic. This set of elements will
    be used to describe albumins, coagulation factors, cytokines, growth
    factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids,
    recombinant vaccines, and immunomodulators.
    """
    
    resource_type = "SubstanceProtein"
    
    # [<FHIRClassProperty self.name='sequenceType' >, <FHIRClassProperty self.name='numberOfSubunits' >, <FHIRClassProperty self.name='disulfideLinkage' >, <FHIRClassProperty self.name='subunit' >]
  

    sequenceType: typing.Optional["CodeableConcept"]

    """ The SubstanceProtein descriptive elements will only be used when a
        complete or partial amino acid sequence is available or derivable
        from a nucleic acid sequence.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    numberOfSubunits: typing.Optional[int]

    """ Number of linear sequences of amino acids linked through peptide
        bonds. The number of subunits constituting the SubstanceProtein
        shall be described. It is possible that the number of subunits can
        be variable.
    Type `int`. """

    disulfideLinkage: typing.Optional[typing.List[str]]

    """ The disulphide bond between two cysteine residues either on the
        same subunit or on two different subunits shall be described. The
        position of the disulfide bonds in the SubstanceProtein shall be
        listed in increasing order of subunit number and position within
        subunit followed by the abbreviation of the amino acids involved.
        The disulfide linkage positions shall actually contain the amino
        acid Cysteine at the respective positions.
    List of `str` items. """

    subunit: typing.Optional[typing.List["SubstanceProteinSubunit"]]

    """ This subclause refers to the description of each subunit
        constituting the SubstanceProtein. A subunit is a linear sequence
        of amino acids linked through peptide bonds. The Subunit
        information shall be provided when the finished SubstanceProtein is
        a complex of multiple sequences; subunits are not used to delineate
        domains within a single sequence. Subunits are listed in order of
        decreasing length; sequences of the same length will be ordered by
        decreasing molecular weight; subunits that have identical sequences
        will be repeated multiple times.
    List of `SubstanceProteinSubunit` items (represented as `dict` in JSON). """




    

     
    



class SubstanceReferenceInformation(DomainResource):
    """ Todo.
    """
    
    resource_type = "SubstanceReferenceInformation"
    
    # [<FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='gene' >, <FHIRClassProperty self.name='geneElement' >, <FHIRClassProperty self.name='classification' >, <FHIRClassProperty self.name='target' >]
  

    comment: typing.Optional[str]

    """ Todo.
    Type `str`. """

    gene: typing.Optional[typing.List["SubstanceReferenceInformationGene"]]

    """ Todo.
    List of `SubstanceReferenceInformationGene` items (represented as `dict` in JSON). """

    geneElement: typing.Optional[typing.List["SubstanceReferenceInformationGeneElement"]]

    """ Todo.
    List of `SubstanceReferenceInformationGeneElement` items (represented as `dict` in JSON). """

    classification: typing.Optional[typing.List["SubstanceReferenceInformationClassification"]]

    """ Todo.
    List of `SubstanceReferenceInformationClassification` items (represented as `dict` in JSON). """

    target: typing.Optional[typing.List["SubstanceReferenceInformationTarget"]]

    """ Todo.
    List of `SubstanceReferenceInformationTarget` items (represented as `dict` in JSON). """




    

     
    



class SubstanceSourceMaterial(DomainResource):
    """ Source material shall capture information on the taxonomic and anatomical
    origins as well as the fraction of a material that can result in or can be
    modified to form a substance. This set of data elements shall be used to
    define polymer substances isolated from biological matrices. Taxonomic and
    anatomical origins shall be described using a controlled vocabulary as
    required. This information is captured for naturally derived polymers ( .
    starch) and structurally diverse substances. For Organisms belonging to the
    Kingdom Plantae the Substance level defines the fresh material of a single
    species or infraspecies, the Herbal Drug and the Herbal preparation. For
    Herbal preparations, the fraction information will be captured at the
    Substance information level and additional information for herbal extracts
    will be captured at the Specified Substance Group 1 information level. See
    for further explanation the Substance Class: Structurally Diverse and the
    herbal annex.
    """
    
    resource_type = "SubstanceSourceMaterial"
    
    # [<FHIRClassProperty self.name='sourceMaterialClass' >, <FHIRClassProperty self.name='sourceMaterialType' >, <FHIRClassProperty self.name='sourceMaterialState' >, <FHIRClassProperty self.name='organismId' >, <FHIRClassProperty self.name='organismName' >, <FHIRClassProperty self.name='parentSubstanceId' >, <FHIRClassProperty self.name='parentSubstanceName' >, <FHIRClassProperty self.name='countryOfOrigin' >, <FHIRClassProperty self.name='geographicalLocation' >, <FHIRClassProperty self.name='developmentStage' >, <FHIRClassProperty self.name='fractionDescription' >, <FHIRClassProperty self.name='organism' >, <FHIRClassProperty self.name='partDescription' >]
  

    sourceMaterialClass: typing.Optional["CodeableConcept"]

    """ General high level classification of the source material specific
        to the origin of the material.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    sourceMaterialType: typing.Optional["CodeableConcept"]

    """ The type of the source material shall be specified based on a
        controlled vocabulary. For vaccines, this subclause refers to the
        class of infectious agent.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    sourceMaterialState: typing.Optional["CodeableConcept"]

    """ The state of the source material when extracted.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    organismId: typing.Optional["Identifier"]

    """ The unique identifier associated with the source material parent
        organism shall be specified.
    Type `Identifier` (represented as `dict` in JSON). """

    organismName: typing.Optional[str]

    """ The organism accepted Scientific name shall be provided based on
        the organism taxonomy.
    Type `str`. """

    parentSubstanceId: typing.Optional[typing.List["Identifier"]]

    """ The parent of the herbal drug Ginkgo biloba, Leaf is the substance
        ID of the substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L.
        (Whole plant).
    List of `Identifier` items (represented as `dict` in JSON). """

    parentSubstanceName: typing.Optional[typing.List[str]]

    """ The parent substance of the Herbal Drug, or Herbal preparation.
    List of `str` items. """

    countryOfOrigin: typing.Optional[typing.List["CodeableConcept"]]

    """ The country where the plant material is harvested or the countries
        where the plasma is sourced from as laid down in accordance with
        the Plasma Master File. For “Plasma-derived substances” the
        attribute country of origin provides information about the
        countries used for the manufacturing of the Cryopoor plama or
        Crioprecipitate.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    geographicalLocation: typing.Optional[typing.List[str]]

    """ The place/region where the plant is harvested or the places/regions
        where the animal source material has its habitat.
    List of `str` items. """

    developmentStage: typing.Optional["CodeableConcept"]

    """ Stage of life for animals, plants, insects and microorganisms. This
        information shall be provided only when the substance is
        significantly different in these stages (e.g. foetal bovine serum).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fractionDescription: typing.Optional[typing.List["SubstanceSourceMaterialFractionDescription"]]

    """ Many complex materials are fractions of parts of plants, animals,
        or minerals. Fraction elements are often necessary to define both
        Substances and Specified Group 1 Substances. For substances derived
        from Plants, fraction information will be captured at the Substance
        information level ( . Oils, Juices and Exudates). Additional
        information for Extracts, such as extraction solvent composition,
        will be captured at the Specified Substance Group 1 information
        level. For plasma-derived products fraction information will be
        captured at the Substance and the Specified Substance Group 1
        levels.
    List of `SubstanceSourceMaterialFractionDescription` items (represented as `dict` in JSON). """

    organism: typing.Optional["SubstanceSourceMaterialOrganism"]

    """ This subclause describes the organism which the substance is
        derived from. For vaccines, the parent organism shall be specified
        based on these subclause elements. As an example, full taxonomy
        will be described for the Substance Name: ., Leaf.
    Type `SubstanceSourceMaterialOrganism` (represented as `dict` in JSON). """

    partDescription: typing.Optional[typing.List["SubstanceSourceMaterialPartDescription"]]

    """ To do.
    List of `SubstanceSourceMaterialPartDescription` items (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecification(DomainResource):
    """ The detailed description of a substance, typically at a level beyond what
    is used for prescribing.
    """
    
    resource_type = "SubstanceSpecification"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='domain' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='moiety' >, <FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='referenceInformation' >, <FHIRClassProperty self.name='structure' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='molecularWeight' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='nucleicAcid' >, <FHIRClassProperty self.name='polymer' >, <FHIRClassProperty self.name='protein' >, <FHIRClassProperty self.name='sourceMaterial' >]
  

    identifier: typing.Optional["Identifier"]

    """ Identifier by which this substance is known.
    Type `Identifier` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ High level categorization, e.g. polymer or nucleic acid.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ Status of substance within the catalogue e.g. approved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    domain: typing.Optional["CodeableConcept"]

    """ If the substance applies to only human or veterinary use.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Textual description of the substance.
    Type `str`. """

    source: typing.Optional[typing.List["Reference"]]

    """ Supporting literature.
    List of `Reference` items (represented as `dict` in JSON). """

    comment: typing.Optional[str]

    """ Textual comment about this record of a substance.
    Type `str`. """

    moiety: typing.Optional[typing.List["SubstanceSpecificationMoiety"]]

    """ Moiety, for structural modifications.
    List of `SubstanceSpecificationMoiety` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List["SubstanceSpecificationProperty"]]

    """ General specifications for this substance, including how it is
        related to other substances.
    List of `SubstanceSpecificationProperty` items (represented as `dict` in JSON). """

    referenceInformation: typing.Optional["Reference"]

    """ General information detailing this substance.
    Type `Reference` (represented as `dict` in JSON). """

    structure: typing.Optional["SubstanceSpecificationStructure"]

    """ Structural information.
    Type `SubstanceSpecificationStructure` (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["SubstanceSpecificationstr"]]

    """ Codes associated with the substance.
    List of `SubstanceSpecificationstr` items (represented as `dict` in JSON). """

    name: typing.Optional[typing.List["SubstanceSpecificationName"]]

    """ Names applicable to this substance.
    List of `SubstanceSpecificationName` items (represented as `dict` in JSON). """

    molecularWeight: typing.Optional[typing.List["SubstanceSpecificationStructureIsotopeMolecularWeight"]]

    """ The molecular weight or weight range (for proteins, polymers or
        nucleic acids).
    List of `SubstanceSpecificationStructureIsotopeMolecularWeight` items (represented as `dict` in JSON). """

    relationship: typing.Optional[typing.List["SubstanceSpecificationRelationship"]]

    """ A link between this substance and another, with details of the
        relationship.
    List of `SubstanceSpecificationRelationship` items (represented as `dict` in JSON). """

    nucleicAcid: typing.Optional["Reference"]

    """ Data items specific to nucleic acids.
    Type `Reference` (represented as `dict` in JSON). """

    polymer: typing.Optional["Reference"]

    """ Data items specific to polymers.
    Type `Reference` (represented as `dict` in JSON). """

    protein: typing.Optional["Reference"]

    """ Data items specific to proteins.
    Type `Reference` (represented as `dict` in JSON). """

    sourceMaterial: typing.Optional["Reference"]

    """ Material or taxonomic/anatomical source for the substance.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class SupplyDelivery(DomainResource):
    """ Delivery of bulk Supplies.
    
    Record of delivery of what is supplied.
    """
    
    resource_type = "SupplyDelivery"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='suppliedItem' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='supplier' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='receiver' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ External identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Fulfills plan, proposal or order.
    List of `Reference` items (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Part of referenced event.
    List of `Reference` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ in-progress | completed | abandoned | entered-in-error.
    Type `str`. """

    patient: typing.Optional["Reference"]

    """ Patient for whom the item is supplied.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Category of dispense event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    suppliedItem: typing.Optional["SupplyDeliverySuppliedItem"]

    """ The item that is delivered or supplied.
    Type `SupplyDeliverySuppliedItem` (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When event occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When event occurred.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ When event occurred.
    Type `Timing` (represented as `dict` in JSON). """

    supplier: typing.Optional["Reference"]

    """ Dispenser.
    Type `Reference` (represented as `dict` in JSON). """

    destination: typing.Optional["Reference"]

    """ Where the Supply was sent.
    Type `Reference` (represented as `dict` in JSON). """

    receiver: typing.Optional[typing.List["Reference"]]

    """ Who collected the Supply.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'SupplyDelivery.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'SupplyDelivery', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When event occurred', 'formal': 'The date or time(s) the activity occurred.', 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))


    

     
    



class SupplyRequest(DomainResource):
    """ Request for a medication, substance or device.
    
    A record of a request for a medication, substance or device used in the
    healthcare setting.
    """
    
    resource_type = "SupplyRequest"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='itemCodeableConcept' >, <FHIRClassProperty self.name='itemReference' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='supplier' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='deliverFrom' >, <FHIRClassProperty self.name='deliverTo' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for SupplyRequest.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ draft | active | suspended +.
    Type `str`. """

    category: typing.Optional["CodeableConcept"]

    """ The kind of supply (central, non-stock, etc.).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ Medication, Substance, or Device requested to be supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    itemReference: typing.Optional["Reference"]

    """ Medication, Substance, or Device requested to be supplied.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: "Quantity"

    """ The requested amount of the item indicated.
    Type `Quantity` (represented as `dict` in JSON). """

    parameter: typing.Optional[typing.List["SupplyRequestParameter"]]

    """ Ordered item details.
    List of `SupplyRequestParameter` items (represented as `dict` in JSON). """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When the request should be fulfilled.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When the request should be fulfilled.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ When the request should be fulfilled.
    Type `Timing` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ When the request was made.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Individual making the request.
    Type `Reference` (represented as `dict` in JSON). """

    supplier: typing.Optional[typing.List["Reference"]]

    """ Who is intended to fulfill the request.
    List of `Reference` items (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ The reason why the supply item was requested.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ The reason why the supply item was requested.
    List of `Reference` items (represented as `dict` in JSON). """

    deliverFrom: typing.Optional["Reference"]

    """ The origin of the supply.
    Type `Reference` (represented as `dict` in JSON). """

    deliverTo: typing.Optional["Reference"]

    """ The destination of the supply.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'SupplyRequest.item[x]', 'choice_of_type': 'item', 'orig_name': 'itemCodeableConcept', 'name': 'itemCodeableConcept', 'parent_name': 'SupplyRequest', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Medication, Substance, or Device requested to be supplied', 'formal': 'The item that is requested to be supplied. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.', 'representation': None}

    _item_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['itemCodeableConcept', 'itemReference']), False))

#   {'path': 'SupplyRequest.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'SupplyRequest', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the request should be fulfilled', 'formal': None, 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))


    

     
    



class Task(DomainResource):
    """ A task to be performed.
    """
    
    resource_type = "Task"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='basedOn' >, <FHIRClassProperty self.name='groupIdentifier' >, <FHIRClassProperty self.name='partOf' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='businessStatus' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='for_' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='executionPeriod' >, <FHIRClassProperty self.name='authoredOn' >, <FHIRClassProperty self.name='lastModified' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='performerType' >, <FHIRClassProperty self.name='owner' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='insurance' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='relevantHistory' >, <FHIRClassProperty self.name='restriction' >, <FHIRClassProperty self.name='input' >, <FHIRClassProperty self.name='output' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Task Instance Identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    instantiatesCanonical: typing.Optional[str]

    """ Formal definition of task.
    Type `str`. """

    instantiatesUri: typing.Optional[str]

    """ Formal definition of task.
    Type `str`. """

    basedOn: typing.Optional[typing.List["Reference"]]

    """ Request fulfilled by this task.
    List of `Reference` items (represented as `dict` in JSON). """

    groupIdentifier: typing.Optional["Identifier"]

    """ Requisition or grouper id.
    Type `Identifier` (represented as `dict` in JSON). """

    partOf: typing.Optional[typing.List["Reference"]]

    """ Composite task.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ draft | requested | received | accepted | +.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    businessStatus: typing.Optional["CodeableConcept"]

    """ E.g. "Specimen collected", "IV prepped".
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intent: str

    """ unknown | proposal | plan | order | original-order | reflex-order |
        filler-order | instance-order | option.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Task Type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Human-readable explanation of task.
    Type `str`. """

    focus: typing.Optional["Reference"]

    """ What task is acting on.
    Type `Reference` (represented as `dict` in JSON). """

    for_: typing.Optional["Reference"]

    """ Beneficiary of the Task.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Healthcare event during which this task originated.
    Type `Reference` (represented as `dict` in JSON). """

    executionPeriod: typing.Optional["Period"]

    """ Start and end time of execution.
    Type `Period` (represented as `dict` in JSON). """

    authoredOn: typing.Optional["FHIRDate"]

    """ Task Creation Date.
    Type `FHIRDate` (represented as `str` in JSON). """

    lastModified: typing.Optional["FHIRDate"]

    """ Task Last Modified Date.
    Type `FHIRDate` (represented as `str` in JSON). """

    requester: typing.Optional["Reference"]

    """ Who is asking for task to be done.
    Type `Reference` (represented as `dict` in JSON). """

    performerType: typing.Optional[typing.List["CodeableConcept"]]

    """ Requested performer.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    owner: typing.Optional["Reference"]

    """ Responsible individual.
    Type `Reference` (represented as `dict` in JSON). """

    location: typing.Optional["Reference"]

    """ Where task occurs.
    Type `Reference` (represented as `dict` in JSON). """

    reasonCode: typing.Optional["CodeableConcept"]

    """ Why task is needed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reasonReference: typing.Optional["Reference"]

    """ Why task is needed.
    Type `Reference` (represented as `dict` in JSON). """

    insurance: typing.Optional[typing.List["Reference"]]

    """ Associated insurance coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments made about the task.
    List of `Annotation` items (represented as `dict` in JSON). """

    relevantHistory: typing.Optional[typing.List["Reference"]]

    """ Key events in history of the Task.
    List of `Reference` items (represented as `dict` in JSON). """

    restriction: typing.Optional["TaskRestriction"]

    """ Constraints on fulfillment tasks.
    Type `TaskRestriction` (represented as `dict` in JSON). """

    input: typing.Optional[typing.List["TaskInput"]]

    """ Information used to perform task.
    List of `TaskInput` items (represented as `dict` in JSON). """

    output: typing.Optional[typing.List["TaskOutput"]]

    """ Information produced as part of task.
    List of `TaskOutput` items (represented as `dict` in JSON). """




    

     
    



class TerminologyCapabilities(DomainResource):
    """ A statement of system capabilities.
    
    A TerminologyCapabilities resource documents a set of capabilities
    (behaviors) of a FHIR Terminology Server that may be used as a statement of
    actual server functionality or a statement of required or desired server
    implementation.
    """
    
    resource_type = "TerminologyCapabilities"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='software' >, <FHIRClassProperty self.name='implementation' >, <FHIRClassProperty self.name='lockedDate' >, <FHIRClassProperty self.name='codeSystem' >, <FHIRClassProperty self.name='expansion' >, <FHIRClassProperty self.name='codeSearch' >, <FHIRClassProperty self.name='validateCode' >, <FHIRClassProperty self.name='translation' >, <FHIRClassProperty self.name='closure' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this terminology capabilities, represented
        as a URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the terminology capabilities.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this terminology capabilities (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this terminology capabilities (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: "FHIRDate"

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the terminology capabilities.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for terminology capabilities (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this terminology capabilities is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    kind: "str"

    """ instance | capability | requirements.
    Type `str`. """

    software: typing.Optional["TerminologyCapabilitiesSoftware"]

    """ Software that is covered by this terminology capability statement.
    Type `TerminologyCapabilitiesSoftware` (represented as `dict` in JSON). """

    implementation: typing.Optional["TerminologyCapabilitiesImplementation"]

    """ If this describes a specific instance.
    Type `TerminologyCapabilitiesImplementation` (represented as `dict` in JSON). """

    lockedDate: typing.Optional[bool]

    """ Whether lockedDate is supported.
    Type `bool`. """

    codeSystem: typing.Optional[typing.List["TerminologyCapabilitiesCodeSystem"]]

    """ A code system supported by the server.
    List of `TerminologyCapabilitiesCodeSystem` items (represented as `dict` in JSON). """

    expansion: typing.Optional["TerminologyCapabilitiesExpansion"]

    """ Information about the [ValueSet/$expand](valueset-operation-
        expand.html) operation.
    Type `TerminologyCapabilitiesExpansion` (represented as `dict` in JSON). """

    codeSearch: typing.Optional["str"]

    """ explicit | all.
    Type `str`. """

    validateCode: typing.Optional["TerminologyCapabilitiesValidateCode"]

    """ Information about the [ValueSet/$validate-code](valueset-operation-
        validate-code.html) operation.
    Type `TerminologyCapabilitiesValidateCode` (represented as `dict` in JSON). """

    translation: typing.Optional["TerminologyCapabilitiesTranslation"]

    """ Information about the [ConceptMap/$translate](conceptmap-operation-
        translate.html) operation.
    Type `TerminologyCapabilitiesTranslation` (represented as `dict` in JSON). """

    closure: typing.Optional["TerminologyCapabilitiesClosure"]

    """ Information about the [ConceptMap/$closure](conceptmap-operation-
        closure.html) operation.
    Type `TerminologyCapabilitiesClosure` (represented as `dict` in JSON). """




    

     
    



class TestReport(DomainResource):
    """ Describes the results of a TestScript execution.
    
    A summary of information based on the results of executing a TestScript.
    """
    
    resource_type = "TestReport"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='testScript' >, <FHIRClassProperty self.name='result' >, <FHIRClassProperty self.name='score' >, <FHIRClassProperty self.name='tester' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='setup' >, <FHIRClassProperty self.name='test' >, <FHIRClassProperty self.name='teardown' >]
  

    identifier: typing.Optional["Identifier"]

    """ External identifier.
    Type `Identifier` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Informal name of the executed TestScript.
    Type `str`. """

    status: "str"

    """ completed | in-progress | waiting | stopped | entered-in-error.
    Type `str`. """

    testScript: "Reference"

    """ Reference to the  version-specific TestScript that was executed to
        produce this TestReport.
    Type `Reference` (represented as `dict` in JSON). """

    result: "str"

    """ pass | fail | pending.
    Type `str`. """

    score: typing.Optional[float]

    """ The final score (percentage of tests passed) resulting from the
        execution of the TestScript.
    Type `float`. """

    tester: typing.Optional[str]

    """ Name of the tester producing this report (Organization or
        individual).
    Type `str`. """

    issued: typing.Optional["FHIRDate"]

    """ When the TestScript was executed and this TestReport was generated.
    Type `FHIRDate` (represented as `str` in JSON). """

    participant: typing.Optional[typing.List["TestReportParticipant"]]

    """ A participant in the test execution, either the execution engine, a
        client, or a server.
    List of `TestReportParticipant` items (represented as `dict` in JSON). """

    setup: typing.Optional["TestReportSetup"]

    """ The results of the series of required setup operations before the
        tests were executed.
    Type `TestReportSetup` (represented as `dict` in JSON). """

    test: typing.Optional[typing.List["TestReportTest"]]

    """ A test executed from the test script.
    List of `TestReportTest` items (represented as `dict` in JSON). """

    teardown: typing.Optional["TestReportTeardown"]

    """ The results of running the series of required clean up steps.
    Type `TestReportTeardown` (represented as `dict` in JSON). """




    

     
    



class TestScript(DomainResource):
    """ Describes a set of tests.
    
    A structured set of tests against a FHIR server or client implementation to
    determine compliance against the FHIR specification.
    """
    
    resource_type = "TestScript"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='origin' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='metadata' >, <FHIRClassProperty self.name='fixture' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='variable' >, <FHIRClassProperty self.name='setup' >, <FHIRClassProperty self.name='test' >, <FHIRClassProperty self.name='teardown' >]
  

    url: str

    """ Canonical identifier for this test script, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional["Identifier"]

    """ Additional identifier for the test script.
    Type `Identifier` (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the test script.
    Type `str`. """

    name: str

    """ Name for this test script (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this test script (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the test script.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for test script (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    purpose: typing.Optional[str]

    """ Why this test script is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    origin: typing.Optional[typing.List["TestScriptOrigin"]]

    """ An abstract server representing a client or sender in a message
        exchange.
    List of `TestScriptOrigin` items (represented as `dict` in JSON). """

    destination: typing.Optional[typing.List["TestScriptDestination"]]

    """ An abstract server representing a destination or receiver in a
        message exchange.
    List of `TestScriptDestination` items (represented as `dict` in JSON). """

    metadata: typing.Optional["TestScriptMetadata"]

    """ Required capability that is assumed to function correctly on the
        FHIR server being tested.
    Type `TestScriptMetadata` (represented as `dict` in JSON). """

    fixture: typing.Optional[typing.List["TestScriptFixture"]]

    """ Fixture in the test script - by reference (uri).
    List of `TestScriptFixture` items (represented as `dict` in JSON). """

    profile: typing.Optional[typing.List["Reference"]]

    """ Reference of the validation profile.
    List of `Reference` items (represented as `dict` in JSON). """

    variable: typing.Optional[typing.List["TestScriptVariable"]]

    """ Placeholder for evaluated elements.
    List of `TestScriptVariable` items (represented as `dict` in JSON). """

    setup: typing.Optional["TestScriptSetup"]

    """ A series of required setup operations before tests are executed.
    Type `TestScriptSetup` (represented as `dict` in JSON). """

    test: typing.Optional[typing.List["TestScriptTest"]]

    """ A test in this script.
    List of `TestScriptTest` items (represented as `dict` in JSON). """

    teardown: typing.Optional["TestScriptTeardown"]

    """ A series of required clean up steps.
    Type `TestScriptTeardown` (represented as `dict` in JSON). """




    

     
    



class ValueSet(DomainResource):
    """ A set of codes drawn from one or more code systems.
    
    A ValueSet resource instance specifies a set of codes drawn from one or
    more code systems, intended for use in a particular context. Value sets
    link between [CodeSystem](codesystem.html) definitions and their use in
    [coded elements](terminologies.html).
    """
    
    resource_type = "ValueSet"
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='immutable' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='copyright' >, <FHIRClassProperty self.name='compose' >, <FHIRClassProperty self.name='expansion' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this value set, represented as a URI
        (globally unique).
    Type `str`. """

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Additional identifier for the value set (business identifier).
    List of `Identifier` items (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ Business version of the value set.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this value set (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this value set (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the value set.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for value set (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    immutable: typing.Optional[bool]

    """ Indicates whether or not any change to the content logical
        definition may occur.
    Type `bool`. """

    purpose: typing.Optional[str]

    """ Why this value set is defined.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Use and/or publishing restrictions.
    Type `str`. """

    compose: typing.Optional["ValueSetCompose"]

    """ Content logical definition of the value set (CLD).
    Type `ValueSetCompose` (represented as `dict` in JSON). """

    expansion: typing.Optional["ValueSetExpansion"]

    """ Used when the value set is "expanded".
    Type `ValueSetExpansion` (represented as `dict` in JSON). """




    

     
    



class VerificationResult(DomainResource):
    """ Describes validation requirements, source(s), status and dates for one or
    more elements.
    """
    
    resource_type = "VerificationResult"
    
    # [<FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='targetLocation' >, <FHIRClassProperty self.name='need' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusDate' >, <FHIRClassProperty self.name='validationType' >, <FHIRClassProperty self.name='validationProcess' >, <FHIRClassProperty self.name='frequency' >, <FHIRClassProperty self.name='lastPerformed' >, <FHIRClassProperty self.name='nextScheduled' >, <FHIRClassProperty self.name='failureAction' >, <FHIRClassProperty self.name='primarySource' >, <FHIRClassProperty self.name='attestation' >, <FHIRClassProperty self.name='validator' >]
  

    target: typing.Optional[typing.List["Reference"]]

    """ A resource that was validated.
    List of `Reference` items (represented as `dict` in JSON). """

    targetLocation: typing.Optional[typing.List[str]]

    """ The fhirpath location(s) within the resource that was validated.
    List of `str` items. """

    need: typing.Optional["CodeableConcept"]

    """ none | initial | periodic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: "str"

    """ attested | validated | in-process | req-revalid | val-fail | reval-
        fail.
    Type `str`. """

    statusDate: typing.Optional["FHIRDate"]

    """ When the validation status was updated.
    Type `FHIRDate` (represented as `str` in JSON). """

    validationType: typing.Optional["CodeableConcept"]

    """ nothing | primary | multiple.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    validationProcess: typing.Optional[typing.List["CodeableConcept"]]

    """ The primary process by which the target is validated (edit check;
        value set; primary source; multiple sources; standalone; in
        context).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    frequency: typing.Optional["Timing"]

    """ Frequency of revalidation.
    Type `Timing` (represented as `dict` in JSON). """

    lastPerformed: typing.Optional["FHIRDate"]

    """ The date/time validation was last completed (including failed
        validations).
    Type `FHIRDate` (represented as `str` in JSON). """

    nextScheduled: typing.Optional["FHIRDate"]

    """ The date when target is next validated, if appropriate.
    Type `FHIRDate` (represented as `str` in JSON). """

    failureAction: typing.Optional["CodeableConcept"]

    """ fatal | warn | rec-only | none.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    primarySource: typing.Optional[typing.List["VerificationResultPrimarySource"]]

    """ Information about the primary source(s) involved in validation.
    List of `VerificationResultPrimarySource` items (represented as `dict` in JSON). """

    attestation: typing.Optional["VerificationResultAttestation"]

    """ Information about the entity attesting to information.
    Type `VerificationResultAttestation` (represented as `dict` in JSON). """

    validator: typing.Optional[typing.List["VerificationResultValidator"]]

    """ Information about the entity validating information.
    List of `VerificationResultValidator` items (represented as `dict` in JSON). """




    

     
    



class VisionPrescription(DomainResource):
    """ Prescription for vision correction products for a patient.
    
    An authorization for the provision of glasses and/or contact lenses to a
    patient.
    """
    
    resource_type = "VisionPrescription"
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='created' >, <FHIRClassProperty self.name='patient' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='dateWritten' >, <FHIRClassProperty self.name='prescriber' >, <FHIRClassProperty self.name='lensSpecification' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for vision prescription.
    List of `Identifier` items (represented as `dict` in JSON). """

    status: "str"

    """ active | cancelled | draft | entered-in-error.
    Type `str`. """

    created: "FHIRDate"

    """ Response creation date.
    Type `FHIRDate` (represented as `str` in JSON). """

    patient: "Reference"

    """ Who prescription is for.
    Type `Reference` (represented as `dict` in JSON). """

    encounter: typing.Optional["Reference"]

    """ Created during encounter / admission / stay.
    Type `Reference` (represented as `dict` in JSON). """

    dateWritten: "FHIRDate"

    """ When prescription was authorized.
    Type `FHIRDate` (represented as `str` in JSON). """

    prescriber: "Reference"

    """ Who authorized the vision prescription.
    Type `Reference` (represented as `dict` in JSON). """

    lensSpecification: typing.List["VisionPrescriptionLensSpecification"]

    """ Vision lens authorization.
    List of `VisionPrescriptionLensSpecification` items (represented as `dict` in JSON). """




    

     
    



class MetadataResource(DomainResource):
    """ Common Ancestor declaration for definitional resources.
    
    Common Ancestor declaration for conformance and knowledge artifact
    resources.
    """
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='experimental' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='useContext' >, <FHIRClassProperty self.name='jurisdiction' >]
  

    url: typing.Optional[str]

    """ Canonical identifier for this metadata resource, represented as a
        URI (globally unique).
    Type `str`. """

    version: typing.Optional[str]

    """ Business version of the metadata resource.
    Type `str`. """

    name: typing.Optional[str]

    """ Name for this metadata resource (computer friendly).
    Type `str`. """

    title: typing.Optional[str]

    """ Name for this metadata resource (human friendly).
    Type `str`. """

    status: "str"

    """ draft | active | retired | unknown.
    Type `str`. """

    experimental: typing.Optional[bool]

    """ For testing purposes, not real usage.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ Date last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    publisher: typing.Optional[str]

    """ Name of the publisher (organization or individual).
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details for the publisher.
    List of `ContactDetail` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Natural language description of the metadata resource.
    Type `str`. """

    useContext: typing.Optional[typing.List["UsageContext"]]

    """ The context that the content is intended to support.
    List of `UsageContext` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Intended jurisdiction for metadata resource (if applicable).
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class Element(FHIRAbstractBase):
    """ Base for all elements.
    
    Base definition for all elements in a resource.
    """
    
    # [<FHIRClassProperty self.name='id' >, <FHIRClassProperty self.name='extension' >]
  

    id: typing.Optional[str]

    """ Unique id for inter-element referencing.
    Type `str`. """

    extension: typing.Optional[typing.List["Extension"]]

    """ Additional content defined by implementations.
    List of `Extension` items (represented as `dict` in JSON). """




    

     
    



class BackboneElement(Element):
    """ Base for elements defined inside a resource.
    
    Base definition for all elements that are defined inside a resource - but
    not those in a data type.
    """
    
    # [<FHIRClassProperty self.name='modifierExtension' >]
  

    modifierExtension: typing.Optional[typing.List["Extension"]]

    """ Extensions that cannot be ignored even if unrecognized.
    List of `Extension` items (represented as `dict` in JSON). """




    

     
    



class Address(Element):
    """ An address expressed using postal conventions (as opposed to GPS or other
    location definition formats).
    
    An address expressed using postal conventions (as opposed to GPS or other
    location definition formats).  This data type may be used to convey
    addresses for use in delivering mail as well as for visiting locations
    which might not be valid for mail delivery.  There are a variety of postal
    address formats defined around the world.
    """
    
    # [<FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='line' >, <FHIRClassProperty self.name='city' >, <FHIRClassProperty self.name='district' >, <FHIRClassProperty self.name='state' >, <FHIRClassProperty self.name='postalCode' >, <FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='period' >]
  

    use: typing.Optional["str"]

    """ home | work | temp | old | billing - purpose of this address.
    Type `str`. """

    type: typing.Optional["str"]

    """ postal | physical | both.
    Type `str`. """

    text: typing.Optional[str]

    """ Text representation of the address.
    Type `str`. """

    line: typing.Optional[typing.List[str]]

    """ Street name, number, direction & P.O. Box etc..
    List of `str` items. """

    city: typing.Optional[str]

    """ Name of city, town etc..
    Type `str`. """

    district: typing.Optional[str]

    """ District name (aka county).
    Type `str`. """

    state: typing.Optional[str]

    """ Sub-unit of country (abbreviations ok).
    Type `str`. """

    postalCode: typing.Optional[str]

    """ Postal code for area.
    Type `str`. """

    country: typing.Optional[str]

    """ Country (e.g. can be ISO 3166 2 or 3 letter code).
    Type `str`. """

    period: typing.Optional["Period"]

    """ Time period when address was/is in use.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class Annotation(Element):
    """ Text node with attribution.
    
    A  text note which also  contains information about who made the statement
    and when.
    """
    
    # [<FHIRClassProperty self.name='authorReference' >, <FHIRClassProperty self.name='authorString' >, <FHIRClassProperty self.name='time' >, <FHIRClassProperty self.name='text' >]
  

    authorReference: typing.Optional["Reference"]

    """ Individual responsible for the annotation.
    Type `Reference` (represented as `dict` in JSON). """

    authorString: typing.Optional[str]

    """ Individual responsible for the annotation.
    Type `str`. """

    time: typing.Optional["FHIRDate"]

    """ When the annotation was made.
    Type `FHIRDate` (represented as `str` in JSON). """

    text: str

    """ The annotation  - text content (as markdown).
    Type `str`. """



#   {'path': 'Annotation.author[x]', 'choice_of_type': 'author', 'orig_name': 'authorReference', 'name': 'authorReference', 'parent_name': 'Annotation', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Individual responsible for the annotation', 'formal': 'The individual responsible for making the annotation.', 'representation': None}

    _author_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['authorReference', 'authorString']), True))


    

     
    



class Attachment(Element):
    """ Content in a format defined elsewhere.
    
    For referring to data content defined in other formats.
    """
    
    # [<FHIRClassProperty self.name='contentType' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='data' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='size' >, <FHIRClassProperty self.name='hash' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='creation' >]
  

    contentType: typing.Optional[str]

    """ Mime type of the content, with charset etc..
    Type `str`. """

    language: typing.Optional[str]

    """ Human language of the content (BCP-47).
    Type `str`. """

    data: typing.Optional[str]

    """ Data inline, base64ed.
    Type `str`. """

    url: typing.Optional[str]

    """ Uri where the data can be found.
    Type `str`. """

    size: typing.Optional[int]

    """ Number of bytes of content (if url provided).
    Type `int`. """

    hash: typing.Optional[str]

    """ Hash of the data (sha-1, base64ed).
    Type `str`. """

    title: typing.Optional[str]

    """ Label to display in place of the data.
    Type `str`. """

    creation: typing.Optional["FHIRDate"]

    """ Date attachment was first created.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class CodeableConcept(Element):
    """ Concept - reference to a terminology or just  text.
    
    A concept that may be defined by a formal reference to a terminology or
    ontology or may be provided by text.
    """
    
    # [<FHIRClassProperty self.name='coding' >, <FHIRClassProperty self.name='text' >]
  

    coding: typing.Optional[typing.List["Coding"]]

    """ Code defined by a terminology system.
    List of `Coding` items (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Plain text representation of the concept.
    Type `str`. """




    

     
    



class Coding(Element):
    """ A reference to a code defined by a terminology system.
    """
    
    # [<FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='userSelected' >]
  

    system: typing.Optional[str]

    """ Identity of the terminology system.
    Type `str`. """

    version: typing.Optional[str]

    """ Version of the system - if relevant.
    Type `str`. """

    code: typing.Optional[str]

    """ Symbol in syntax defined by the system.
    Type `str`. """

    display: typing.Optional[str]

    """ Representation defined by the system.
    Type `str`. """

    userSelected: typing.Optional[bool]

    """ If this coding was chosen directly by the user.
    Type `bool`. """




    

     
    



class ContactDetail(Element):
    """ Contact information.
    
    Specifies contact information for a person or organization.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >]
  

    name: typing.Optional[str]

    """ Name of an individual to contact.
    Type `str`. """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details for individual or organization.
    List of `ContactPoint` items (represented as `dict` in JSON). """




    

     
    



class ContactPoint(Element):
    """ Details of a Technology mediated contact point (phone, fax, email, etc.).
    
    Details for all kinds of technology mediated contact points for a person or
    organization, including telephone, email, etc.
    """
    
    # [<FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='rank' >, <FHIRClassProperty self.name='period' >]
  

    system: typing.Optional["str"]

    """ phone | fax | email | pager | url | sms | other.
    Type `str`. """

    value: typing.Optional[str]

    """ The actual contact point details.
    Type `str`. """

    use: typing.Optional["str"]

    """ home | work | temp | old | mobile - purpose of this contact point.
    Type `str`. """

    rank: typing.Optional[int]

    """ Specify preferred order of use (1 = highest).
    Type `int`. """

    period: typing.Optional["Period"]

    """ Time period when the contact point was/is in use.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class Contributor(Element):
    """ Contributor information.
    
    A contributor to the content of a knowledge asset, including authors,
    editors, reviewers, and endorsers.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='contact' >]
  

    type: "str"

    """ author | editor | reviewer | endorser.
    Type `str`. """

    name: str

    """ Who contributed the content.
    Type `str`. """

    contact: typing.Optional[typing.List["ContactDetail"]]

    """ Contact details of the contributor.
    List of `ContactDetail` items (represented as `dict` in JSON). """




    

     
    



class DataRequirement(Element):
    """ Describes a required data item.
    
    Describes a required data item for evaluation in terms of the type of data,
    and optional code or date-based filters of the data.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='mustSupport' >, <FHIRClassProperty self.name='codeFilter' >, <FHIRClassProperty self.name='dateFilter' >, <FHIRClassProperty self.name='limit' >, <FHIRClassProperty self.name='sort' >]
  

    type: str

    """ The type of the required data.
    Type `str`. """

    profile: typing.Optional[typing.List[str]]

    """ The profile of the required data.
    List of `str` items. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
    Type `Reference` (represented as `dict` in JSON). """

    mustSupport: typing.Optional[typing.List[str]]

    """ Indicates specific structure elements that are referenced by the
        knowledge module.
    List of `str` items. """

    codeFilter: typing.Optional[typing.List["DataRequirementCodeFilter"]]

    """ What codes are expected.
    List of `DataRequirementCodeFilter` items (represented as `dict` in JSON). """

    dateFilter: typing.Optional[typing.List["DataRequirementDateFilter"]]

    """ What dates/date ranges are expected.
    List of `DataRequirementDateFilter` items (represented as `dict` in JSON). """

    limit: typing.Optional[int]

    """ Number of results.
    Type `int`. """

    sort: typing.Optional[typing.List["DataRequirementSort"]]

    """ Order of the results.
    List of `DataRequirementSort` items (represented as `dict` in JSON). """



#   {'path': 'DataRequirement.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'DataRequirement', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device', 'formal': 'The intended subjects of the data requirement. If this element is not provided, a Patient subject is assumed.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))


    

     
    



class DataRequirementCodeFilter(Element):
    """ What codes are expected.
    
    Code filters specify additional constraints on the data, specifying the
    value set of interest for a particular element of the data. Each code
    filter defines an additional constraint on the data, i.e. code filters are
    AND'ed, not OR'ed.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='searchParam' >, <FHIRClassProperty self.name='valueSet' >, <FHIRClassProperty self.name='code' >]
  

    path: typing.Optional[str]

    """ A code-valued attribute to filter on.
    Type `str`. """

    searchParam: typing.Optional[str]

    """ A coded (token) parameter to search on.
    Type `str`. """

    valueSet: typing.Optional[str]

    """ Valueset for the filter.
    Type `str`. """

    code: typing.Optional[typing.List["Coding"]]

    """ What code is expected.
    List of `Coding` items (represented as `dict` in JSON). """




    

     
    



class DataRequirementDateFilter(Element):
    """ What dates/date ranges are expected.
    
    Date filters specify additional constraints on the data in terms of the
    applicable date range for specific elements. Each date filter specifies an
    additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='searchParam' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueDuration' >]
  

    path: typing.Optional[str]

    """ A date-valued attribute to filter on.
    Type `str`. """

    searchParam: typing.Optional[str]

    """ A date valued parameter to search on.
    Type `str`. """

    valueDateTime: typing.Optional["FHIRDate"]

    """ The value of the filter, as a Period, DateTime, or Duration value.
    Type `FHIRDate` (represented as `str` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ The value of the filter, as a Period, DateTime, or Duration value.
    Type `Period` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ The value of the filter, as a Period, DateTime, or Duration value.
    Type `Duration` (represented as `dict` in JSON). """



#   {'path': 'DataRequirement.dateFilter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueDateTime', 'name': 'valueDateTime', 'parent_name': 'DataRequirement.dateFilter', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The value of the filter, as a Period, DateTime, or Duration value', 'formal': 'The value of the filter. If period is specified, the filter will return only those data items that fall within the bounds determined by the Period, inclusive of the period boundaries. If dateTime is specified, the filter will return only those data items that are equal to the specified dateTime. If a Duration is specified, the filter will return only those data items that fall within Duration before now.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueDateTime', 'valuePeriod', 'valueDuration']), True))


    

     
    



class DataRequirementSort(Element):
    """ Order of the results.
    
    Specifies the order of the results to be returned.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='direction' >]
  

    path: str

    """ The name of the attribute to perform the sort.
    Type `str`. """

    direction: "str"

    """ ascending | descending.
    Type `str`. """




    

     
    



class DosageDoseAndRate(Element):
    """ Amount of medication administered.
    
    The amount of medication administered.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='doseRange' >, <FHIRClassProperty self.name='doseQuantity' >, <FHIRClassProperty self.name='rateRatio' >, <FHIRClassProperty self.name='rateRange' >, <FHIRClassProperty self.name='rateQuantity' >]
  

    type: typing.Optional["CodeableConcept"]

    """ The kind of dose or rate specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    doseRange: typing.Optional["Range"]

    """ Amount of medication per dose.
    Type `Range` (represented as `dict` in JSON). """

    doseQuantity: typing.Optional["Quantity"]

    """ Amount of medication per dose.
    Type `Quantity` (represented as `dict` in JSON). """

    rateRatio: typing.Optional["Ratio"]

    """ Amount of medication per unit of time.
    Type `Ratio` (represented as `dict` in JSON). """

    rateRange: typing.Optional["Range"]

    """ Amount of medication per unit of time.
    Type `Range` (represented as `dict` in JSON). """

    rateQuantity: typing.Optional["Quantity"]

    """ Amount of medication per unit of time.
    Type `Quantity` (represented as `dict` in JSON). """



#   {'path': 'Dosage.doseAndRate.dose[x]', 'choice_of_type': 'dose', 'orig_name': 'doseRange', 'name': 'doseRange', 'parent_name': 'Dosage.doseAndRate', 'class_name': 'Range', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Amount of medication per dose', 'formal': None, 'representation': None}

    _dose_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['doseRange', 'doseQuantity']), True))

#   {'path': 'Dosage.doseAndRate.rate[x]', 'choice_of_type': 'rate', 'orig_name': 'rateRatio', 'name': 'rateRatio', 'parent_name': 'Dosage.doseAndRate', 'class_name': 'Ratio', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Amount of medication per unit of time', 'formal': None, 'representation': None}

    _rate_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['rateRatio', 'rateRange', 'rateQuantity']), True))


    

     
    



class ElementDefinitionSlicing(Element):
    """ This element is sliced - slices follow.
    
    Indicates that the element is sliced into a set of alternative definitions
    (i.e. in a structure definition, there are multiple different constraints
    on a single element in the base resource). Slicing can be used in any
    resource that has cardinality ..* on the base resource, or any resource
    with a choice of types. The set of slices is any elements that come after
    this in the element sequence that have the same path, until a shorter path
    occurs (the shorter path terminates the set).
    """
    
    # [<FHIRClassProperty self.name='discriminator' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='ordered' >, <FHIRClassProperty self.name='rules' >]
  

    discriminator: typing.Optional[typing.List["ElementDefinitionSlicingDiscriminator"]]

    """ Element values that are used to distinguish the slices.
    List of `ElementDefinitionSlicingDiscriminator` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Text description of how slicing works (or not).
    Type `str`. """

    ordered: typing.Optional[bool]

    """ If elements must be in same order as slices.
    Type `bool`. """

    rules: "str"

    """ closed | open | openAtEnd.
    Type `str`. """




    

     
    



class ElementDefinitionSlicingDiscriminator(Element):
    """ Element values that are used to distinguish the slices.
    
    Designates which child elements are used to discriminate between the slices
    when processing an instance. If one or more discriminators are provided,
    the value of the child elements in the instance data SHALL completely
    distinguish which slice the element in the resource matches based on the
    allowed values for those elements in each of the slices.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='path' >]
  

    type: "str"

    """ value | exists | pattern | type | profile.
    Type `str`. """

    path: str

    """ Path to element value.
    Type `str`. """




    

     
    



class ElementDefinitionBase(Element):
    """ Base definition information for tools.
    
    Information about the base definition of the element, provided to make it
    unnecessary for tools to trace the deviation of the element through the
    derived and related profiles. When the element definition is not the
    original definition of an element - i.g. either in a constraint on another
    type, or for elements from a super type in a snap shot - then the
    information in provided in the element definition may be different to the
    base definition. On the original definition of the element, it will be
    same.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >]
  

    path: str

    """ Path that identifies the base element.
    Type `str`. """

    min: int

    """ Min cardinality of the base element.
    Type `int`. """

    max: str

    """ Max cardinality of the base element.
    Type `str`. """




    

     
    



class ElementDefinitionType(Element):
    """ Data type and Profile for this element.
    
    The data type or resource that the value of this element is permitted to
    be.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='targetProfile' >, <FHIRClassProperty self.name='aggregation' >, <FHIRClassProperty self.name='versioning' >]
  

    code: str

    """ Data type or Resource (reference to definition).
    Type `str`. """

    profile: typing.Optional[typing.List[str]]

    """ Profiles (StructureDefinition or IG) - one must apply.
    List of `str` items. """

    targetProfile: typing.Optional[typing.List[str]]

    """ Profile (StructureDefinition or IG) on the Reference/canonical
        target - one must apply.
    List of `str` items. """

    aggregation: typing.Optional[typing.List["str"]]

    """ contained | referenced | bundled - how aggregated.
    List of `str` items. """

    versioning: typing.Optional["str"]

    """ either | independent | specific.
    Type `str`. """




    

     
    



class ElementDefinitionExample(Element):
    """ Example value (as defined for type).
    
    A sample value for this element demonstrating the type of information that
    would typically be found in the element.
    """
    
    # [<FHIRClassProperty self.name='label' >, <FHIRClassProperty self.name='valueBase64Binary' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueCanonical' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueInstant' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueMarkdown' >, <FHIRClassProperty self.name='valueOid' >, <FHIRClassProperty self.name='valuePositiveInt' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueUnsignedInt' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueUrl' >, <FHIRClassProperty self.name='valueUuid' >, <FHIRClassProperty self.name='valueAddress' >, <FHIRClassProperty self.name='valueAge' >, <FHIRClassProperty self.name='valueAnnotation' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueContactPoint' >, <FHIRClassProperty self.name='valueCount' >, <FHIRClassProperty self.name='valueDistance' >, <FHIRClassProperty self.name='valueDuration' >, <FHIRClassProperty self.name='valueHumanName' >, <FHIRClassProperty self.name='valueIdentifier' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueSignature' >, <FHIRClassProperty self.name='valueTiming' >, <FHIRClassProperty self.name='valueContactDetail' >, <FHIRClassProperty self.name='valueContributor' >, <FHIRClassProperty self.name='valueDataRequirement' >, <FHIRClassProperty self.name='valueExpression' >, <FHIRClassProperty self.name='valueParameterDefinition' >, <FHIRClassProperty self.name='valueRelatedArtifact' >, <FHIRClassProperty self.name='valueTriggerDefinition' >, <FHIRClassProperty self.name='valueUsageContext' >, <FHIRClassProperty self.name='valueDosage' >, <FHIRClassProperty self.name='valueMeta' >]
  

    label: str

    """ Describes the purpose of this example.
    Type `str`. """

    valueBase64Binary: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Value of Example (one of allowed types).
    Type `bool`. """

    valueCanonical: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Value of Example (one of allowed types).
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Value of Example (one of allowed types).
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ Value of Example (one of allowed types).
    Type `float`. """

    valueId: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueInstant: typing.Optional["FHIRDate"]

    """ Value of Example (one of allowed types).
    Type `FHIRDate` (represented as `str` in JSON). """

    valueInteger: typing.Optional[int]

    """ Value of Example (one of allowed types).
    Type `int`. """

    valueMarkdown: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueOid: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valuePositiveInt: typing.Optional[int]

    """ Value of Example (one of allowed types).
    Type `int`. """

    valueString: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueTime: typing.Optional["FHIRDate"]

    """ Value of Example (one of allowed types).
    Type `FHIRDate` (represented as `str` in JSON). """

    valueUnsignedInt: typing.Optional[int]

    """ Value of Example (one of allowed types).
    Type `int`. """

    valueUri: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueUrl: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueUuid: typing.Optional[str]

    """ Value of Example (one of allowed types).
    Type `str`. """

    valueAddress: typing.Optional["Address"]

    """ Value of Example (one of allowed types).
    Type `Address` (represented as `dict` in JSON). """

    valueAge: typing.Optional["Age"]

    """ Value of Example (one of allowed types).
    Type `Age` (represented as `dict` in JSON). """

    valueAnnotation: typing.Optional["Annotation"]

    """ Value of Example (one of allowed types).
    Type `Annotation` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Value of Example (one of allowed types).
    Type `Attachment` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value of Example (one of allowed types).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Value of Example (one of allowed types).
    Type `Coding` (represented as `dict` in JSON). """

    valueContactPoint: typing.Optional["ContactPoint"]

    """ Value of Example (one of allowed types).
    Type `ContactPoint` (represented as `dict` in JSON). """

    valueCount: typing.Optional["Count"]

    """ Value of Example (one of allowed types).
    Type `Count` (represented as `dict` in JSON). """

    valueDistance: typing.Optional["Distance"]

    """ Value of Example (one of allowed types).
    Type `Distance` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ Value of Example (one of allowed types).
    Type `Duration` (represented as `dict` in JSON). """

    valueHumanName: typing.Optional["HumanName"]

    """ Value of Example (one of allowed types).
    Type `HumanName` (represented as `dict` in JSON). """

    valueIdentifier: typing.Optional["Identifier"]

    """ Value of Example (one of allowed types).
    Type `Identifier` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ Value of Example (one of allowed types).
    Type `Money` (represented as `dict` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Value of Example (one of allowed types).
    Type `Period` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Value of Example (one of allowed types).
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value of Example (one of allowed types).
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Value of Example (one of allowed types).
    Type `Ratio` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Value of Example (one of allowed types).
    Type `Reference` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Value of Example (one of allowed types).
    Type `SampledData` (represented as `dict` in JSON). """

    valueSignature: typing.Optional["Signature"]

    """ Value of Example (one of allowed types).
    Type `Signature` (represented as `dict` in JSON). """

    valueTiming: typing.Optional["Timing"]

    """ Value of Example (one of allowed types).
    Type `Timing` (represented as `dict` in JSON). """

    valueContactDetail: typing.Optional["ContactDetail"]

    """ Value of Example (one of allowed types).
    Type `ContactDetail` (represented as `dict` in JSON). """

    valueContributor: typing.Optional["Contributor"]

    """ Value of Example (one of allowed types).
    Type `Contributor` (represented as `dict` in JSON). """

    valueDataRequirement: typing.Optional["DataRequirement"]

    """ Value of Example (one of allowed types).
    Type `DataRequirement` (represented as `dict` in JSON). """

    valueExpression: typing.Optional["Expression"]

    """ Value of Example (one of allowed types).
    Type `Expression` (represented as `dict` in JSON). """

    valueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Value of Example (one of allowed types).
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    valueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Value of Example (one of allowed types).
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    valueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Value of Example (one of allowed types).
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    valueUsageContext: typing.Optional["UsageContext"]

    """ Value of Example (one of allowed types).
    Type `UsageContext` (represented as `dict` in JSON). """

    valueDosage: typing.Optional["Dosage"]

    """ Value of Example (one of allowed types).
    Type `Dosage` (represented as `dict` in JSON). """

    valueMeta: typing.Optional["Meta"]

    """ Value of Example (one of allowed types).
    Type `Meta` (represented as `dict` in JSON). """



#   {'path': 'ElementDefinition.example.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBase64Binary', 'name': 'valueBase64Binary', 'parent_name': 'ElementDefinition.example', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Value of Example (one of allowed types)', 'formal': 'The actual value for the element, which must be one of the types allowed for this element.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBase64Binary', 'valueBoolean', 'valueCanonical', 'valueCode', 'valueDate', 'valueDateTime', 'valueDecimal', 'valueId', 'valueInstant', 'valueInteger', 'valueMarkdown', 'valueOid', 'valuePositiveInt', 'valueString', 'valueTime', 'valueUnsignedInt', 'valueUri', 'valueUrl', 'valueUuid', 'valueAddress', 'valueAge', 'valueAnnotation', 'valueAttachment', 'valueCodeableConcept', 'valueCoding', 'valueContactPoint', 'valueCount', 'valueDistance', 'valueDuration', 'valueHumanName', 'valueIdentifier', 'valueMoney', 'valuePeriod', 'valueQuantity', 'valueRange', 'valueRatio', 'valueReference', 'valueSampledData', 'valueSignature', 'valueTiming', 'valueContactDetail', 'valueContributor', 'valueDataRequirement', 'valueExpression', 'valueParameterDefinition', 'valueRelatedArtifact', 'valueTriggerDefinition', 'valueUsageContext', 'valueDosage', 'valueMeta']), False))


    

     
    



class ElementDefinitionConstraint(Element):
    """ Condition that must evaluate to true.
    
    Formal constraints such as co-occurrence and other constraints that can be
    computationally evaluated within the context of the instance.
    """
    
    # [<FHIRClassProperty self.name='key' >, <FHIRClassProperty self.name='requirements' >, <FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='human' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='xpath' >, <FHIRClassProperty self.name='source' >]
  

    key: str

    """ Target of 'condition' reference above.
    Type `str`. """

    requirements: typing.Optional[str]

    """ Why this constraint is necessary or appropriate.
    Type `str`. """

    severity: "str"

    """ error | warning.
    Type `str`. """

    human: str

    """ Human description of constraint.
    Type `str`. """

    expression: typing.Optional[str]

    """ FHIRPath expression of constraint.
    Type `str`. """

    xpath: typing.Optional[str]

    """ XPath expression of constraint.
    Type `str`. """

    source: typing.Optional[str]

    """ Reference to original source of constraint.
    Type `str`. """




    

     
    



class ElementDefinitionBinding(Element):
    """ ValueSet details if this is coded.
    
    Binds to a value set if this element is coded (code, Coding,
    CodeableConcept, Quantity), or the data types (string, uri).
    """
    
    # [<FHIRClassProperty self.name='strength' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='valueSet' >]
  

    strength: "str"

    """ required | extensible | preferred | example.
    Type `str`. """

    description: typing.Optional[str]

    """ Human explanation of the value set.
    Type `str`. """

    valueSet: typing.Optional[str]

    """ Source of value set.
    Type `str`. """




    

     
    



class ElementDefinitionMapping(Element):
    """ Map element to another set of definitions.
    
    Identifies a concept from an external specification that roughly
    corresponds to this element.
    """
    
    # [<FHIRClassProperty self.name='identity' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='map' >, <FHIRClassProperty self.name='comment' >]
  

    identity: str

    """ Reference to mapping declaration.
    Type `str`. """

    language: typing.Optional[str]

    """ Computable language of mapping.
    Type `str`. """

    map: str

    """ Details of the mapping.
    Type `str`. """

    comment: typing.Optional[str]

    """ Comments about the mapping or its use.
    Type `str`. """




    

     
    



class Expression(Element):
    """ An expression that can be used to generate a value.
    
    A expression that is evaluated in a specified context and returns a value.
    The context of use of the expression must specify the context in which the
    expression is evaluated, and how the result of the expression is used.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='reference' >]
  

    description: typing.Optional[str]

    """ Natural language description of the condition.
    Type `str`. """

    name: typing.Optional[str]

    """ Short name assigned to expression for reuse.
    Type `str`. """

    language: str

    """ text/cql | text/fhirpath | application/x-fhir-query | etc..
    Type `str`. """

    expression: typing.Optional[str]

    """ Expression in specified language.
    Type `str`. """

    reference: typing.Optional[str]

    """ Where the expression is found.
    Type `str`. """




    

     
    



class Extension(Element):
    """ Optional Extensions Element.
    
    Optional Extension Element - found in all resources.
    """
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='valueBase64Binary' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueCanonical' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueInstant' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueMarkdown' >, <FHIRClassProperty self.name='valueOid' >, <FHIRClassProperty self.name='valuePositiveInt' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueUnsignedInt' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueUrl' >, <FHIRClassProperty self.name='valueUuid' >, <FHIRClassProperty self.name='valueAddress' >, <FHIRClassProperty self.name='valueAge' >, <FHIRClassProperty self.name='valueAnnotation' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueContactPoint' >, <FHIRClassProperty self.name='valueCount' >, <FHIRClassProperty self.name='valueDistance' >, <FHIRClassProperty self.name='valueDuration' >, <FHIRClassProperty self.name='valueHumanName' >, <FHIRClassProperty self.name='valueIdentifier' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueSignature' >, <FHIRClassProperty self.name='valueTiming' >, <FHIRClassProperty self.name='valueContactDetail' >, <FHIRClassProperty self.name='valueContributor' >, <FHIRClassProperty self.name='valueDataRequirement' >, <FHIRClassProperty self.name='valueExpression' >, <FHIRClassProperty self.name='valueParameterDefinition' >, <FHIRClassProperty self.name='valueRelatedArtifact' >, <FHIRClassProperty self.name='valueTriggerDefinition' >, <FHIRClassProperty self.name='valueUsageContext' >, <FHIRClassProperty self.name='valueDosage' >, <FHIRClassProperty self.name='valueMeta' >]
  

    url: str

    """ identifies the meaning of the extension.
    Type `str`. """

    valueBase64Binary: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Value of extension.
    Type `bool`. """

    valueCanonical: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Value of extension.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Value of extension.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ Value of extension.
    Type `float`. """

    valueId: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueInstant: typing.Optional["FHIRDate"]

    """ Value of extension.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueInteger: typing.Optional[int]

    """ Value of extension.
    Type `int`. """

    valueMarkdown: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueOid: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valuePositiveInt: typing.Optional[int]

    """ Value of extension.
    Type `int`. """

    valueString: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueTime: typing.Optional["FHIRDate"]

    """ Value of extension.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueUnsignedInt: typing.Optional[int]

    """ Value of extension.
    Type `int`. """

    valueUri: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueUrl: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueUuid: typing.Optional[str]

    """ Value of extension.
    Type `str`. """

    valueAddress: typing.Optional["Address"]

    """ Value of extension.
    Type `Address` (represented as `dict` in JSON). """

    valueAge: typing.Optional["Age"]

    """ Value of extension.
    Type `Age` (represented as `dict` in JSON). """

    valueAnnotation: typing.Optional["Annotation"]

    """ Value of extension.
    Type `Annotation` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Value of extension.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value of extension.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Value of extension.
    Type `Coding` (represented as `dict` in JSON). """

    valueContactPoint: typing.Optional["ContactPoint"]

    """ Value of extension.
    Type `ContactPoint` (represented as `dict` in JSON). """

    valueCount: typing.Optional["Count"]

    """ Value of extension.
    Type `Count` (represented as `dict` in JSON). """

    valueDistance: typing.Optional["Distance"]

    """ Value of extension.
    Type `Distance` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ Value of extension.
    Type `Duration` (represented as `dict` in JSON). """

    valueHumanName: typing.Optional["HumanName"]

    """ Value of extension.
    Type `HumanName` (represented as `dict` in JSON). """

    valueIdentifier: typing.Optional["Identifier"]

    """ Value of extension.
    Type `Identifier` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ Value of extension.
    Type `Money` (represented as `dict` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Value of extension.
    Type `Period` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Value of extension.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value of extension.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Value of extension.
    Type `Ratio` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Value of extension.
    Type `Reference` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Value of extension.
    Type `SampledData` (represented as `dict` in JSON). """

    valueSignature: typing.Optional["Signature"]

    """ Value of extension.
    Type `Signature` (represented as `dict` in JSON). """

    valueTiming: typing.Optional["Timing"]

    """ Value of extension.
    Type `Timing` (represented as `dict` in JSON). """

    valueContactDetail: typing.Optional["ContactDetail"]

    """ Value of extension.
    Type `ContactDetail` (represented as `dict` in JSON). """

    valueContributor: typing.Optional["Contributor"]

    """ Value of extension.
    Type `Contributor` (represented as `dict` in JSON). """

    valueDataRequirement: typing.Optional["DataRequirement"]

    """ Value of extension.
    Type `DataRequirement` (represented as `dict` in JSON). """

    valueExpression: typing.Optional["Expression"]

    """ Value of extension.
    Type `Expression` (represented as `dict` in JSON). """

    valueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Value of extension.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    valueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Value of extension.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    valueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Value of extension.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    valueUsageContext: typing.Optional["UsageContext"]

    """ Value of extension.
    Type `UsageContext` (represented as `dict` in JSON). """

    valueDosage: typing.Optional["Dosage"]

    """ Value of extension.
    Type `Dosage` (represented as `dict` in JSON). """

    valueMeta: typing.Optional["Meta"]

    """ Value of extension.
    Type `Meta` (represented as `dict` in JSON). """



#   {'path': 'Extension.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBase64Binary', 'name': 'valueBase64Binary', 'parent_name': 'Extension', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value of extension', 'formal': 'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBase64Binary', 'valueBoolean', 'valueCanonical', 'valueCode', 'valueDate', 'valueDateTime', 'valueDecimal', 'valueId', 'valueInstant', 'valueInteger', 'valueMarkdown', 'valueOid', 'valuePositiveInt', 'valueString', 'valueTime', 'valueUnsignedInt', 'valueUri', 'valueUrl', 'valueUuid', 'valueAddress', 'valueAge', 'valueAnnotation', 'valueAttachment', 'valueCodeableConcept', 'valueCoding', 'valueContactPoint', 'valueCount', 'valueDistance', 'valueDuration', 'valueHumanName', 'valueIdentifier', 'valueMoney', 'valuePeriod', 'valueQuantity', 'valueRange', 'valueRatio', 'valueReference', 'valueSampledData', 'valueSignature', 'valueTiming', 'valueContactDetail', 'valueContributor', 'valueDataRequirement', 'valueExpression', 'valueParameterDefinition', 'valueRelatedArtifact', 'valueTriggerDefinition', 'valueUsageContext', 'valueDosage', 'valueMeta']), True))


    

     
    



class HumanName(Element):
    """ Name of a human - parts and usage.
    
    A human's name with the ability to identify parts and usage.
    """
    
    # [<FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='family' >, <FHIRClassProperty self.name='given' >, <FHIRClassProperty self.name='prefix' >, <FHIRClassProperty self.name='suffix' >, <FHIRClassProperty self.name='period' >]
  

    use: typing.Optional["str"]

    """ usual | official | temp | nickname | anonymous | old | maiden.
    Type `str`. """

    text: typing.Optional[str]

    """ Text representation of the full name.
    Type `str`. """

    family: typing.Optional[str]

    """ Family name (often called 'Surname').
    Type `str`. """

    given: typing.Optional[typing.List[str]]

    """ Given names (not always 'first'). Includes middle names.
    List of `str` items. """

    prefix: typing.Optional[typing.List[str]]

    """ Parts that come before the name.
    List of `str` items. """

    suffix: typing.Optional[typing.List[str]]

    """ Parts that come after the name.
    List of `str` items. """

    period: typing.Optional["Period"]

    """ Time period when name was/is in use.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class Identifier(Element):
    """ An identifier intended for computation.
    
    An identifier - identifies some entity uniquely and unambiguously.
    Typically this is used for business identifiers.
    """
    
    # [<FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='assigner' >]
  

    use: typing.Optional["str"]

    """ usual | official | temp | secondary | old (If known).
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Description of identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    system: typing.Optional[str]

    """ The namespace for the identifier value.
    Type `str`. """

    value: typing.Optional[str]

    """ The value that is unique.
    Type `str`. """

    period: typing.Optional["Period"]

    """ Time period when id is/was valid for use.
    Type `Period` (represented as `dict` in JSON). """

    assigner: typing.Optional["Reference"]

    """ Organization that issued id (may be just text).
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class Meta(Element):
    """ Metadata about a resource.
    
    The metadata about a resource. This is content in the resource that is
    maintained by the infrastructure. Changes to the content might not always
    be associated with version changes to the resource.
    """
    
    # [<FHIRClassProperty self.name='versionId' >, <FHIRClassProperty self.name='lastUpdated' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='security' >, <FHIRClassProperty self.name='tag' >]
  

    versionId: typing.Optional[str]

    """ Version specific identifier.
    Type `str`. """

    lastUpdated: typing.Optional["FHIRDate"]

    """ When the resource version last changed.
    Type `FHIRDate` (represented as `str` in JSON). """

    source: typing.Optional[str]

    """ Identifies where the resource comes from.
    Type `str`. """

    profile: typing.Optional[typing.List[str]]

    """ Profiles this resource claims to conform to.
    List of `str` items. """

    security: typing.Optional[typing.List["Coding"]]

    """ Security Labels applied to this resource.
    List of `Coding` items (represented as `dict` in JSON). """

    tag: typing.Optional[typing.List["Coding"]]

    """ Tags applied to this resource.
    List of `Coding` items (represented as `dict` in JSON). """




    

     
    



class Money(Element):
    """ An amount of economic utility in some recognized currency.
    """
    
    # [<FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='currency' >]
  

    value: typing.Optional[float]

    """ Numerical value (with implicit precision).
    Type `float`. """

    currency: typing.Optional[str]

    """ ISO 4217 Currency Code.
    Type `str`. """




    

     
    



class Narrative(Element):
    """ Human-readable summary of the resource (essential clinical and business
    information).
    
    A human-readable summary of the resource conveying the essential clinical
    and business information for the resource.
    """
    
    # [<FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='div' >]
  

    status: "str"

    """ generated | extensions | additional | empty.
    Type `str`. """

    div: str

    """ Limited xhtml content.
    Type `str`. """




    

     
    



class ParameterDefinition(Element):
    """ Definition of a parameter to a module.
    
    The parameters to the module. This collection specifies both the input and
    output parameters. Input parameters are provided by the caller as part of
    the $evaluate operation. Output parameters are included in the
    GuidanceResponse.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='profile' >]
  

    name: typing.Optional[str]

    """ Name used to access the parameter value.
    Type `str`. """

    use: "str"

    """ in | out.
    Type `str`. """

    min: typing.Optional[int]

    """ Minimum cardinality.
    Type `int`. """

    max: typing.Optional[str]

    """ Maximum cardinality (a number of *).
    Type `str`. """

    documentation: typing.Optional[str]

    """ A brief description of the parameter.
    Type `str`. """

    type: str

    """ What type of value.
    Type `str`. """

    profile: typing.Optional[str]

    """ What profile the value is expected to be.
    Type `str`. """




    

     
    



class Period(Element):
    """ Time range defined by start and end date/time.
    
    A time period defined by a start and end date and optionally time.
    """
    
    # [<FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >]
  

    start: typing.Optional["FHIRDate"]

    """ Starting time with inclusive boundary.
    Type `FHIRDate` (represented as `str` in JSON). """

    end: typing.Optional["FHIRDate"]

    """ End time with inclusive boundary, if not ongoing.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class Quantity(Element):
    """ A measured or measurable amount.
    
    A measured amount (or an amount that can potentially be measured). Note
    that measured amounts include amounts that are not precisely quantified,
    including amounts involving arbitrary units and floating currencies.
    """
    
    # [<FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='comparator' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='code' >]
  

    value: typing.Optional[float]

    """ Numerical value (with implicit precision).
    Type `float`. """

    comparator: typing.Optional["str"]

    """ < | <= | >= | > - how to understand the value.
    Type `str`. """

    unit: typing.Optional[str]

    """ Unit representation.
    Type `str`. """

    system: typing.Optional[str]

    """ System that defines coded unit form.
    Type `str`. """

    code: typing.Optional[str]

    """ Coded form of the unit.
    Type `str`. """




    

     
    



class Range(Element):
    """ Set of values bounded by low and high.
    
    A set of ordered Quantities defined by a low and high limit.
    """
    
    # [<FHIRClassProperty self.name='low' >, <FHIRClassProperty self.name='high' >]
  

    low: typing.Optional["Quantity"]

    """ Low limit.
    Type `Quantity` (represented as `dict` in JSON). """

    high: typing.Optional["Quantity"]

    """ High limit.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class Ratio(Element):
    """ A ratio of two Quantity values - a numerator and a denominator.
    
    A relationship of two Quantity values - expressed as a numerator and a
    denominator.
    """
    
    # [<FHIRClassProperty self.name='numerator' >, <FHIRClassProperty self.name='denominator' >]
  

    numerator: typing.Optional["Quantity"]

    """ Numerator value.
    Type `Quantity` (represented as `dict` in JSON). """

    denominator: typing.Optional["Quantity"]

    """ Denominator value.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class Reference(Element):
    """ A reference from one resource to another.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='display' >]
  

    reference: typing.Optional[str]

    """ Literal reference, Relative, internal or absolute URL.
    Type `str`. """

    type: typing.Optional[str]

    """ Type the reference refers to (e.g. "Patient").
    Type `str`. """

    identifier: typing.Optional["Identifier"]

    """ Logical reference, when literal reference is not known.
    Type `Identifier` (represented as `dict` in JSON). """

    display: typing.Optional[str]

    """ Text alternative for the resource.
    Type `str`. """




    

     
    



class RelatedArtifact(Element):
    """ Related artifacts for a knowledge resource.
    
    Related artifacts such as additional documentation, justification, or
    bibliographic references.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='label' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='citation' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='document' >, <FHIRClassProperty self.name='resource' >]
  

    type: "str"

    """ documentation | justification | citation | predecessor | successor
        | derived-from | depends-on | composed-of.
    Type `str`. """

    label: typing.Optional[str]

    """ Short label.
    Type `str`. """

    display: typing.Optional[str]

    """ Brief description of the related artifact.
    Type `str`. """

    citation: typing.Optional[str]

    """ Bibliographic citation for the artifact.
    Type `str`. """

    url: typing.Optional[str]

    """ Where the artifact can be accessed.
    Type `str`. """

    document: typing.Optional["Attachment"]

    """ What document is being referenced.
    Type `Attachment` (represented as `dict` in JSON). """

    resource: typing.Optional[str]

    """ What resource is being referenced.
    Type `str`. """




    

     
    



class SampledData(Element):
    """ A series of measurements taken by a device.
    
    A series of measurements taken by a device, with upper and lower limits.
    There may be more than one dimension in the data.
    """
    
    # [<FHIRClassProperty self.name='origin' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='lowerLimit' >, <FHIRClassProperty self.name='upperLimit' >, <FHIRClassProperty self.name='dimensions' >, <FHIRClassProperty self.name='data' >]
  

    origin: "Quantity"

    """ Zero value and units.
    Type `Quantity` (represented as `dict` in JSON). """

    period: float

    """ Number of milliseconds between samples.
    Type `float`. """

    factor: typing.Optional[float]

    """ Multiply data by this before adding to origin.
    Type `float`. """

    lowerLimit: typing.Optional[float]

    """ Lower limit of detection.
    Type `float`. """

    upperLimit: typing.Optional[float]

    """ Upper limit of detection.
    Type `float`. """

    dimensions: int

    """ Number of sample points at each time point.
    Type `int`. """

    data: typing.Optional[str]

    """ Decimal values with spaces, or "E" | "U" | "L".
    Type `str`. """




    

     
    



class Signature(Element):
    """ A Signature - XML DigSig, JWS, Graphical image of signature, etc..
    
    A signature along with supporting context. The signature may be a digital
    signature that is cryptographic in nature, or some other signature
    acceptable to the domain. This other signature may be as simple as a
    graphical image representing a hand-written signature, or a signature
    ceremony Different signature approaches have different utilities.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='when' >, <FHIRClassProperty self.name='who' >, <FHIRClassProperty self.name='onBehalfOf' >, <FHIRClassProperty self.name='targetFormat' >, <FHIRClassProperty self.name='sigFormat' >, <FHIRClassProperty self.name='data' >]
  

    type: typing.List["Coding"]

    """ Indication of the reason the entity signed the object(s).
    List of `Coding` items (represented as `dict` in JSON). """

    when: "FHIRDate"

    """ When the signature was created.
    Type `FHIRDate` (represented as `str` in JSON). """

    who: "Reference"

    """ Who signed.
    Type `Reference` (represented as `dict` in JSON). """

    onBehalfOf: typing.Optional["Reference"]

    """ The party represented.
    Type `Reference` (represented as `dict` in JSON). """

    targetFormat: typing.Optional[str]

    """ The technical format of the signed resources.
    Type `str`. """

    sigFormat: typing.Optional[str]

    """ The technical format of the signature.
    Type `str`. """

    data: typing.Optional[str]

    """ The actual signature content (XML DigSig. JWS, picture, etc.).
    Type `str`. """




    

     
    



class SubstanceAmountReferenceRange(Element):
    """ Reference range of possible or expected values.
    """
    
    # [<FHIRClassProperty self.name='lowLimit' >, <FHIRClassProperty self.name='highLimit' >]
  

    lowLimit: typing.Optional["Quantity"]

    """ Lower limit possible or expected.
    Type `Quantity` (represented as `dict` in JSON). """

    highLimit: typing.Optional["Quantity"]

    """ Upper limit possible or expected.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class TimingRepeat(Element):
    """ When the event is to occur.
    
    A set of rules that describe when the event is scheduled.
    """
    
    # [<FHIRClassProperty self.name='boundsDuration' >, <FHIRClassProperty self.name='boundsRange' >, <FHIRClassProperty self.name='boundsPeriod' >, <FHIRClassProperty self.name='count' >, <FHIRClassProperty self.name='countMax' >, <FHIRClassProperty self.name='duration' >, <FHIRClassProperty self.name='durationMax' >, <FHIRClassProperty self.name='durationUnit' >, <FHIRClassProperty self.name='frequency' >, <FHIRClassProperty self.name='frequencyMax' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='periodMax' >, <FHIRClassProperty self.name='periodUnit' >, <FHIRClassProperty self.name='dayOfWeek' >, <FHIRClassProperty self.name='timeOfDay' >, <FHIRClassProperty self.name='when' >, <FHIRClassProperty self.name='offset' >]
  

    boundsDuration: typing.Optional["Duration"]

    """ Length/Range of lengths, or (Start and/or end) limits.
    Type `Duration` (represented as `dict` in JSON). """

    boundsRange: typing.Optional["Range"]

    """ Length/Range of lengths, or (Start and/or end) limits.
    Type `Range` (represented as `dict` in JSON). """

    boundsPeriod: typing.Optional["Period"]

    """ Length/Range of lengths, or (Start and/or end) limits.
    Type `Period` (represented as `dict` in JSON). """

    count: typing.Optional[int]

    """ Number of times to repeat.
    Type `int`. """

    countMax: typing.Optional[int]

    """ Maximum number of times to repeat.
    Type `int`. """

    duration: typing.Optional[float]

    """ How long when it happens.
    Type `float`. """

    durationMax: typing.Optional[float]

    """ How long when it happens (Max).
    Type `float`. """

    durationUnit: typing.Optional[str]

    """ s | min | h | d | wk | mo | a - unit of time (UCUM).
    Type `str`. """

    frequency: typing.Optional[int]

    """ Event occurs frequency times per period.
    Type `int`. """

    frequencyMax: typing.Optional[int]

    """ Event occurs up to frequencyMax times per period.
    Type `int`. """

    period: typing.Optional[float]

    """ Event occurs frequency times per period.
    Type `float`. """

    periodMax: typing.Optional[float]

    """ Upper limit of period (3-4 hours).
    Type `float`. """

    periodUnit: typing.Optional[str]

    """ s | min | h | d | wk | mo | a - unit of time (UCUM).
    Type `str`. """

    dayOfWeek: typing.Optional[typing.List["str"]]

    """ mon | tue | wed | thu | fri | sat | sun.
    List of `str` items. """

    timeOfDay: typing.Optional[typing.List["FHIRDate"]]

    """ Time of day for action.
    List of `FHIRDate` items (represented as `str` in JSON). """

    when: typing.Optional[typing.List[str]]

    """ Code for time period of occurrence.
    List of `str` items. """

    offset: typing.Optional[int]

    """ Minutes from event (before or after).
    Type `int`. """



#   {'path': 'Timing.repeat.bounds[x]', 'choice_of_type': 'bounds', 'orig_name': 'boundsDuration', 'name': 'boundsDuration', 'parent_name': 'Timing.repeat', 'class_name': 'Duration', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Length/Range of lengths, or (Start and/or end) limits', 'formal': 'Either a duration for the length of the timing schedule, a range of possible length, or outer bounds for start and/or end limits of the timing schedule.', 'representation': None}

    _bounds_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['boundsDuration', 'boundsRange', 'boundsPeriod']), True))


    

     
    



class TriggerDefinition(Element):
    """ Defines an expected trigger for a module.
    
    A description of a triggering event. Triggering events can be named events,
    data events, or periodic, as determined by the type element.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='timingTiming' >, <FHIRClassProperty self.name='timingReference' >, <FHIRClassProperty self.name='timingDate' >, <FHIRClassProperty self.name='timingDateTime' >, <FHIRClassProperty self.name='data' >, <FHIRClassProperty self.name='condition' >]
  

    type: "str"

    """ named-event | periodic | data-changed | data-added | data-modified
        | data-removed | data-accessed | data-access-ended.
    Type `str`. """

    name: typing.Optional[str]

    """ Name or URI that identifies the event.
    Type `str`. """

    timingTiming: typing.Optional["Timing"]

    """ Timing of the event.
    Type `Timing` (represented as `dict` in JSON). """

    timingReference: typing.Optional["Reference"]

    """ Timing of the event.
    Type `Reference` (represented as `dict` in JSON). """

    timingDate: typing.Optional["FHIRDate"]

    """ Timing of the event.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingDateTime: typing.Optional["FHIRDate"]

    """ Timing of the event.
    Type `FHIRDate` (represented as `str` in JSON). """

    data: typing.Optional[typing.List["DataRequirement"]]

    """ Triggering data of the event (multiple = 'and').
    List of `DataRequirement` items (represented as `dict` in JSON). """

    condition: typing.Optional["Expression"]

    """ Whether the event triggers (boolean expression).
    Type `Expression` (represented as `dict` in JSON). """



#   {'path': 'TriggerDefinition.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingTiming', 'name': 'timingTiming', 'parent_name': 'TriggerDefinition', 'class_name': 'Timing', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Timing of the event', 'formal': 'The timing of the event (if this is a periodic trigger).', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingTiming', 'timingReference', 'timingDate', 'timingDateTime']), True))


    

     
    



class UsageContext(Element):
    """ Describes the context of use for a conformance or knowledge resource.
    
    Specifies clinical/business/etc. metadata that can be used to retrieve,
    index and/or categorize an artifact. This metadata can either be specific
    to the applicable population (e.g., age category, DRG) or the specific
    context of care (e.g., venue, care setting, provider of care).
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueReference' >]
  

    code: "Coding"

    """ Type of context being specified.
    Type `Coding` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value that defines the context.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Value that defines the context.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value that defines the context.
    Type `Range` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Value that defines the context.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'UsageContext.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCodeableConcept', 'name': 'valueCodeableConcept', 'parent_name': 'UsageContext', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Value that defines the context', 'formal': 'A value that defines the context specified in this context of use. The interpretation of the value is defined by the code.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCodeableConcept', 'valueQuantity', 'valueRange', 'valueReference']), False))


    

     
    



class Quantity(Element):
    """ A measured or measurable amount.
    
    A measured amount (or an amount that can potentially be measured). Note
    that measured amounts include amounts that are not precisely quantified,
    including amounts involving arbitrary units and floating currencies.
    """
    
    # [<FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='comparator' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='code' >]
  

    value: typing.Optional[float]

    """ Numerical value (with implicit precision).
    Type `float`. """

    comparator: typing.Optional["str"]

    """ < | <= | >= | > - how to understand the value.
    Type `str`. """

    unit: typing.Optional[str]

    """ Unit representation.
    Type `str`. """

    system: typing.Optional[str]

    """ System that defines coded unit form.
    Type `str`. """

    code: typing.Optional[str]

    """ Coded form of the unit.
    Type `str`. """




    

     
    



class Age(Quantity):
    """ A duration of time during which an organism (or a process) has existed.
    """
    
    # []
  




    

     
    



class Count(Quantity):
    """ A measured or measurable amount.
    
    A measured amount (or an amount that can potentially be measured). Note
    that measured amounts include amounts that are not precisely quantified,
    including amounts involving arbitrary units and floating currencies.
    """
    
    # []
  




    

     
    



class Distance(Quantity):
    """ A length - a value with a unit that is a physical distance.
    """
    
    # []
  




    

     
    



class Duration(Quantity):
    """ A length of time.
    """
    
    # []
  




    

     
    



class Age(Quantity):
    """ A duration of time during which an organism (or a process) has existed.
    """
    
    # []
  




    

     
    



class Count(Quantity):
    """ A measured or measurable amount.
    
    A measured amount (or an amount that can potentially be measured). Note
    that measured amounts include amounts that are not precisely quantified,
    including amounts involving arbitrary units and floating currencies.
    """
    
    # []
  




    

     
    



class Distance(Quantity):
    """ A length - a value with a unit that is a physical distance.
    """
    
    # []
  




    

     
    



class Duration(Quantity):
    """ A length of time.
    """
    
    # []
  




    

     
    



class Dosage(BackboneElement):
    """ How the medication is/was taken or should be taken.
    
    Indicates how the medication is/was taken or should be taken by the
    patient.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='additionalInstruction' >, <FHIRClassProperty self.name='patientInstruction' >, <FHIRClassProperty self.name='timing' >, <FHIRClassProperty self.name='asNeededBoolean' >, <FHIRClassProperty self.name='asNeededCodeableConcept' >, <FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='route' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='doseAndRate' >, <FHIRClassProperty self.name='maxDosePerPeriod' >, <FHIRClassProperty self.name='maxDosePerAdministration' >, <FHIRClassProperty self.name='maxDosePerLifetime' >]
  

    sequence: typing.Optional[int]

    """ The order of the dosage instructions.
    Type `int`. """

    text: typing.Optional[str]

    """ Free text dosage instructions e.g. SIG.
    Type `str`. """

    additionalInstruction: typing.Optional[typing.List["CodeableConcept"]]

    """ Supplemental instruction or warnings to the patient - e.g. "with
        meals", "may cause drowsiness".
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    patientInstruction: typing.Optional[str]

    """ Patient or consumer oriented instructions.
    Type `str`. """

    timing: typing.Optional["Timing"]

    """ When medication should be administered.
    Type `Timing` (represented as `dict` in JSON). """

    asNeededBoolean: typing.Optional[bool]

    """ Take "as needed" (for x).
    Type `bool`. """

    asNeededCodeableConcept: typing.Optional["CodeableConcept"]

    """ Take "as needed" (for x).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    site: typing.Optional["CodeableConcept"]

    """ Body site to administer to.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    route: typing.Optional["CodeableConcept"]

    """ How drug should enter body.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ Technique for administering medication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    doseAndRate: typing.Optional[typing.List["DosageDoseAndRate"]]

    """ Amount of medication administered.
    List of `DosageDoseAndRate` items (represented as `dict` in JSON). """

    maxDosePerPeriod: typing.Optional["Ratio"]

    """ Upper limit on medication per unit of time.
    Type `Ratio` (represented as `dict` in JSON). """

    maxDosePerAdministration: typing.Optional["Quantity"]

    """ Upper limit on medication per administration.
    Type `Quantity` (represented as `dict` in JSON). """

    maxDosePerLifetime: typing.Optional["Quantity"]

    """ Upper limit on medication per lifetime of the patient.
    Type `Quantity` (represented as `dict` in JSON). """



#   {'path': 'Dosage.asNeeded[x]', 'choice_of_type': 'asNeeded', 'orig_name': 'asNeededBoolean', 'name': 'asNeededBoolean', 'parent_name': 'Dosage', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Take "as needed" (for x)', 'formal': 'Indicates whether the Medication is only taken when needed within a specific dosing schedule (Boolean option), or it indicates the precondition for taking the Medication (CodeableConcept).', 'representation': None}

    _asNeeded_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['asNeededBoolean', 'asNeededCodeableConcept']), True))


    

     
    



class ElementDefinition(BackboneElement):
    """ Definition of an element in a resource or extension.
    
    Captures constraints on each element within the resource, profile, or
    extension.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='representation' >, <FHIRClassProperty self.name='sliceName' >, <FHIRClassProperty self.name='sliceIsConstraining' >, <FHIRClassProperty self.name='label' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='slicing' >, <FHIRClassProperty self.name='short' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='requirements' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >, <FHIRClassProperty self.name='base' >, <FHIRClassProperty self.name='contentReference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='defaultValueBase64Binary' >, <FHIRClassProperty self.name='defaultValueBoolean' >, <FHIRClassProperty self.name='defaultValueCanonical' >, <FHIRClassProperty self.name='defaultValueCode' >, <FHIRClassProperty self.name='defaultValueDate' >, <FHIRClassProperty self.name='defaultValueDateTime' >, <FHIRClassProperty self.name='defaultValueDecimal' >, <FHIRClassProperty self.name='defaultValueId' >, <FHIRClassProperty self.name='defaultValueInstant' >, <FHIRClassProperty self.name='defaultValueInteger' >, <FHIRClassProperty self.name='defaultValueMarkdown' >, <FHIRClassProperty self.name='defaultValueOid' >, <FHIRClassProperty self.name='defaultValuePositiveInt' >, <FHIRClassProperty self.name='defaultValueString' >, <FHIRClassProperty self.name='defaultValueTime' >, <FHIRClassProperty self.name='defaultValueUnsignedInt' >, <FHIRClassProperty self.name='defaultValueUri' >, <FHIRClassProperty self.name='defaultValueUrl' >, <FHIRClassProperty self.name='defaultValueUuid' >, <FHIRClassProperty self.name='defaultValueAddress' >, <FHIRClassProperty self.name='defaultValueAge' >, <FHIRClassProperty self.name='defaultValueAnnotation' >, <FHIRClassProperty self.name='defaultValueAttachment' >, <FHIRClassProperty self.name='defaultValueCodeableConcept' >, <FHIRClassProperty self.name='defaultValueCoding' >, <FHIRClassProperty self.name='defaultValueContactPoint' >, <FHIRClassProperty self.name='defaultValueCount' >, <FHIRClassProperty self.name='defaultValueDistance' >, <FHIRClassProperty self.name='defaultValueDuration' >, <FHIRClassProperty self.name='defaultValueHumanName' >, <FHIRClassProperty self.name='defaultValueIdentifier' >, <FHIRClassProperty self.name='defaultValueMoney' >, <FHIRClassProperty self.name='defaultValuePeriod' >, <FHIRClassProperty self.name='defaultValueQuantity' >, <FHIRClassProperty self.name='defaultValueRange' >, <FHIRClassProperty self.name='defaultValueRatio' >, <FHIRClassProperty self.name='defaultValueReference' >, <FHIRClassProperty self.name='defaultValueSampledData' >, <FHIRClassProperty self.name='defaultValueSignature' >, <FHIRClassProperty self.name='defaultValueTiming' >, <FHIRClassProperty self.name='defaultValueContactDetail' >, <FHIRClassProperty self.name='defaultValueContributor' >, <FHIRClassProperty self.name='defaultValueDataRequirement' >, <FHIRClassProperty self.name='defaultValueExpression' >, <FHIRClassProperty self.name='defaultValueParameterDefinition' >, <FHIRClassProperty self.name='defaultValueRelatedArtifact' >, <FHIRClassProperty self.name='defaultValueTriggerDefinition' >, <FHIRClassProperty self.name='defaultValueUsageContext' >, <FHIRClassProperty self.name='defaultValueDosage' >, <FHIRClassProperty self.name='defaultValueMeta' >, <FHIRClassProperty self.name='meaningWhenMissing' >, <FHIRClassProperty self.name='orderMeaning' >, <FHIRClassProperty self.name='fixedBase64Binary' >, <FHIRClassProperty self.name='fixedBoolean' >, <FHIRClassProperty self.name='fixedCanonical' >, <FHIRClassProperty self.name='fixedCode' >, <FHIRClassProperty self.name='fixedDate' >, <FHIRClassProperty self.name='fixedDateTime' >, <FHIRClassProperty self.name='fixedDecimal' >, <FHIRClassProperty self.name='fixedId' >, <FHIRClassProperty self.name='fixedInstant' >, <FHIRClassProperty self.name='fixedInteger' >, <FHIRClassProperty self.name='fixedMarkdown' >, <FHIRClassProperty self.name='fixedOid' >, <FHIRClassProperty self.name='fixedPositiveInt' >, <FHIRClassProperty self.name='fixedString' >, <FHIRClassProperty self.name='fixedTime' >, <FHIRClassProperty self.name='fixedUnsignedInt' >, <FHIRClassProperty self.name='fixedUri' >, <FHIRClassProperty self.name='fixedUrl' >, <FHIRClassProperty self.name='fixedUuid' >, <FHIRClassProperty self.name='fixedAddress' >, <FHIRClassProperty self.name='fixedAge' >, <FHIRClassProperty self.name='fixedAnnotation' >, <FHIRClassProperty self.name='fixedAttachment' >, <FHIRClassProperty self.name='fixedCodeableConcept' >, <FHIRClassProperty self.name='fixedCoding' >, <FHIRClassProperty self.name='fixedContactPoint' >, <FHIRClassProperty self.name='fixedCount' >, <FHIRClassProperty self.name='fixedDistance' >, <FHIRClassProperty self.name='fixedDuration' >, <FHIRClassProperty self.name='fixedHumanName' >, <FHIRClassProperty self.name='fixedIdentifier' >, <FHIRClassProperty self.name='fixedMoney' >, <FHIRClassProperty self.name='fixedPeriod' >, <FHIRClassProperty self.name='fixedQuantity' >, <FHIRClassProperty self.name='fixedRange' >, <FHIRClassProperty self.name='fixedRatio' >, <FHIRClassProperty self.name='fixedReference' >, <FHIRClassProperty self.name='fixedSampledData' >, <FHIRClassProperty self.name='fixedSignature' >, <FHIRClassProperty self.name='fixedTiming' >, <FHIRClassProperty self.name='fixedContactDetail' >, <FHIRClassProperty self.name='fixedContributor' >, <FHIRClassProperty self.name='fixedDataRequirement' >, <FHIRClassProperty self.name='fixedExpression' >, <FHIRClassProperty self.name='fixedParameterDefinition' >, <FHIRClassProperty self.name='fixedRelatedArtifact' >, <FHIRClassProperty self.name='fixedTriggerDefinition' >, <FHIRClassProperty self.name='fixedUsageContext' >, <FHIRClassProperty self.name='fixedDosage' >, <FHIRClassProperty self.name='fixedMeta' >, <FHIRClassProperty self.name='patternBase64Binary' >, <FHIRClassProperty self.name='patternBoolean' >, <FHIRClassProperty self.name='patternCanonical' >, <FHIRClassProperty self.name='patternCode' >, <FHIRClassProperty self.name='patternDate' >, <FHIRClassProperty self.name='patternDateTime' >, <FHIRClassProperty self.name='patternDecimal' >, <FHIRClassProperty self.name='patternId' >, <FHIRClassProperty self.name='patternInstant' >, <FHIRClassProperty self.name='patternInteger' >, <FHIRClassProperty self.name='patternMarkdown' >, <FHIRClassProperty self.name='patternOid' >, <FHIRClassProperty self.name='patternPositiveInt' >, <FHIRClassProperty self.name='patternString' >, <FHIRClassProperty self.name='patternTime' >, <FHIRClassProperty self.name='patternUnsignedInt' >, <FHIRClassProperty self.name='patternUri' >, <FHIRClassProperty self.name='patternUrl' >, <FHIRClassProperty self.name='patternUuid' >, <FHIRClassProperty self.name='patternAddress' >, <FHIRClassProperty self.name='patternAge' >, <FHIRClassProperty self.name='patternAnnotation' >, <FHIRClassProperty self.name='patternAttachment' >, <FHIRClassProperty self.name='patternCodeableConcept' >, <FHIRClassProperty self.name='patternCoding' >, <FHIRClassProperty self.name='patternContactPoint' >, <FHIRClassProperty self.name='patternCount' >, <FHIRClassProperty self.name='patternDistance' >, <FHIRClassProperty self.name='patternDuration' >, <FHIRClassProperty self.name='patternHumanName' >, <FHIRClassProperty self.name='patternIdentifier' >, <FHIRClassProperty self.name='patternMoney' >, <FHIRClassProperty self.name='patternPeriod' >, <FHIRClassProperty self.name='patternQuantity' >, <FHIRClassProperty self.name='patternRange' >, <FHIRClassProperty self.name='patternRatio' >, <FHIRClassProperty self.name='patternReference' >, <FHIRClassProperty self.name='patternSampledData' >, <FHIRClassProperty self.name='patternSignature' >, <FHIRClassProperty self.name='patternTiming' >, <FHIRClassProperty self.name='patternContactDetail' >, <FHIRClassProperty self.name='patternContributor' >, <FHIRClassProperty self.name='patternDataRequirement' >, <FHIRClassProperty self.name='patternExpression' >, <FHIRClassProperty self.name='patternParameterDefinition' >, <FHIRClassProperty self.name='patternRelatedArtifact' >, <FHIRClassProperty self.name='patternTriggerDefinition' >, <FHIRClassProperty self.name='patternUsageContext' >, <FHIRClassProperty self.name='patternDosage' >, <FHIRClassProperty self.name='patternMeta' >, <FHIRClassProperty self.name='example' >, <FHIRClassProperty self.name='minValueDate' >, <FHIRClassProperty self.name='minValueDateTime' >, <FHIRClassProperty self.name='minValueInstant' >, <FHIRClassProperty self.name='minValueTime' >, <FHIRClassProperty self.name='minValueDecimal' >, <FHIRClassProperty self.name='minValueInteger' >, <FHIRClassProperty self.name='minValuePositiveInt' >, <FHIRClassProperty self.name='minValueUnsignedInt' >, <FHIRClassProperty self.name='minValueQuantity' >, <FHIRClassProperty self.name='maxValueDate' >, <FHIRClassProperty self.name='maxValueDateTime' >, <FHIRClassProperty self.name='maxValueInstant' >, <FHIRClassProperty self.name='maxValueTime' >, <FHIRClassProperty self.name='maxValueDecimal' >, <FHIRClassProperty self.name='maxValueInteger' >, <FHIRClassProperty self.name='maxValuePositiveInt' >, <FHIRClassProperty self.name='maxValueUnsignedInt' >, <FHIRClassProperty self.name='maxValueQuantity' >, <FHIRClassProperty self.name='maxLength' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='constraint' >, <FHIRClassProperty self.name='mustSupport' >, <FHIRClassProperty self.name='isModifier' >, <FHIRClassProperty self.name='isModifierReason' >, <FHIRClassProperty self.name='isSummary' >, <FHIRClassProperty self.name='binding' >, <FHIRClassProperty self.name='mapping' >]
  

    path: str

    """ Path of the element in the hierarchy of elements.
    Type `str`. """

    representation: typing.Optional[typing.List["str"]]

    """ xmlAttr | xmlText | typeAttr | cdaText | xhtml.
    List of `str` items. """

    sliceName: typing.Optional[str]

    """ Name for this particular element (in a set of slices).
    Type `str`. """

    sliceIsConstraining: typing.Optional[bool]

    """ If this slice definition constrains an inherited slice definition
        (or not).
    Type `bool`. """

    label: typing.Optional[str]

    """ Name for element to display with or prompt for element.
    Type `str`. """

    code: typing.Optional[typing.List["Coding"]]

    """ Corresponding codes in terminologies.
    List of `Coding` items (represented as `dict` in JSON). """

    slicing: typing.Optional["ElementDefinitionSlicing"]

    """ This element is sliced - slices follow.
    Type `ElementDefinitionSlicing` (represented as `dict` in JSON). """

    short: typing.Optional[str]

    """ Concise definition for space-constrained presentation.
    Type `str`. """

    definition: typing.Optional[str]

    """ Full formal definition as narrative text.
    Type `str`. """

    comment: typing.Optional[str]

    """ Comments about the use of this element.
    Type `str`. """

    requirements: typing.Optional[str]

    """ Why this resource has been created.
    Type `str`. """

    alias: typing.Optional[typing.List[str]]

    """ Other names.
    List of `str` items. """

    min: typing.Optional[int]

    """ Minimum Cardinality.
    Type `int`. """

    max: typing.Optional[str]

    """ Maximum Cardinality (a number or *).
    Type `str`. """

    base: typing.Optional["ElementDefinitionBase"]

    """ Base definition information for tools.
    Type `ElementDefinitionBase` (represented as `dict` in JSON). """

    contentReference: typing.Optional[str]

    """ Reference to definition of content for the element.
    Type `str`. """

    type: typing.Optional[typing.List["ElementDefinitionType"]]

    """ Data type and Profile for this element.
    List of `ElementDefinitionType` items (represented as `dict` in JSON). """

    defaultValueBase64Binary: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueBoolean: typing.Optional[bool]

    """ Specified value if missing from instance.
    Type `bool`. """

    defaultValueCanonical: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueCode: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueDate: typing.Optional["FHIRDate"]

    """ Specified value if missing from instance.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueDateTime: typing.Optional["FHIRDate"]

    """ Specified value if missing from instance.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueDecimal: typing.Optional[float]

    """ Specified value if missing from instance.
    Type `float`. """

    defaultValueId: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueInstant: typing.Optional["FHIRDate"]

    """ Specified value if missing from instance.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueInteger: typing.Optional[int]

    """ Specified value if missing from instance.
    Type `int`. """

    defaultValueMarkdown: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueOid: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValuePositiveInt: typing.Optional[int]

    """ Specified value if missing from instance.
    Type `int`. """

    defaultValueString: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueTime: typing.Optional["FHIRDate"]

    """ Specified value if missing from instance.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueUnsignedInt: typing.Optional[int]

    """ Specified value if missing from instance.
    Type `int`. """

    defaultValueUri: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueUrl: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueUuid: typing.Optional[str]

    """ Specified value if missing from instance.
    Type `str`. """

    defaultValueAddress: typing.Optional["Address"]

    """ Specified value if missing from instance.
    Type `Address` (represented as `dict` in JSON). """

    defaultValueAge: typing.Optional["Age"]

    """ Specified value if missing from instance.
    Type `Age` (represented as `dict` in JSON). """

    defaultValueAnnotation: typing.Optional["Annotation"]

    """ Specified value if missing from instance.
    Type `Annotation` (represented as `dict` in JSON). """

    defaultValueAttachment: typing.Optional["Attachment"]

    """ Specified value if missing from instance.
    Type `Attachment` (represented as `dict` in JSON). """

    defaultValueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Specified value if missing from instance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    defaultValueCoding: typing.Optional["Coding"]

    """ Specified value if missing from instance.
    Type `Coding` (represented as `dict` in JSON). """

    defaultValueContactPoint: typing.Optional["ContactPoint"]

    """ Specified value if missing from instance.
    Type `ContactPoint` (represented as `dict` in JSON). """

    defaultValueCount: typing.Optional["Count"]

    """ Specified value if missing from instance.
    Type `Count` (represented as `dict` in JSON). """

    defaultValueDistance: typing.Optional["Distance"]

    """ Specified value if missing from instance.
    Type `Distance` (represented as `dict` in JSON). """

    defaultValueDuration: typing.Optional["Duration"]

    """ Specified value if missing from instance.
    Type `Duration` (represented as `dict` in JSON). """

    defaultValueHumanName: typing.Optional["HumanName"]

    """ Specified value if missing from instance.
    Type `HumanName` (represented as `dict` in JSON). """

    defaultValueIdentifier: typing.Optional["Identifier"]

    """ Specified value if missing from instance.
    Type `Identifier` (represented as `dict` in JSON). """

    defaultValueMoney: typing.Optional["Money"]

    """ Specified value if missing from instance.
    Type `Money` (represented as `dict` in JSON). """

    defaultValuePeriod: typing.Optional["Period"]

    """ Specified value if missing from instance.
    Type `Period` (represented as `dict` in JSON). """

    defaultValueQuantity: typing.Optional["Quantity"]

    """ Specified value if missing from instance.
    Type `Quantity` (represented as `dict` in JSON). """

    defaultValueRange: typing.Optional["Range"]

    """ Specified value if missing from instance.
    Type `Range` (represented as `dict` in JSON). """

    defaultValueRatio: typing.Optional["Ratio"]

    """ Specified value if missing from instance.
    Type `Ratio` (represented as `dict` in JSON). """

    defaultValueReference: typing.Optional["Reference"]

    """ Specified value if missing from instance.
    Type `Reference` (represented as `dict` in JSON). """

    defaultValueSampledData: typing.Optional["SampledData"]

    """ Specified value if missing from instance.
    Type `SampledData` (represented as `dict` in JSON). """

    defaultValueSignature: typing.Optional["Signature"]

    """ Specified value if missing from instance.
    Type `Signature` (represented as `dict` in JSON). """

    defaultValueTiming: typing.Optional["Timing"]

    """ Specified value if missing from instance.
    Type `Timing` (represented as `dict` in JSON). """

    defaultValueContactDetail: typing.Optional["ContactDetail"]

    """ Specified value if missing from instance.
    Type `ContactDetail` (represented as `dict` in JSON). """

    defaultValueContributor: typing.Optional["Contributor"]

    """ Specified value if missing from instance.
    Type `Contributor` (represented as `dict` in JSON). """

    defaultValueDataRequirement: typing.Optional["DataRequirement"]

    """ Specified value if missing from instance.
    Type `DataRequirement` (represented as `dict` in JSON). """

    defaultValueExpression: typing.Optional["Expression"]

    """ Specified value if missing from instance.
    Type `Expression` (represented as `dict` in JSON). """

    defaultValueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Specified value if missing from instance.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    defaultValueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Specified value if missing from instance.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    defaultValueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Specified value if missing from instance.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    defaultValueUsageContext: typing.Optional["UsageContext"]

    """ Specified value if missing from instance.
    Type `UsageContext` (represented as `dict` in JSON). """

    defaultValueDosage: typing.Optional["Dosage"]

    """ Specified value if missing from instance.
    Type `Dosage` (represented as `dict` in JSON). """

    defaultValueMeta: typing.Optional["Meta"]

    """ Specified value if missing from instance.
    Type `Meta` (represented as `dict` in JSON). """

    meaningWhenMissing: typing.Optional[str]

    """ Implicit meaning when this element is missing.
    Type `str`. """

    orderMeaning: typing.Optional[str]

    """ What the order of the elements means.
    Type `str`. """

    fixedBase64Binary: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedBoolean: typing.Optional[bool]

    """ Value must be exactly this.
    Type `bool`. """

    fixedCanonical: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedCode: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedDate: typing.Optional["FHIRDate"]

    """ Value must be exactly this.
    Type `FHIRDate` (represented as `str` in JSON). """

    fixedDateTime: typing.Optional["FHIRDate"]

    """ Value must be exactly this.
    Type `FHIRDate` (represented as `str` in JSON). """

    fixedDecimal: typing.Optional[float]

    """ Value must be exactly this.
    Type `float`. """

    fixedId: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedInstant: typing.Optional["FHIRDate"]

    """ Value must be exactly this.
    Type `FHIRDate` (represented as `str` in JSON). """

    fixedInteger: typing.Optional[int]

    """ Value must be exactly this.
    Type `int`. """

    fixedMarkdown: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedOid: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedPositiveInt: typing.Optional[int]

    """ Value must be exactly this.
    Type `int`. """

    fixedString: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedTime: typing.Optional["FHIRDate"]

    """ Value must be exactly this.
    Type `FHIRDate` (represented as `str` in JSON). """

    fixedUnsignedInt: typing.Optional[int]

    """ Value must be exactly this.
    Type `int`. """

    fixedUri: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedUrl: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedUuid: typing.Optional[str]

    """ Value must be exactly this.
    Type `str`. """

    fixedAddress: typing.Optional["Address"]

    """ Value must be exactly this.
    Type `Address` (represented as `dict` in JSON). """

    fixedAge: typing.Optional["Age"]

    """ Value must be exactly this.
    Type `Age` (represented as `dict` in JSON). """

    fixedAnnotation: typing.Optional["Annotation"]

    """ Value must be exactly this.
    Type `Annotation` (represented as `dict` in JSON). """

    fixedAttachment: typing.Optional["Attachment"]

    """ Value must be exactly this.
    Type `Attachment` (represented as `dict` in JSON). """

    fixedCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value must be exactly this.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fixedCoding: typing.Optional["Coding"]

    """ Value must be exactly this.
    Type `Coding` (represented as `dict` in JSON). """

    fixedContactPoint: typing.Optional["ContactPoint"]

    """ Value must be exactly this.
    Type `ContactPoint` (represented as `dict` in JSON). """

    fixedCount: typing.Optional["Count"]

    """ Value must be exactly this.
    Type `Count` (represented as `dict` in JSON). """

    fixedDistance: typing.Optional["Distance"]

    """ Value must be exactly this.
    Type `Distance` (represented as `dict` in JSON). """

    fixedDuration: typing.Optional["Duration"]

    """ Value must be exactly this.
    Type `Duration` (represented as `dict` in JSON). """

    fixedHumanName: typing.Optional["HumanName"]

    """ Value must be exactly this.
    Type `HumanName` (represented as `dict` in JSON). """

    fixedIdentifier: typing.Optional["Identifier"]

    """ Value must be exactly this.
    Type `Identifier` (represented as `dict` in JSON). """

    fixedMoney: typing.Optional["Money"]

    """ Value must be exactly this.
    Type `Money` (represented as `dict` in JSON). """

    fixedPeriod: typing.Optional["Period"]

    """ Value must be exactly this.
    Type `Period` (represented as `dict` in JSON). """

    fixedQuantity: typing.Optional["Quantity"]

    """ Value must be exactly this.
    Type `Quantity` (represented as `dict` in JSON). """

    fixedRange: typing.Optional["Range"]

    """ Value must be exactly this.
    Type `Range` (represented as `dict` in JSON). """

    fixedRatio: typing.Optional["Ratio"]

    """ Value must be exactly this.
    Type `Ratio` (represented as `dict` in JSON). """

    fixedReference: typing.Optional["Reference"]

    """ Value must be exactly this.
    Type `Reference` (represented as `dict` in JSON). """

    fixedSampledData: typing.Optional["SampledData"]

    """ Value must be exactly this.
    Type `SampledData` (represented as `dict` in JSON). """

    fixedSignature: typing.Optional["Signature"]

    """ Value must be exactly this.
    Type `Signature` (represented as `dict` in JSON). """

    fixedTiming: typing.Optional["Timing"]

    """ Value must be exactly this.
    Type `Timing` (represented as `dict` in JSON). """

    fixedContactDetail: typing.Optional["ContactDetail"]

    """ Value must be exactly this.
    Type `ContactDetail` (represented as `dict` in JSON). """

    fixedContributor: typing.Optional["Contributor"]

    """ Value must be exactly this.
    Type `Contributor` (represented as `dict` in JSON). """

    fixedDataRequirement: typing.Optional["DataRequirement"]

    """ Value must be exactly this.
    Type `DataRequirement` (represented as `dict` in JSON). """

    fixedExpression: typing.Optional["Expression"]

    """ Value must be exactly this.
    Type `Expression` (represented as `dict` in JSON). """

    fixedParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Value must be exactly this.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    fixedRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Value must be exactly this.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    fixedTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Value must be exactly this.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    fixedUsageContext: typing.Optional["UsageContext"]

    """ Value must be exactly this.
    Type `UsageContext` (represented as `dict` in JSON). """

    fixedDosage: typing.Optional["Dosage"]

    """ Value must be exactly this.
    Type `Dosage` (represented as `dict` in JSON). """

    fixedMeta: typing.Optional["Meta"]

    """ Value must be exactly this.
    Type `Meta` (represented as `dict` in JSON). """

    patternBase64Binary: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternBoolean: typing.Optional[bool]

    """ Value must have at least these property values.
    Type `bool`. """

    patternCanonical: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternCode: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternDate: typing.Optional["FHIRDate"]

    """ Value must have at least these property values.
    Type `FHIRDate` (represented as `str` in JSON). """

    patternDateTime: typing.Optional["FHIRDate"]

    """ Value must have at least these property values.
    Type `FHIRDate` (represented as `str` in JSON). """

    patternDecimal: typing.Optional[float]

    """ Value must have at least these property values.
    Type `float`. """

    patternId: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternInstant: typing.Optional["FHIRDate"]

    """ Value must have at least these property values.
    Type `FHIRDate` (represented as `str` in JSON). """

    patternInteger: typing.Optional[int]

    """ Value must have at least these property values.
    Type `int`. """

    patternMarkdown: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternOid: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternPositiveInt: typing.Optional[int]

    """ Value must have at least these property values.
    Type `int`. """

    patternString: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternTime: typing.Optional["FHIRDate"]

    """ Value must have at least these property values.
    Type `FHIRDate` (represented as `str` in JSON). """

    patternUnsignedInt: typing.Optional[int]

    """ Value must have at least these property values.
    Type `int`. """

    patternUri: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternUrl: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternUuid: typing.Optional[str]

    """ Value must have at least these property values.
    Type `str`. """

    patternAddress: typing.Optional["Address"]

    """ Value must have at least these property values.
    Type `Address` (represented as `dict` in JSON). """

    patternAge: typing.Optional["Age"]

    """ Value must have at least these property values.
    Type `Age` (represented as `dict` in JSON). """

    patternAnnotation: typing.Optional["Annotation"]

    """ Value must have at least these property values.
    Type `Annotation` (represented as `dict` in JSON). """

    patternAttachment: typing.Optional["Attachment"]

    """ Value must have at least these property values.
    Type `Attachment` (represented as `dict` in JSON). """

    patternCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value must have at least these property values.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    patternCoding: typing.Optional["Coding"]

    """ Value must have at least these property values.
    Type `Coding` (represented as `dict` in JSON). """

    patternContactPoint: typing.Optional["ContactPoint"]

    """ Value must have at least these property values.
    Type `ContactPoint` (represented as `dict` in JSON). """

    patternCount: typing.Optional["Count"]

    """ Value must have at least these property values.
    Type `Count` (represented as `dict` in JSON). """

    patternDistance: typing.Optional["Distance"]

    """ Value must have at least these property values.
    Type `Distance` (represented as `dict` in JSON). """

    patternDuration: typing.Optional["Duration"]

    """ Value must have at least these property values.
    Type `Duration` (represented as `dict` in JSON). """

    patternHumanName: typing.Optional["HumanName"]

    """ Value must have at least these property values.
    Type `HumanName` (represented as `dict` in JSON). """

    patternIdentifier: typing.Optional["Identifier"]

    """ Value must have at least these property values.
    Type `Identifier` (represented as `dict` in JSON). """

    patternMoney: typing.Optional["Money"]

    """ Value must have at least these property values.
    Type `Money` (represented as `dict` in JSON). """

    patternPeriod: typing.Optional["Period"]

    """ Value must have at least these property values.
    Type `Period` (represented as `dict` in JSON). """

    patternQuantity: typing.Optional["Quantity"]

    """ Value must have at least these property values.
    Type `Quantity` (represented as `dict` in JSON). """

    patternRange: typing.Optional["Range"]

    """ Value must have at least these property values.
    Type `Range` (represented as `dict` in JSON). """

    patternRatio: typing.Optional["Ratio"]

    """ Value must have at least these property values.
    Type `Ratio` (represented as `dict` in JSON). """

    patternReference: typing.Optional["Reference"]

    """ Value must have at least these property values.
    Type `Reference` (represented as `dict` in JSON). """

    patternSampledData: typing.Optional["SampledData"]

    """ Value must have at least these property values.
    Type `SampledData` (represented as `dict` in JSON). """

    patternSignature: typing.Optional["Signature"]

    """ Value must have at least these property values.
    Type `Signature` (represented as `dict` in JSON). """

    patternTiming: typing.Optional["Timing"]

    """ Value must have at least these property values.
    Type `Timing` (represented as `dict` in JSON). """

    patternContactDetail: typing.Optional["ContactDetail"]

    """ Value must have at least these property values.
    Type `ContactDetail` (represented as `dict` in JSON). """

    patternContributor: typing.Optional["Contributor"]

    """ Value must have at least these property values.
    Type `Contributor` (represented as `dict` in JSON). """

    patternDataRequirement: typing.Optional["DataRequirement"]

    """ Value must have at least these property values.
    Type `DataRequirement` (represented as `dict` in JSON). """

    patternExpression: typing.Optional["Expression"]

    """ Value must have at least these property values.
    Type `Expression` (represented as `dict` in JSON). """

    patternParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Value must have at least these property values.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    patternRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Value must have at least these property values.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    patternTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Value must have at least these property values.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    patternUsageContext: typing.Optional["UsageContext"]

    """ Value must have at least these property values.
    Type `UsageContext` (represented as `dict` in JSON). """

    patternDosage: typing.Optional["Dosage"]

    """ Value must have at least these property values.
    Type `Dosage` (represented as `dict` in JSON). """

    patternMeta: typing.Optional["Meta"]

    """ Value must have at least these property values.
    Type `Meta` (represented as `dict` in JSON). """

    example: typing.Optional[typing.List["ElementDefinitionExample"]]

    """ Example value (as defined for type).
    List of `ElementDefinitionExample` items (represented as `dict` in JSON). """

    minValueDate: typing.Optional["FHIRDate"]

    """ Minimum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    minValueDateTime: typing.Optional["FHIRDate"]

    """ Minimum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    minValueInstant: typing.Optional["FHIRDate"]

    """ Minimum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    minValueTime: typing.Optional["FHIRDate"]

    """ Minimum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    minValueDecimal: typing.Optional[float]

    """ Minimum Allowed Value (for some types).
    Type `float`. """

    minValueInteger: typing.Optional[int]

    """ Minimum Allowed Value (for some types).
    Type `int`. """

    minValuePositiveInt: typing.Optional[int]

    """ Minimum Allowed Value (for some types).
    Type `int`. """

    minValueUnsignedInt: typing.Optional[int]

    """ Minimum Allowed Value (for some types).
    Type `int`. """

    minValueQuantity: typing.Optional["Quantity"]

    """ Minimum Allowed Value (for some types).
    Type `Quantity` (represented as `dict` in JSON). """

    maxValueDate: typing.Optional["FHIRDate"]

    """ Maximum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    maxValueDateTime: typing.Optional["FHIRDate"]

    """ Maximum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    maxValueInstant: typing.Optional["FHIRDate"]

    """ Maximum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    maxValueTime: typing.Optional["FHIRDate"]

    """ Maximum Allowed Value (for some types).
    Type `FHIRDate` (represented as `str` in JSON). """

    maxValueDecimal: typing.Optional[float]

    """ Maximum Allowed Value (for some types).
    Type `float`. """

    maxValueInteger: typing.Optional[int]

    """ Maximum Allowed Value (for some types).
    Type `int`. """

    maxValuePositiveInt: typing.Optional[int]

    """ Maximum Allowed Value (for some types).
    Type `int`. """

    maxValueUnsignedInt: typing.Optional[int]

    """ Maximum Allowed Value (for some types).
    Type `int`. """

    maxValueQuantity: typing.Optional["Quantity"]

    """ Maximum Allowed Value (for some types).
    Type `Quantity` (represented as `dict` in JSON). """

    maxLength: typing.Optional[int]

    """ Max length for strings.
    Type `int`. """

    condition: typing.Optional[typing.List[str]]

    """ Reference to invariant about presence.
    List of `str` items. """

    constraint: typing.Optional[typing.List["ElementDefinitionConstraint"]]

    """ Condition that must evaluate to true.
    List of `ElementDefinitionConstraint` items (represented as `dict` in JSON). """

    mustSupport: typing.Optional[bool]

    """ If the element must be supported.
    Type `bool`. """

    isModifier: typing.Optional[bool]

    """ If this modifies the meaning of other elements.
    Type `bool`. """

    isModifierReason: typing.Optional[str]

    """ Reason that this element is marked as a modifier.
    Type `str`. """

    isSummary: typing.Optional[bool]

    """ Include when _summary = true?.
    Type `bool`. """

    binding: typing.Optional["ElementDefinitionBinding"]

    """ ValueSet details if this is coded.
    Type `ElementDefinitionBinding` (represented as `dict` in JSON). """

    mapping: typing.Optional[typing.List["ElementDefinitionMapping"]]

    """ Map element to another set of definitions.
    List of `ElementDefinitionMapping` items (represented as `dict` in JSON). """



#   {'path': 'ElementDefinition.defaultValue[x]', 'choice_of_type': 'defaultValue', 'orig_name': 'defaultValueBase64Binary', 'name': 'defaultValueBase64Binary', 'parent_name': 'ElementDefinition', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Specified value if missing from instance', 'formal': "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false').", 'representation': None}

    _defaultValue_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['defaultValueBase64Binary', 'defaultValueBoolean', 'defaultValueCanonical', 'defaultValueCode', 'defaultValueDate', 'defaultValueDateTime', 'defaultValueDecimal', 'defaultValueId', 'defaultValueInstant', 'defaultValueInteger', 'defaultValueMarkdown', 'defaultValueOid', 'defaultValuePositiveInt', 'defaultValueString', 'defaultValueTime', 'defaultValueUnsignedInt', 'defaultValueUri', 'defaultValueUrl', 'defaultValueUuid', 'defaultValueAddress', 'defaultValueAge', 'defaultValueAnnotation', 'defaultValueAttachment', 'defaultValueCodeableConcept', 'defaultValueCoding', 'defaultValueContactPoint', 'defaultValueCount', 'defaultValueDistance', 'defaultValueDuration', 'defaultValueHumanName', 'defaultValueIdentifier', 'defaultValueMoney', 'defaultValuePeriod', 'defaultValueQuantity', 'defaultValueRange', 'defaultValueRatio', 'defaultValueReference', 'defaultValueSampledData', 'defaultValueSignature', 'defaultValueTiming', 'defaultValueContactDetail', 'defaultValueContributor', 'defaultValueDataRequirement', 'defaultValueExpression', 'defaultValueParameterDefinition', 'defaultValueRelatedArtifact', 'defaultValueTriggerDefinition', 'defaultValueUsageContext', 'defaultValueDosage', 'defaultValueMeta']), True))

#   {'path': 'ElementDefinition.fixed[x]', 'choice_of_type': 'fixed', 'orig_name': 'fixedBase64Binary', 'name': 'fixedBase64Binary', 'parent_name': 'ElementDefinition', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value must be exactly this', 'formal': 'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.', 'representation': None}

    _fixed_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['fixedBase64Binary', 'fixedBoolean', 'fixedCanonical', 'fixedCode', 'fixedDate', 'fixedDateTime', 'fixedDecimal', 'fixedId', 'fixedInstant', 'fixedInteger', 'fixedMarkdown', 'fixedOid', 'fixedPositiveInt', 'fixedString', 'fixedTime', 'fixedUnsignedInt', 'fixedUri', 'fixedUrl', 'fixedUuid', 'fixedAddress', 'fixedAge', 'fixedAnnotation', 'fixedAttachment', 'fixedCodeableConcept', 'fixedCoding', 'fixedContactPoint', 'fixedCount', 'fixedDistance', 'fixedDuration', 'fixedHumanName', 'fixedIdentifier', 'fixedMoney', 'fixedPeriod', 'fixedQuantity', 'fixedRange', 'fixedRatio', 'fixedReference', 'fixedSampledData', 'fixedSignature', 'fixedTiming', 'fixedContactDetail', 'fixedContributor', 'fixedDataRequirement', 'fixedExpression', 'fixedParameterDefinition', 'fixedRelatedArtifact', 'fixedTriggerDefinition', 'fixedUsageContext', 'fixedDosage', 'fixedMeta']), True))

#   {'path': 'ElementDefinition.pattern[x]', 'choice_of_type': 'pattern', 'orig_name': 'patternBase64Binary', 'name': 'patternBase64Binary', 'parent_name': 'ElementDefinition', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value must have at least these property values', 'formal': 'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.', 'representation': None}

    _pattern_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['patternBase64Binary', 'patternBoolean', 'patternCanonical', 'patternCode', 'patternDate', 'patternDateTime', 'patternDecimal', 'patternId', 'patternInstant', 'patternInteger', 'patternMarkdown', 'patternOid', 'patternPositiveInt', 'patternString', 'patternTime', 'patternUnsignedInt', 'patternUri', 'patternUrl', 'patternUuid', 'patternAddress', 'patternAge', 'patternAnnotation', 'patternAttachment', 'patternCodeableConcept', 'patternCoding', 'patternContactPoint', 'patternCount', 'patternDistance', 'patternDuration', 'patternHumanName', 'patternIdentifier', 'patternMoney', 'patternPeriod', 'patternQuantity', 'patternRange', 'patternRatio', 'patternReference', 'patternSampledData', 'patternSignature', 'patternTiming', 'patternContactDetail', 'patternContributor', 'patternDataRequirement', 'patternExpression', 'patternParameterDefinition', 'patternRelatedArtifact', 'patternTriggerDefinition', 'patternUsageContext', 'patternDosage', 'patternMeta']), True))

#   {'path': 'ElementDefinition.minValue[x]', 'choice_of_type': 'minValue', 'orig_name': 'minValueDate', 'name': 'minValueDate', 'parent_name': 'ElementDefinition', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Minimum Allowed Value (for some types)', 'formal': 'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.', 'representation': None}

    _minValue_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['minValueDate', 'minValueDateTime', 'minValueInstant', 'minValueTime', 'minValueDecimal', 'minValueInteger', 'minValuePositiveInt', 'minValueUnsignedInt', 'minValueQuantity']), True))

#   {'path': 'ElementDefinition.maxValue[x]', 'choice_of_type': 'maxValue', 'orig_name': 'maxValueDate', 'name': 'maxValueDate', 'parent_name': 'ElementDefinition', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Maximum Allowed Value (for some types)', 'formal': 'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.', 'representation': None}

    _maxValue_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['maxValueDate', 'maxValueDateTime', 'maxValueInstant', 'maxValueTime', 'maxValueDecimal', 'maxValueInteger', 'maxValuePositiveInt', 'maxValueUnsignedInt', 'maxValueQuantity']), True))


    

     
    



class MarketingStatus(BackboneElement):
    """ The marketing status describes the date when a medicinal product is
    actually put on the market or the date as of which it is no longer
    available.
    """
    
    # [<FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='dateRange' >, <FHIRClassProperty self.name='restoreDate' >]
  

    country: "CodeableConcept"

    """ The country in which the marketing authorisation has been granted
        shall be specified It should be specified using the ISO 3166 ‑ 1
        alpha-2 code elements.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    jurisdiction: typing.Optional["CodeableConcept"]

    """ Where a Medicines Regulatory Agency has granted a marketing
        authorisation for which specific provisions within a jurisdiction
        apply, the jurisdiction can be specified using an appropriate
        controlled terminology The controlled term and the controlled term
        identifier shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: "CodeableConcept"

    """ This attribute provides information on the status of the marketing
        of the medicinal product See ISO/TS 20443 for more information and
        examples.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    dateRange: "Period"

    """ The date when the Medicinal Product is placed on the market by the
        Marketing Authorisation Holder (or where applicable, the
        manufacturer/distributor) in a country and/or jurisdiction shall be
        provided A complete date consisting of day, month and year shall be
        specified using the ISO 8601 date format NOTE “Placed on the
        market” refers to the release of the Medicinal Product into the
        distribution chain.
    Type `Period` (represented as `dict` in JSON). """

    restoreDate: typing.Optional["FHIRDate"]

    """ The date when the Medicinal Product is placed on the market by the
        Marketing Authorisation Holder (or where applicable, the
        manufacturer/distributor) in a country and/or jurisdiction shall be
        provided A complete date consisting of day, month and year shall be
        specified using the ISO 8601 date format NOTE “Placed on the
        market” refers to the release of the Medicinal Product into the
        distribution chain.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class Population(BackboneElement):
    """ A definition of a set of people that apply to some clinically related
    context, for example people contraindicated for a certain medication.
    
    A populatioof people with some set of grouping criteria.
    """
    
    # [<FHIRClassProperty self.name='ageRange' >, <FHIRClassProperty self.name='ageCodeableConcept' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='race' >, <FHIRClassProperty self.name='physiologicalCondition' >]
  

    ageRange: typing.Optional["Range"]

    """ The age of the specific population.
    Type `Range` (represented as `dict` in JSON). """

    ageCodeableConcept: typing.Optional["CodeableConcept"]

    """ The age of the specific population.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    gender: typing.Optional["CodeableConcept"]

    """ The gender of the specific population.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    race: typing.Optional["CodeableConcept"]

    """ Race of the specific population.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    physiologicalCondition: typing.Optional["CodeableConcept"]

    """ The existing physiological conditions of the specific population to
        which this applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'Population.age[x]', 'choice_of_type': 'age', 'orig_name': 'ageRange', 'name': 'ageRange', 'parent_name': 'Population', 'class_name': 'Range', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The age of the specific population', 'formal': None, 'representation': None}

    _age_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['ageRange', 'ageCodeableConcept']), True))


    

     
    



class ProdCharacteristic(BackboneElement):
    """ The marketing status describes the date when a medicinal product is
    actually put on the market or the date as of which it is no longer
    available.
    """
    
    # [<FHIRClassProperty self.name='height' >, <FHIRClassProperty self.name='width' >, <FHIRClassProperty self.name='depth' >, <FHIRClassProperty self.name='weight' >, <FHIRClassProperty self.name='nominalVolume' >, <FHIRClassProperty self.name='externalDiameter' >, <FHIRClassProperty self.name='shape' >, <FHIRClassProperty self.name='color' >, <FHIRClassProperty self.name='imprint' >, <FHIRClassProperty self.name='image' >, <FHIRClassProperty self.name='scoring' >]
  

    height: typing.Optional["Quantity"]

    """ Where applicable, the height can be specified using a numerical
        value and its unit of measurement The unit of measurement shall be
        specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    width: typing.Optional["Quantity"]

    """ Where applicable, the width can be specified using a numerical
        value and its unit of measurement The unit of measurement shall be
        specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    depth: typing.Optional["Quantity"]

    """ Where applicable, the depth can be specified using a numerical
        value and its unit of measurement The unit of measurement shall be
        specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    weight: typing.Optional["Quantity"]

    """ Where applicable, the weight can be specified using a numerical
        value and its unit of measurement The unit of measurement shall be
        specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    nominalVolume: typing.Optional["Quantity"]

    """ Where applicable, the nominal volume can be specified using a
        numerical value and its unit of measurement The unit of measurement
        shall be specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    externalDiameter: typing.Optional["Quantity"]

    """ Where applicable, the external diameter can be specified using a
        numerical value and its unit of measurement The unit of measurement
        shall be specified in accordance with ISO 11240 and the resulting
        terminology The symbol and the symbol identifier shall be used.
    Type `Quantity` (represented as `dict` in JSON). """

    shape: typing.Optional[str]

    """ Where applicable, the shape can be specified An appropriate
        controlled vocabulary shall be used The term and the term
        identifier shall be used.
    Type `str`. """

    color: typing.Optional[typing.List[str]]

    """ Where applicable, the color can be specified An appropriate
        controlled vocabulary shall be used The term and the term
        identifier shall be used.
    List of `str` items. """

    imprint: typing.Optional[typing.List[str]]

    """ Where applicable, the imprint can be specified as text.
    List of `str` items. """

    image: typing.Optional[typing.List["Attachment"]]

    """ Where applicable, the image can be provided The format of the image
        attachment shall be specified by regional implementations.
    List of `Attachment` items (represented as `dict` in JSON). """

    scoring: typing.Optional["CodeableConcept"]

    """ Where applicable, the scoring can be specified An appropriate
        controlled vocabulary shall be used The term and the term
        identifier shall be used.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ProductShelfLife(BackboneElement):
    """ The shelf-life and storage information for a medicinal product item or
    container can be described using this class.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='specialPrecautionsForStorage' >]
  

    identifier: typing.Optional["Identifier"]

    """ Unique identifier for the packaged Medicinal Product.
    Type `Identifier` (represented as `dict` in JSON). """

    type: "CodeableConcept"

    """ This describes the shelf life, taking into account various
        scenarios such as shelf life of the packaged Medicinal Product
        itself, shelf life after transformation where necessary and shelf
        life after the first opening of a bottle, etc. The shelf life type
        shall be specified using an appropriate controlled vocabulary The
        controlled term and the controlled term identifier shall be
        specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    period: "Quantity"

    """ The shelf life time period can be specified using a numerical value
        for the period of time and its unit of time measurement The unit of
        measurement shall be specified in accordance with ISO 11240 and the
        resulting terminology The symbol and the symbol identifier shall be
        used.
    Type `Quantity` (represented as `dict` in JSON). """

    specialPrecautionsForStorage: typing.Optional[typing.List["CodeableConcept"]]

    """ Special precautions for storage, if any, can be specified using an
        appropriate controlled vocabulary The controlled term and the
        controlled term identifier shall be specified.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class SubstanceAmount(BackboneElement):
    """ Chemical substances are a single substance type whose primary defining
    element is the molecular structure. Chemical substances shall be defined on
    the basis of their complete covalent molecular structure; the presence of a
    salt (counter-ion) and/or solvates (water, alcohols) is also captured.
    Purity, grade, physical form or particle size are not taken into account in
    the definition of a chemical substance or in the assignment of a Substance
    ID.
    """
    
    # [<FHIRClassProperty self.name='amountQuantity' >, <FHIRClassProperty self.name='amountRange' >, <FHIRClassProperty self.name='amountString' >, <FHIRClassProperty self.name='amountType' >, <FHIRClassProperty self.name='amountText' >, <FHIRClassProperty self.name='referenceRange' >]
  

    amountQuantity: typing.Optional["Quantity"]

    """ Used to capture quantitative values for a variety of elements. If
        only limits are given, the arithmetic mean would be the average. If
        only a single definite value for a given element is given, it would
        be captured in this field.
    Type `Quantity` (represented as `dict` in JSON). """

    amountRange: typing.Optional["Range"]

    """ Used to capture quantitative values for a variety of elements. If
        only limits are given, the arithmetic mean would be the average. If
        only a single definite value for a given element is given, it would
        be captured in this field.
    Type `Range` (represented as `dict` in JSON). """

    amountString: typing.Optional[str]

    """ Used to capture quantitative values for a variety of elements. If
        only limits are given, the arithmetic mean would be the average. If
        only a single definite value for a given element is given, it would
        be captured in this field.
    Type `str`. """

    amountType: typing.Optional["CodeableConcept"]

    """ Most elements that require a quantitative value will also have a
        field called amount type. Amount type should always be specified
        because the actual value of the amount is often dependent on it.
        EXAMPLE: In capturing the actual relative amounts of substances or
        molecular fragments it is essential to indicate whether the amount
        refers to a mole ratio or weight ratio. For any given element an
        effort should be made to use same the amount type for all related
        definitional elements.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amountText: typing.Optional[str]

    """ A textual comment on a numeric value.
    Type `str`. """

    referenceRange: typing.Optional["SubstanceAmountReferenceRange"]

    """ Reference range of possible or expected values.
    Type `SubstanceAmountReferenceRange` (represented as `dict` in JSON). """



#   {'path': 'SubstanceAmount.amount[x]', 'choice_of_type': 'amount', 'orig_name': 'amountQuantity', 'name': 'amountQuantity', 'parent_name': 'SubstanceAmount', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Used to capture quantitative values for a variety of elements. If only limits are given, the arithmetic mean would be the average. If only a single definite value for a given element is given, it would be captured in this field', 'formal': None, 'representation': None}

    _amount_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['amountQuantity', 'amountRange', 'amountString']), True))


    

     
    



class Timing(BackboneElement):
    """ A timing schedule that specifies an event that may occur multiple times.
    
    Specifies an event that may occur multiple times. Timing schedules are used
    to record when things are planned, expected or requested to occur. The most
    common usage is in dosage instructions for medications. They are also used
    when planning care of various kinds, and may be used for reporting the
    schedule to which past regular activities were carried out.
    """
    
    # [<FHIRClassProperty self.name='event' >, <FHIRClassProperty self.name='repeat' >, <FHIRClassProperty self.name='code' >]
  

    event: typing.Optional[typing.List["FHIRDate"]]

    """ When the event occurs.
    List of `FHIRDate` items (represented as `str` in JSON). """

    repeat: typing.Optional["TimingRepeat"]

    """ When the event is to occur.
    Type `TimingRepeat` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ BID | TID | QID | AM | PM | QD | QOD | +.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class AccountCoverage(BackboneElement):
    """ The party(s) that are responsible for covering the payment of this account,
    and what order should they be applied to the account.
    """
    
    # [<FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='priority' >]
  

    coverage: "Reference"

    """ The party(s), such as insurances, that may contribute to the
        payment of this account.
    Type `Reference` (represented as `dict` in JSON). """

    priority: typing.Optional[int]

    """ The priority of the coverage in the context of this account.
    Type `int`. """




    

     
    



class AccountGuarantor(BackboneElement):
    """ The parties ultimately responsible for balancing the Account.
    
    The parties responsible for balancing the account if other payment options
    fall short.
    """
    
    # [<FHIRClassProperty self.name='party' >, <FHIRClassProperty self.name='onHold' >, <FHIRClassProperty self.name='period' >]
  

    party: "Reference"

    """ Responsible entity.
    Type `Reference` (represented as `dict` in JSON). """

    onHold: typing.Optional[bool]

    """ Credit or other hold applied.
    Type `bool`. """

    period: typing.Optional["Period"]

    """ Guarantee account during.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class ActivityDefinitionParticipant(BackboneElement):
    """ Who should participate in the action.
    
    Indicates who should participate in performing the action described.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='role' >]
  

    type: "str"

    """ patient | practitioner | related-person | device.
    Type `str`. """

    role: typing.Optional["CodeableConcept"]

    """ E.g. Nurse, Surgeon, Parent, etc..
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ActivityDefinitionDynamicValue(BackboneElement):
    """ Dynamic aspects of the definition.
    
    Dynamic values that will be evaluated to produce values for elements of the
    resulting resource. For example, if the dosage of a medication must be
    computed based on the patient's weight, a dynamic value would be used to
    specify an expression that calculated the weight, and the path on the
    request resource that would contain the result.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='expression' >]
  

    path: str

    """ The path to the element to be set dynamically.
    Type `str`. """

    expression: "Expression"

    """ An expression that provides the dynamic value for the customization.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class AdverseEventSuspectEntity(BackboneElement):
    """ The suspected agent causing the adverse event.
    
    Describes the entity that is suspected to have caused the adverse event.
    """
    
    # [<FHIRClassProperty self.name='instance' >, <FHIRClassProperty self.name='causality' >]
  

    instance: "Reference"

    """ Refers to the specific entity that caused the adverse event.
    Type `Reference` (represented as `dict` in JSON). """

    causality: typing.Optional[typing.List["AdverseEventSuspectEntityCausality"]]

    """ Information on the possible cause of the event.
    List of `AdverseEventSuspectEntityCausality` items (represented as `dict` in JSON). """




    

     
    



class AdverseEventSuspectEntityCausality(BackboneElement):
    """ Information on the possible cause of the event.
    """
    
    # [<FHIRClassProperty self.name='assessment' >, <FHIRClassProperty self.name='productRelatedness' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='method' >]
  

    assessment: typing.Optional["CodeableConcept"]

    """ Assessment of if the entity caused the event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productRelatedness: typing.Optional[str]

    """ AdverseEvent.suspectEntity.causalityProductRelatedness.
    Type `str`. """

    author: typing.Optional["Reference"]

    """ AdverseEvent.suspectEntity.causalityAuthor.
    Type `Reference` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ ProbabilityScale | Bayesian | Checklist.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class AllergyIntoleranceReaction(BackboneElement):
    """ Adverse Reaction Events linked to exposure to substance.
    
    Details about each adverse reaction event linked to exposure to the
    identified substance.
    """
    
    # [<FHIRClassProperty self.name='substance' >, <FHIRClassProperty self.name='manifestation' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='onset' >, <FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='exposureRoute' >, <FHIRClassProperty self.name='note' >]
  

    substance: typing.Optional["CodeableConcept"]

    """ Specific substance or pharmaceutical product considered to be
        responsible for event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    manifestation: typing.List["CodeableConcept"]

    """ Clinical symptoms/signs associated with the Event.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Description of the event as a whole.
    Type `str`. """

    onset: typing.Optional["FHIRDate"]

    """ Date(/time) when manifestations showed.
    Type `FHIRDate` (represented as `str` in JSON). """

    severity: typing.Optional["str"]

    """ mild | moderate | severe (of event as a whole).
    Type `str`. """

    exposureRoute: typing.Optional["CodeableConcept"]

    """ How the subject was exposed to the substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Text about event not captured in other fields.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class AppointmentParticipant(BackboneElement):
    """ Participants involved in appointment.
    
    List of participants involved in the appointment.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='required' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='period' >]
  

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Role of participant in the appointment.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    actor: typing.Optional["Reference"]

    """ Person, Location/HealthcareService or Device.
    Type `Reference` (represented as `dict` in JSON). """

    required: typing.Optional["str"]

    """ required | optional | information-only.
    Type `str`. """

    status: "str"

    """ accepted | declined | tentative | needs-action.
    Type `str`. """

    period: typing.Optional["Period"]

    """ Participation period of the actor.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class AuditEventAgent(BackboneElement):
    """ Actor involved in the event.
    
    An actor taking an active role in the event or activity that is logged.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='who' >, <FHIRClassProperty self.name='altId' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='requestor' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='policy' >, <FHIRClassProperty self.name='media' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='purposeOfUse' >]
  

    type: typing.Optional["CodeableConcept"]

    """ How agent participated.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    role: typing.Optional[typing.List["CodeableConcept"]]

    """ Agent role in the event.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    who: typing.Optional["Reference"]

    """ Identifier of who.
    Type `Reference` (represented as `dict` in JSON). """

    altId: typing.Optional[str]

    """ Alternative User identity.
    Type `str`. """

    name: typing.Optional[str]

    """ Human friendly name for the agent.
    Type `str`. """

    requestor: bool

    """ Whether user is initiator.
    Type `bool`. """

    location: typing.Optional["Reference"]

    """ Where.
    Type `Reference` (represented as `dict` in JSON). """

    policy: typing.Optional[typing.List[str]]

    """ Policy that authorized event.
    List of `str` items. """

    media: typing.Optional["Coding"]

    """ Type of media.
    Type `Coding` (represented as `dict` in JSON). """

    network: typing.Optional["AuditEventAgentNetwork"]

    """ Logical network location for application activity.
    Type `AuditEventAgentNetwork` (represented as `dict` in JSON). """

    purposeOfUse: typing.Optional[typing.List["CodeableConcept"]]

    """ Reason given for this user.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class AuditEventAgentNetwork(BackboneElement):
    """ Logical network location for application activity.
    
    Logical network location for application activity, if the activity has a
    network location.
    """
    
    # [<FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='type' >]
  

    address: typing.Optional[str]

    """ Identifier for the network access point of the user device.
    Type `str`. """

    type: typing.Optional[str]

    """ The type of network access point.
    Type `str`. """




    

     
    



class AuditEventSource(BackboneElement):
    """ Audit Event Reporter.
    
    The system that is reporting the event.
    """
    
    # [<FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='observer' >, <FHIRClassProperty self.name='type' >]
  

    site: typing.Optional[str]

    """ Logical source location within the enterprise.
    Type `str`. """

    observer: "Reference"

    """ The identity of source detecting the event.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["Coding"]]

    """ The type of source where event originated.
    List of `Coding` items (represented as `dict` in JSON). """




    

     
    



class AuditEventEntity(BackboneElement):
    """ Data or objects used.
    
    Specific instances of data or objects that have been accessed.
    """
    
    # [<FHIRClassProperty self.name='what' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='lifecycle' >, <FHIRClassProperty self.name='securityLabel' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='query' >, <FHIRClassProperty self.name='detail' >]
  

    what: typing.Optional["Reference"]

    """ Specific instance of resource.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional["Coding"]

    """ Type of entity involved.
    Type `Coding` (represented as `dict` in JSON). """

    role: typing.Optional["Coding"]

    """ What role the entity played.
    Type `Coding` (represented as `dict` in JSON). """

    lifecycle: typing.Optional["Coding"]

    """ Life-cycle stage for the entity.
    Type `Coding` (represented as `dict` in JSON). """

    securityLabel: typing.Optional[typing.List["Coding"]]

    """ Security labels on the entity.
    List of `Coding` items (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Descriptor for entity.
    Type `str`. """

    description: typing.Optional[str]

    """ Descriptive text.
    Type `str`. """

    query: typing.Optional[str]

    """ Query parameters.
    Type `str`. """

    detail: typing.Optional[typing.List["AuditEventEntityDetail"]]

    """ Additional Information about the entity.
    List of `AuditEventEntityDetail` items (represented as `dict` in JSON). """




    

     
    



class AuditEventEntityDetail(BackboneElement):
    """ Additional Information about the entity.
    
    Tagged value pairs for conveying additional information about the entity.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueBase64Binary' >]
  

    type: str

    """ Name of the property.
    Type `str`. """

    valueString: typing.Optional[str]

    """ Property value.
    Type `str`. """

    valueBase64Binary: typing.Optional[str]

    """ Property value.
    Type `str`. """



#   {'path': 'AuditEvent.entity.detail.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueString', 'name': 'valueString', 'parent_name': 'AuditEvent.entity.detail', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Property value', 'formal': 'The  value of the extra detail.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueString', 'valueBase64Binary']), False))


    

     
    



class BiologicallyDerivedProductCollection(BackboneElement):
    """ How this product was collected.
    """
    
    # [<FHIRClassProperty self.name='collector' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='collectedDateTime' >, <FHIRClassProperty self.name='collectedPeriod' >]
  

    collector: typing.Optional["Reference"]

    """ Individual performing collection.
    Type `Reference` (represented as `dict` in JSON). """

    source: typing.Optional["Reference"]

    """ Who is product from.
    Type `Reference` (represented as `dict` in JSON). """

    collectedDateTime: typing.Optional["FHIRDate"]

    """ Time of product collection.
    Type `FHIRDate` (represented as `str` in JSON). """

    collectedPeriod: typing.Optional["Period"]

    """ Time of product collection.
    Type `Period` (represented as `dict` in JSON). """



#   {'path': 'BiologicallyDerivedProduct.collection.collected[x]', 'choice_of_type': 'collected', 'orig_name': 'collectedDateTime', 'name': 'collectedDateTime', 'parent_name': 'BiologicallyDerivedProduct.collection', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time of product collection', 'formal': None, 'representation': None}

    _collected_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['collectedDateTime', 'collectedPeriod']), True))


    

     
    



class BiologicallyDerivedProductProcessing(BackboneElement):
    """ Any processing of the product during collection.
    
    Any processing of the product during collection that does not change the
    fundamental nature of the product. For example adding anti-coagulants
    during the collection of Peripheral Blood Stem Cells.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='procedure' >, <FHIRClassProperty self.name='additive' >, <FHIRClassProperty self.name='timeDateTime' >, <FHIRClassProperty self.name='timePeriod' >]
  

    description: typing.Optional[str]

    """ Description of of processing.
    Type `str`. """

    procedure: typing.Optional["CodeableConcept"]

    """ Procesing code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additive: typing.Optional["Reference"]

    """ Substance added during processing.
    Type `Reference` (represented as `dict` in JSON). """

    timeDateTime: typing.Optional["FHIRDate"]

    """ Time of processing.
    Type `FHIRDate` (represented as `str` in JSON). """

    timePeriod: typing.Optional["Period"]

    """ Time of processing.
    Type `Period` (represented as `dict` in JSON). """



#   {'path': 'BiologicallyDerivedProduct.processing.time[x]', 'choice_of_type': 'time', 'orig_name': 'timeDateTime', 'name': 'timeDateTime', 'parent_name': 'BiologicallyDerivedProduct.processing', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time of processing', 'formal': None, 'representation': None}

    _time_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timeDateTime', 'timePeriod']), True))


    

     
    



class BiologicallyDerivedProductManipulation(BackboneElement):
    """ Any manipulation of product post-collection.
    
    Any manipulation of product post-collection that is intended to alter the
    product.  For example a buffy-coat enrichment or CD8 reduction of
    Peripheral Blood Stem Cells to make it more suitable for infusion.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='timeDateTime' >, <FHIRClassProperty self.name='timePeriod' >]
  

    description: typing.Optional[str]

    """ Description of manipulation.
    Type `str`. """

    timeDateTime: typing.Optional["FHIRDate"]

    """ Time of manipulation.
    Type `FHIRDate` (represented as `str` in JSON). """

    timePeriod: typing.Optional["Period"]

    """ Time of manipulation.
    Type `Period` (represented as `dict` in JSON). """



#   {'path': 'BiologicallyDerivedProduct.manipulation.time[x]', 'choice_of_type': 'time', 'orig_name': 'timeDateTime', 'name': 'timeDateTime', 'parent_name': 'BiologicallyDerivedProduct.manipulation', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time of manipulation', 'formal': None, 'representation': None}

    _time_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timeDateTime', 'timePeriod']), True))


    

     
    



class BiologicallyDerivedProductStorage(BackboneElement):
    """ Product storage.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='temperature' >, <FHIRClassProperty self.name='scale' >, <FHIRClassProperty self.name='duration' >]
  

    description: typing.Optional[str]

    """ Description of storage.
    Type `str`. """

    temperature: typing.Optional[float]

    """ Storage temperature.
    Type `float`. """

    scale: typing.Optional["str"]

    """ farenheit | celsius | kelvin.
    Type `str`. """

    duration: typing.Optional["Period"]

    """ Storage timeperiod.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class BundleLink(BackboneElement):
    """ Links related to this Bundle.
    
    A series of links that provide context to this bundle.
    """
    
    # [<FHIRClassProperty self.name='relation' >, <FHIRClassProperty self.name='url' >]
  

    relation: str

    """ See http://www.iana.org/assignments/link-relations/link-
        relations.xhtml#link-relations-1.
    Type `str`. """

    url: str

    """ Reference details for the link.
    Type `str`. """




    

     
    



class BundleEntry(BackboneElement):
    """ Entry in the bundle - will have a resource or information.
    
    An entry in a bundle resource - will either contain a resource or
    information about a resource (transactions and history only).
    """
    
    # [<FHIRClassProperty self.name='link' >, <FHIRClassProperty self.name='fullUrl' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='search' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='response' >]
  

    link: typing.Optional[typing.List["BundleLink"]]

    """ Links related to this entry.
    List of `BundleLink` items (represented as `dict` in JSON). """

    fullUrl: typing.Optional[str]

    """ URI for resource (Absolute URL server address or URI for UUID/OID).
    Type `str`. """

    resource: typing.Optional["Resource"]

    """ A resource in the bundle.
    Type `Resource` (represented as `dict` in JSON). """

    search: typing.Optional["BundleEntrySearch"]

    """ Search related information.
    Type `BundleEntrySearch` (represented as `dict` in JSON). """

    request: typing.Optional["BundleEntryRequest"]

    """ Additional execution information (transaction/batch/history).
    Type `BundleEntryRequest` (represented as `dict` in JSON). """

    response: typing.Optional["BundleEntryResponse"]

    """ Results of execution (transaction/batch/history).
    Type `BundleEntryResponse` (represented as `dict` in JSON). """




    

     
    



class BundleEntrySearch(BackboneElement):
    """ Search related information.
    
    Information about the search process that lead to the creation of this
    entry.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='score' >]
  

    mode: typing.Optional["str"]

    """ match | include | outcome - why this is in the result set.
    Type `str`. """

    score: typing.Optional[float]

    """ Search ranking (between 0 and 1).
    Type `float`. """




    

     
    



class BundleEntryRequest(BackboneElement):
    """ Additional execution information (transaction/batch/history).
    
    Additional information about how this entry should be processed as part of
    a transaction or batch.  For history, it shows how the entry was processed
    to create the version contained in the entry.
    """
    
    # [<FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='ifNoneMatch' >, <FHIRClassProperty self.name='ifModifiedSince' >, <FHIRClassProperty self.name='ifMatch' >, <FHIRClassProperty self.name='ifNoneExist' >]
  

    method: "str"

    """ GET | HEAD | POST | PUT | DELETE | PATCH.
    Type `str`. """

    url: str

    """ URL for HTTP equivalent of this entry.
    Type `str`. """

    ifNoneMatch: typing.Optional[str]

    """ For managing cache currency.
    Type `str`. """

    ifModifiedSince: typing.Optional["FHIRDate"]

    """ For managing cache currency.
    Type `FHIRDate` (represented as `str` in JSON). """

    ifMatch: typing.Optional[str]

    """ For managing update contention.
    Type `str`. """

    ifNoneExist: typing.Optional[str]

    """ For conditional creates.
    Type `str`. """




    

     
    



class BundleEntryResponse(BackboneElement):
    """ Results of execution (transaction/batch/history).
    
    Indicates the results of processing the corresponding 'request' entry in
    the batch or transaction being responded to or what the results of an
    operation where when returning history.
    """
    
    # [<FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='etag' >, <FHIRClassProperty self.name='lastModified' >, <FHIRClassProperty self.name='outcome' >]
  

    status: str

    """ Status response code (text optional).
    Type `str`. """

    location: typing.Optional[str]

    """ The location (if the operation returns a location).
    Type `str`. """

    etag: typing.Optional[str]

    """ The Etag for the resource (if relevant).
    Type `str`. """

    lastModified: typing.Optional["FHIRDate"]

    """ Server's date time modified.
    Type `FHIRDate` (represented as `str` in JSON). """

    outcome: typing.Optional["Resource"]

    """ OperationOutcome with hints and warnings (for batch/transaction).
    Type `Resource` (represented as `dict` in JSON). """




    

     
    



class CapabilityStatementSoftware(BackboneElement):
    """ Software that is covered by this capability statement.
    
    Software that is covered by this capability statement.  It is used when the
    capability statement describes the capabilities of a particular software
    version, independent of an installation.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='releaseDate' >]
  

    name: str

    """ A name the software is known by.
    Type `str`. """

    version: typing.Optional[str]

    """ Version covered by this statement.
    Type `str`. """

    releaseDate: typing.Optional["FHIRDate"]

    """ Date this version was released.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class CapabilityStatementImplementation(BackboneElement):
    """ If this describes a specific instance.
    
    Identifies a specific implementation instance that is described by the
    capability statement - i.e. a particular installation, rather than the
    capabilities of a software program.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='custodian' >]
  

    description: str

    """ Describes this specific instance.
    Type `str`. """

    url: typing.Optional[str]

    """ Base URL for the installation.
    Type `str`. """

    custodian: typing.Optional["Reference"]

    """ Organization that manages the data.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class CapabilityStatementRest(BackboneElement):
    """ If the endpoint is a RESTful one.
    
    A definition of the restful capabilities of the solution, if any.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='security' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='interaction' >, <FHIRClassProperty self.name='searchParam' >, <FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='compartment' >]
  

    mode: "str"

    """ client | server.
    Type `str`. """

    documentation: typing.Optional[str]

    """ General description of implementation.
    Type `str`. """

    security: typing.Optional["CapabilityStatementRestSecurity"]

    """ Information about security of implementation.
    Type `CapabilityStatementRestSecurity` (represented as `dict` in JSON). """

    resource: typing.Optional[typing.List["CapabilityStatementRestResource"]]

    """ Resource served on the REST interface.
    List of `CapabilityStatementRestResource` items (represented as `dict` in JSON). """

    interaction: typing.Optional[typing.List["CapabilityStatementRestInteraction"]]

    """ What operations are supported?.
    List of `CapabilityStatementRestInteraction` items (represented as `dict` in JSON). """

    searchParam: typing.Optional[typing.List["CapabilityStatementRestResourceSearchParam"]]

    """ Search parameters for searching all resources.
    List of `CapabilityStatementRestResourceSearchParam` items (represented as `dict` in JSON). """

    operation: typing.Optional[typing.List["CapabilityStatementRestResourceOperation"]]

    """ Definition of a system level operation.
    List of `CapabilityStatementRestResourceOperation` items (represented as `dict` in JSON). """

    compartment: typing.Optional[typing.List[str]]

    """ Compartments served/used by system.
    List of `str` items. """




    

     
    



class CapabilityStatementRestSecurity(BackboneElement):
    """ Information about security of implementation.
    
    Information about security implementation from an interface perspective -
    what a client needs to know.
    """
    
    # [<FHIRClassProperty self.name='cors' >, <FHIRClassProperty self.name='service' >, <FHIRClassProperty self.name='description' >]
  

    cors: typing.Optional[bool]

    """ Adds CORS Headers (http://enable-cors.org/).
    Type `bool`. """

    service: typing.Optional[typing.List["CodeableConcept"]]

    """ OAuth | SMART-on-FHIR | NTLM | Basic | Kerberos | Certificates.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ General description of how security works.
    Type `str`. """




    

     
    



class CapabilityStatementRestResource(BackboneElement):
    """ Resource served on the REST interface.
    
    A specification of the restful capabilities of the solution for a specific
    resource type.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='supportedProfile' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='interaction' >, <FHIRClassProperty self.name='versioning' >, <FHIRClassProperty self.name='readHistory' >, <FHIRClassProperty self.name='updateCreate' >, <FHIRClassProperty self.name='conditionalCreate' >, <FHIRClassProperty self.name='conditionalRead' >, <FHIRClassProperty self.name='conditionalUpdate' >, <FHIRClassProperty self.name='conditionalDelete' >, <FHIRClassProperty self.name='referencePolicy' >, <FHIRClassProperty self.name='searchInclude' >, <FHIRClassProperty self.name='searchRevInclude' >, <FHIRClassProperty self.name='searchParam' >, <FHIRClassProperty self.name='operation' >]
  

    type: "str"

    """ A resource type that is supported.
    Type `str`. """

    profile: typing.Optional[str]

    """ Base System profile for all uses of resource.
    Type `str`. """

    supportedProfile: typing.Optional[typing.List[str]]

    """ Profiles for use cases supported.
    List of `str` items. """

    documentation: typing.Optional[str]

    """ Additional information about the use of the resource type.
    Type `str`. """

    interaction: typing.Optional[typing.List["CapabilityStatementRestResourceInteraction"]]

    """ What operations are supported?.
    List of `CapabilityStatementRestResourceInteraction` items (represented as `dict` in JSON). """

    versioning: typing.Optional["str"]

    """ no-version | versioned | versioned-update.
    Type `str`. """

    readHistory: typing.Optional[bool]

    """ Whether vRead can return past versions.
    Type `bool`. """

    updateCreate: typing.Optional[bool]

    """ If update can commit to a new identity.
    Type `bool`. """

    conditionalCreate: typing.Optional[bool]

    """ If allows/uses conditional create.
    Type `bool`. """

    conditionalRead: typing.Optional["str"]

    """ not-supported | modified-since | not-match | full-support.
    Type `str`. """

    conditionalUpdate: typing.Optional[bool]

    """ If allows/uses conditional update.
    Type `bool`. """

    conditionalDelete: typing.Optional["str"]

    """ not-supported | single | multiple - how conditional delete is
        supported.
    Type `str`. """

    referencePolicy: typing.Optional[typing.List["str"]]

    """ literal | logical | resolves | enforced | local.
    List of `str` items. """

    searchInclude: typing.Optional[typing.List[str]]

    """ _include values supported by the server.
    List of `str` items. """

    searchRevInclude: typing.Optional[typing.List[str]]

    """ _revinclude values supported by the server.
    List of `str` items. """

    searchParam: typing.Optional[typing.List["CapabilityStatementRestResourceSearchParam"]]

    """ Search parameters supported by implementation.
    List of `CapabilityStatementRestResourceSearchParam` items (represented as `dict` in JSON). """

    operation: typing.Optional[typing.List["CapabilityStatementRestResourceOperation"]]

    """ Definition of a resource operation.
    List of `CapabilityStatementRestResourceOperation` items (represented as `dict` in JSON). """




    

     
    



class CapabilityStatementRestResourceInteraction(BackboneElement):
    """ What operations are supported?.
    
    Identifies a restful operation supported by the solution.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='documentation' >]
  

    code: "str"

    """ read | vread | update | patch | delete | history-instance |
        history-type | create | search-type.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Anything special about operation behavior.
    Type `str`. """




    

     
    



class CapabilityStatementRestResourceSearchParam(BackboneElement):
    """ Search parameters supported by implementation.
    
    Search parameters for implementations to support and/or make use of -
    either references to ones defined in the specification, or additional ones
    defined for/by the implementation.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='documentation' >]
  

    name: str

    """ Name of search parameter.
    Type `str`. """

    definition: typing.Optional[str]

    """ Source of definition for parameter.
    Type `str`. """

    type: "str"

    """ number | date | string | token | reference | composite | quantity |
        uri | special.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Server-specific usage.
    Type `str`. """




    

     
    



class CapabilityStatementRestResourceOperation(BackboneElement):
    """ Definition of a resource operation.
    
    Definition of an operation or a named query together with its parameters
    and their meaning and type. Consult the definition of the operation for
    details about how to invoke the operation, and the parameters.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='documentation' >]
  

    name: str

    """ Name by which the operation/query is invoked.
    Type `str`. """

    definition: str

    """ The defined operation/query.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Specific details about operation behavior.
    Type `str`. """




    

     
    



class CapabilityStatementRestInteraction(BackboneElement):
    """ What operations are supported?.
    
    A specification of restful operations supported by the system.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='documentation' >]
  

    code: "str"

    """ transaction | batch | search-system | history-system.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Anything special about operation behavior.
    Type `str`. """




    

     
    



class CapabilityStatementMessaging(BackboneElement):
    """ If messaging is supported.
    
    A description of the messaging capabilities of the solution.
    """
    
    # [<FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='reliableCache' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='supportedMessage' >]
  

    endpoint: typing.Optional[typing.List["CapabilityStatementMessagingEndpoint"]]

    """ Where messages should be sent.
    List of `CapabilityStatementMessagingEndpoint` items (represented as `dict` in JSON). """

    reliableCache: typing.Optional[int]

    """ Reliable Message Cache Length (min).
    Type `int`. """

    documentation: typing.Optional[str]

    """ Messaging interface behavior details.
    Type `str`. """

    supportedMessage: typing.Optional[typing.List["CapabilityStatementMessagingSupportedMessage"]]

    """ Messages supported by this system.
    List of `CapabilityStatementMessagingSupportedMessage` items (represented as `dict` in JSON). """




    

     
    



class CapabilityStatementMessagingEndpoint(BackboneElement):
    """ Where messages should be sent.
    
    An endpoint (network accessible address) to which messages and/or replies
    are to be sent.
    """
    
    # [<FHIRClassProperty self.name='protocol' >, <FHIRClassProperty self.name='address' >]
  

    protocol: "Coding"

    """ http | ftp | mllp +.
    Type `Coding` (represented as `dict` in JSON). """

    address: str

    """ Network address or identifier of the end-point.
    Type `str`. """




    

     
    



class CapabilityStatementMessagingSupportedMessage(BackboneElement):
    """ Messages supported by this system.
    
    References to message definitions for messages this system can send or
    receive.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='definition' >]
  

    mode: "str"

    """ sender | receiver.
    Type `str`. """

    definition: str

    """ Message supported by this system.
    Type `str`. """




    

     
    



class CapabilityStatementDocument(BackboneElement):
    """ Document definition.
    
    A document definition.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='profile' >]
  

    mode: "str"

    """ producer | consumer.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Description of document support.
    Type `str`. """

    profile: str

    """ Constraint on the resources used in the document.
    Type `str`. """




    

     
    



class CarePlanActivity(BackboneElement):
    """ Action to occur as part of plan.
    
    Identifies a planned action to occur as part of the plan.  For example, a
    medication to be used, lab tests to perform, self-monitoring, education,
    etc.
    """
    
    # [<FHIRClassProperty self.name='outcomeCodeableConcept' >, <FHIRClassProperty self.name='outcomeReference' >, <FHIRClassProperty self.name='progress' >, <FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='detail' >]
  

    outcomeCodeableConcept: typing.Optional[typing.List["CodeableConcept"]]

    """ Results of the activity.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    outcomeReference: typing.Optional[typing.List["Reference"]]

    """ Appointment, Encounter, Procedure, etc..
    List of `Reference` items (represented as `dict` in JSON). """

    progress: typing.Optional[typing.List["Annotation"]]

    """ Comments about the activity status/progress.
    List of `Annotation` items (represented as `dict` in JSON). """

    reference: typing.Optional["Reference"]

    """ Activity details defined in specific resource.
    Type `Reference` (represented as `dict` in JSON). """

    detail: typing.Optional["CarePlanActivityDetail"]

    """ In-line definition of activity.
    Type `CarePlanActivityDetail` (represented as `dict` in JSON). """




    

     
    



class CarePlanActivityDetail(BackboneElement):
    """ In-line definition of activity.
    
    A simple summary of a planned activity suitable for a general care plan
    system (e.g. form driven) that doesn't know about specific resources such
    as procedure etc.
    """
    
    # [<FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='instantiatesCanonical' >, <FHIRClassProperty self.name='instantiatesUri' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='goal' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusReason' >, <FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='scheduledTiming' >, <FHIRClassProperty self.name='scheduledPeriod' >, <FHIRClassProperty self.name='scheduledString' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='productCodeableConcept' >, <FHIRClassProperty self.name='productReference' >, <FHIRClassProperty self.name='dailyAmount' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='description' >]
  

    kind: typing.Optional["str"]

    """ Appointment | CommunicationRequest | DeviceRequest |
        MedicationRequest | NutritionOrder | Task | ServiceRequest |
        VisionPrescription.
    Type `str`. """

    instantiatesCanonical: typing.Optional[typing.List[str]]

    """ Instantiates FHIR protocol or definition.
    List of `str` items. """

    instantiatesUri: typing.Optional[typing.List[str]]

    """ Instantiates external protocol or definition.
    List of `str` items. """

    code: typing.Optional["CodeableConcept"]

    """ Detail type of activity.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why activity should be done or why activity was prohibited.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why activity is needed.
    List of `Reference` items (represented as `dict` in JSON). """

    goal: typing.Optional[typing.List["Reference"]]

    """ Goals this activity relates to.
    List of `Reference` items (represented as `dict` in JSON). """

    status: "str"

    """ not-started | scheduled | in-progress | on-hold | completed |
        cancelled | stopped | unknown | entered-in-error.
    Type `str`. """

    statusReason: typing.Optional["CodeableConcept"]

    """ Reason for current status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    doNotPerform: typing.Optional[bool]

    """ If true, activity is prohibiting action.
    Type `bool`. """

    scheduledTiming: typing.Optional["Timing"]

    """ When activity is to occur.
    Type `Timing` (represented as `dict` in JSON). """

    scheduledPeriod: typing.Optional["Period"]

    """ When activity is to occur.
    Type `Period` (represented as `dict` in JSON). """

    scheduledString: typing.Optional[str]

    """ When activity is to occur.
    Type `str`. """

    location: typing.Optional["Reference"]

    """ Where it should happen.
    Type `Reference` (represented as `dict` in JSON). """

    performer: typing.Optional[typing.List["Reference"]]

    """ Who will be responsible?.
    List of `Reference` items (represented as `dict` in JSON). """

    productCodeableConcept: typing.Optional["CodeableConcept"]

    """ What is to be administered/supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productReference: typing.Optional["Reference"]

    """ What is to be administered/supplied.
    Type `Reference` (represented as `dict` in JSON). """

    dailyAmount: typing.Optional["Quantity"]

    """ How to consume/day?.
    Type `Quantity` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ How much to administer/supply/consume.
    Type `Quantity` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Extra info describing activity to perform.
    Type `str`. """



#   {'path': 'CarePlan.activity.detail.scheduled[x]', 'choice_of_type': 'scheduled', 'orig_name': 'scheduledTiming', 'name': 'scheduledTiming', 'parent_name': 'CarePlan.activity.detail', 'class_name': 'Timing', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When activity is to occur', 'formal': 'The period, timing or frequency upon which the described activity is to occur.', 'representation': None}

    _scheduled_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['scheduledTiming', 'scheduledPeriod', 'scheduledString']), True))

#   {'path': 'CarePlan.activity.detail.product[x]', 'choice_of_type': 'product', 'orig_name': 'productCodeableConcept', 'name': 'productCodeableConcept', 'parent_name': 'CarePlan.activity.detail', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'What is to be administered/supplied', 'formal': 'Identifies the food, drug or other product to be consumed or supplied in the activity.', 'representation': None}

    _product_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['productCodeableConcept', 'productReference']), True))


    

     
    



class CareTeamParticipant(BackboneElement):
    """ Members of the team.
    
    Identifies all people and organizations who are expected to be involved in
    the care team.
    """
    
    # [<FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='member' >, <FHIRClassProperty self.name='onBehalfOf' >, <FHIRClassProperty self.name='period' >]
  

    role: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of involvement.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    member: typing.Optional["Reference"]

    """ Who is involved.
    Type `Reference` (represented as `dict` in JSON). """

    onBehalfOf: typing.Optional["Reference"]

    """ Organization of the practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time period of participant.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class CatalogEntryRelatedEntry(BackboneElement):
    """ An item that this catalog entry is related to.
    
    Used for example, to point to a substance, or to a device used to
    administer a medication.
    """
    
    # [<FHIRClassProperty self.name='relationtype' >, <FHIRClassProperty self.name='item' >]
  

    relationtype: "str"

    """ triggers | is-replaced-by.
    Type `str`. """

    item: "Reference"

    """ The reference to the related item.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ChargeItemPerformer(BackboneElement):
    """ Who performed charged service.
    
    Indicates who or what performed or participated in the charged service.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >]
  

    function: typing.Optional["CodeableConcept"]

    """ What type of performance was done.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Individual who was performing.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ChargeItemDefinitionApplicability(BackboneElement):
    """ Whether or not the billing code is applicable.
    
    Expressions that describe applicability criteria for the billing code.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='expression' >]
  

    description: typing.Optional[str]

    """ Natural language description of the condition.
    Type `str`. """

    language: typing.Optional[str]

    """ Language of the expression.
    Type `str`. """

    expression: typing.Optional[str]

    """ Boolean-valued expression.
    Type `str`. """




    

     
    



class ChargeItemDefinitionPropertyGroup(BackboneElement):
    """ Group of properties which are applicable under the same conditions.
    
    Group of properties which are applicable under the same conditions. If no
    applicability rules are established for the group, then all properties
    always apply.
    """
    
    # [<FHIRClassProperty self.name='applicability' >, <FHIRClassProperty self.name='priceComponent' >]
  

    applicability: typing.Optional[typing.List["ChargeItemDefinitionApplicability"]]

    """ Conditions under which the priceComponent is applicable.
    List of `ChargeItemDefinitionApplicability` items (represented as `dict` in JSON). """

    priceComponent: typing.Optional[typing.List["ChargeItemDefinitionPropertyGroupPriceComponent"]]

    """ Components of total line item price.
    List of `ChargeItemDefinitionPropertyGroupPriceComponent` items (represented as `dict` in JSON). """




    

     
    



class ChargeItemDefinitionPropertyGroupPriceComponent(BackboneElement):
    """ Components of total line item price.
    
    The price for a ChargeItem may be calculated as a base price with
    surcharges/deductions that apply in certain conditions. A
    ChargeItemDefinition resource that defines the prices, factors and
    conditions that apply to a billing code is currently under development. The
    priceComponent element can be used to offer transparency to the recipient
    of the Invoice of how the prices have been calculated.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='amount' >]
  

    type: "str"

    """ base | surcharge | deduction | discount | tax | informational.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Code identifying the specific component.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Factor used for calculating this component.
    Type `float`. """

    amount: typing.Optional["Money"]

    """ Monetary amount associated with this component.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class ClaimRelated(BackboneElement):
    """ Prior or corollary claims.
    
    Other claims which are related to this claim such as prior submissions or
    claims for related services or for the same event.
    """
    
    # [<FHIRClassProperty self.name='claim' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='reference' >]
  

    claim: typing.Optional["Reference"]

    """ Reference to the related claim.
    Type `Reference` (represented as `dict` in JSON). """

    relationship: typing.Optional["CodeableConcept"]

    """ How the reference claim is related.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reference: typing.Optional["Identifier"]

    """ File or case reference.
    Type `Identifier` (represented as `dict` in JSON). """




    

     
    



class ClaimPayee(BackboneElement):
    """ Recipient of benefits payable.
    
    The party to be reimbursed for cost of the products and services according
    to the terms of the policy.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='party' >]
  

    type: "CodeableConcept"

    """ Category of recipient.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    party: typing.Optional["Reference"]

    """ Recipient reference.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ClaimCareTeam(BackboneElement):
    """ Members of the care team.
    
    The members of the team who provided the products and services.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='qualification' >]
  

    sequence: int

    """ Order of care team.
    Type `int`. """

    provider: "Reference"

    """ Practitioner or organization.
    Type `Reference` (represented as `dict` in JSON). """

    responsible: typing.Optional[bool]

    """ Indicator of the lead practitioner.
    Type `bool`. """

    role: typing.Optional["CodeableConcept"]

    """ Function within the team.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    qualification: typing.Optional["CodeableConcept"]

    """ Practitioner credential or specialization.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ClaimSupportingInfo(BackboneElement):
    """ Supporting information.
    
    Additional information codes regarding exceptions, special considerations,
    the condition, situation, prior or concurrent issues.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='timingDate' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='reason' >]
  

    sequence: int

    """ Information instance identifier.
    Type `int`. """

    category: "CodeableConcept"

    """ Classification of the supplied information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Type of information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    timingDate: typing.Optional["FHIRDate"]

    """ When it occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ When it occurred.
    Type `Period` (represented as `dict` in JSON). """

    valueBoolean: typing.Optional[bool]

    """ Data to be provided.
    Type `bool`. """

    valueString: typing.Optional[str]

    """ Data to be provided.
    Type `str`. """

    valueQuantity: typing.Optional["Quantity"]

    """ Data to be provided.
    Type `Quantity` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Data to be provided.
    Type `Attachment` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Data to be provided.
    Type `Reference` (represented as `dict` in JSON). """

    reason: typing.Optional["CodeableConcept"]

    """ Explanation for the information.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'Claim.supportingInfo.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingDate', 'name': 'timingDate', 'parent_name': 'Claim.supportingInfo', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When it occurred', 'formal': 'The date when or period to which this information refers.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingDate', 'timingPeriod']), True))

#   {'path': 'Claim.supportingInfo.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBoolean', 'name': 'valueBoolean', 'parent_name': 'Claim.supportingInfo', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Data to be provided', 'formal': 'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBoolean', 'valueString', 'valueQuantity', 'valueAttachment', 'valueReference']), True))


    

     
    



class ClaimDiagnosis(BackboneElement):
    """ Pertinent diagnosis information.
    
    Information about diagnoses relevant to the claim items.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='diagnosisCodeableConcept' >, <FHIRClassProperty self.name='diagnosisReference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='onAdmission' >, <FHIRClassProperty self.name='packageCode' >]
  

    sequence: int

    """ Diagnosis instance identifier.
    Type `int`. """

    diagnosisCodeableConcept: typing.Optional["CodeableConcept"]

    """ Nature of illness or problem.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diagnosisReference: typing.Optional["Reference"]

    """ Nature of illness or problem.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Timing or nature of the diagnosis.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    onAdmission: typing.Optional["CodeableConcept"]

    """ Present on admission.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    packageCode: typing.Optional["CodeableConcept"]

    """ Package billing code.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'Claim.diagnosis.diagnosis[x]', 'choice_of_type': 'diagnosis', 'orig_name': 'diagnosisCodeableConcept', 'name': 'diagnosisCodeableConcept', 'parent_name': 'Claim.diagnosis', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Nature of illness or problem', 'formal': 'The nature of illness or problem in a coded form or as a reference to an external defined Condition.', 'representation': None}

    _diagnosis_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['diagnosisCodeableConcept', 'diagnosisReference']), False))


    

     
    



class ClaimProcedure(BackboneElement):
    """ Clinical procedures performed.
    
    Procedures performed on the patient relevant to the billing items with the
    claim.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='procedureCodeableConcept' >, <FHIRClassProperty self.name='procedureReference' >, <FHIRClassProperty self.name='udi' >]
  

    sequence: int

    """ Procedure instance identifier.
    Type `int`. """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Category of Procedure.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the procedure was performed.
    Type `FHIRDate` (represented as `str` in JSON). """

    procedureCodeableConcept: typing.Optional["CodeableConcept"]

    """ Specific clinical procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    procedureReference: typing.Optional["Reference"]

    """ Specific clinical procedure.
    Type `Reference` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'Claim.procedure.procedure[x]', 'choice_of_type': 'procedure', 'orig_name': 'procedureCodeableConcept', 'name': 'procedureCodeableConcept', 'parent_name': 'Claim.procedure', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Specific clinical procedure', 'formal': 'The code or reference to a Procedure resource which identifies the clinical intervention performed.', 'representation': None}

    _procedure_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['procedureCodeableConcept', 'procedureReference']), False))


    

     
    



class ClaimInsurance(BackboneElement):
    """ Patient insurance information.
    
    Financial instruments for reimbursement for the health care products and
    services specified on the claim.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='focal' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='businessArrangement' >, <FHIRClassProperty self.name='preAuthRef' >, <FHIRClassProperty self.name='claimResponse' >]
  

    sequence: int

    """ Insurance instance identifier.
    Type `int`. """

    focal: bool

    """ Coverage to be used for adjudication.
    Type `bool`. """

    identifier: typing.Optional["Identifier"]

    """ Pre-assigned Claim number.
    Type `Identifier` (represented as `dict` in JSON). """

    coverage: "Reference"

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """

    businessArrangement: typing.Optional[str]

    """ Additional provider contract number.
    Type `str`. """

    preAuthRef: typing.Optional[typing.List[str]]

    """ Prior authorization reference number.
    List of `str` items. """

    claimResponse: typing.Optional["Reference"]

    """ Adjudication results.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ClaimAccident(BackboneElement):
    """ Details of the event.
    
    Details of an accident which resulted in injuries which required the
    products and services listed in the claim.
    """
    
    # [<FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >]
  

    date: "FHIRDate"

    """ When the incident occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ The nature of the accident.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Where the event occurred.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Where the event occurred.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Claim.accident.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationAddress', 'name': 'locationAddress', 'parent_name': 'Claim.accident', 'class_name': 'Address', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Where the event occurred', 'formal': 'The physical location of the accident event.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationAddress', 'locationReference']), True))


    

     
    



class ClaimItem(BackboneElement):
    """ Product or service provided.
    
    A claim line. Either a simple  product or service or a 'group' of details
    which can each be a simple items or groups of sub-details.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='careTeamSequence' >, <FHIRClassProperty self.name='diagnosisSequence' >, <FHIRClassProperty self.name='procedureSequence' >, <FHIRClassProperty self.name='informationSequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='locationCodeableConcept' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='subSite' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='detail' >]
  

    sequence: int

    """ Item instance identifier.
    Type `int`. """

    careTeamSequence: typing.Optional[typing.List[int]]

    """ Applicable careTeam members.
    List of `int` items. """

    diagnosisSequence: typing.Optional[typing.List[int]]

    """ Applicable diagnoses.
    List of `int` items. """

    procedureSequence: typing.Optional[typing.List[int]]

    """ Applicable procedures.
    List of `int` items. """

    informationSequence: typing.Optional[typing.List[int]]

    """ Applicable exception and supporting information.
    List of `int` items. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Product or service billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Date or dates of service or product delivery.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Date or dates of service or product delivery.
    Type `Period` (represented as `dict` in JSON). """

    locationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Place of service or where product was supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Place of service or where product was supplied.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Place of service or where product was supplied.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Anatomical location.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subSite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical sub-location.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    encounter: typing.Optional[typing.List["Reference"]]

    """ Encounters related to this billed item.
    List of `Reference` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["ClaimItemDetail"]]

    """ Product or service provided.
    List of `ClaimItemDetail` items (represented as `dict` in JSON). """



#   {'path': 'Claim.item.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'Claim.item', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date or dates of service or product delivery', 'formal': 'The date or dates when the service or product was supplied, performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))

#   {'path': 'Claim.item.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationCodeableConcept', 'name': 'locationCodeableConcept', 'parent_name': 'Claim.item', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Place of service or where product was supplied', 'formal': 'Where the product or service was provided.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationCodeableConcept', 'locationAddress', 'locationReference']), True))


    

     
    



class ClaimItemDetail(BackboneElement):
    """ Product or service provided.
    
    A claim detail line. Either a simple (a product or service) or a 'group' of
    sub-details which are simple items.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >, <FHIRClassProperty self.name='subDetail' >]
  

    sequence: int

    """ Item instance identifier.
    Type `int`. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """

    subDetail: typing.Optional[typing.List["ClaimItemDetailSubDetail"]]

    """ Product or service provided.
    List of `ClaimItemDetailSubDetail` items (represented as `dict` in JSON). """




    

     
    



class ClaimItemDetailSubDetail(BackboneElement):
    """ Product or service provided.
    
    A claim detail line. Either a simple (a product or service) or a 'group' of
    sub-details which are simple items.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >]
  

    sequence: int

    """ Item instance identifier.
    Type `int`. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseItem(BackboneElement):
    """ Adjudication for claim line items.
    
    A claim line. Either a simple (a product or service) or a 'group' of
    details which can also be a simple items or groups of sub-details.
    """
    
    # [<FHIRClassProperty self.name='itemSequence' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='detail' >]
  

    itemSequence: int

    """ Claim item instance identifier.
    Type `int`. """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.List["ClaimResponseItemAdjudication"]

    """ Adjudication details.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["ClaimResponseItemDetail"]]

    """ Adjudication for claim details.
    List of `ClaimResponseItemDetail` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseItemAdjudication(BackboneElement):
    """ Adjudication details.
    
    If this item is a group then the values here are a summary of the
    adjudication of the detail items. If this item is a simple product or
    service then this is the result of the adjudication of this item.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='value' >]
  

    category: "CodeableConcept"

    """ Type of adjudication information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reason: typing.Optional["CodeableConcept"]

    """ Explanation of adjudication outcome.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Money"]

    """ Monetary amount.
    Type `Money` (represented as `dict` in JSON). """

    value: typing.Optional[float]

    """ Non-monetary value.
    Type `float`. """




    

     
    



class ClaimResponseItemDetail(BackboneElement):
    """ Adjudication for claim details.
    
    A claim detail. Either a simple (a product or service) or a 'group' of sub-
    details which are simple items.
    """
    
    # [<FHIRClassProperty self.name='detailSequence' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='subDetail' >]
  

    detailSequence: int

    """ Claim detail instance identifier.
    Type `int`. """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.List["ClaimResponseItemAdjudication"]

    """ Detail level adjudication details.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """

    subDetail: typing.Optional[typing.List["ClaimResponseItemDetailSubDetail"]]

    """ Adjudication for claim sub-details.
    List of `ClaimResponseItemDetailSubDetail` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseItemDetailSubDetail(BackboneElement):
    """ Adjudication for claim sub-details.
    
    A sub-detail adjudication of a simple product or service.
    """
    
    # [<FHIRClassProperty self.name='subDetailSequence' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >]
  

    subDetailSequence: int

    """ Claim sub-detail instance identifier.
    Type `int`. """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ClaimResponseItemAdjudication"]]

    """ Subdetail level adjudication details.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseAddItem(BackboneElement):
    """ Insurer added line items.
    
    The first-tier service adjudications for payor added product or service
    lines.
    """
    
    # [<FHIRClassProperty self.name='itemSequence' >, <FHIRClassProperty self.name='detailSequence' >, <FHIRClassProperty self.name='subdetailSequence' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='locationCodeableConcept' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='subSite' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='detail' >]
  

    itemSequence: typing.Optional[typing.List[int]]

    """ Item sequence number.
    List of `int` items. """

    detailSequence: typing.Optional[typing.List[int]]

    """ Detail sequence number.
    List of `int` items. """

    subdetailSequence: typing.Optional[typing.List[int]]

    """ Subdetail sequence number.
    List of `int` items. """

    provider: typing.Optional[typing.List["Reference"]]

    """ Authorized providers.
    List of `Reference` items (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Date or dates of service or product delivery.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Date or dates of service or product delivery.
    Type `Period` (represented as `dict` in JSON). """

    locationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Place of service or where product was supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Place of service or where product was supplied.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Place of service or where product was supplied.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Anatomical location.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subSite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical sub-location.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.List["ClaimResponseItemAdjudication"]

    """ Added items adjudication.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["ClaimResponseAddItemDetail"]]

    """ Insurer added line details.
    List of `ClaimResponseAddItemDetail` items (represented as `dict` in JSON). """



#   {'path': 'ClaimResponse.addItem.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'ClaimResponse.addItem', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date or dates of service or product delivery', 'formal': 'The date or dates when the service or product was supplied, performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))

#   {'path': 'ClaimResponse.addItem.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationCodeableConcept', 'name': 'locationCodeableConcept', 'parent_name': 'ClaimResponse.addItem', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Place of service or where product was supplied', 'formal': 'Where the product or service was provided.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationCodeableConcept', 'locationAddress', 'locationReference']), True))


    

     
    



class ClaimResponseAddItemDetail(BackboneElement):
    """ Insurer added line details.
    
    The second-tier service adjudications for payor added services.
    """
    
    # [<FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='subDetail' >]
  

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.List["ClaimResponseItemAdjudication"]

    """ Added items detail adjudication.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """

    subDetail: typing.Optional[typing.List["ClaimResponseAddItemDetailSubDetail"]]

    """ Insurer added line items.
    List of `ClaimResponseAddItemDetailSubDetail` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseAddItemDetailSubDetail(BackboneElement):
    """ Insurer added line items.
    
    The third-tier service adjudications for payor added services.
    """
    
    # [<FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >]
  

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.List["ClaimResponseItemAdjudication"]

    """ Added items detail adjudication.
    List of `ClaimResponseItemAdjudication` items (represented as `dict` in JSON). """




    

     
    



class ClaimResponseTotal(BackboneElement):
    """ Adjudication totals.
    
    Categorized monetary totals for the adjudication.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='amount' >]
  

    category: "CodeableConcept"

    """ Type of adjudication information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: "Money"

    """ Financial total for the category.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class ClaimResponsePayment(BackboneElement):
    """ Payment Details.
    
    Payment details for the adjudication of the claim.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='adjustment' >, <FHIRClassProperty self.name='adjustmentReason' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='identifier' >]
  

    type: "CodeableConcept"

    """ Partial or complete payment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    adjustment: typing.Optional["Money"]

    """ Payment adjustment for non-claim issues.
    Type `Money` (represented as `dict` in JSON). """

    adjustmentReason: typing.Optional["CodeableConcept"]

    """ Explanation for the adjustment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Expected date of payment.
    Type `FHIRDate` (represented as `str` in JSON). """

    amount: "Money"

    """ Payable amount after adjustment.
    Type `Money` (represented as `dict` in JSON). """

    identifier: typing.Optional["Identifier"]

    """ Business identifier for the payment.
    Type `Identifier` (represented as `dict` in JSON). """




    

     
    



class ClaimResponseProcessNote(BackboneElement):
    """ Note concerning adjudication.
    
    A note that describes or explains adjudication results in a human readable
    form.
    """
    
    # [<FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='language' >]
  

    number: typing.Optional[int]

    """ Note instance identifier.
    Type `int`. """

    type: typing.Optional["str"]

    """ display | print | printoper.
    Type `str`. """

    text: str

    """ Note explanatory text.
    Type `str`. """

    language: typing.Optional["CodeableConcept"]

    """ Language of the text.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ClaimResponseInsurance(BackboneElement):
    """ Patient insurance information.
    
    Financial instruments for reimbursement for the health care products and
    services specified on the claim.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='focal' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='businessArrangement' >, <FHIRClassProperty self.name='claimResponse' >]
  

    sequence: int

    """ Insurance instance identifier.
    Type `int`. """

    focal: bool

    """ Coverage to be used for adjudication.
    Type `bool`. """

    coverage: "Reference"

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """

    businessArrangement: typing.Optional[str]

    """ Additional provider contract number.
    Type `str`. """

    claimResponse: typing.Optional["Reference"]

    """ Adjudication results.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ClaimResponseError(BackboneElement):
    """ Processing errors.
    
    Errors encountered during the processing of the adjudication.
    """
    
    # [<FHIRClassProperty self.name='itemSequence' >, <FHIRClassProperty self.name='detailSequence' >, <FHIRClassProperty self.name='subDetailSequence' >, <FHIRClassProperty self.name='code' >]
  

    itemSequence: typing.Optional[int]

    """ Item sequence number.
    Type `int`. """

    detailSequence: typing.Optional[int]

    """ Detail sequence number.
    Type `int`. """

    subDetailSequence: typing.Optional[int]

    """ Subdetail sequence number.
    Type `int`. """

    code: "CodeableConcept"

    """ Error code detailing processing issues.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ClinicalImpressionInvestigation(BackboneElement):
    """ One or more sets of investigations (signs, symptoms, etc.).
    
    One or more sets of investigations (signs, symptoms, etc.). The actual
    grouping of investigations varies greatly depending on the type and context
    of the assessment. These investigations may include data generated during
    the assessment process, or data previously generated and recorded that is
    pertinent to the outcomes.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='item' >]
  

    code: "CodeableConcept"

    """ A name/code for the set.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["Reference"]]

    """ Record of a specific investigation.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class ClinicalImpressionFinding(BackboneElement):
    """ Possible or likely findings and diagnoses.
    
    Specific findings or diagnoses that were considered likely or relevant to
    ongoing treatment.
    """
    
    # [<FHIRClassProperty self.name='itemCodeableConcept' >, <FHIRClassProperty self.name='itemReference' >, <FHIRClassProperty self.name='basis' >]
  

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ What was found.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    itemReference: typing.Optional["Reference"]

    """ What was found.
    Type `Reference` (represented as `dict` in JSON). """

    basis: typing.Optional[str]

    """ Which investigations support finding.
    Type `str`. """




    

     
    



class CodeSystemFilter(BackboneElement):
    """ Filter that can be used in a value set.
    
    A filter that can be used in a value set compose statement when selecting
    concepts using a filter.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='operator' >, <FHIRClassProperty self.name='value' >]
  

    code: str

    """ Code that identifies the filter.
    Type `str`. """

    description: typing.Optional[str]

    """ How or why the filter is used.
    Type `str`. """

    operator: typing.List["str"]

    """ = | is-a | descendent-of | is-not-a | regex | in | not-in |
        generalizes | exists.
    List of `str` items. """

    value: str

    """ What to use for the value.
    Type `str`. """




    

     
    



class CodeSystemProperty(BackboneElement):
    """ Additional information supplied about each concept.
    
    A property defines an additional slot through which additional information
    can be provided about a concept.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='uri' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='type' >]
  

    code: str

    """ Identifies the property on the concepts, and when referred to in
        operations.
    Type `str`. """

    uri: typing.Optional[str]

    """ Formal identifier for the property.
    Type `str`. """

    description: typing.Optional[str]

    """ Why the property is defined, and/or what it conveys.
    Type `str`. """

    type: "str"

    """ code | Coding | string | integer | boolean | dateTime | decimal.
    Type `str`. """




    

     
    



class CodeSystemConcept(BackboneElement):
    """ Concepts in the code system.
    
    Concepts that are in the code system. The concept definitions are
    inherently hierarchical, but the definitions must be consulted to determine
    what the meanings of the hierarchical relationships are.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='designation' >, <FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='concept' >]
  

    code: str

    """ Code that identifies concept.
    Type `str`. """

    display: typing.Optional[str]

    """ Text to display to the user.
    Type `str`. """

    definition: typing.Optional[str]

    """ Formal definition.
    Type `str`. """

    designation: typing.Optional[typing.List["CodeSystemConceptDesignation"]]

    """ Additional representations for the concept.
    List of `CodeSystemConceptDesignation` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List["CodeSystemConceptProperty"]]

    """ Property value for the concept.
    List of `CodeSystemConceptProperty` items (represented as `dict` in JSON). """

    concept: typing.Optional[typing.List["CodeSystemConcept"]]

    """ Child Concepts (is-a/contains/categorizes).
    List of `CodeSystemConcept` items (represented as `dict` in JSON). """




    

     
    



class CodeSystemConceptDesignation(BackboneElement):
    """ Additional representations for the concept.
    
    Additional representations for the concept - other languages, aliases,
    specialized purposes, used for particular purposes, etc.
    """
    
    # [<FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='value' >]
  

    language: typing.Optional[str]

    """ Human language of the designation.
    Type `str`. """

    use: typing.Optional["Coding"]

    """ Details how this designation would be used.
    Type `Coding` (represented as `dict` in JSON). """

    value: str

    """ The text value for this designation.
    Type `str`. """




    

     
    



class CodeSystemConceptProperty(BackboneElement):
    """ Property value for the concept.
    
    A property value for this concept.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >]
  

    code: str

    """ Reference to CodeSystem.property.code.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Value of the property for this concept.
    Type `str`. """

    valueCoding: typing.Optional["Coding"]

    """ Value of the property for this concept.
    Type `Coding` (represented as `dict` in JSON). """

    valueString: typing.Optional[str]

    """ Value of the property for this concept.
    Type `str`. """

    valueInteger: typing.Optional[int]

    """ Value of the property for this concept.
    Type `int`. """

    valueBoolean: typing.Optional[bool]

    """ Value of the property for this concept.
    Type `bool`. """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Value of the property for this concept.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ Value of the property for this concept.
    Type `float`. """



#   {'path': 'CodeSystem.concept.property.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCode', 'name': 'valueCode', 'parent_name': 'CodeSystem.concept.property', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Value of the property for this concept', 'formal': 'The value of this property.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCode', 'valueCoding', 'valueString', 'valueInteger', 'valueBoolean', 'valueDateTime', 'valueDecimal']), False))


    

     
    



class CommunicationPayload(BackboneElement):
    """ Message payload.
    
    Text, attachment(s), or resource(s) that was communicated to the recipient.
    """
    
    # [<FHIRClassProperty self.name='contentString' >, <FHIRClassProperty self.name='contentAttachment' >, <FHIRClassProperty self.name='contentReference' >]
  

    contentString: typing.Optional[str]

    """ Message part content.
    Type `str`. """

    contentAttachment: typing.Optional["Attachment"]

    """ Message part content.
    Type `Attachment` (represented as `dict` in JSON). """

    contentReference: typing.Optional["Reference"]

    """ Message part content.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Communication.payload.content[x]', 'choice_of_type': 'content', 'orig_name': 'contentString', 'name': 'contentString', 'parent_name': 'Communication.payload', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Message part content', 'formal': 'A communicated content (or for multi-part communications, one portion of the communication).', 'representation': None}

    _content_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['contentString', 'contentAttachment', 'contentReference']), False))


    

     
    



class CommunicationRequestPayload(BackboneElement):
    """ Message payload.
    
    Text, attachment(s), or resource(s) to be communicated to the recipient.
    """
    
    # [<FHIRClassProperty self.name='contentString' >, <FHIRClassProperty self.name='contentAttachment' >, <FHIRClassProperty self.name='contentReference' >]
  

    contentString: typing.Optional[str]

    """ Message part content.
    Type `str`. """

    contentAttachment: typing.Optional["Attachment"]

    """ Message part content.
    Type `Attachment` (represented as `dict` in JSON). """

    contentReference: typing.Optional["Reference"]

    """ Message part content.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'CommunicationRequest.payload.content[x]', 'choice_of_type': 'content', 'orig_name': 'contentString', 'name': 'contentString', 'parent_name': 'CommunicationRequest.payload', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Message part content', 'formal': 'The communicated content (or for multi-part communications, one portion of the communication).', 'representation': None}

    _content_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['contentString', 'contentAttachment', 'contentReference']), False))


    

     
    



class CompartmentDefinitionResource(BackboneElement):
    """ How a resource is related to the compartment.
    
    Information about how a resource is related to the compartment.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='param' >, <FHIRClassProperty self.name='documentation' >]
  

    code: "str"

    """ Name of resource type.
    Type `str`. """

    param: typing.Optional[typing.List[str]]

    """ Search Parameter Name, or chained parameters.
    List of `str` items. """

    documentation: typing.Optional[str]

    """ Additional documentation about the resource and compartment.
    Type `str`. """




    

     
    



class CompositionAttester(BackboneElement):
    """ Attests to accuracy of composition.
    
    A participant who has attested to the accuracy of the composition/document.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='time' >, <FHIRClassProperty self.name='party' >]
  

    mode: "str"

    """ personal | professional | legal | official.
    Type `str`. """

    time: typing.Optional["FHIRDate"]

    """ When the composition was attested.
    Type `FHIRDate` (represented as `str` in JSON). """

    party: typing.Optional["Reference"]

    """ Who attested the composition.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class CompositionRelatesTo(BackboneElement):
    """ Relationships to other compositions/documents.
    
    Relationships that this composition has with other compositions or
    documents that already exist.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='targetIdentifier' >, <FHIRClassProperty self.name='targetReference' >]
  

    code: "str"

    """ replaces | transforms | signs | appends.
    Type `str`. """

    targetIdentifier: typing.Optional["Identifier"]

    """ Target of the relationship.
    Type `Identifier` (represented as `dict` in JSON). """

    targetReference: typing.Optional["Reference"]

    """ Target of the relationship.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Composition.relatesTo.target[x]', 'choice_of_type': 'target', 'orig_name': 'targetIdentifier', 'name': 'targetIdentifier', 'parent_name': 'Composition.relatesTo', 'class_name': 'Identifier', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Target of the relationship', 'formal': 'The target composition/document of this relationship.', 'representation': None}

    _target_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['targetIdentifier', 'targetReference']), False))


    

     
    



class CompositionEvent(BackboneElement):
    """ The clinical service(s) being documented.
    
    The clinical service, such as a colonoscopy or an appendectomy, being
    documented.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='detail' >]
  

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Code(s) that apply to the event being documented.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ The period covered by the documentation.
    Type `Period` (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["Reference"]]

    """ The event(s) being documented.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class CompositionSection(BackboneElement):
    """ Composition is broken into sections.
    
    The root of the sections that make up the composition.
    """
    
    # [<FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='focus' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='orderedBy' >, <FHIRClassProperty self.name='entry' >, <FHIRClassProperty self.name='emptyReason' >, <FHIRClassProperty self.name='section' >]
  

    title: typing.Optional[str]

    """ Label for section (e.g. for ToC).
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Classification of section (recommended).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    author: typing.Optional[typing.List["Reference"]]

    """ Who and/or what authored the section.
    List of `Reference` items (represented as `dict` in JSON). """

    focus: typing.Optional["Reference"]

    """ Who/what the section is about, when it is not about the subject of
        composition.
    Type `Reference` (represented as `dict` in JSON). """

    text: typing.Optional["Narrative"]

    """ Text summary of the section, for human interpretation.
    Type `Narrative` (represented as `dict` in JSON). """

    mode: typing.Optional["str"]

    """ working | snapshot | changes.
    Type `str`. """

    orderedBy: typing.Optional["CodeableConcept"]

    """ Order of section entries.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    entry: typing.Optional[typing.List["Reference"]]

    """ A reference to data that supports this section.
    List of `Reference` items (represented as `dict` in JSON). """

    emptyReason: typing.Optional["CodeableConcept"]

    """ Why the section is empty.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    section: typing.Optional[typing.List["CompositionSection"]]

    """ Nested Section.
    List of `CompositionSection` items (represented as `dict` in JSON). """




    

     
    



class ConceptMapGroup(BackboneElement):
    """ Same source and target systems.
    
    A group of mappings that all have the same source and target system.
    """
    
    # [<FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='sourceVersion' >, <FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='targetVersion' >, <FHIRClassProperty self.name='element' >, <FHIRClassProperty self.name='unmapped' >]
  

    source: typing.Optional[str]

    """ Source system where concepts to be mapped are defined.
    Type `str`. """

    sourceVersion: typing.Optional[str]

    """ Specific version of the  code system.
    Type `str`. """

    target: typing.Optional[str]

    """ Target system that the concepts are to be mapped to.
    Type `str`. """

    targetVersion: typing.Optional[str]

    """ Specific version of the  code system.
    Type `str`. """

    element: typing.List["ConceptMapGroupElement"]

    """ Mappings for a concept from the source set.
    List of `ConceptMapGroupElement` items (represented as `dict` in JSON). """

    unmapped: typing.Optional["ConceptMapGroupUnmapped"]

    """ What to do when there is no mapping for the source concept.
    Type `ConceptMapGroupUnmapped` (represented as `dict` in JSON). """




    

     
    



class ConceptMapGroupElement(BackboneElement):
    """ Mappings for a concept from the source set.
    
    Mappings for an individual concept in the source to one or more concepts in
    the target.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='target' >]
  

    code: typing.Optional[str]

    """ Identifies element being mapped.
    Type `str`. """

    display: typing.Optional[str]

    """ Display for the code.
    Type `str`. """

    target: typing.Optional[typing.List["ConceptMapGroupElementTarget"]]

    """ Concept in target system for element.
    List of `ConceptMapGroupElementTarget` items (represented as `dict` in JSON). """




    

     
    



class ConceptMapGroupElementTarget(BackboneElement):
    """ Concept in target system for element.
    
    A concept from the target value set that this concept maps to.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='equivalence' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='dependsOn' >, <FHIRClassProperty self.name='product' >]
  

    code: typing.Optional[str]

    """ Code that identifies the target element.
    Type `str`. """

    display: typing.Optional[str]

    """ Display for the code.
    Type `str`. """

    equivalence: "str"

    """ relatedto | equivalent | equal | wider | subsumes | narrower |
        specializes | inexact | unmatched | disjoint.
    Type `str`. """

    comment: typing.Optional[str]

    """ Description of status/issues in mapping.
    Type `str`. """

    dependsOn: typing.Optional[typing.List["ConceptMapGroupElementTargetDependsOn"]]

    """ Other elements required for this mapping (from context).
    List of `ConceptMapGroupElementTargetDependsOn` items (represented as `dict` in JSON). """

    product: typing.Optional[typing.List["ConceptMapGroupElementTargetDependsOn"]]

    """ Other concepts that this mapping also produces.
    List of `ConceptMapGroupElementTargetDependsOn` items (represented as `dict` in JSON). """




    

     
    



class ConceptMapGroupElementTargetDependsOn(BackboneElement):
    """ Other elements required for this mapping (from context).
    
    A set of additional dependencies for this mapping to hold. This mapping is
    only applicable if the specified element can be resolved, and it has the
    specified value.
    """
    
    # [<FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='display' >]
  

    property: str

    """ Reference to property mapping depends on.
    Type `str`. """

    system: typing.Optional[str]

    """ Code System (if necessary).
    Type `str`. """

    value: str

    """ Value of the referenced element.
    Type `str`. """

    display: typing.Optional[str]

    """ Display for the code (if value is a code).
    Type `str`. """




    

     
    



class ConceptMapGroupUnmapped(BackboneElement):
    """ What to do when there is no mapping for the source concept.
    
    What to do when there is no mapping for the source concept. "Unmapped" does
    not include codes that are unmatched, and the unmapped element is ignored
    in a code is specified to have equivalence = unmatched.
    """
    
    # [<FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='url' >]
  

    mode: "str"

    """ provided | fixed | other-map.
    Type `str`. """

    code: typing.Optional[str]

    """ Fixed code when mode = fixed.
    Type `str`. """

    display: typing.Optional[str]

    """ Display for the code.
    Type `str`. """

    url: typing.Optional[str]

    """ canonical reference to an additional ConceptMap to use for mapping
        if the source concept is unmapped.
    Type `str`. """




    

     
    



class ConditionStage(BackboneElement):
    """ Stage/grade, usually assessed formally.
    
    Clinical stage or grade of a condition. May include formal severity
    assessments.
    """
    
    # [<FHIRClassProperty self.name='summary' >, <FHIRClassProperty self.name='assessment' >, <FHIRClassProperty self.name='type' >]
  

    summary: typing.Optional["CodeableConcept"]

    """ Simple summary (disease specific).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    assessment: typing.Optional[typing.List["Reference"]]

    """ Formal record of assessment.
    List of `Reference` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Kind of staging.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ConditionEvidence(BackboneElement):
    """ Supporting evidence.
    
    Supporting evidence / manifestations that are the basis of the Condition's
    verification status, such as evidence that confirmed or refuted the
    condition.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='detail' >]
  

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Manifestation/symptom.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["Reference"]]

    """ Supporting information found elsewhere.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class ConsentPolicy(BackboneElement):
    """ Policies covered by this consent.
    
    The references to the policies that are included in this consent scope.
    Policies may be organizational, but are often defined jurisdictionally, or
    in law.
    """
    
    # [<FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='uri' >]
  

    authority: typing.Optional[str]

    """ Enforcement source for policy.
    Type `str`. """

    uri: typing.Optional[str]

    """ Specific policy covered by this consent.
    Type `str`. """




    

     
    



class ConsentVerification(BackboneElement):
    """ Consent Verified by patient or family.
    
    Whether a treatment instruction (e.g. artificial respiration yes or no) was
    verified with the patient, his/her family or another authorized person.
    """
    
    # [<FHIRClassProperty self.name='verified' >, <FHIRClassProperty self.name='verifiedWith' >, <FHIRClassProperty self.name='verificationDate' >]
  

    verified: bool

    """ Has been verified.
    Type `bool`. """

    verifiedWith: typing.Optional["Reference"]

    """ Person who verified.
    Type `Reference` (represented as `dict` in JSON). """

    verificationDate: typing.Optional["FHIRDate"]

    """ When consent verified.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class ConsentProvision(BackboneElement):
    """ Constraints to the base Consent.policyRule.
    
    An exception to the base policy of this consent. An exception can be an
    addition or removal of access permissions.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='action' >, <FHIRClassProperty self.name='securityLabel' >, <FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='dataPeriod' >, <FHIRClassProperty self.name='data' >, <FHIRClassProperty self.name='provision' >]
  

    type: typing.Optional["str"]

    """ deny | permit.
    Type `str`. """

    period: typing.Optional["Period"]

    """ Timeframe for this rule.
    Type `Period` (represented as `dict` in JSON). """

    actor: typing.Optional[typing.List["ConsentProvisionActor"]]

    """ Who|what controlled by this rule (or group, by role).
    List of `ConsentProvisionActor` items (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["CodeableConcept"]]

    """ Actions controlled by this rule.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    securityLabel: typing.Optional[typing.List["Coding"]]

    """ Security Labels that define affected resources.
    List of `Coding` items (represented as `dict` in JSON). """

    purpose: typing.Optional[typing.List["Coding"]]

    """ Context of activities covered by this rule.
    List of `Coding` items (represented as `dict` in JSON). """

    class_: typing.Optional[typing.List["Coding"]]

    """ e.g. Resource Type, Profile, CDA, etc..
    List of `Coding` items (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ e.g. LOINC or SNOMED CT code, etc. in the content.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    dataPeriod: typing.Optional["Period"]

    """ Timeframe for data controlled by this rule.
    Type `Period` (represented as `dict` in JSON). """

    data: typing.Optional[typing.List["ConsentProvisionData"]]

    """ Data controlled by this rule.
    List of `ConsentProvisionData` items (represented as `dict` in JSON). """

    provision: typing.Optional[typing.List["ConsentProvision"]]

    """ Nested Exception Rules.
    List of `ConsentProvision` items (represented as `dict` in JSON). """




    

     
    



class ConsentProvisionActor(BackboneElement):
    """ Who|what controlled by this rule (or group, by role).
    
    Who or what is controlled by this rule. Use group to identify a set of
    actors by some property they share (e.g. 'admitting officers').
    """
    
    # [<FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='reference' >]
  

    role: "CodeableConcept"

    """ How the actor is involved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reference: "Reference"

    """ Resource for the actor (or group, by role).
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ConsentProvisionData(BackboneElement):
    """ Data controlled by this rule.
    
    The resources controlled by this rule if specific resources are referenced.
    """
    
    # [<FHIRClassProperty self.name='meaning' >, <FHIRClassProperty self.name='reference' >]
  

    meaning: "str"

    """ instance | related | dependents | authoredby.
    Type `str`. """

    reference: "Reference"

    """ The actual data reference.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ContractContentDefinition(BackboneElement):
    """ Contract precursor content.
    
    Precusory content developed with a focus and intent of supporting the
    formation a Contract instance, which may be associated with and
    transformable into a Contract.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='publisher' >, <FHIRClassProperty self.name='publicationDate' >, <FHIRClassProperty self.name='publicationStatus' >, <FHIRClassProperty self.name='copyright' >]
  

    type: "CodeableConcept"

    """ Content structure and use.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional["CodeableConcept"]

    """ Detailed Content Type Definition.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    publisher: typing.Optional["Reference"]

    """ Publisher Entity.
    Type `Reference` (represented as `dict` in JSON). """

    publicationDate: typing.Optional["FHIRDate"]

    """ When published.
    Type `FHIRDate` (represented as `str` in JSON). """

    publicationStatus: "str"

    """ amended | appended | cancelled | disputed | entered-in-error |
        executable | executed | negotiable | offered | policy | rejected |
        renewed | revoked | resolved | terminated.
    Type `str`. """

    copyright: typing.Optional[str]

    """ Publication Ownership.
    Type `str`. """




    

     
    



class ContractTerm(BackboneElement):
    """ Contract Term List.
    
    One or more Contract Provisions, which may be related and conveyed as a
    group, and may contain nested groups.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='issued' >, <FHIRClassProperty self.name='applies' >, <FHIRClassProperty self.name='topicCodeableConcept' >, <FHIRClassProperty self.name='topicReference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subType' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='securityLabel' >, <FHIRClassProperty self.name='offer' >, <FHIRClassProperty self.name='asset' >, <FHIRClassProperty self.name='action' >, <FHIRClassProperty self.name='group' >]
  

    identifier: typing.Optional["Identifier"]

    """ Contract Term Number.
    Type `Identifier` (represented as `dict` in JSON). """

    issued: typing.Optional["FHIRDate"]

    """ Contract Term Issue Date Time.
    Type `FHIRDate` (represented as `str` in JSON). """

    applies: typing.Optional["Period"]

    """ Contract Term Effective Time.
    Type `Period` (represented as `dict` in JSON). """

    topicCodeableConcept: typing.Optional["CodeableConcept"]

    """ Term Concern.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    topicReference: typing.Optional["Reference"]

    """ Term Concern.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Contract Term Type or Form.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subType: typing.Optional["CodeableConcept"]

    """ Contract Term Type specific classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Term Statement.
    Type `str`. """

    securityLabel: typing.Optional[typing.List["ContractTermSecurityLabel"]]

    """ Protection for the Term.
    List of `ContractTermSecurityLabel` items (represented as `dict` in JSON). """

    offer: "ContractTermOffer"

    """ Context of the Contract term.
    Type `ContractTermOffer` (represented as `dict` in JSON). """

    asset: typing.Optional[typing.List["ContractTermAsset"]]

    """ Contract Term Asset List.
    List of `ContractTermAsset` items (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["ContractTermAction"]]

    """ Entity being ascribed responsibility.
    List of `ContractTermAction` items (represented as `dict` in JSON). """

    group: typing.Optional[typing.List["ContractTerm"]]

    """ Nested Contract Term Group.
    List of `ContractTerm` items (represented as `dict` in JSON). """



#   {'path': 'Contract.term.topic[x]', 'choice_of_type': 'topic', 'orig_name': 'topicCodeableConcept', 'name': 'topicCodeableConcept', 'parent_name': 'Contract.term', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Term Concern', 'formal': 'The entity that the term applies to.', 'representation': None}

    _topic_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['topicCodeableConcept', 'topicReference']), True))


    

     
    



class ContractTermSecurityLabel(BackboneElement):
    """ Protection for the Term.
    
    Security labels that protect the handling of information about the term and
    its elements, which may be specifically identified..
    """
    
    # [<FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='classification' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='control' >]
  

    number: typing.Optional[typing.List[int]]

    """ Link to Security Labels.
    List of `int` items. """

    classification: "Coding"

    """ Confidentiality Protection.
    Type `Coding` (represented as `dict` in JSON). """

    category: typing.Optional[typing.List["Coding"]]

    """ Applicable Policy.
    List of `Coding` items (represented as `dict` in JSON). """

    control: typing.Optional[typing.List["Coding"]]

    """ Handling Instructions.
    List of `Coding` items (represented as `dict` in JSON). """




    

     
    



class ContractTermOffer(BackboneElement):
    """ Context of the Contract term.
    
    The matter of concern in the context of this provision of the agrement.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='party' >, <FHIRClassProperty self.name='topic' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='decision' >, <FHIRClassProperty self.name='decisionMode' >, <FHIRClassProperty self.name='answer' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='securityLabelNumber' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Offer business ID.
    List of `Identifier` items (represented as `dict` in JSON). """

    party: typing.Optional[typing.List["ContractTermOfferParty"]]

    """ Offer Recipient.
    List of `ContractTermOfferParty` items (represented as `dict` in JSON). """

    topic: typing.Optional["Reference"]

    """ Negotiable offer asset.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Contract Offer Type or Form.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    decision: typing.Optional["CodeableConcept"]

    """ Accepting party choice.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    decisionMode: typing.Optional[typing.List["CodeableConcept"]]

    """ How decision is conveyed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    answer: typing.Optional[typing.List["ContractTermOfferAnswer"]]

    """ Response to offer text.
    List of `ContractTermOfferAnswer` items (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Human readable offer text.
    Type `str`. """

    linkId: typing.Optional[typing.List[str]]

    """ Pointer to text.
    List of `str` items. """

    securityLabelNumber: typing.Optional[typing.List[int]]

    """ Offer restriction numbers.
    List of `int` items. """




    

     
    



class ContractTermOfferParty(BackboneElement):
    """ Offer Recipient.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='role' >]
  

    reference: typing.List["Reference"]

    """ Referenced entity.
    List of `Reference` items (represented as `dict` in JSON). """

    role: "CodeableConcept"

    """ Participant engagement type.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ContractTermOfferAnswer(BackboneElement):
    """ Response to offer text.
    """
    
    # [<FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueReference' >]
  

    valueBoolean: typing.Optional[bool]

    """ The actual answer response.
    Type `bool`. """

    valueDecimal: typing.Optional[float]

    """ The actual answer response.
    Type `float`. """

    valueInteger: typing.Optional[int]

    """ The actual answer response.
    Type `int`. """

    valueDate: typing.Optional["FHIRDate"]

    """ The actual answer response.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ The actual answer response.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ The actual answer response.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueString: typing.Optional[str]

    """ The actual answer response.
    Type `str`. """

    valueUri: typing.Optional[str]

    """ The actual answer response.
    Type `str`. """

    valueAttachment: typing.Optional["Attachment"]

    """ The actual answer response.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ The actual answer response.
    Type `Coding` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ The actual answer response.
    Type `Quantity` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ The actual answer response.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Contract.term.offer.answer.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBoolean', 'name': 'valueBoolean', 'parent_name': 'Contract.term.offer.answer', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'The actual answer response', 'formal': 'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBoolean', 'valueDecimal', 'valueInteger', 'valueDate', 'valueDateTime', 'valueTime', 'valueString', 'valueUri', 'valueAttachment', 'valueCoding', 'valueQuantity', 'valueReference']), False))


    

     
    



class ContractTermAsset(BackboneElement):
    """ Contract Term Asset List.
    """
    
    # [<FHIRClassProperty self.name='scope' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='typeReference' >, <FHIRClassProperty self.name='subtype' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='periodType' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='usePeriod' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='answer' >, <FHIRClassProperty self.name='securityLabelNumber' >, <FHIRClassProperty self.name='valuedItem' >]
  

    scope: typing.Optional["CodeableConcept"]

    """ Range of asset.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Asset category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    typeReference: typing.Optional[typing.List["Reference"]]

    """ Associated entities.
    List of `Reference` items (represented as `dict` in JSON). """

    subtype: typing.Optional[typing.List["CodeableConcept"]]

    """ Asset sub-category.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    relationship: typing.Optional["Coding"]

    """ Kinship of the asset.
    Type `Coding` (represented as `dict` in JSON). """

    context: typing.Optional[typing.List["ContractTermAssetContext"]]

    """ Circumstance of the asset.
    List of `ContractTermAssetContext` items (represented as `dict` in JSON). """

    condition: typing.Optional[str]

    """ Quality desctiption of asset.
    Type `str`. """

    periodType: typing.Optional[typing.List["CodeableConcept"]]

    """ Asset availability types.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    period: typing.Optional[typing.List["Period"]]

    """ Time period of the asset.
    List of `Period` items (represented as `dict` in JSON). """

    usePeriod: typing.Optional[typing.List["Period"]]

    """ Time period.
    List of `Period` items (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Asset clause or question text.
    Type `str`. """

    linkId: typing.Optional[typing.List[str]]

    """ Pointer to asset text.
    List of `str` items. """

    answer: typing.Optional[typing.List["ContractTermOfferAnswer"]]

    """ Response to assets.
    List of `ContractTermOfferAnswer` items (represented as `dict` in JSON). """

    securityLabelNumber: typing.Optional[typing.List[int]]

    """ Asset restriction numbers.
    List of `int` items. """

    valuedItem: typing.Optional[typing.List["ContractTermAssetValuedItem"]]

    """ Contract Valued Item List.
    List of `ContractTermAssetValuedItem` items (represented as `dict` in JSON). """




    

     
    



class ContractTermAssetContext(BackboneElement):
    """ Circumstance of the asset.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='text' >]
  

    reference: typing.Optional["Reference"]

    """ Creator,custodian or owner.
    Type `Reference` (represented as `dict` in JSON). """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Codeable asset context.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Context description.
    Type `str`. """




    

     
    



class ContractTermAssetValuedItem(BackboneElement):
    """ Contract Valued Item List.
    """
    
    # [<FHIRClassProperty self.name='entityCodeableConcept' >, <FHIRClassProperty self.name='entityReference' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='effectiveTime' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='points' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='payment' >, <FHIRClassProperty self.name='paymentDate' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='recipient' >, <FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='securityLabelNumber' >]
  

    entityCodeableConcept: typing.Optional["CodeableConcept"]

    """ Contract Valued Item Type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    entityReference: typing.Optional["Reference"]

    """ Contract Valued Item Type.
    Type `Reference` (represented as `dict` in JSON). """

    identifier: typing.Optional["Identifier"]

    """ Contract Valued Item Number.
    Type `Identifier` (represented as `dict` in JSON). """

    effectiveTime: typing.Optional["FHIRDate"]

    """ Contract Valued Item Effective Tiem.
    Type `FHIRDate` (represented as `str` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of Contract Valued Items.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Contract Valued Item fee, charge, or cost.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Contract Valued Item Price Scaling Factor.
    Type `float`. """

    points: typing.Optional[float]

    """ Contract Valued Item Difficulty Scaling Factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total Contract Valued Item Value.
    Type `Money` (represented as `dict` in JSON). """

    payment: typing.Optional[str]

    """ Terms of valuation.
    Type `str`. """

    paymentDate: typing.Optional["FHIRDate"]

    """ When payment is due.
    Type `FHIRDate` (represented as `str` in JSON). """

    responsible: typing.Optional["Reference"]

    """ Who will make payment.
    Type `Reference` (represented as `dict` in JSON). """

    recipient: typing.Optional["Reference"]

    """ Who will receive payment.
    Type `Reference` (represented as `dict` in JSON). """

    linkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    securityLabelNumber: typing.Optional[typing.List[int]]

    """ Security Labels that define affected terms.
    List of `int` items. """



#   {'path': 'Contract.term.asset.valuedItem.entity[x]', 'choice_of_type': 'entity', 'orig_name': 'entityCodeableConcept', 'name': 'entityCodeableConcept', 'parent_name': 'Contract.term.asset.valuedItem', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Contract Valued Item Type', 'formal': 'Specific type of Contract Valued Item that may be priced.', 'representation': None}

    _entity_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['entityCodeableConcept', 'entityReference']), True))


    

     
    



class ContractTermAction(BackboneElement):
    """ Entity being ascribed responsibility.
    
    An actor taking a role in an activity for which it can be assigned some
    degree of responsibility for the activity taking place.
    """
    
    # [<FHIRClassProperty self.name='doNotPerform' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='subject' >, <FHIRClassProperty self.name='intent' >, <FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='contextLinkId' >, <FHIRClassProperty self.name='occurrenceDateTime' >, <FHIRClassProperty self.name='occurrencePeriod' >, <FHIRClassProperty self.name='occurrenceTiming' >, <FHIRClassProperty self.name='requester' >, <FHIRClassProperty self.name='requesterLinkId' >, <FHIRClassProperty self.name='performerType' >, <FHIRClassProperty self.name='performerRole' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='performerLinkId' >, <FHIRClassProperty self.name='reasonCode' >, <FHIRClassProperty self.name='reasonReference' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='reasonLinkId' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='securityLabelNumber' >]
  

    doNotPerform: typing.Optional[bool]

    """ True if the term prohibits the  action.
    Type `bool`. """

    type: "CodeableConcept"

    """ Type or form of the action.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subject: typing.Optional[typing.List["ContractTermActionSubject"]]

    """ Entity of the action.
    List of `ContractTermActionSubject` items (represented as `dict` in JSON). """

    intent: "CodeableConcept"

    """ Purpose for the Contract Term Action.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    linkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    status: "CodeableConcept"

    """ State of the action.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    context: typing.Optional["Reference"]

    """ Episode associated with action.
    Type `Reference` (represented as `dict` in JSON). """

    contextLinkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    occurrenceDateTime: typing.Optional["FHIRDate"]

    """ When action happens.
    Type `FHIRDate` (represented as `str` in JSON). """

    occurrencePeriod: typing.Optional["Period"]

    """ When action happens.
    Type `Period` (represented as `dict` in JSON). """

    occurrenceTiming: typing.Optional["Timing"]

    """ When action happens.
    Type `Timing` (represented as `dict` in JSON). """

    requester: typing.Optional[typing.List["Reference"]]

    """ Who asked for action.
    List of `Reference` items (represented as `dict` in JSON). """

    requesterLinkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    performerType: typing.Optional[typing.List["CodeableConcept"]]

    """ Kind of service performer.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    performerRole: typing.Optional["CodeableConcept"]

    """ Competency of the performer.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Actor that wil execute (or not) the action.
    Type `Reference` (represented as `dict` in JSON). """

    performerLinkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    reasonCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Why is action (not) needed?.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reasonReference: typing.Optional[typing.List["Reference"]]

    """ Why is action (not) needed?.
    List of `Reference` items (represented as `dict` in JSON). """

    reason: typing.Optional[typing.List[str]]

    """ Why action is to be performed.
    List of `str` items. """

    reasonLinkId: typing.Optional[typing.List[str]]

    """ Pointer to specific item.
    List of `str` items. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Comments about the action.
    List of `Annotation` items (represented as `dict` in JSON). """

    securityLabelNumber: typing.Optional[typing.List[int]]

    """ Action restriction numbers.
    List of `int` items. """



#   {'path': 'Contract.term.action.occurrence[x]', 'choice_of_type': 'occurrence', 'orig_name': 'occurrenceDateTime', 'name': 'occurrenceDateTime', 'parent_name': 'Contract.term.action', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When action happens', 'formal': None, 'representation': None}

    _occurrence_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['occurrenceDateTime', 'occurrencePeriod', 'occurrenceTiming']), True))


    

     
    



class ContractTermActionSubject(BackboneElement):
    """ Entity of the action.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='role' >]
  

    reference: typing.List["Reference"]

    """ Entity of the action.
    List of `Reference` items (represented as `dict` in JSON). """

    role: typing.Optional["CodeableConcept"]

    """ Role type of the agent.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ContractSigner(BackboneElement):
    """ Contract Signatory.
    
    Parties with legal standing in the Contract, including the principal
    parties, the grantor(s) and grantee(s), which are any person or
    organization bound by the contract, and any ancillary parties, which
    facilitate the execution of the contract such as a notary or witness.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='party' >, <FHIRClassProperty self.name='signature' >]
  

    type: "Coding"

    """ Contract Signatory Role.
    Type `Coding` (represented as `dict` in JSON). """

    party: "Reference"

    """ Contract Signatory Party.
    Type `Reference` (represented as `dict` in JSON). """

    signature: typing.List["Signature"]

    """ Contract Documentation Signature.
    List of `Signature` items (represented as `dict` in JSON). """




    

     
    



class ContractFriendly(BackboneElement):
    """ Contract Friendly Language.
    
    The "patient friendly language" versionof the Contract in whole or in
    parts. "Patient friendly language" means the representation of the Contract
    and Contract Provisions in a manner that is readily accessible and
    understandable by a layperson in accordance with best practices for
    communication styles that ensure that those agreeing to or signing the
    Contract understand the roles, actions, obligations, responsibilities, and
    implication of the agreement.
    """
    
    # [<FHIRClassProperty self.name='contentAttachment' >, <FHIRClassProperty self.name='contentReference' >]
  

    contentAttachment: typing.Optional["Attachment"]

    """ Easily comprehended representation of this Contract.
    Type `Attachment` (represented as `dict` in JSON). """

    contentReference: typing.Optional["Reference"]

    """ Easily comprehended representation of this Contract.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Contract.friendly.content[x]', 'choice_of_type': 'content', 'orig_name': 'contentAttachment', 'name': 'contentAttachment', 'parent_name': 'Contract.friendly', 'class_name': 'Attachment', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Easily comprehended representation of this Contract', 'formal': 'Human readable rendering of this Contract in a format and representation intended to enhance comprehension and ensure understandability.', 'representation': None}

    _content_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['contentAttachment', 'contentReference']), False))


    

     
    



class ContractLegal(BackboneElement):
    """ Contract Legal Language.
    
    List of Legal expressions or representations of this Contract.
    """
    
    # [<FHIRClassProperty self.name='contentAttachment' >, <FHIRClassProperty self.name='contentReference' >]
  

    contentAttachment: typing.Optional["Attachment"]

    """ Contract Legal Text.
    Type `Attachment` (represented as `dict` in JSON). """

    contentReference: typing.Optional["Reference"]

    """ Contract Legal Text.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Contract.legal.content[x]', 'choice_of_type': 'content', 'orig_name': 'contentAttachment', 'name': 'contentAttachment', 'parent_name': 'Contract.legal', 'class_name': 'Attachment', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Contract Legal Text', 'formal': 'Contract legal text in human renderable form.', 'representation': None}

    _content_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['contentAttachment', 'contentReference']), False))


    

     
    



class ContractRule(BackboneElement):
    """ Computable Contract Language.
    
    List of Computable Policy Rule Language Representations of this Contract.
    """
    
    # [<FHIRClassProperty self.name='contentAttachment' >, <FHIRClassProperty self.name='contentReference' >]
  

    contentAttachment: typing.Optional["Attachment"]

    """ Computable Contract Rules.
    Type `Attachment` (represented as `dict` in JSON). """

    contentReference: typing.Optional["Reference"]

    """ Computable Contract Rules.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Contract.rule.content[x]', 'choice_of_type': 'content', 'orig_name': 'contentAttachment', 'name': 'contentAttachment', 'parent_name': 'Contract.rule', 'class_name': 'Attachment', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Computable Contract Rules', 'formal': 'Computable Contract conveyed using a policy rule language (e.g. XACML, DKAL, SecPal).', 'representation': None}

    _content_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['contentAttachment', 'contentReference']), False))


    

     
    



class CoverageClass(BackboneElement):
    """ Additional coverage classifications.
    
    A suite of underwriter specific classifiers.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='name' >]
  

    type: "CodeableConcept"

    """ Type of class such as 'group' or 'plan'.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: str

    """ Value associated with the type.
    Type `str`. """

    name: typing.Optional[str]

    """ Human readable description of the type and value.
    Type `str`. """




    

     
    



class CoverageCostToBeneficiary(BackboneElement):
    """ Patient payments for services/products.
    
    A suite of codes indicating the cost category and associated amount which
    have been detailed in the policy and may have been  included on the health
    card.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='exception' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Cost category.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ The amount or percentage due from the beneficiary.
    Type `Quantity` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ The amount or percentage due from the beneficiary.
    Type `Money` (represented as `dict` in JSON). """

    exception: typing.Optional[typing.List["CoverageCostToBeneficiaryException"]]

    """ Exceptions for patient payments.
    List of `CoverageCostToBeneficiaryException` items (represented as `dict` in JSON). """



#   {'path': 'Coverage.costToBeneficiary.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueQuantity', 'name': 'valueQuantity', 'parent_name': 'Coverage.costToBeneficiary', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'The amount or percentage due from the beneficiary', 'formal': 'The amount due from the patient for the cost category.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueQuantity', 'valueMoney']), False))


    

     
    



class CoverageCostToBeneficiaryException(BackboneElement):
    """ Exceptions for patient payments.
    
    A suite of codes indicating exceptions or reductions to patient costs and
    their effective periods.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='period' >]
  

    type: "CodeableConcept"

    """ Exception category.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ The effective period of the exception.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class CoverageEligibilityRequestSupportingInfo(BackboneElement):
    """ Supporting information.
    
    Additional information codes regarding exceptions, special considerations,
    the condition, situation, prior or concurrent issues.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='information' >, <FHIRClassProperty self.name='appliesToAll' >]
  

    sequence: int

    """ Information instance identifier.
    Type `int`. """

    information: "Reference"

    """ Data to be provided.
    Type `Reference` (represented as `dict` in JSON). """

    appliesToAll: typing.Optional[bool]

    """ Applies to all items.
    Type `bool`. """




    

     
    



class CoverageEligibilityRequestInsurance(BackboneElement):
    """ Patient insurance information.
    
    Financial instruments for reimbursement for the health care products and
    services.
    """
    
    # [<FHIRClassProperty self.name='focal' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='businessArrangement' >]
  

    focal: typing.Optional[bool]

    """ Applicable coverage.
    Type `bool`. """

    coverage: "Reference"

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """

    businessArrangement: typing.Optional[str]

    """ Additional provider contract number.
    Type `str`. """




    

     
    



class CoverageEligibilityRequestItem(BackboneElement):
    """ Item to be evaluated for eligibiity.
    
    Service categories or billable services for which benefit details and/or an
    authorization prior to service delivery may be required by the payor.
    """
    
    # [<FHIRClassProperty self.name='supportingInfoSequence' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='facility' >, <FHIRClassProperty self.name='diagnosis' >, <FHIRClassProperty self.name='detail' >]
  

    supportingInfoSequence: typing.Optional[typing.List[int]]

    """ Applicable exception or supporting information.
    List of `int` items. """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: typing.Optional["CodeableConcept"]

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Product or service billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    provider: typing.Optional["Reference"]

    """ Perfoming practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    facility: typing.Optional["Reference"]

    """ Servicing facility.
    Type `Reference` (represented as `dict` in JSON). """

    diagnosis: typing.Optional[typing.List["CoverageEligibilityRequestItemDiagnosis"]]

    """ Applicable diagnosis.
    List of `CoverageEligibilityRequestItemDiagnosis` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["Reference"]]

    """ Product or service details.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class CoverageEligibilityRequestItemDiagnosis(BackboneElement):
    """ Applicable diagnosis.
    
    Patient diagnosis for which care is sought.
    """
    
    # [<FHIRClassProperty self.name='diagnosisCodeableConcept' >, <FHIRClassProperty self.name='diagnosisReference' >]
  

    diagnosisCodeableConcept: typing.Optional["CodeableConcept"]

    """ Nature of illness or problem.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diagnosisReference: typing.Optional["Reference"]

    """ Nature of illness or problem.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'CoverageEligibilityRequest.item.diagnosis.diagnosis[x]', 'choice_of_type': 'diagnosis', 'orig_name': 'diagnosisCodeableConcept', 'name': 'diagnosisCodeableConcept', 'parent_name': 'CoverageEligibilityRequest.item.diagnosis', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Nature of illness or problem', 'formal': 'The nature of illness or problem in a coded form or as a reference to an external defined Condition.', 'representation': None}

    _diagnosis_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['diagnosisCodeableConcept', 'diagnosisReference']), True))


    

     
    



class CoverageEligibilityResponseInsurance(BackboneElement):
    """ Patient insurance information.
    
    Financial instruments for reimbursement for the health care products and
    services.
    """
    
    # [<FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='inforce' >, <FHIRClassProperty self.name='benefitPeriod' >, <FHIRClassProperty self.name='item' >]
  

    coverage: "Reference"

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """

    inforce: typing.Optional[bool]

    """ Coverage inforce indicator.
    Type `bool`. """

    benefitPeriod: typing.Optional["Period"]

    """ When the benefits are applicable.
    Type `Period` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["CoverageEligibilityResponseInsuranceItem"]]

    """ Benefits and authorization details.
    List of `CoverageEligibilityResponseInsuranceItem` items (represented as `dict` in JSON). """




    

     
    



class CoverageEligibilityResponseInsuranceItem(BackboneElement):
    """ Benefits and authorization details.
    
    Benefits and optionally current balances, and authorization details by
    category or service.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='excluded' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='term' >, <FHIRClassProperty self.name='benefit' >, <FHIRClassProperty self.name='authorizationRequired' >, <FHIRClassProperty self.name='authorizationSupporting' >, <FHIRClassProperty self.name='authorizationUrl' >]
  

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: typing.Optional["CodeableConcept"]

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Product or service billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    provider: typing.Optional["Reference"]

    """ Performing practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    excluded: typing.Optional[bool]

    """ Excluded from the plan.
    Type `bool`. """

    name: typing.Optional[str]

    """ Short name for the benefit.
    Type `str`. """

    description: typing.Optional[str]

    """ Description of the benefit or services covered.
    Type `str`. """

    network: typing.Optional["CodeableConcept"]

    """ In or out of network.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unit: typing.Optional["CodeableConcept"]

    """ Individual or family.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    term: typing.Optional["CodeableConcept"]

    """ Annual or lifetime.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    benefit: typing.Optional[typing.List["CoverageEligibilityResponseInsuranceItemBenefit"]]

    """ Benefit Summary.
    List of `CoverageEligibilityResponseInsuranceItemBenefit` items (represented as `dict` in JSON). """

    authorizationRequired: typing.Optional[bool]

    """ Authorization required flag.
    Type `bool`. """

    authorizationSupporting: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of required supporting materials.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    authorizationUrl: typing.Optional[str]

    """ Preauthorization requirements endpoint.
    Type `str`. """




    

     
    



class CoverageEligibilityResponseInsuranceItemBenefit(BackboneElement):
    """ Benefit Summary.
    
    Benefits used to date.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='allowedUnsignedInt' >, <FHIRClassProperty self.name='allowedString' >, <FHIRClassProperty self.name='allowedMoney' >, <FHIRClassProperty self.name='usedUnsignedInt' >, <FHIRClassProperty self.name='usedString' >, <FHIRClassProperty self.name='usedMoney' >]
  

    type: "CodeableConcept"

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    allowedUnsignedInt: typing.Optional[int]

    """ Benefits allowed.
    Type `int`. """

    allowedString: typing.Optional[str]

    """ Benefits allowed.
    Type `str`. """

    allowedMoney: typing.Optional["Money"]

    """ Benefits allowed.
    Type `Money` (represented as `dict` in JSON). """

    usedUnsignedInt: typing.Optional[int]

    """ Benefits used.
    Type `int`. """

    usedString: typing.Optional[str]

    """ Benefits used.
    Type `str`. """

    usedMoney: typing.Optional["Money"]

    """ Benefits used.
    Type `Money` (represented as `dict` in JSON). """



#   {'path': 'CoverageEligibilityResponse.insurance.item.benefit.allowed[x]', 'choice_of_type': 'allowed', 'orig_name': 'allowedUnsignedInt', 'name': 'allowedUnsignedInt', 'parent_name': 'CoverageEligibilityResponse.insurance.item.benefit', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Benefits allowed', 'formal': 'The quantity of the benefit which is permitted under the coverage.', 'representation': None}

    _allowed_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['allowedUnsignedInt', 'allowedString', 'allowedMoney']), True))

#   {'path': 'CoverageEligibilityResponse.insurance.item.benefit.used[x]', 'choice_of_type': 'used', 'orig_name': 'usedUnsignedInt', 'name': 'usedUnsignedInt', 'parent_name': 'CoverageEligibilityResponse.insurance.item.benefit', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Benefits used', 'formal': 'The quantity of the benefit which have been consumed to date.', 'representation': None}

    _used_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['usedUnsignedInt', 'usedString', 'usedMoney']), True))


    

     
    



class CoverageEligibilityResponseError(BackboneElement):
    """ Processing errors.
    
    Errors encountered during the processing of the request.
    """
    
    # [<FHIRClassProperty self.name='code' >]
  

    code: "CodeableConcept"

    """ Error code detailing processing issues.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class DetectedIssueEvidence(BackboneElement):
    """ Supporting evidence.
    
    Supporting evidence or manifestations that provide the basis for
    identifying the detected issue such as a GuidanceResponse or MeasureReport.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='detail' >]
  

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Manifestation.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["Reference"]]

    """ Supporting information.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class DetectedIssueMitigation(BackboneElement):
    """ Step taken to address.
    
    Indicates an action that has been taken or is committed to reduce or
    eliminate the likelihood of the risk identified by the detected issue from
    manifesting.  Can also reflect an observation of known mitigating factors
    that may reduce/eliminate the need for any action.
    """
    
    # [<FHIRClassProperty self.name='action' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='author' >]
  

    action: "CodeableConcept"

    """ What mitigation?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date committed.
    Type `FHIRDate` (represented as `str` in JSON). """

    author: typing.Optional["Reference"]

    """ Who is committing?.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class DeviceUdiCarrier(BackboneElement):
    """ Unique Device Identifier (UDI) Barcode string.
    
    Unique device identifier (UDI) assigned to device label or package.  Note
    that the Device may include multiple udiCarriers as it either may include
    just the udiCarrier for the jurisdiction it is sold, or for multiple
    jurisdictions it could have been sold.
    """
    
    # [<FHIRClassProperty self.name='deviceIdentifier' >, <FHIRClassProperty self.name='issuer' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='carrierAIDC' >, <FHIRClassProperty self.name='carrierHRF' >, <FHIRClassProperty self.name='entryType' >]
  

    deviceIdentifier: typing.Optional[str]

    """ Mandatory fixed portion of UDI.
    Type `str`. """

    issuer: typing.Optional[str]

    """ UDI Issuing Organization.
    Type `str`. """

    jurisdiction: typing.Optional[str]

    """ Regional UDI authority.
    Type `str`. """

    carrierAIDC: typing.Optional[str]

    """ UDI Machine Readable Barcode String.
    Type `str`. """

    carrierHRF: typing.Optional[str]

    """ UDI Human Readable Barcode String.
    Type `str`. """

    entryType: typing.Optional["str"]

    """ barcode | rfid | manual +.
    Type `str`. """




    

     
    



class DeviceDeviceName(BackboneElement):
    """ The name of the device as given by the manufacturer.
    
    This represents the manufacturer's name of the device as provided by the
    device, from a UDI label, or by a person describing the Device.  This
    typically would be used when a person provides the name(s) or when the
    device represents one of the names available from DeviceDefinition.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >]
  

    name: str

    """ The name of the device.
    Type `str`. """

    type: "str"

    """ udi-label-name | user-friendly-name | patient-reported-name |
        manufacturer-name | model-name | other.
    Type `str`. """




    

     
    



class DeviceSpecialization(BackboneElement):
    """ The capabilities supported on a  device, the standards to which the device
    conforms for a particular purpose, and used for the communication.
    """
    
    # [<FHIRClassProperty self.name='systemType' >, <FHIRClassProperty self.name='version' >]
  

    systemType: "CodeableConcept"

    """ The standard that is used to operate and communicate.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    version: typing.Optional[str]

    """ The version of the standard that is used to operate and communicate.
    Type `str`. """




    

     
    



class DeviceVersion(BackboneElement):
    """ The actual design of the device or software version running on the device.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='component' >, <FHIRClassProperty self.name='value' >]
  

    type: typing.Optional["CodeableConcept"]

    """ The type of the device version.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    component: typing.Optional["Identifier"]

    """ A single component of the device version.
    Type `Identifier` (represented as `dict` in JSON). """

    value: str

    """ The version text.
    Type `str`. """




    

     
    



class DeviceProperty(BackboneElement):
    """ The actual configuration settings of a device as it actually operates,
    e.g., regulation status, time properties.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueCode' >]
  

    type: "CodeableConcept"

    """ Code that specifies the property DeviceDefinitionPropetyCode
        (Extensible).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional[typing.List["Quantity"]]

    """ Property value as a quantity.
    List of `Quantity` items (represented as `dict` in JSON). """

    valueCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Property value as a code, e.g., NTP4 (synced to NTP).
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class DeviceDefinitionUdiDeviceIdentifier(BackboneElement):
    """ Unique Device Identifier (UDI) Barcode string.
    
    Unique device identifier (UDI) assigned to device label or package.  Note
    that the Device may include multiple udiCarriers as it either may include
    just the udiCarrier for the jurisdiction it is sold, or for multiple
    jurisdictions it could have been sold.
    """
    
    # [<FHIRClassProperty self.name='deviceIdentifier' >, <FHIRClassProperty self.name='issuer' >, <FHIRClassProperty self.name='jurisdiction' >]
  

    deviceIdentifier: str

    """ The identifier that is to be associated with every Device that
        references this DeviceDefintiion for the issuer and jurisdication
        porvided in the DeviceDefinition.udiDeviceIdentifier.
    Type `str`. """

    issuer: str

    """ The organization that assigns the identifier algorithm.
    Type `str`. """

    jurisdiction: str

    """ The jurisdiction to which the deviceIdentifier applies.
    Type `str`. """




    

     
    



class DeviceDefinitionDeviceName(BackboneElement):
    """ A name given to the device to identify it.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >]
  

    name: str

    """ The name of the device.
    Type `str`. """

    type: "str"

    """ udi-label-name | user-friendly-name | patient-reported-name |
        manufacturer-name | model-name | other.
    Type `str`. """




    

     
    



class DeviceDefinitionSpecialization(BackboneElement):
    """ The capabilities supported on a  device, the standards to which the device
    conforms for a particular purpose, and used for the communication.
    """
    
    # [<FHIRClassProperty self.name='systemType' >, <FHIRClassProperty self.name='version' >]
  

    systemType: str

    """ The standard that is used to operate and communicate.
    Type `str`. """

    version: typing.Optional[str]

    """ The version of the standard that is used to operate and communicate.
    Type `str`. """




    

     
    



class DeviceDefinitionCapability(BackboneElement):
    """ Device capabilities.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='description' >]
  

    type: "CodeableConcept"

    """ Type of capability.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[typing.List["CodeableConcept"]]

    """ Description of capability.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class DeviceDefinitionProperty(BackboneElement):
    """ The actual configuration settings of a device as it actually operates,
    e.g., regulation status, time properties.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueCode' >]
  

    type: "CodeableConcept"

    """ Code that specifies the property DeviceDefinitionPropetyCode
        (Extensible).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional[typing.List["Quantity"]]

    """ Property value as a quantity.
    List of `Quantity` items (represented as `dict` in JSON). """

    valueCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Property value as a code, e.g., NTP4 (synced to NTP).
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class DeviceDefinitionMaterial(BackboneElement):
    """ A substance used to create the material(s) of which the device is made.
    """
    
    # [<FHIRClassProperty self.name='substance' >, <FHIRClassProperty self.name='alternate' >, <FHIRClassProperty self.name='allergenicIndicator' >]
  

    substance: "CodeableConcept"

    """ The substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    alternate: typing.Optional[bool]

    """ Indicates an alternative material of the device.
    Type `bool`. """

    allergenicIndicator: typing.Optional[bool]

    """ Whether the substance is a known or suspected allergen.
    Type `bool`. """




    

     
    



class DeviceMetricCalibration(BackboneElement):
    """ Describes the calibrations that have been performed or that are required to
    be performed.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='state' >, <FHIRClassProperty self.name='time' >]
  

    type: typing.Optional["str"]

    """ unspecified | offset | gain | two-point.
    Type `str`. """

    state: typing.Optional["str"]

    """ not-calibrated | calibration-required | calibrated | unspecified.
    Type `str`. """

    time: typing.Optional["FHIRDate"]

    """ Describes the time last calibration has been performed.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class DeviceRequestParameter(BackboneElement):
    """ Device details.
    
    Specific parameters for the ordered item.  For example, the prism value for
    lenses.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueBoolean' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Device detail.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value of detail.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Value of detail.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value of detail.
    Type `Range` (represented as `dict` in JSON). """

    valueBoolean: typing.Optional[bool]

    """ Value of detail.
    Type `bool`. """



#   {'path': 'DeviceRequest.parameter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCodeableConcept', 'name': 'valueCodeableConcept', 'parent_name': 'DeviceRequest.parameter', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value of detail', 'formal': 'The value of the device detail.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCodeableConcept', 'valueQuantity', 'valueRange', 'valueBoolean']), True))


    

     
    



class DiagnosticReportMedia(BackboneElement):
    """ Key images associated with this report.
    
    A list of key images associated with this report. The images are generally
    created during the diagnostic process, and may be directly of the patient,
    or of treated specimens (i.e. slides of interest).
    """
    
    # [<FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='link' >]
  

    comment: typing.Optional[str]

    """ Comment about the image (e.g. explanation).
    Type `str`. """

    link: "Reference"

    """ Reference to the image source.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class DocumentManifestRelated(BackboneElement):
    """ Related things.
    
    Related identifiers or resources associated with the DocumentManifest.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='ref' >]
  

    identifier: typing.Optional["Identifier"]

    """ Identifiers of things that are related.
    Type `Identifier` (represented as `dict` in JSON). """

    ref: typing.Optional["Reference"]

    """ Related Resource.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class DocumentReferenceRelatesTo(BackboneElement):
    """ Relationships to other documents.
    
    Relationships that this document has with other document references that
    already exist.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='target' >]
  

    code: "str"

    """ replaces | transforms | signs | appends.
    Type `str`. """

    target: "Reference"

    """ Target of the relationship.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class DocumentReferenceContent(BackboneElement):
    """ Document referenced.
    
    The document and format referenced. There may be multiple content element
    repetitions, each with a different format.
    """
    
    # [<FHIRClassProperty self.name='attachment' >, <FHIRClassProperty self.name='format' >]
  

    attachment: "Attachment"

    """ Where to access the document.
    Type `Attachment` (represented as `dict` in JSON). """

    format: typing.Optional["Coding"]

    """ Format/content rules for the document.
    Type `Coding` (represented as `dict` in JSON). """




    

     
    



class DocumentReferenceContext(BackboneElement):
    """ Clinical context of document.
    
    The clinical context in which the document was prepared.
    """
    
    # [<FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='event' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='facilityType' >, <FHIRClassProperty self.name='practiceSetting' >, <FHIRClassProperty self.name='sourcePatientInfo' >, <FHIRClassProperty self.name='related' >]
  

    encounter: typing.Optional[typing.List["Reference"]]

    """ Context of the document  content.
    List of `Reference` items (represented as `dict` in JSON). """

    event: typing.Optional[typing.List["CodeableConcept"]]

    """ Main clinical acts documented.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time of service that is being documented.
    Type `Period` (represented as `dict` in JSON). """

    facilityType: typing.Optional["CodeableConcept"]

    """ Kind of facility where patient was seen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    practiceSetting: typing.Optional["CodeableConcept"]

    """ Additional details about where the content was created (e.g.
        clinical specialty).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    sourcePatientInfo: typing.Optional["Reference"]

    """ Patient demographics from source.
    Type `Reference` (represented as `dict` in JSON). """

    related: typing.Optional[typing.List["Reference"]]

    """ Related identifiers or resources.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class EffectEvidenceSynthesisSampleSize(BackboneElement):
    """ What sample size was involved?.
    
    A description of the size of the sample involved in the synthesis.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='numberOfStudies' >, <FHIRClassProperty self.name='numberOfParticipants' >]
  

    description: typing.Optional[str]

    """ Description of sample size.
    Type `str`. """

    numberOfStudies: typing.Optional[int]

    """ How many studies?.
    Type `int`. """

    numberOfParticipants: typing.Optional[int]

    """ How many participants?.
    Type `int`. """




    

     
    



class EffectEvidenceSynthesisResultsByExposure(BackboneElement):
    """ What was the result per exposure?.
    
    A description of the results for each exposure considered in the effect
    estimate.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='exposureState' >, <FHIRClassProperty self.name='variantState' >, <FHIRClassProperty self.name='riskEvidenceSynthesis' >]
  

    description: typing.Optional[str]

    """ Description of results by exposure.
    Type `str`. """

    exposureState: typing.Optional["str"]

    """ exposure | exposure-alternative.
    Type `str`. """

    variantState: typing.Optional["CodeableConcept"]

    """ Variant exposure states.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    riskEvidenceSynthesis: "Reference"

    """ Risk evidence synthesis.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class EffectEvidenceSynthesisEffectEstimate(BackboneElement):
    """ What was the estimated effect.
    
    The estimated effect of the exposure variant.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='variantState' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='unitOfMeasure' >, <FHIRClassProperty self.name='precisionEstimate' >]
  

    description: typing.Optional[str]

    """ Description of effect estimate.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Type of efffect estimate.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    variantState: typing.Optional["CodeableConcept"]

    """ Variant exposure states.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: typing.Optional[float]

    """ Point estimate.
    Type `float`. """

    unitOfMeasure: typing.Optional["CodeableConcept"]

    """ What unit is the outcome described in?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    precisionEstimate: typing.Optional[typing.List["EffectEvidenceSynthesisEffectEstimatePrecisionEstimate"]]

    """ How precise the estimate is.
    List of `EffectEvidenceSynthesisEffectEstimatePrecisionEstimate` items (represented as `dict` in JSON). """




    

     
    



class EffectEvidenceSynthesisEffectEstimatePrecisionEstimate(BackboneElement):
    """ How precise the estimate is.
    
    A description of the precision of the estimate for the effect.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='level' >, <FHIRClassProperty self.name='from_' >, <FHIRClassProperty self.name='to' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of precision estimate.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    level: typing.Optional[float]

    """ Level of confidence interval.
    Type `float`. """

    from_: typing.Optional[float]

    """ Lower bound.
    Type `float`. """

    to: typing.Optional[float]

    """ Upper bound.
    Type `float`. """




    

     
    



class EffectEvidenceSynthesisCertainty(BackboneElement):
    """ How certain is the effect.
    
    A description of the certainty of the effect estimate.
    """
    
    # [<FHIRClassProperty self.name='rating' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='certaintySubcomponent' >]
  

    rating: typing.Optional[typing.List["CodeableConcept"]]

    """ Certainty rating.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    certaintySubcomponent: typing.Optional[typing.List["EffectEvidenceSynthesisCertaintyCertaintySubcomponent"]]

    """ A component that contributes to the overall certainty.
    List of `EffectEvidenceSynthesisCertaintyCertaintySubcomponent` items (represented as `dict` in JSON). """




    

     
    



class EffectEvidenceSynthesisCertaintyCertaintySubcomponent(BackboneElement):
    """ A component that contributes to the overall certainty.
    
    A description of a component of the overall certainty.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='rating' >, <FHIRClassProperty self.name='note' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of subcomponent of certainty rating.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    rating: typing.Optional[typing.List["CodeableConcept"]]

    """ Subcomponent certainty rating.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class EncounterStatusHistory(BackboneElement):
    """ List of past encounter statuses.
    
    The status history permits the encounter resource to contain the status
    history without needing to read through the historical versions of the
    resource, or even have the server store them.
    """
    
    # [<FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='period' >]
  

    status: "str"

    """ planned | arrived | triaged | in-progress | onleave | finished |
        cancelled +.
    Type `str`. """

    period: "Period"

    """ The time that the episode was in the specified status.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class EncounterClassHistory(BackboneElement):
    """ List of past encounter classes.
    
    The class history permits the tracking of the encounters transitions
    without needing to go  through the resource history.  This would be used
    for a case where an admission starts of as an emergency encounter, then
    transitions into an inpatient scenario. Doing this and not restarting a new
    encounter ensures that any lab/diagnostic results can more easily follow
    the patient and not require re-processing and not get lost or cancelled
    during a kind of discharge from emergency to inpatient.
    """
    
    # [<FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='period' >]
  

    class_: "Coding"

    """ inpatient | outpatient | ambulatory | emergency +.
    Type `Coding` (represented as `dict` in JSON). """

    period: "Period"

    """ The time that the episode was in the specified class.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class EncounterParticipant(BackboneElement):
    """ List of participants involved in the encounter.
    
    The list of people responsible for providing the service.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='individual' >]
  

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Role of participant in encounter.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Period of time during the encounter that the participant
        participated.
    Type `Period` (represented as `dict` in JSON). """

    individual: typing.Optional["Reference"]

    """ Persons involved in the encounter other than the patient.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class EncounterDiagnosis(BackboneElement):
    """ The list of diagnosis relevant to this encounter.
    """
    
    # [<FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='rank' >]
  

    condition: "Reference"

    """ The diagnosis or procedure relevant to the encounter.
    Type `Reference` (represented as `dict` in JSON). """

    use: typing.Optional["CodeableConcept"]

    """ Role that this diagnosis has within the encounter (e.g. admission,
        billing, discharge …).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    rank: typing.Optional[int]

    """ Ranking of the diagnosis (for each role type).
    Type `int`. """




    

     
    



class EncounterHospitalization(BackboneElement):
    """ Details about the admission to a healthcare service.
    """
    
    # [<FHIRClassProperty self.name='preAdmissionIdentifier' >, <FHIRClassProperty self.name='origin' >, <FHIRClassProperty self.name='admitSource' >, <FHIRClassProperty self.name='reAdmission' >, <FHIRClassProperty self.name='dietPreference' >, <FHIRClassProperty self.name='specialCourtesy' >, <FHIRClassProperty self.name='specialArrangement' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='dischargeDisposition' >]
  

    preAdmissionIdentifier: typing.Optional["Identifier"]

    """ Pre-admission identifier.
    Type `Identifier` (represented as `dict` in JSON). """

    origin: typing.Optional["Reference"]

    """ The location/organization from which the patient came before
        admission.
    Type `Reference` (represented as `dict` in JSON). """

    admitSource: typing.Optional["CodeableConcept"]

    """ From where patient was admitted (physician referral, transfer).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reAdmission: typing.Optional["CodeableConcept"]

    """ The type of hospital re-admission that has occurred (if any). If
        the value is absent, then this is not identified as a readmission.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    dietPreference: typing.Optional[typing.List["CodeableConcept"]]

    """ Diet preferences reported by the patient.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialCourtesy: typing.Optional[typing.List["CodeableConcept"]]

    """ Special courtesies (VIP, board member).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    specialArrangement: typing.Optional[typing.List["CodeableConcept"]]

    """ Wheelchair, translator, stretcher, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    destination: typing.Optional["Reference"]

    """ Location/organization to which the patient is discharged.
    Type `Reference` (represented as `dict` in JSON). """

    dischargeDisposition: typing.Optional["CodeableConcept"]

    """ Category or kind of location after discharge.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class EncounterLocation(BackboneElement):
    """ List of locations where the patient has been.
    
    List of locations where  the patient has been during this encounter.
    """
    
    # [<FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='physicalType' >, <FHIRClassProperty self.name='period' >]
  

    location: "Reference"

    """ Location the encounter takes place.
    Type `Reference` (represented as `dict` in JSON). """

    status: typing.Optional["str"]

    """ planned | active | reserved | completed.
    Type `str`. """

    physicalType: typing.Optional["CodeableConcept"]

    """ The physical type of the location (usually the level in the
        location hierachy - bed room ward etc.).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Time period during which the patient was present at the location.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class EpisodeOfCareStatusHistory(BackboneElement):
    """ Past list of status codes (the current status may be included to cover the
    start date of the status).
    
    The history of statuses that the EpisodeOfCare has been through (without
    requiring processing the history of the resource).
    """
    
    # [<FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='period' >]
  

    status: "str"

    """ planned | waitlist | active | onhold | finished | cancelled |
        entered-in-error.
    Type `str`. """

    period: "Period"

    """ Duration the EpisodeOfCare was in the specified status.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class EpisodeOfCareDiagnosis(BackboneElement):
    """ The list of diagnosis relevant to this episode of care.
    """
    
    # [<FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='rank' >]
  

    condition: "Reference"

    """ Conditions/problems/diagnoses this episode of care is for.
    Type `Reference` (represented as `dict` in JSON). """

    role: typing.Optional["CodeableConcept"]

    """ Role that this diagnosis has within the episode of care (e.g.
        admission, billing, discharge …).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    rank: typing.Optional[int]

    """ Ranking of the diagnosis (for each role type).
    Type `int`. """




    

     
    



class EvidenceVariableCharacteristic(BackboneElement):
    """ What defines the members of the evidence element.
    
    A characteristic that defines the members of the evidence element. Multiple
    characteristics are applied with "and" semantics.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='definitionReference' >, <FHIRClassProperty self.name='definitionCanonical' >, <FHIRClassProperty self.name='definitionCodeableConcept' >, <FHIRClassProperty self.name='definitionExpression' >, <FHIRClassProperty self.name='definitionDataRequirement' >, <FHIRClassProperty self.name='definitionTriggerDefinition' >, <FHIRClassProperty self.name='usageContext' >, <FHIRClassProperty self.name='exclude' >, <FHIRClassProperty self.name='participantEffectiveDateTime' >, <FHIRClassProperty self.name='participantEffectivePeriod' >, <FHIRClassProperty self.name='participantEffectiveDuration' >, <FHIRClassProperty self.name='participantEffectiveTiming' >, <FHIRClassProperty self.name='timeFromStart' >, <FHIRClassProperty self.name='groupMeasure' >]
  

    description: typing.Optional[str]

    """ Natural language description of the characteristic.
    Type `str`. """

    definitionReference: typing.Optional["Reference"]

    """ What code or expression defines members?.
    Type `Reference` (represented as `dict` in JSON). """

    definitionCanonical: typing.Optional[str]

    """ What code or expression defines members?.
    Type `str`. """

    definitionCodeableConcept: typing.Optional["CodeableConcept"]

    """ What code or expression defines members?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    definitionExpression: typing.Optional["Expression"]

    """ What code or expression defines members?.
    Type `Expression` (represented as `dict` in JSON). """

    definitionDataRequirement: typing.Optional["DataRequirement"]

    """ What code or expression defines members?.
    Type `DataRequirement` (represented as `dict` in JSON). """

    definitionTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ What code or expression defines members?.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    usageContext: typing.Optional[typing.List["UsageContext"]]

    """ What code/value pairs define members?.
    List of `UsageContext` items (represented as `dict` in JSON). """

    exclude: typing.Optional[bool]

    """ Whether the characteristic includes or excludes members.
    Type `bool`. """

    participantEffectiveDateTime: typing.Optional["FHIRDate"]

    """ What time period do participants cover.
    Type `FHIRDate` (represented as `str` in JSON). """

    participantEffectivePeriod: typing.Optional["Period"]

    """ What time period do participants cover.
    Type `Period` (represented as `dict` in JSON). """

    participantEffectiveDuration: typing.Optional["Duration"]

    """ What time period do participants cover.
    Type `Duration` (represented as `dict` in JSON). """

    participantEffectiveTiming: typing.Optional["Timing"]

    """ What time period do participants cover.
    Type `Timing` (represented as `dict` in JSON). """

    timeFromStart: typing.Optional["Duration"]

    """ Observation time from study start.
    Type `Duration` (represented as `dict` in JSON). """

    groupMeasure: typing.Optional["str"]

    """ mean | median | mean-of-mean | mean-of-median | median-of-mean |
        median-of-median.
    Type `str`. """



#   {'path': 'EvidenceVariable.characteristic.definition[x]', 'choice_of_type': 'definition', 'orig_name': 'definitionReference', 'name': 'definitionReference', 'parent_name': 'EvidenceVariable.characteristic', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What code or expression defines members?', 'formal': 'Define members of the evidence element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).', 'representation': None}

    _definition_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['definitionReference', 'definitionCanonical', 'definitionCodeableConcept', 'definitionExpression', 'definitionDataRequirement', 'definitionTriggerDefinition']), False))

#   {'path': 'EvidenceVariable.characteristic.participantEffective[x]', 'choice_of_type': 'participantEffective', 'orig_name': 'participantEffectiveDateTime', 'name': 'participantEffectiveDateTime', 'parent_name': 'EvidenceVariable.characteristic', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'What time period do participants cover', 'formal': 'Indicates what effective period the study covers.', 'representation': None}

    _participantEffective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['participantEffectiveDateTime', 'participantEffectivePeriod', 'participantEffectiveDuration', 'participantEffectiveTiming']), True))


    

     
    



class ExampleScenarioActor(BackboneElement):
    """ Actor participating in the resource.
    """
    
    # [<FHIRClassProperty self.name='actorId' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >]
  

    actorId: str

    """ ID or acronym of the actor.
    Type `str`. """

    type: "str"

    """ person | entity.
    Type `str`. """

    name: typing.Optional[str]

    """ The name of the actor as shown in the page.
    Type `str`. """

    description: typing.Optional[str]

    """ The description of the actor.
    Type `str`. """




    

     
    



class ExampleScenarioInstance(BackboneElement):
    """ Each resource and each version that is present in the workflow.
    """
    
    # [<FHIRClassProperty self.name='resourceId' >, <FHIRClassProperty self.name='resourceType' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='containedInstance' >]
  

    resourceId: str

    """ The id of the resource for referencing.
    Type `str`. """

    resourceType: "str"

    """ The type of the resource.
    Type `str`. """

    name: typing.Optional[str]

    """ A short name for the resource instance.
    Type `str`. """

    description: typing.Optional[str]

    """ Human-friendly description of the resource instance.
    Type `str`. """

    version: typing.Optional[typing.List["ExampleScenarioInstanceVersion"]]

    """ A specific version of the resource.
    List of `ExampleScenarioInstanceVersion` items (represented as `dict` in JSON). """

    containedInstance: typing.Optional[typing.List["ExampleScenarioInstanceContainedInstance"]]

    """ Resources contained in the instance.
    List of `ExampleScenarioInstanceContainedInstance` items (represented as `dict` in JSON). """




    

     
    



class ExampleScenarioInstanceVersion(BackboneElement):
    """ A specific version of the resource.
    """
    
    # [<FHIRClassProperty self.name='versionId' >, <FHIRClassProperty self.name='description' >]
  

    versionId: str

    """ The identifier of a specific version of a resource.
    Type `str`. """

    description: str

    """ The description of the resource version.
    Type `str`. """




    

     
    



class ExampleScenarioInstanceContainedInstance(BackboneElement):
    """ Resources contained in the instance.
    
    Resources contained in the instance (e.g. the observations contained in a
    bundle).
    """
    
    # [<FHIRClassProperty self.name='resourceId' >, <FHIRClassProperty self.name='versionId' >]
  

    resourceId: str

    """ Each resource contained in the instance.
    Type `str`. """

    versionId: typing.Optional[str]

    """ A specific version of a resource contained in the instance.
    Type `str`. """




    

     
    



class ExampleScenarioProcess(BackboneElement):
    """ Each major process - a group of operations.
    """
    
    # [<FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='preConditions' >, <FHIRClassProperty self.name='postConditions' >, <FHIRClassProperty self.name='step' >]
  

    title: str

    """ The diagram title of the group of operations.
    Type `str`. """

    description: typing.Optional[str]

    """ A longer description of the group of operations.
    Type `str`. """

    preConditions: typing.Optional[str]

    """ Description of initial status before the process starts.
    Type `str`. """

    postConditions: typing.Optional[str]

    """ Description of final status after the process ends.
    Type `str`. """

    step: typing.Optional[typing.List["ExampleScenarioProcessStep"]]

    """ Each step of the process.
    List of `ExampleScenarioProcessStep` items (represented as `dict` in JSON). """




    

     
    



class ExampleScenarioProcessStep(BackboneElement):
    """ Each step of the process.
    """
    
    # [<FHIRClassProperty self.name='process' >, <FHIRClassProperty self.name='pause' >, <FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='alternative' >]
  

    process: typing.Optional[typing.List["ExampleScenarioProcess"]]

    """ Nested process.
    List of `ExampleScenarioProcess` items (represented as `dict` in JSON). """

    pause: typing.Optional[bool]

    """ If there is a pause in the flow.
    Type `bool`. """

    operation: typing.Optional["ExampleScenarioProcessStepOperation"]

    """ Each interaction or action.
    Type `ExampleScenarioProcessStepOperation` (represented as `dict` in JSON). """

    alternative: typing.Optional[typing.List["ExampleScenarioProcessStepAlternative"]]

    """ Alternate non-typical step action.
    List of `ExampleScenarioProcessStepAlternative` items (represented as `dict` in JSON). """




    

     
    



class ExampleScenarioProcessStepOperation(BackboneElement):
    """ Each interaction or action.
    """
    
    # [<FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='initiator' >, <FHIRClassProperty self.name='receiver' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='initiatorActive' >, <FHIRClassProperty self.name='receiverActive' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='response' >]
  

    number: str

    """ The sequential number of the interaction.
    Type `str`. """

    type: typing.Optional[str]

    """ The type of operation - CRUD.
    Type `str`. """

    name: typing.Optional[str]

    """ The human-friendly name of the interaction.
    Type `str`. """

    initiator: typing.Optional[str]

    """ Who starts the transaction.
    Type `str`. """

    receiver: typing.Optional[str]

    """ Who receives the transaction.
    Type `str`. """

    description: typing.Optional[str]

    """ A comment to be inserted in the diagram.
    Type `str`. """

    initiatorActive: typing.Optional[bool]

    """ Whether the initiator is deactivated right after the transaction.
    Type `bool`. """

    receiverActive: typing.Optional[bool]

    """ Whether the receiver is deactivated right after the transaction.
    Type `bool`. """

    request: typing.Optional["ExampleScenarioInstanceContainedInstance"]

    """ Each resource instance used by the initiator.
    Type `ExampleScenarioInstanceContainedInstance` (represented as `dict` in JSON). """

    response: typing.Optional["ExampleScenarioInstanceContainedInstance"]

    """ Each resource instance used by the responder.
    Type `ExampleScenarioInstanceContainedInstance` (represented as `dict` in JSON). """




    

     
    



class ExampleScenarioProcessStepAlternative(BackboneElement):
    """ Alternate non-typical step action.
    
    Indicates an alternative step that can be taken instead of the operations
    on the base step in exceptional/atypical circumstances.
    """
    
    # [<FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='step' >]
  

    title: str

    """ Label for alternative.
    Type `str`. """

    description: typing.Optional[str]

    """ A human-readable description of each option.
    Type `str`. """

    step: typing.Optional[typing.List["ExampleScenarioProcessStep"]]

    """ What happens in each alternative option.
    List of `ExampleScenarioProcessStep` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitRelated(BackboneElement):
    """ Prior or corollary claims.
    
    Other claims which are related to this claim such as prior submissions or
    claims for related services or for the same event.
    """
    
    # [<FHIRClassProperty self.name='claim' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='reference' >]
  

    claim: typing.Optional["Reference"]

    """ Reference to the related claim.
    Type `Reference` (represented as `dict` in JSON). """

    relationship: typing.Optional["CodeableConcept"]

    """ How the reference claim is related.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reference: typing.Optional["Identifier"]

    """ File or case reference.
    Type `Identifier` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitPayee(BackboneElement):
    """ Recipient of benefits payable.
    
    The party to be reimbursed for cost of the products and services according
    to the terms of the policy.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='party' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Category of recipient.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    party: typing.Optional["Reference"]

    """ Recipient reference.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitCareTeam(BackboneElement):
    """ Care Team members.
    
    The members of the team who provided the products and services.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='qualification' >]
  

    sequence: int

    """ Order of care team.
    Type `int`. """

    provider: "Reference"

    """ Practitioner or organization.
    Type `Reference` (represented as `dict` in JSON). """

    responsible: typing.Optional[bool]

    """ Indicator of the lead practitioner.
    Type `bool`. """

    role: typing.Optional["CodeableConcept"]

    """ Function within the team.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    qualification: typing.Optional["CodeableConcept"]

    """ Practitioner credential or specialization.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitSupportingInfo(BackboneElement):
    """ Supporting information.
    
    Additional information codes regarding exceptions, special considerations,
    the condition, situation, prior or concurrent issues.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='timingDate' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='reason' >]
  

    sequence: int

    """ Information instance identifier.
    Type `int`. """

    category: "CodeableConcept"

    """ Classification of the supplied information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Type of information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    timingDate: typing.Optional["FHIRDate"]

    """ When it occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ When it occurred.
    Type `Period` (represented as `dict` in JSON). """

    valueBoolean: typing.Optional[bool]

    """ Data to be provided.
    Type `bool`. """

    valueString: typing.Optional[str]

    """ Data to be provided.
    Type `str`. """

    valueQuantity: typing.Optional["Quantity"]

    """ Data to be provided.
    Type `Quantity` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Data to be provided.
    Type `Attachment` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Data to be provided.
    Type `Reference` (represented as `dict` in JSON). """

    reason: typing.Optional["Coding"]

    """ Explanation for the information.
    Type `Coding` (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.supportingInfo.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingDate', 'name': 'timingDate', 'parent_name': 'ExplanationOfBenefit.supportingInfo', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When it occurred', 'formal': 'The date when or period to which this information refers.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingDate', 'timingPeriod']), True))

#   {'path': 'ExplanationOfBenefit.supportingInfo.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBoolean', 'name': 'valueBoolean', 'parent_name': 'ExplanationOfBenefit.supportingInfo', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Data to be provided', 'formal': 'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBoolean', 'valueString', 'valueQuantity', 'valueAttachment', 'valueReference']), True))


    

     
    



class ExplanationOfBenefitDiagnosis(BackboneElement):
    """ Pertinent diagnosis information.
    
    Information about diagnoses relevant to the claim items.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='diagnosisCodeableConcept' >, <FHIRClassProperty self.name='diagnosisReference' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='onAdmission' >, <FHIRClassProperty self.name='packageCode' >]
  

    sequence: int

    """ Diagnosis instance identifier.
    Type `int`. """

    diagnosisCodeableConcept: typing.Optional["CodeableConcept"]

    """ Nature of illness or problem.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diagnosisReference: typing.Optional["Reference"]

    """ Nature of illness or problem.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Timing or nature of the diagnosis.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    onAdmission: typing.Optional["CodeableConcept"]

    """ Present on admission.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    packageCode: typing.Optional["CodeableConcept"]

    """ Package billing code.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.diagnosis.diagnosis[x]', 'choice_of_type': 'diagnosis', 'orig_name': 'diagnosisCodeableConcept', 'name': 'diagnosisCodeableConcept', 'parent_name': 'ExplanationOfBenefit.diagnosis', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Nature of illness or problem', 'formal': 'The nature of illness or problem in a coded form or as a reference to an external defined Condition.', 'representation': None}

    _diagnosis_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['diagnosisCodeableConcept', 'diagnosisReference']), False))


    

     
    



class ExplanationOfBenefitProcedure(BackboneElement):
    """ Clinical procedures performed.
    
    Procedures performed on the patient relevant to the billing items with the
    claim.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='procedureCodeableConcept' >, <FHIRClassProperty self.name='procedureReference' >, <FHIRClassProperty self.name='udi' >]
  

    sequence: int

    """ Procedure instance identifier.
    Type `int`. """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Category of Procedure.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ When the procedure was performed.
    Type `FHIRDate` (represented as `str` in JSON). """

    procedureCodeableConcept: typing.Optional["CodeableConcept"]

    """ Specific clinical procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    procedureReference: typing.Optional["Reference"]

    """ Specific clinical procedure.
    Type `Reference` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.procedure.procedure[x]', 'choice_of_type': 'procedure', 'orig_name': 'procedureCodeableConcept', 'name': 'procedureCodeableConcept', 'parent_name': 'ExplanationOfBenefit.procedure', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Specific clinical procedure', 'formal': 'The code or reference to a Procedure resource which identifies the clinical intervention performed.', 'representation': None}

    _procedure_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['procedureCodeableConcept', 'procedureReference']), False))


    

     
    



class ExplanationOfBenefitInsurance(BackboneElement):
    """ Patient insurance information.
    
    Financial instruments for reimbursement for the health care products and
    services specified on the claim.
    """
    
    # [<FHIRClassProperty self.name='focal' >, <FHIRClassProperty self.name='coverage' >, <FHIRClassProperty self.name='preAuthRef' >]
  

    focal: bool

    """ Coverage to be used for adjudication.
    Type `bool`. """

    coverage: "Reference"

    """ Insurance information.
    Type `Reference` (represented as `dict` in JSON). """

    preAuthRef: typing.Optional[typing.List[str]]

    """ Prior authorization reference number.
    List of `str` items. """




    

     
    



class ExplanationOfBenefitAccident(BackboneElement):
    """ Details of the event.
    
    Details of a accident which resulted in injuries which required the
    products and services listed in the claim.
    """
    
    # [<FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >]
  

    date: typing.Optional["FHIRDate"]

    """ When the incident occurred.
    Type `FHIRDate` (represented as `str` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ The nature of the accident.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Where the event occurred.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Where the event occurred.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.accident.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationAddress', 'name': 'locationAddress', 'parent_name': 'ExplanationOfBenefit.accident', 'class_name': 'Address', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Where the event occurred', 'formal': 'The physical location of the accident event.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationAddress', 'locationReference']), True))


    

     
    



class ExplanationOfBenefitItem(BackboneElement):
    """ Product or service provided.
    
    A claim line. Either a simple (a product or service) or a 'group' of
    details which can also be a simple items or groups of sub-details.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='careTeamSequence' >, <FHIRClassProperty self.name='diagnosisSequence' >, <FHIRClassProperty self.name='procedureSequence' >, <FHIRClassProperty self.name='informationSequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='locationCodeableConcept' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='subSite' >, <FHIRClassProperty self.name='encounter' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='detail' >]
  

    sequence: int

    """ Item instance identifier.
    Type `int`. """

    careTeamSequence: typing.Optional[typing.List[int]]

    """ Applicable care team members.
    List of `int` items. """

    diagnosisSequence: typing.Optional[typing.List[int]]

    """ Applicable diagnoses.
    List of `int` items. """

    procedureSequence: typing.Optional[typing.List[int]]

    """ Applicable procedures.
    List of `int` items. """

    informationSequence: typing.Optional[typing.List[int]]

    """ Applicable exception and supporting information.
    List of `int` items. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Product or service billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Date or dates of service or product delivery.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Date or dates of service or product delivery.
    Type `Period` (represented as `dict` in JSON). """

    locationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Place of service or where product was supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Place of service or where product was supplied.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Place of service or where product was supplied.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Anatomical location.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subSite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical sub-location.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    encounter: typing.Optional[typing.List["Reference"]]

    """ Encounters related to this billed item.
    List of `Reference` items (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Adjudication details.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["ExplanationOfBenefitItemDetail"]]

    """ Additional items.
    List of `ExplanationOfBenefitItemDetail` items (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.item.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'ExplanationOfBenefit.item', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date or dates of service or product delivery', 'formal': 'The date or dates when the service or product was supplied, performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))

#   {'path': 'ExplanationOfBenefit.item.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationCodeableConcept', 'name': 'locationCodeableConcept', 'parent_name': 'ExplanationOfBenefit.item', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Place of service or where product was supplied', 'formal': 'Where the product or service was provided.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationCodeableConcept', 'locationAddress', 'locationReference']), True))


    

     
    



class ExplanationOfBenefitItemAdjudication(BackboneElement):
    """ Adjudication details.
    
    If this item is a group then the values here are a summary of the
    adjudication of the detail items. If this item is a simple product or
    service then this is the result of the adjudication of this item.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='value' >]
  

    category: "CodeableConcept"

    """ Type of adjudication information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reason: typing.Optional["CodeableConcept"]

    """ Explanation of adjudication outcome.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Money"]

    """ Monetary amount.
    Type `Money` (represented as `dict` in JSON). """

    value: typing.Optional[float]

    """ Non-monitary value.
    Type `float`. """




    

     
    



class ExplanationOfBenefitItemDetail(BackboneElement):
    """ Additional items.
    
    Second-tier of goods and services.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='subDetail' >]
  

    sequence: int

    """ Product or service provided.
    Type `int`. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Detail level adjudication details.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """

    subDetail: typing.Optional[typing.List["ExplanationOfBenefitItemDetailSubDetail"]]

    """ Additional items.
    List of `ExplanationOfBenefitItemDetailSubDetail` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitItemDetailSubDetail(BackboneElement):
    """ Additional items.
    
    Third-tier of goods and services.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='revenue' >, <FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='udi' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >]
  

    sequence: int

    """ Product or service provided.
    Type `int`. """

    revenue: typing.Optional["CodeableConcept"]

    """ Revenue or cost center code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    category: typing.Optional["CodeableConcept"]

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    udi: typing.Optional[typing.List["Reference"]]

    """ Unique device identifier.
    List of `Reference` items (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Subdetail level adjudication details.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitAddItem(BackboneElement):
    """ Insurer added line items.
    
    The first-tier service adjudications for payor added product or service
    lines.
    """
    
    # [<FHIRClassProperty self.name='itemSequence' >, <FHIRClassProperty self.name='detailSequence' >, <FHIRClassProperty self.name='subDetailSequence' >, <FHIRClassProperty self.name='provider' >, <FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='programCode' >, <FHIRClassProperty self.name='servicedDate' >, <FHIRClassProperty self.name='servicedPeriod' >, <FHIRClassProperty self.name='locationCodeableConcept' >, <FHIRClassProperty self.name='locationAddress' >, <FHIRClassProperty self.name='locationReference' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='subSite' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='detail' >]
  

    itemSequence: typing.Optional[typing.List[int]]

    """ Item sequence number.
    List of `int` items. """

    detailSequence: typing.Optional[typing.List[int]]

    """ Detail sequence number.
    List of `int` items. """

    subDetailSequence: typing.Optional[typing.List[int]]

    """ Subdetail sequence number.
    List of `int` items. """

    provider: typing.Optional[typing.List["Reference"]]

    """ Authorized providers.
    List of `Reference` items (represented as `dict` in JSON). """

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    programCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Program the product or service is provided under.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    servicedDate: typing.Optional["FHIRDate"]

    """ Date or dates of service or product delivery.
    Type `FHIRDate` (represented as `str` in JSON). """

    servicedPeriod: typing.Optional["Period"]

    """ Date or dates of service or product delivery.
    Type `Period` (represented as `dict` in JSON). """

    locationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Place of service or where product was supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    locationAddress: typing.Optional["Address"]

    """ Place of service or where product was supplied.
    Type `Address` (represented as `dict` in JSON). """

    locationReference: typing.Optional["Reference"]

    """ Place of service or where product was supplied.
    Type `Reference` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Anatomical location.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subSite: typing.Optional[typing.List["CodeableConcept"]]

    """ Anatomical sub-location.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Added items adjudication.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """

    detail: typing.Optional[typing.List["ExplanationOfBenefitAddItemDetail"]]

    """ Insurer added line items.
    List of `ExplanationOfBenefitAddItemDetail` items (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.addItem.serviced[x]', 'choice_of_type': 'serviced', 'orig_name': 'servicedDate', 'name': 'servicedDate', 'parent_name': 'ExplanationOfBenefit.addItem', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date or dates of service or product delivery', 'formal': 'The date or dates when the service or product was supplied, performed or completed.', 'representation': None}

    _serviced_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['servicedDate', 'servicedPeriod']), True))

#   {'path': 'ExplanationOfBenefit.addItem.location[x]', 'choice_of_type': 'location', 'orig_name': 'locationCodeableConcept', 'name': 'locationCodeableConcept', 'parent_name': 'ExplanationOfBenefit.addItem', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Place of service or where product was supplied', 'formal': 'Where the product or service was provided.', 'representation': None}

    _location_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['locationCodeableConcept', 'locationAddress', 'locationReference']), True))


    

     
    



class ExplanationOfBenefitAddItemDetail(BackboneElement):
    """ Insurer added line items.
    
    The second-tier service adjudications for payor added services.
    """
    
    # [<FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >, <FHIRClassProperty self.name='subDetail' >]
  

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Added items adjudication.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """

    subDetail: typing.Optional[typing.List["ExplanationOfBenefitAddItemDetailSubDetail"]]

    """ Insurer added line items.
    List of `ExplanationOfBenefitAddItemDetailSubDetail` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitAddItemDetailSubDetail(BackboneElement):
    """ Insurer added line items.
    
    The third-tier service adjudications for payor added services.
    """
    
    # [<FHIRClassProperty self.name='productOrService' >, <FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='unitPrice' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='net' >, <FHIRClassProperty self.name='noteNumber' >, <FHIRClassProperty self.name='adjudication' >]
  

    productOrService: "CodeableConcept"

    """ Billing, service, product, or drug code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    modifier: typing.Optional[typing.List["CodeableConcept"]]

    """ Service/Product billing modifiers.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Count of products or services.
    Type `Quantity` (represented as `dict` in JSON). """

    unitPrice: typing.Optional["Money"]

    """ Fee, charge or cost per item.
    Type `Money` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Price scaling factor.
    Type `float`. """

    net: typing.Optional["Money"]

    """ Total item cost.
    Type `Money` (represented as `dict` in JSON). """

    noteNumber: typing.Optional[typing.List[int]]

    """ Applicable note numbers.
    List of `int` items. """

    adjudication: typing.Optional[typing.List["ExplanationOfBenefitItemAdjudication"]]

    """ Added items adjudication.
    List of `ExplanationOfBenefitItemAdjudication` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitTotal(BackboneElement):
    """ Adjudication totals.
    
    Categorized monetary totals for the adjudication.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='amount' >]
  

    category: "CodeableConcept"

    """ Type of adjudication information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: "Money"

    """ Financial total for the category.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitPayment(BackboneElement):
    """ Payment Details.
    
    Payment details for the adjudication of the claim.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='adjustment' >, <FHIRClassProperty self.name='adjustmentReason' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='identifier' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Partial or complete payment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    adjustment: typing.Optional["Money"]

    """ Payment adjustment for non-claim issues.
    Type `Money` (represented as `dict` in JSON). """

    adjustmentReason: typing.Optional["CodeableConcept"]

    """ Explanation for the variance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Expected date of payment.
    Type `FHIRDate` (represented as `str` in JSON). """

    amount: typing.Optional["Money"]

    """ Payable amount after adjustment.
    Type `Money` (represented as `dict` in JSON). """

    identifier: typing.Optional["Identifier"]

    """ Business identifier for the payment.
    Type `Identifier` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitProcessNote(BackboneElement):
    """ Note concerning adjudication.
    
    A note that describes or explains adjudication results in a human readable
    form.
    """
    
    # [<FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='language' >]
  

    number: typing.Optional[int]

    """ Note instance identifier.
    Type `int`. """

    type: typing.Optional["str"]

    """ display | print | printoper.
    Type `str`. """

    text: typing.Optional[str]

    """ Note explanatory text.
    Type `str`. """

    language: typing.Optional["CodeableConcept"]

    """ Language of the text.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitBenefitBalance(BackboneElement):
    """ Balance by Benefit Category.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='excluded' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='term' >, <FHIRClassProperty self.name='financial' >]
  

    category: "CodeableConcept"

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    excluded: typing.Optional[bool]

    """ Excluded from the plan.
    Type `bool`. """

    name: typing.Optional[str]

    """ Short name for the benefit.
    Type `str`. """

    description: typing.Optional[str]

    """ Description of the benefit or services covered.
    Type `str`. """

    network: typing.Optional["CodeableConcept"]

    """ In or out of network.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unit: typing.Optional["CodeableConcept"]

    """ Individual or family.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    term: typing.Optional["CodeableConcept"]

    """ Annual or lifetime.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    financial: typing.Optional[typing.List["ExplanationOfBenefitBenefitBalanceFinancial"]]

    """ Benefit Summary.
    List of `ExplanationOfBenefitBenefitBalanceFinancial` items (represented as `dict` in JSON). """




    

     
    



class ExplanationOfBenefitBenefitBalanceFinancial(BackboneElement):
    """ Benefit Summary.
    
    Benefits Used to date.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='allowedUnsignedInt' >, <FHIRClassProperty self.name='allowedString' >, <FHIRClassProperty self.name='allowedMoney' >, <FHIRClassProperty self.name='usedUnsignedInt' >, <FHIRClassProperty self.name='usedMoney' >]
  

    type: "CodeableConcept"

    """ Benefit classification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    allowedUnsignedInt: typing.Optional[int]

    """ Benefits allowed.
    Type `int`. """

    allowedString: typing.Optional[str]

    """ Benefits allowed.
    Type `str`. """

    allowedMoney: typing.Optional["Money"]

    """ Benefits allowed.
    Type `Money` (represented as `dict` in JSON). """

    usedUnsignedInt: typing.Optional[int]

    """ Benefits used.
    Type `int`. """

    usedMoney: typing.Optional["Money"]

    """ Benefits used.
    Type `Money` (represented as `dict` in JSON). """



#   {'path': 'ExplanationOfBenefit.benefitBalance.financial.allowed[x]', 'choice_of_type': 'allowed', 'orig_name': 'allowedUnsignedInt', 'name': 'allowedUnsignedInt', 'parent_name': 'ExplanationOfBenefit.benefitBalance.financial', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Benefits allowed', 'formal': 'The quantity of the benefit which is permitted under the coverage.', 'representation': None}

    _allowed_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['allowedUnsignedInt', 'allowedString', 'allowedMoney']), True))

#   {'path': 'ExplanationOfBenefit.benefitBalance.financial.used[x]', 'choice_of_type': 'used', 'orig_name': 'usedUnsignedInt', 'name': 'usedUnsignedInt', 'parent_name': 'ExplanationOfBenefit.benefitBalance.financial', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Benefits used', 'formal': 'The quantity of the benefit which have been consumed to date.', 'representation': None}

    _used_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['usedUnsignedInt', 'usedMoney']), True))


    

     
    



class FamilyMemberHistoryCondition(BackboneElement):
    """ Condition that the related person had.
    
    The significant Conditions (or condition) that the family member had. This
    is a repeating section to allow a system to represent more than one
    condition per resource, though there is nothing stopping multiple resources
    - one per condition.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='contributedToDeath' >, <FHIRClassProperty self.name='onsetAge' >, <FHIRClassProperty self.name='onsetRange' >, <FHIRClassProperty self.name='onsetPeriod' >, <FHIRClassProperty self.name='onsetString' >, <FHIRClassProperty self.name='note' >]
  

    code: "CodeableConcept"

    """ Condition suffered by relation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    outcome: typing.Optional["CodeableConcept"]

    """ deceased | permanent disability | etc..
    Type `CodeableConcept` (represented as `dict` in JSON). """

    contributedToDeath: typing.Optional[bool]

    """ Whether the condition contributed to the cause of death.
    Type `bool`. """

    onsetAge: typing.Optional["Age"]

    """ When condition first manifested.
    Type `Age` (represented as `dict` in JSON). """

    onsetRange: typing.Optional["Range"]

    """ When condition first manifested.
    Type `Range` (represented as `dict` in JSON). """

    onsetPeriod: typing.Optional["Period"]

    """ When condition first manifested.
    Type `Period` (represented as `dict` in JSON). """

    onsetString: typing.Optional[str]

    """ When condition first manifested.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Extra information about condition.
    List of `Annotation` items (represented as `dict` in JSON). """



#   {'path': 'FamilyMemberHistory.condition.onset[x]', 'choice_of_type': 'onset', 'orig_name': 'onsetAge', 'name': 'onsetAge', 'parent_name': 'FamilyMemberHistory.condition', 'class_name': 'Age', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When condition first manifested', 'formal': 'Either the age of onset, range of approximate age or descriptive string can be recorded.  For conditions with multiple occurrences, this describes the first known occurrence.', 'representation': None}

    _onset_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['onsetAge', 'onsetRange', 'onsetPeriod', 'onsetString']), True))


    

     
    



class GoalTarget(BackboneElement):
    """ Target outcome for the goal.
    
    Indicates what should be done by when.
    """
    
    # [<FHIRClassProperty self.name='measure' >, <FHIRClassProperty self.name='detailQuantity' >, <FHIRClassProperty self.name='detailRange' >, <FHIRClassProperty self.name='detailCodeableConcept' >, <FHIRClassProperty self.name='detailString' >, <FHIRClassProperty self.name='detailBoolean' >, <FHIRClassProperty self.name='detailInteger' >, <FHIRClassProperty self.name='detailRatio' >, <FHIRClassProperty self.name='dueDate' >, <FHIRClassProperty self.name='dueDuration' >]
  

    measure: typing.Optional["CodeableConcept"]

    """ The parameter whose value is being tracked.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    detailQuantity: typing.Optional["Quantity"]

    """ The target value to be achieved.
    Type `Quantity` (represented as `dict` in JSON). """

    detailRange: typing.Optional["Range"]

    """ The target value to be achieved.
    Type `Range` (represented as `dict` in JSON). """

    detailCodeableConcept: typing.Optional["CodeableConcept"]

    """ The target value to be achieved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    detailString: typing.Optional[str]

    """ The target value to be achieved.
    Type `str`. """

    detailBoolean: typing.Optional[bool]

    """ The target value to be achieved.
    Type `bool`. """

    detailInteger: typing.Optional[int]

    """ The target value to be achieved.
    Type `int`. """

    detailRatio: typing.Optional["Ratio"]

    """ The target value to be achieved.
    Type `Ratio` (represented as `dict` in JSON). """

    dueDate: typing.Optional["FHIRDate"]

    """ Reach goal on or before.
    Type `FHIRDate` (represented as `str` in JSON). """

    dueDuration: typing.Optional["Duration"]

    """ Reach goal on or before.
    Type `Duration` (represented as `dict` in JSON). """



#   {'path': 'Goal.target.detail[x]', 'choice_of_type': 'detail', 'orig_name': 'detailQuantity', 'name': 'detailQuantity', 'parent_name': 'Goal.target', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The target value to be achieved', 'formal': 'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.', 'representation': None}

    _detail_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['detailQuantity', 'detailRange', 'detailCodeableConcept', 'detailString', 'detailBoolean', 'detailInteger', 'detailRatio']), True))

#   {'path': 'Goal.target.due[x]', 'choice_of_type': 'due', 'orig_name': 'dueDate', 'name': 'dueDate', 'parent_name': 'Goal.target', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Reach goal on or before', 'formal': 'Indicates either the date or the duration after start by which the goal should be met.', 'representation': None}

    _due_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['dueDate', 'dueDuration']), True))


    

     
    



class GraphDefinitionLink(BackboneElement):
    """ Links this graph makes rules about.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='sliceName' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='target' >]
  

    path: typing.Optional[str]

    """ Path in the resource that contains the link.
    Type `str`. """

    sliceName: typing.Optional[str]

    """ Which slice (if profiled).
    Type `str`. """

    min: typing.Optional[int]

    """ Minimum occurrences for this link.
    Type `int`. """

    max: typing.Optional[str]

    """ Maximum occurrences for this link.
    Type `str`. """

    description: typing.Optional[str]

    """ Why this link is specified.
    Type `str`. """

    target: typing.Optional[typing.List["GraphDefinitionLinkTarget"]]

    """ Potential target for the link.
    List of `GraphDefinitionLinkTarget` items (represented as `dict` in JSON). """




    

     
    



class GraphDefinitionLinkTarget(BackboneElement):
    """ Potential target for the link.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='params' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='compartment' >, <FHIRClassProperty self.name='link' >]
  

    type: "str"

    """ Type of resource this link refers to.
    Type `str`. """

    params: typing.Optional[str]

    """ Criteria for reverse lookup.
    Type `str`. """

    profile: typing.Optional[str]

    """ Profile for the target resource.
    Type `str`. """

    compartment: typing.Optional[typing.List["GraphDefinitionLinkTargetCompartment"]]

    """ Compartment Consistency Rules.
    List of `GraphDefinitionLinkTargetCompartment` items (represented as `dict` in JSON). """

    link: typing.Optional[typing.List["GraphDefinitionLink"]]

    """ Additional links from target resource.
    List of `GraphDefinitionLink` items (represented as `dict` in JSON). """




    

     
    



class GraphDefinitionLinkTargetCompartment(BackboneElement):
    """ Compartment Consistency Rules.
    """
    
    # [<FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='rule' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='description' >]
  

    use: "str"

    """ condition | requirement.
    Type `str`. """

    code: "str"

    """ Patient | Encounter | RelatedPerson | Practitioner | Device.
    Type `str`. """

    rule: "str"

    """ identical | matching | different | custom.
    Type `str`. """

    expression: typing.Optional[str]

    """ Custom rule, as a FHIRPath expression.
    Type `str`. """

    description: typing.Optional[str]

    """ Documentation for FHIRPath expression.
    Type `str`. """




    

     
    



class GroupCharacteristic(BackboneElement):
    """ Include / Exclude group members by Trait.
    
    Identifies traits whose presence r absence is shared by members of the
    group.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='exclude' >, <FHIRClassProperty self.name='period' >]
  

    code: "CodeableConcept"

    """ Kind of characteristic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value held by characteristic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueBoolean: typing.Optional[bool]

    """ Value held by characteristic.
    Type `bool`. """

    valueQuantity: typing.Optional["Quantity"]

    """ Value held by characteristic.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value held by characteristic.
    Type `Range` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Value held by characteristic.
    Type `Reference` (represented as `dict` in JSON). """

    exclude: bool

    """ Group includes or excludes.
    Type `bool`. """

    period: typing.Optional["Period"]

    """ Period over which characteristic is tested.
    Type `Period` (represented as `dict` in JSON). """



#   {'path': 'Group.characteristic.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCodeableConcept', 'name': 'valueCodeableConcept', 'parent_name': 'Group.characteristic', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Value held by characteristic', 'formal': "The value of the trait that holds (or does not hold - see 'exclude') for members of the group.", 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCodeableConcept', 'valueBoolean', 'valueQuantity', 'valueRange', 'valueReference']), False))


    

     
    



class GroupMember(BackboneElement):
    """ Who or what is in group.
    
    Identifies the resource instances that are members of the group.
    """
    
    # [<FHIRClassProperty self.name='entity' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='inactive' >]
  

    entity: "Reference"

    """ Reference to the group member.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Period member belonged to the group.
    Type `Period` (represented as `dict` in JSON). """

    inactive: typing.Optional[bool]

    """ If member is no longer in group.
    Type `bool`. """




    

     
    



class HealthcareServiceEligibility(BackboneElement):
    """ Specific eligibility requirements required to use the service.
    
    Does this service have specific eligibility requirements that need to be
    met in order to use the service?
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='comment' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Coded value for the eligibility.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    comment: typing.Optional[str]

    """ Describes the eligibility conditions for the service.
    Type `str`. """




    

     
    



class HealthcareServiceAvailableTime(BackboneElement):
    """ Times the Service Site is available.
    
    A collection of times that the Service Site is available.
    """
    
    # [<FHIRClassProperty self.name='daysOfWeek' >, <FHIRClassProperty self.name='allDay' >, <FHIRClassProperty self.name='availableStartTime' >, <FHIRClassProperty self.name='availableEndTime' >]
  

    daysOfWeek: typing.Optional[typing.List["str"]]

    """ mon | tue | wed | thu | fri | sat | sun.
    List of `str` items. """

    allDay: typing.Optional[bool]

    """ Always available? e.g. 24 hour service.
    Type `bool`. """

    availableStartTime: typing.Optional["FHIRDate"]

    """ Opening time of day (ignored if allDay = true).
    Type `FHIRDate` (represented as `str` in JSON). """

    availableEndTime: typing.Optional["FHIRDate"]

    """ Closing time of day (ignored if allDay = true).
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class HealthcareServiceNotAvailable(BackboneElement):
    """ Not available during this time due to provided reason.
    
    The HealthcareService is not available during this period of time due to
    the provided reason.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='during' >]
  

    description: str

    """ Reason presented to the user explaining why time not available.
    Type `str`. """

    during: typing.Optional["Period"]

    """ Service not available from this date.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class ImagingStudySeries(BackboneElement):
    """ Each study has one or more series of instances.
    
    Each study has one or more series of images or other content.
    """
    
    # [<FHIRClassProperty self.name='uid' >, <FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='modality' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='numberOfInstances' >, <FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='laterality' >, <FHIRClassProperty self.name='specimen' >, <FHIRClassProperty self.name='started' >, <FHIRClassProperty self.name='performer' >, <FHIRClassProperty self.name='instance' >]
  

    uid: str

    """ DICOM Series Instance UID for the series.
    Type `str`. """

    number: typing.Optional[int]

    """ Numeric identifier of this series.
    Type `int`. """

    modality: "Coding"

    """ The modality of the instances in the series.
    Type `Coding` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ A short human readable summary of the series.
    Type `str`. """

    numberOfInstances: typing.Optional[int]

    """ Number of Series Related Instances.
    Type `int`. """

    endpoint: typing.Optional[typing.List["Reference"]]

    """ Series access endpoint.
    List of `Reference` items (represented as `dict` in JSON). """

    bodySite: typing.Optional["Coding"]

    """ Body part examined.
    Type `Coding` (represented as `dict` in JSON). """

    laterality: typing.Optional["Coding"]

    """ Body part laterality.
    Type `Coding` (represented as `dict` in JSON). """

    specimen: typing.Optional[typing.List["Reference"]]

    """ Specimen imaged.
    List of `Reference` items (represented as `dict` in JSON). """

    started: typing.Optional["FHIRDate"]

    """ When the series started.
    Type `FHIRDate` (represented as `str` in JSON). """

    performer: typing.Optional[typing.List["ImagingStudySeriesPerformer"]]

    """ Who performed the series.
    List of `ImagingStudySeriesPerformer` items (represented as `dict` in JSON). """

    instance: typing.Optional[typing.List["ImagingStudySeriesInstance"]]

    """ A single SOP instance from the series.
    List of `ImagingStudySeriesInstance` items (represented as `dict` in JSON). """




    

     
    



class ImagingStudySeriesPerformer(BackboneElement):
    """ Who performed the series.
    
    Indicates who or what performed the series and how they were involved.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >]
  

    function: typing.Optional["CodeableConcept"]

    """ Type of performance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Who performed the series.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ImagingStudySeriesInstance(BackboneElement):
    """ A single SOP instance from the series.
    
    A single SOP instance within the series, e.g. an image, or presentation
    state.
    """
    
    # [<FHIRClassProperty self.name='uid' >, <FHIRClassProperty self.name='sopClass' >, <FHIRClassProperty self.name='number' >, <FHIRClassProperty self.name='title' >]
  

    uid: str

    """ DICOM SOP Instance UID.
    Type `str`. """

    sopClass: "Coding"

    """ DICOM class type.
    Type `Coding` (represented as `dict` in JSON). """

    number: typing.Optional[int]

    """ The number of this instance in the series.
    Type `int`. """

    title: typing.Optional[str]

    """ Description of instance.
    Type `str`. """




    

     
    



class ImmunizationPerformer(BackboneElement):
    """ Who performed event.
    
    Indicates who performed the immunization event.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >]
  

    function: typing.Optional["CodeableConcept"]

    """ What type of performance was done.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Individual or organization who was performing.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ImmunizationEducation(BackboneElement):
    """ Educational material presented to patient.
    
    Educational material presented to the patient (or guardian) at the time of
    vaccine administration.
    """
    
    # [<FHIRClassProperty self.name='documentType' >, <FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='publicationDate' >, <FHIRClassProperty self.name='presentationDate' >]
  

    documentType: typing.Optional[str]

    """ Educational material document identifier.
    Type `str`. """

    reference: typing.Optional[str]

    """ Educational material reference pointer.
    Type `str`. """

    publicationDate: typing.Optional["FHIRDate"]

    """ Educational material publication date.
    Type `FHIRDate` (represented as `str` in JSON). """

    presentationDate: typing.Optional["FHIRDate"]

    """ Educational material presentation date.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class ImmunizationReaction(BackboneElement):
    """ Details of a reaction that follows immunization.
    
    Categorical data indicating that an adverse event is associated in time to
    an immunization.
    """
    
    # [<FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='detail' >, <FHIRClassProperty self.name='reported' >]
  

    date: typing.Optional["FHIRDate"]

    """ When reaction started.
    Type `FHIRDate` (represented as `str` in JSON). """

    detail: typing.Optional["Reference"]

    """ Additional information on reaction.
    Type `Reference` (represented as `dict` in JSON). """

    reported: typing.Optional[bool]

    """ Indicates self-reported reaction.
    Type `bool`. """




    

     
    



class ImmunizationProtocolApplied(BackboneElement):
    """ Protocol followed by the provider.
    
    The protocol (set of recommendations) being followed by the provider who
    administered the dose.
    """
    
    # [<FHIRClassProperty self.name='series' >, <FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='targetDisease' >, <FHIRClassProperty self.name='doseNumberPositiveInt' >, <FHIRClassProperty self.name='doseNumberString' >, <FHIRClassProperty self.name='seriesDosesPositiveInt' >, <FHIRClassProperty self.name='seriesDosesString' >]
  

    series: typing.Optional[str]

    """ Name of vaccine series.
    Type `str`. """

    authority: typing.Optional["Reference"]

    """ Who is responsible for publishing the recommendations.
    Type `Reference` (represented as `dict` in JSON). """

    targetDisease: typing.Optional[typing.List["CodeableConcept"]]

    """ Vaccine preventatable disease being targetted.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    doseNumberPositiveInt: typing.Optional[int]

    """ Dose number within series.
    Type `int`. """

    doseNumberString: typing.Optional[str]

    """ Dose number within series.
    Type `str`. """

    seriesDosesPositiveInt: typing.Optional[int]

    """ Recommended number of doses for immunity.
    Type `int`. """

    seriesDosesString: typing.Optional[str]

    """ Recommended number of doses for immunity.
    Type `str`. """



#   {'path': 'Immunization.protocolApplied.doseNumber[x]', 'choice_of_type': 'doseNumber', 'orig_name': 'doseNumberPositiveInt', 'name': 'doseNumberPositiveInt', 'parent_name': 'Immunization.protocolApplied', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Dose number within series', 'formal': 'Nominal position in a series.', 'representation': None}

    _doseNumber_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['doseNumberPositiveInt', 'doseNumberString']), False))

#   {'path': 'Immunization.protocolApplied.seriesDoses[x]', 'choice_of_type': 'seriesDoses', 'orig_name': 'seriesDosesPositiveInt', 'name': 'seriesDosesPositiveInt', 'parent_name': 'Immunization.protocolApplied', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Recommended number of doses for immunity', 'formal': 'The recommended number of doses to achieve immunity.', 'representation': None}

    _seriesDoses_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['seriesDosesPositiveInt', 'seriesDosesString']), True))


    

     
    



class ImmunizationRecommendationRecommendation(BackboneElement):
    """ Vaccine administration recommendations.
    """
    
    # [<FHIRClassProperty self.name='vaccineCode' >, <FHIRClassProperty self.name='targetDisease' >, <FHIRClassProperty self.name='contraindicatedVaccineCode' >, <FHIRClassProperty self.name='forecastStatus' >, <FHIRClassProperty self.name='forecastReason' >, <FHIRClassProperty self.name='dateCriterion' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='series' >, <FHIRClassProperty self.name='doseNumberPositiveInt' >, <FHIRClassProperty self.name='doseNumberString' >, <FHIRClassProperty self.name='seriesDosesPositiveInt' >, <FHIRClassProperty self.name='seriesDosesString' >, <FHIRClassProperty self.name='supportingImmunization' >, <FHIRClassProperty self.name='supportingPatientInformation' >]
  

    vaccineCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Vaccine  or vaccine group recommendation applies to.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    targetDisease: typing.Optional["CodeableConcept"]

    """ Disease to be immunized against.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    contraindicatedVaccineCode: typing.Optional[typing.List["CodeableConcept"]]

    """ Vaccine which is contraindicated to fulfill the recommendation.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    forecastStatus: "CodeableConcept"

    """ Vaccine recommendation status.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    forecastReason: typing.Optional[typing.List["CodeableConcept"]]

    """ Vaccine administration status reason.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    dateCriterion: typing.Optional[typing.List["ImmunizationRecommendationRecommendationDateCriterion"]]

    """ Dates governing proposed immunization.
    List of `ImmunizationRecommendationRecommendationDateCriterion` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Protocol details.
    Type `str`. """

    series: typing.Optional[str]

    """ Name of vaccination series.
    Type `str`. """

    doseNumberPositiveInt: typing.Optional[int]

    """ Recommended dose number within series.
    Type `int`. """

    doseNumberString: typing.Optional[str]

    """ Recommended dose number within series.
    Type `str`. """

    seriesDosesPositiveInt: typing.Optional[int]

    """ Recommended number of doses for immunity.
    Type `int`. """

    seriesDosesString: typing.Optional[str]

    """ Recommended number of doses for immunity.
    Type `str`. """

    supportingImmunization: typing.Optional[typing.List["Reference"]]

    """ Past immunizations supporting recommendation.
    List of `Reference` items (represented as `dict` in JSON). """

    supportingPatientInformation: typing.Optional[typing.List["Reference"]]

    """ Patient observations supporting recommendation.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'ImmunizationRecommendation.recommendation.doseNumber[x]', 'choice_of_type': 'doseNumber', 'orig_name': 'doseNumberPositiveInt', 'name': 'doseNumberPositiveInt', 'parent_name': 'ImmunizationRecommendation.recommendation', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Recommended dose number within series', 'formal': 'Nominal position of the recommended dose in a series (e.g. dose 2 is the next recommended dose).', 'representation': None}

    _doseNumber_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['doseNumberPositiveInt', 'doseNumberString']), True))

#   {'path': 'ImmunizationRecommendation.recommendation.seriesDoses[x]', 'choice_of_type': 'seriesDoses', 'orig_name': 'seriesDosesPositiveInt', 'name': 'seriesDosesPositiveInt', 'parent_name': 'ImmunizationRecommendation.recommendation', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Recommended number of doses for immunity', 'formal': 'The recommended number of doses to achieve immunity.', 'representation': None}

    _seriesDoses_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['seriesDosesPositiveInt', 'seriesDosesString']), True))


    

     
    



class ImmunizationRecommendationRecommendationDateCriterion(BackboneElement):
    """ Dates governing proposed immunization.
    
    Vaccine date recommendations.  For example, earliest date to administer,
    latest date to administer, etc.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='value' >]
  

    code: "CodeableConcept"

    """ Type of date.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: "FHIRDate"

    """ Recommended date.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class ImplementationGuideDependsOn(BackboneElement):
    """ Another Implementation guide this depends on.
    
    Another implementation guide that this implementation depends on.
    Typically, an implementation guide uses value sets, profiles etc.defined in
    other implementation guides.
    """
    
    # [<FHIRClassProperty self.name='uri' >, <FHIRClassProperty self.name='packageId' >, <FHIRClassProperty self.name='version' >]
  

    uri: str

    """ Identity of the IG that this depends on.
    Type `str`. """

    packageId: typing.Optional[str]

    """ NPM Package name for IG this depends on.
    Type `str`. """

    version: typing.Optional[str]

    """ Version of the IG.
    Type `str`. """




    

     
    



class ImplementationGuideGlobal(BackboneElement):
    """ Profiles that apply globally.
    
    A set of profiles that all resources covered by this implementation guide
    must conform to.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='profile' >]
  

    type: "str"

    """ Type this profile applies to.
    Type `str`. """

    profile: str

    """ Profile that all resources must conform to.
    Type `str`. """




    

     
    



class ImplementationGuideDefinition(BackboneElement):
    """ Information needed to build the IG.
    
    The information needed by an IG publisher tool to publish the whole
    implementation guide.
    """
    
    # [<FHIRClassProperty self.name='grouping' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='page' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='template' >]
  

    grouping: typing.Optional[typing.List["ImplementationGuideDefinitionGrouping"]]

    """ Grouping used to present related resources in the IG.
    List of `ImplementationGuideDefinitionGrouping` items (represented as `dict` in JSON). """

    resource: typing.List["ImplementationGuideDefinitionResource"]

    """ Resource in the implementation guide.
    List of `ImplementationGuideDefinitionResource` items (represented as `dict` in JSON). """

    page: typing.Optional["ImplementationGuideDefinitionPage"]

    """ Page/Section in the Guide.
    Type `ImplementationGuideDefinitionPage` (represented as `dict` in JSON). """

    parameter: typing.Optional[typing.List["ImplementationGuideDefinitionParameter"]]

    """ Defines how IG is built by tools.
    List of `ImplementationGuideDefinitionParameter` items (represented as `dict` in JSON). """

    template: typing.Optional[typing.List["ImplementationGuideDefinitionTemplate"]]

    """ A template for building resources.
    List of `ImplementationGuideDefinitionTemplate` items (represented as `dict` in JSON). """




    

     
    



class ImplementationGuideDefinitionGrouping(BackboneElement):
    """ Grouping used to present related resources in the IG.
    
    A logical group of resources. Logical groups can be used when building
    pages.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >]
  

    name: str

    """ Descriptive name for the package.
    Type `str`. """

    description: typing.Optional[str]

    """ Human readable text describing the package.
    Type `str`. """




    

     
    



class ImplementationGuideDefinitionResource(BackboneElement):
    """ Resource in the implementation guide.
    
    A resource that is part of the implementation guide. Conformance resources
    (value set, structure definition, capability statements etc.) are obvious
    candidates for inclusion, but any kind of resource can be included as an
    example resource.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='fhirVersion' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='exampleBoolean' >, <FHIRClassProperty self.name='exampleCanonical' >, <FHIRClassProperty self.name='groupingId' >]
  

    reference: "Reference"

    """ Location of the resource.
    Type `Reference` (represented as `dict` in JSON). """

    fhirVersion: typing.Optional[typing.List[str]]

    """ Versions this applies to (if different to IG).
    List of `str` items. """

    name: typing.Optional[str]

    """ Human Name for the resource.
    Type `str`. """

    description: typing.Optional[str]

    """ Reason why included in guide.
    Type `str`. """

    exampleBoolean: typing.Optional[bool]

    """ Is an example/What is this an example of?.
    Type `bool`. """

    exampleCanonical: typing.Optional[str]

    """ Is an example/What is this an example of?.
    Type `str`. """

    groupingId: typing.Optional[str]

    """ Grouping this is part of.
    Type `str`. """



#   {'path': 'ImplementationGuide.definition.resource.example[x]', 'choice_of_type': 'example', 'orig_name': 'exampleBoolean', 'name': 'exampleBoolean', 'parent_name': 'ImplementationGuide.definition.resource', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Is an example/What is this an example of?', 'formal': 'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.', 'representation': None}

    _example_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['exampleBoolean', 'exampleCanonical']), True))


    

     
    



class ImplementationGuideDefinitionPage(BackboneElement):
    """ Page/Section in the Guide.
    
    A page / section in the implementation guide. The root page is the
    implementation guide home page.
    """
    
    # [<FHIRClassProperty self.name='nameUrl' >, <FHIRClassProperty self.name='nameReference' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='generation' >, <FHIRClassProperty self.name='page' >]
  

    nameUrl: typing.Optional[str]

    """ Where to find that page.
    Type `str`. """

    nameReference: typing.Optional["Reference"]

    """ Where to find that page.
    Type `Reference` (represented as `dict` in JSON). """

    title: str

    """ Short title shown for navigational assistance.
    Type `str`. """

    generation: "str"

    """ html | markdown | xml | generated.
    Type `str`. """

    page: typing.Optional[typing.List["ImplementationGuideDefinitionPage"]]

    """ Nested Pages / Sections.
    List of `ImplementationGuideDefinitionPage` items (represented as `dict` in JSON). """



#   {'path': 'ImplementationGuide.definition.page.name[x]', 'choice_of_type': 'name', 'orig_name': 'nameUrl', 'name': 'nameUrl', 'parent_name': 'ImplementationGuide.definition.page', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Where to find that page', 'formal': 'The source address for the page.', 'representation': None}

    _name_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['nameUrl', 'nameReference']), False))


    

     
    



class ImplementationGuideDefinitionParameter(BackboneElement):
    """ Defines how IG is built by tools.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='value' >]
  

    code: "str"

    """ apply | path-resource | path-pages | path-tx-cache | expansion-
        parameter | rule-broken-links | generate-xml | generate-json |
        generate-turtle | html-template.
    Type `str`. """

    value: str

    """ Value for named type.
    Type `str`. """




    

     
    



class ImplementationGuideDefinitionTemplate(BackboneElement):
    """ A template for building resources.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='scope' >]
  

    code: str

    """ Type of template specified.
    Type `str`. """

    source: str

    """ The source location for the template.
    Type `str`. """

    scope: typing.Optional[str]

    """ The scope in which the template applies.
    Type `str`. """




    

     
    



class ImplementationGuideManifest(BackboneElement):
    """ Information about an assembled IG.
    
    Information about an assembled implementation guide, created by the
    publication tooling.
    """
    
    # [<FHIRClassProperty self.name='rendering' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='page' >, <FHIRClassProperty self.name='image' >, <FHIRClassProperty self.name='other' >]
  

    rendering: typing.Optional[str]

    """ Location of rendered implementation guide.
    Type `str`. """

    resource: typing.List["ImplementationGuideManifestResource"]

    """ Resource in the implementation guide.
    List of `ImplementationGuideManifestResource` items (represented as `dict` in JSON). """

    page: typing.Optional[typing.List["ImplementationGuideManifestPage"]]

    """ HTML page within the parent IG.
    List of `ImplementationGuideManifestPage` items (represented as `dict` in JSON). """

    image: typing.Optional[typing.List[str]]

    """ Image within the IG.
    List of `str` items. """

    other: typing.Optional[typing.List[str]]

    """ Additional linkable file in IG.
    List of `str` items. """




    

     
    



class ImplementationGuideManifestResource(BackboneElement):
    """ Resource in the implementation guide.
    
    A resource that is part of the implementation guide. Conformance resources
    (value set, structure definition, capability statements etc.) are obvious
    candidates for inclusion, but any kind of resource can be included as an
    example resource.
    """
    
    # [<FHIRClassProperty self.name='reference' >, <FHIRClassProperty self.name='exampleBoolean' >, <FHIRClassProperty self.name='exampleCanonical' >, <FHIRClassProperty self.name='relativePath' >]
  

    reference: "Reference"

    """ Location of the resource.
    Type `Reference` (represented as `dict` in JSON). """

    exampleBoolean: typing.Optional[bool]

    """ Is an example/What is this an example of?.
    Type `bool`. """

    exampleCanonical: typing.Optional[str]

    """ Is an example/What is this an example of?.
    Type `str`. """

    relativePath: typing.Optional[str]

    """ Relative path for page in IG.
    Type `str`. """



#   {'path': 'ImplementationGuide.manifest.resource.example[x]', 'choice_of_type': 'example', 'orig_name': 'exampleBoolean', 'name': 'exampleBoolean', 'parent_name': 'ImplementationGuide.manifest.resource', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Is an example/What is this an example of?', 'formal': 'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.', 'representation': None}

    _example_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['exampleBoolean', 'exampleCanonical']), True))


    

     
    



class ImplementationGuideManifestPage(BackboneElement):
    """ HTML page within the parent IG.
    
    Information about a page within the IG.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='anchor' >]
  

    name: str

    """ HTML page name.
    Type `str`. """

    title: typing.Optional[str]

    """ Title of the page, for references.
    Type `str`. """

    anchor: typing.Optional[typing.List[str]]

    """ Anchor available on the page.
    List of `str` items. """




    

     
    



class InsurancePlanContact(BackboneElement):
    """ Contact for the product.
    
    The contact for the health insurance product for a certain purpose.
    """
    
    # [<FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >]
  

    purpose: typing.Optional["CodeableConcept"]

    """ The type of contact.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    name: typing.Optional["HumanName"]

    """ A name associated with the contact.
    Type `HumanName` (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details (telephone, email, etc.)  for a contact.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional["Address"]

    """ Visiting or postal addresses for the contact.
    Type `Address` (represented as `dict` in JSON). """




    

     
    



class InsurancePlanCoverage(BackboneElement):
    """ Coverage details.
    
    Details about the coverage offered by the insurance product.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='benefit' >]
  

    type: "CodeableConcept"

    """ Type of coverage.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    network: typing.Optional[typing.List["Reference"]]

    """ What networks provide coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    benefit: typing.List["InsurancePlanCoverageBenefit"]

    """ List of benefits.
    List of `InsurancePlanCoverageBenefit` items (represented as `dict` in JSON). """




    

     
    



class InsurancePlanCoverageBenefit(BackboneElement):
    """ List of benefits.
    
    Specific benefits under this type of coverage.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='requirement' >, <FHIRClassProperty self.name='limit' >]
  

    type: "CodeableConcept"

    """ Type of benefit.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    requirement: typing.Optional[str]

    """ Referral requirements.
    Type `str`. """

    limit: typing.Optional[typing.List["InsurancePlanCoverageBenefitLimit"]]

    """ Benefit limits.
    List of `InsurancePlanCoverageBenefitLimit` items (represented as `dict` in JSON). """




    

     
    



class InsurancePlanCoverageBenefitLimit(BackboneElement):
    """ Benefit limits.
    
    The specific limits on the benefit.
    """
    
    # [<FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='code' >]
  

    value: typing.Optional["Quantity"]

    """ Maximum value allowed.
    Type `Quantity` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Benefit limit details.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class InsurancePlanPlan(BackboneElement):
    """ Plan details.
    
    Details about an insurance plan.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='coverageArea' >, <FHIRClassProperty self.name='network' >, <FHIRClassProperty self.name='generalCost' >, <FHIRClassProperty self.name='specificCost' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Business Identifier for Product.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Type of plan.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    coverageArea: typing.Optional[typing.List["Reference"]]

    """ Where product applies.
    List of `Reference` items (represented as `dict` in JSON). """

    network: typing.Optional[typing.List["Reference"]]

    """ What networks provide coverage.
    List of `Reference` items (represented as `dict` in JSON). """

    generalCost: typing.Optional[typing.List["InsurancePlanPlanGeneralCost"]]

    """ Overall costs.
    List of `InsurancePlanPlanGeneralCost` items (represented as `dict` in JSON). """

    specificCost: typing.Optional[typing.List["InsurancePlanPlanSpecificCost"]]

    """ Specific costs.
    List of `InsurancePlanPlanSpecificCost` items (represented as `dict` in JSON). """




    

     
    



class InsurancePlanPlanGeneralCost(BackboneElement):
    """ Overall costs.
    
    Overall costs associated with the plan.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='groupSize' >, <FHIRClassProperty self.name='cost' >, <FHIRClassProperty self.name='comment' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of cost.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    groupSize: typing.Optional[int]

    """ Number of enrollees.
    Type `int`. """

    cost: typing.Optional["Money"]

    """ Cost value.
    Type `Money` (represented as `dict` in JSON). """

    comment: typing.Optional[str]

    """ Additional cost information.
    Type `str`. """




    

     
    



class InsurancePlanPlanSpecificCost(BackboneElement):
    """ Specific costs.
    
    Costs associated with the coverage provided by the product.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='benefit' >]
  

    category: "CodeableConcept"

    """ General category of benefit.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    benefit: typing.Optional[typing.List["InsurancePlanPlanSpecificCostBenefit"]]

    """ Benefits list.
    List of `InsurancePlanPlanSpecificCostBenefit` items (represented as `dict` in JSON). """




    

     
    



class InsurancePlanPlanSpecificCostBenefit(BackboneElement):
    """ Benefits list.
    
    List of the specific benefits under this category of benefit.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='cost' >]
  

    type: "CodeableConcept"

    """ Type of specific benefit.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    cost: typing.Optional[typing.List["InsurancePlanPlanSpecificCostBenefitCost"]]

    """ List of the costs.
    List of `InsurancePlanPlanSpecificCostBenefitCost` items (represented as `dict` in JSON). """




    

     
    



class InsurancePlanPlanSpecificCostBenefitCost(BackboneElement):
    """ List of the costs.
    
    List of the costs associated with a specific benefit.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='applicability' >, <FHIRClassProperty self.name='qualifiers' >, <FHIRClassProperty self.name='value' >]
  

    type: "CodeableConcept"

    """ Type of cost.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    applicability: typing.Optional["CodeableConcept"]

    """ in-network | out-of-network | other.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    qualifiers: typing.Optional[typing.List["CodeableConcept"]]

    """ Additional information about the cost.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    value: typing.Optional["Quantity"]

    """ The actual cost value.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class InvoiceParticipant(BackboneElement):
    """ Participant in creation of this Invoice.
    
    Indicates who or what performed or participated in the charged service.
    """
    
    # [<FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='actor' >]
  

    role: typing.Optional["CodeableConcept"]

    """ Type of involvement in creation of this Invoice.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Individual who was involved.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class InvoiceLineItem(BackboneElement):
    """ Line items of this Invoice.
    
    Each line item represents one charge for goods and services rendered.
    Details such as date, code and amount are found in the referenced
    ChargeItem resource.
    """
    
    # [<FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='chargeItemReference' >, <FHIRClassProperty self.name='chargeItemCodeableConcept' >, <FHIRClassProperty self.name='priceComponent' >]
  

    sequence: typing.Optional[int]

    """ Sequence number of line item.
    Type `int`. """

    chargeItemReference: typing.Optional["Reference"]

    """ Reference to ChargeItem containing details of this line item or an
        inline billing code.
    Type `Reference` (represented as `dict` in JSON). """

    chargeItemCodeableConcept: typing.Optional["CodeableConcept"]

    """ Reference to ChargeItem containing details of this line item or an
        inline billing code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    priceComponent: typing.Optional[typing.List["InvoiceLineItemPriceComponent"]]

    """ Components of total line item price.
    List of `InvoiceLineItemPriceComponent` items (represented as `dict` in JSON). """



#   {'path': 'Invoice.lineItem.chargeItem[x]', 'choice_of_type': 'chargeItem', 'orig_name': 'chargeItemReference', 'name': 'chargeItemReference', 'parent_name': 'Invoice.lineItem', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': False, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Reference to ChargeItem containing details of this line item or an inline billing code', 'formal': 'The ChargeItem contains information such as the billing code, date, amount etc. If no further details are required for the lineItem, inline billing codes can be added using the CodeableConcept data type instead of the Reference.', 'representation': None}

    _chargeItem_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['chargeItemReference', 'chargeItemCodeableConcept']), False))


    

     
    



class InvoiceLineItemPriceComponent(BackboneElement):
    """ Components of total line item price.
    
    The price for a ChargeItem may be calculated as a base price with
    surcharges/deductions that apply in certain conditions. A
    ChargeItemDefinition resource that defines the prices, factors and
    conditions that apply to a billing code is currently under development. The
    priceComponent element can be used to offer transparency to the recipient
    of the Invoice as to how the prices have been calculated.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='factor' >, <FHIRClassProperty self.name='amount' >]
  

    type: "str"

    """ base | surcharge | deduction | discount | tax | informational.
    Type `str`. """

    code: typing.Optional["CodeableConcept"]

    """ Code identifying the specific component.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    factor: typing.Optional[float]

    """ Factor used for calculating this component.
    Type `float`. """

    amount: typing.Optional["Money"]

    """ Monetary amount associated with this component.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class LinkageItem(BackboneElement):
    """ Item to be linked.
    
    Identifies which record considered as the reference to the same real-world
    occurrence as well as how the items should be evaluated within the
    collection of linked items.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='resource' >]
  

    type: "str"

    """ source | alternate | historical.
    Type `str`. """

    resource: "Reference"

    """ Resource being linked.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ListEntry(BackboneElement):
    """ Entries in the list.
    
    Entries in this list.
    """
    
    # [<FHIRClassProperty self.name='flag' >, <FHIRClassProperty self.name='deleted' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='item' >]
  

    flag: typing.Optional["CodeableConcept"]

    """ Status/Workflow information about this item.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    deleted: typing.Optional[bool]

    """ If this item is actually marked as deleted.
    Type `bool`. """

    date: typing.Optional["FHIRDate"]

    """ When item added to list.
    Type `FHIRDate` (represented as `str` in JSON). """

    item: "Reference"

    """ Actual entry.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class LocationPosition(BackboneElement):
    """ The absolute geographic location.
    
    The absolute geographic location of the Location, expressed using the WGS84
    datum (This is the same co-ordinate system used in KML).
    """
    
    # [<FHIRClassProperty self.name='longitude' >, <FHIRClassProperty self.name='latitude' >, <FHIRClassProperty self.name='altitude' >]
  

    longitude: float

    """ Longitude with WGS84 datum.
    Type `float`. """

    latitude: float

    """ Latitude with WGS84 datum.
    Type `float`. """

    altitude: typing.Optional[float]

    """ Altitude with WGS84 datum.
    Type `float`. """




    

     
    



class LocationHoursOfOperation(BackboneElement):
    """ What days/times during a week is this location usually open.
    """
    
    # [<FHIRClassProperty self.name='daysOfWeek' >, <FHIRClassProperty self.name='allDay' >, <FHIRClassProperty self.name='openingTime' >, <FHIRClassProperty self.name='closingTime' >]
  

    daysOfWeek: typing.Optional[typing.List["str"]]

    """ mon | tue | wed | thu | fri | sat | sun.
    List of `str` items. """

    allDay: typing.Optional[bool]

    """ The Location is open all day.
    Type `bool`. """

    openingTime: typing.Optional["FHIRDate"]

    """ Time that the Location opens.
    Type `FHIRDate` (represented as `str` in JSON). """

    closingTime: typing.Optional["FHIRDate"]

    """ Time that the Location closes.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class MeasureGroup(BackboneElement):
    """ Population criteria group.
    
    A group of population criteria for the measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='stratifier' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Meaning of the group.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Summary description.
    Type `str`. """

    population: typing.Optional[typing.List["MeasureGroupPopulation"]]

    """ Population criteria.
    List of `MeasureGroupPopulation` items (represented as `dict` in JSON). """

    stratifier: typing.Optional[typing.List["MeasureGroupStratifier"]]

    """ Stratifier criteria for the measure.
    List of `MeasureGroupStratifier` items (represented as `dict` in JSON). """




    

     
    



class MeasureGroupPopulation(BackboneElement):
    """ Population criteria.
    
    A population criteria for the measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='criteria' >]
  

    code: typing.Optional["CodeableConcept"]

    """ initial-population | numerator | numerator-exclusion | denominator
        | denominator-exclusion | denominator-exception | measure-
        population | measure-population-exclusion | measure-observation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ The human readable description of this population criteria.
    Type `str`. """

    criteria: "Expression"

    """ The criteria that defines this population.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class MeasureGroupStratifier(BackboneElement):
    """ Stratifier criteria for the measure.
    
    The stratifier criteria for the measure report, specified as either the
    name of a valid CQL expression defined within a referenced library or a
    valid FHIR Resource Path.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='criteria' >, <FHIRClassProperty self.name='component' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Meaning of the stratifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ The human readable description of this stratifier.
    Type `str`. """

    criteria: typing.Optional["Expression"]

    """ How the measure should be stratified.
    Type `Expression` (represented as `dict` in JSON). """

    component: typing.Optional[typing.List["MeasureGroupStratifierComponent"]]

    """ Stratifier criteria component for the measure.
    List of `MeasureGroupStratifierComponent` items (represented as `dict` in JSON). """




    

     
    



class MeasureGroupStratifierComponent(BackboneElement):
    """ Stratifier criteria component for the measure.
    
    A component of the stratifier criteria for the measure report, specified as
    either the name of a valid CQL expression defined within a referenced
    library or a valid FHIR Resource Path.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='criteria' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Meaning of the stratifier component.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ The human readable description of this stratifier component.
    Type `str`. """

    criteria: "Expression"

    """ Component of how the measure should be stratified.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class MeasureSupplementalData(BackboneElement):
    """ What other data should be reported with the measure.
    
    The supplemental data criteria for the measure report, specified as either
    the name of a valid CQL expression within a referenced library, or a valid
    FHIR Resource Path.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='usage' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='criteria' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Meaning of the supplemental data.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    usage: typing.Optional[typing.List["CodeableConcept"]]

    """ supplemental-data | risk-adjustment-factor.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ The human readable description of this supplemental data.
    Type `str`. """

    criteria: "Expression"

    """ Expression describing additional data to be reported.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroup(BackboneElement):
    """ Measure results for each group.
    
    The results of the calculation, one for each population group in the
    measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='measureScore' >, <FHIRClassProperty self.name='stratifier' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Meaning of the group.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    population: typing.Optional[typing.List["MeasureReportGroupPopulation"]]

    """ The populations in the group.
    List of `MeasureReportGroupPopulation` items (represented as `dict` in JSON). """

    measureScore: typing.Optional["Quantity"]

    """ What score this group achieved.
    Type `Quantity` (represented as `dict` in JSON). """

    stratifier: typing.Optional[typing.List["MeasureReportGroupStratifier"]]

    """ Stratification results.
    List of `MeasureReportGroupStratifier` items (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroupPopulation(BackboneElement):
    """ The populations in the group.
    
    The populations that make up the population group, one for each type of
    population appropriate for the measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='count' >, <FHIRClassProperty self.name='subjectResults' >]
  

    code: typing.Optional["CodeableConcept"]

    """ initial-population | numerator | numerator-exclusion | denominator
        | denominator-exclusion | denominator-exception | measure-
        population | measure-population-exclusion | measure-observation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    count: typing.Optional[int]

    """ Size of the population.
    Type `int`. """

    subjectResults: typing.Optional["Reference"]

    """ For subject-list reports, the subject results in this population.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroupStratifier(BackboneElement):
    """ Stratification results.
    
    When a measure includes multiple stratifiers, there will be a stratifier
    group for each stratifier defined by the measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='stratum' >]
  

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ What stratifier of the group.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    stratum: typing.Optional[typing.List["MeasureReportGroupStratifierStratum"]]

    """ Stratum results, one for each unique value, or set of values, in
        the stratifier, or stratifier components.
    List of `MeasureReportGroupStratifierStratum` items (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroupStratifierStratum(BackboneElement):
    """ Stratum results, one for each unique value, or set of values, in the
    stratifier, or stratifier components.
    
    This element contains the results for a single stratum within the
    stratifier. For example, when stratifying on administrative gender, there
    will be four strata, one for each possible gender value.
    """
    
    # [<FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='component' >, <FHIRClassProperty self.name='population' >, <FHIRClassProperty self.name='measureScore' >]
  

    value: typing.Optional["CodeableConcept"]

    """ The stratum value, e.g. male.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    component: typing.Optional[typing.List["MeasureReportGroupStratifierStratumComponent"]]

    """ Stratifier component values.
    List of `MeasureReportGroupStratifierStratumComponent` items (represented as `dict` in JSON). """

    population: typing.Optional[typing.List["MeasureReportGroupStratifierStratumPopulation"]]

    """ Population results in this stratum.
    List of `MeasureReportGroupStratifierStratumPopulation` items (represented as `dict` in JSON). """

    measureScore: typing.Optional["Quantity"]

    """ What score this stratum achieved.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroupStratifierStratumComponent(BackboneElement):
    """ Stratifier component values.
    
    A stratifier component value.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='value' >]
  

    code: "CodeableConcept"

    """ What stratifier component of the group.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: "CodeableConcept"

    """ The stratum component value, e.g. male.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class MeasureReportGroupStratifierStratumPopulation(BackboneElement):
    """ Population results in this stratum.
    
    The populations that make up the stratum, one for each type of population
    appropriate to the measure.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='count' >, <FHIRClassProperty self.name='subjectResults' >]
  

    code: typing.Optional["CodeableConcept"]

    """ initial-population | numerator | numerator-exclusion | denominator
        | denominator-exclusion | denominator-exception | measure-
        population | measure-population-exclusion | measure-observation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    count: typing.Optional[int]

    """ Size of the population.
    Type `int`. """

    subjectResults: typing.Optional["Reference"]

    """ For subject-list reports, the subject results in this population.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicationIngredient(BackboneElement):
    """ Active or inactive ingredient.
    
    Identifies a particular constituent of interest in the product.
    """
    
    # [<FHIRClassProperty self.name='itemCodeableConcept' >, <FHIRClassProperty self.name='itemReference' >, <FHIRClassProperty self.name='isActive' >, <FHIRClassProperty self.name='strength' >]
  

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ The actual ingredient or content.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    itemReference: typing.Optional["Reference"]

    """ The actual ingredient or content.
    Type `Reference` (represented as `dict` in JSON). """

    isActive: typing.Optional[bool]

    """ Active ingredient indicator.
    Type `bool`. """

    strength: typing.Optional["Ratio"]

    """ Quantity of ingredient present.
    Type `Ratio` (represented as `dict` in JSON). """



#   {'path': 'Medication.ingredient.item[x]', 'choice_of_type': 'item', 'orig_name': 'itemCodeableConcept', 'name': 'itemCodeableConcept', 'parent_name': 'Medication.ingredient', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'The actual ingredient or content', 'formal': 'The actual ingredient - either a substance (simple ingredient) or another medication of a medication.', 'representation': None}

    _item_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['itemCodeableConcept', 'itemReference']), False))


    

     
    



class MedicationBatch(BackboneElement):
    """ Details about packaged medications.
    
    Information that only applies to packages (not products).
    """
    
    # [<FHIRClassProperty self.name='lotNumber' >, <FHIRClassProperty self.name='expirationDate' >]
  

    lotNumber: typing.Optional[str]

    """ Identifier assigned to batch.
    Type `str`. """

    expirationDate: typing.Optional["FHIRDate"]

    """ When batch will expire.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class MedicationAdministrationPerformer(BackboneElement):
    """ Who performed the medication administration and what they did.
    
    Indicates who or what performed the medication administration and how they
    were involved.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >]
  

    function: typing.Optional["CodeableConcept"]

    """ Type of performance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Who performed the medication administration.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicationAdministrationDosage(BackboneElement):
    """ Details of how medication was taken.
    
    Describes the medication dosage information details e.g. dose, rate, site,
    route, etc.
    """
    
    # [<FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='site' >, <FHIRClassProperty self.name='route' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='dose' >, <FHIRClassProperty self.name='rateRatio' >, <FHIRClassProperty self.name='rateQuantity' >]
  

    text: typing.Optional[str]

    """ Free text dosage instructions e.g. SIG.
    Type `str`. """

    site: typing.Optional["CodeableConcept"]

    """ Body site administered to.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    route: typing.Optional["CodeableConcept"]

    """ Path of substance into body.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ How drug was administered.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    dose: typing.Optional["Quantity"]

    """ Amount of medication per dose.
    Type `Quantity` (represented as `dict` in JSON). """

    rateRatio: typing.Optional["Ratio"]

    """ Dose quantity per unit of time.
    Type `Ratio` (represented as `dict` in JSON). """

    rateQuantity: typing.Optional["Quantity"]

    """ Dose quantity per unit of time.
    Type `Quantity` (represented as `dict` in JSON). """



#   {'path': 'MedicationAdministration.dosage.rate[x]', 'choice_of_type': 'rate', 'orig_name': 'rateRatio', 'name': 'rateRatio', 'parent_name': 'MedicationAdministration.dosage', 'class_name': 'Ratio', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Dose quantity per unit of time', 'formal': 'Identifies the speed with which the medication was or will be introduced into the patient.  Typically, the rate for an infusion e.g. 100 ml per 1 hour or 100 ml/hr.  May also be expressed as a rate per unit of time, e.g. 500 ml per 2 hours.  Other examples:  200 mcg/min or 200 mcg/1 minute; 1 liter/8 hours.', 'representation': None}

    _rate_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['rateRatio', 'rateQuantity']), True))


    

     
    



class MedicationDispensePerformer(BackboneElement):
    """ Who performed event.
    
    Indicates who or what performed the event.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >]
  

    function: typing.Optional["CodeableConcept"]

    """ Who performed the dispense and what they did.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ Individual who was performing.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicationDispenseSubstitution(BackboneElement):
    """ Whether a substitution was performed on the dispense.
    
    Indicates whether or not substitution was made as part of the dispense.  In
    some cases, substitution will be expected but does not happen, in other
    cases substitution is not expected but does happen.  This block explains
    what substitution did or did not happen and why.  If nothing is specified,
    substitution was not done.
    """
    
    # [<FHIRClassProperty self.name='wasSubstituted' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='responsibleParty' >]
  

    wasSubstituted: bool

    """ Whether a substitution was or was not performed on the dispense.
    Type `bool`. """

    type: typing.Optional["CodeableConcept"]

    """ Code signifying whether a different drug was dispensed from what
        was prescribed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reason: typing.Optional[typing.List["CodeableConcept"]]

    """ Why was substitution made.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    responsibleParty: typing.Optional[typing.List["Reference"]]

    """ Who is responsible for the substitution.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeRelatedMedicationKnowledge(BackboneElement):
    """ Associated or related medication information.
    
    Associated or related knowledge about a medication.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='reference' >]
  

    type: "CodeableConcept"

    """ Category of medicationKnowledge.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reference: typing.List["Reference"]

    """ Associated documentation about the associated medication knowledge.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeMonograph(BackboneElement):
    """ Associated documentation about the medication.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='source' >]
  

    type: typing.Optional["CodeableConcept"]

    """ The category of medication document.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional["Reference"]

    """ Associated documentation about the medication.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeIngredient(BackboneElement):
    """ Active or inactive ingredient.
    
    Identifies a particular constituent of interest in the product.
    """
    
    # [<FHIRClassProperty self.name='itemCodeableConcept' >, <FHIRClassProperty self.name='itemReference' >, <FHIRClassProperty self.name='isActive' >, <FHIRClassProperty self.name='strength' >]
  

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ Medication(s) or substance(s) contained in the medication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    itemReference: typing.Optional["Reference"]

    """ Medication(s) or substance(s) contained in the medication.
    Type `Reference` (represented as `dict` in JSON). """

    isActive: typing.Optional[bool]

    """ Active ingredient indicator.
    Type `bool`. """

    strength: typing.Optional["Ratio"]

    """ Quantity of ingredient present.
    Type `Ratio` (represented as `dict` in JSON). """



#   {'path': 'MedicationKnowledge.ingredient.item[x]', 'choice_of_type': 'item', 'orig_name': 'itemCodeableConcept', 'name': 'itemCodeableConcept', 'parent_name': 'MedicationKnowledge.ingredient', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Medication(s) or substance(s) contained in the medication', 'formal': 'The actual ingredient - either a substance (simple ingredient) or another medication.', 'representation': None}

    _item_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['itemCodeableConcept', 'itemReference']), False))


    

     
    



class MedicationKnowledgeCost(BackboneElement):
    """ The pricing of the medication.
    
    The price of the medication.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='cost' >]
  

    type: "CodeableConcept"

    """ The category of the cost information.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional[str]

    """ The source or owner for the price information.
    Type `str`. """

    cost: "Money"

    """ The price of the medication.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeMonitoringProgram(BackboneElement):
    """ Program under which a medication is reviewed.
    
    The program under which the medication is reviewed.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='name' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of program under which the medication is monitored.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Name of the reviewing program.
    Type `str`. """




    

     
    



class MedicationKnowledgeAdministrationGuidelines(BackboneElement):
    """ Guidelines for administration of the medication.
    
    Guidelines for the administration of the medication.
    """
    
    # [<FHIRClassProperty self.name='dosage' >, <FHIRClassProperty self.name='indicationCodeableConcept' >, <FHIRClassProperty self.name='indicationReference' >, <FHIRClassProperty self.name='patientCharacteristics' >]
  

    dosage: typing.Optional[typing.List["MedicationKnowledgeAdministrationGuidelinesDosage"]]

    """ Dosage for the medication for the specific guidelines.
    List of `MedicationKnowledgeAdministrationGuidelinesDosage` items (represented as `dict` in JSON). """

    indicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Indication for use that apply to the specific administration
        guidelines.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    indicationReference: typing.Optional["Reference"]

    """ Indication for use that apply to the specific administration
        guidelines.
    Type `Reference` (represented as `dict` in JSON). """

    patientCharacteristics: typing.Optional[typing.List["MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics"]]

    """ Characteristics of the patient that are relevant to the
        administration guidelines.
    List of `MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics` items (represented as `dict` in JSON). """



#   {'path': 'MedicationKnowledge.administrationGuidelines.indication[x]', 'choice_of_type': 'indication', 'orig_name': 'indicationCodeableConcept', 'name': 'indicationCodeableConcept', 'parent_name': 'MedicationKnowledge.administrationGuidelines', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Indication for use that apply to the specific administration guidelines', 'formal': None, 'representation': None}

    _indication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['indicationCodeableConcept', 'indicationReference']), True))


    

     
    



class MedicationKnowledgeAdministrationGuidelinesDosage(BackboneElement):
    """ Dosage for the medication for the specific guidelines.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='dosage' >]
  

    type: "CodeableConcept"

    """ Type of dosage.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    dosage: typing.List["Dosage"]

    """ Dosage for the medication for the specific guidelines.
    List of `Dosage` items (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics(BackboneElement):
    """ Characteristics of the patient that are relevant to the administration
    guidelines.
    
    Characteristics of the patient that are relevant to the administration
    guidelines (for example, height, weight, gender, etc.).
    """
    
    # [<FHIRClassProperty self.name='characteristicCodeableConcept' >, <FHIRClassProperty self.name='characteristicQuantity' >, <FHIRClassProperty self.name='value' >]
  

    characteristicCodeableConcept: typing.Optional["CodeableConcept"]

    """ Specific characteristic that is relevant to the administration
        guideline.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    characteristicQuantity: typing.Optional["Quantity"]

    """ Specific characteristic that is relevant to the administration
        guideline.
    Type `Quantity` (represented as `dict` in JSON). """

    value: typing.Optional[typing.List[str]]

    """ The specific characteristic.
    List of `str` items. """



#   {'path': 'MedicationKnowledge.administrationGuidelines.patientCharacteristics.characteristic[x]', 'choice_of_type': 'characteristic', 'orig_name': 'characteristicCodeableConcept', 'name': 'characteristicCodeableConcept', 'parent_name': 'MedicationKnowledge.administrationGuidelines.patientCharacteristics', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Specific characteristic that is relevant to the administration guideline', 'formal': 'Specific characteristic that is relevant to the administration guideline (e.g. height, weight, gender).', 'representation': None}

    _characteristic_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['characteristicCodeableConcept', 'characteristicQuantity']), False))


    

     
    



class MedicationKnowledgeMedicineClassification(BackboneElement):
    """ Categorization of the medication within a formulary or classification
    system.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='classification' >]
  

    type: "CodeableConcept"

    """ The type of category for the medication (for example, therapeutic
        classification, therapeutic sub-classification).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    classification: typing.Optional[typing.List["CodeableConcept"]]

    """ Specific category assigned to the medication.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgePackaging(BackboneElement):
    """ Details about packaged medications.
    
    Information that only applies to packages (not products).
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='quantity' >]
  

    type: typing.Optional["CodeableConcept"]

    """ A code that defines the specific type of packaging that the
        medication can be found in.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ The number of product units the package would contain if fully
        loaded.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeDrugCharacteristic(BackboneElement):
    """ Specifies descriptive properties of the medicine.
    
    Specifies descriptive properties of the medicine, such as color, shape,
    imprints, etc.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueBase64Binary' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Code specifying the type of characteristic of medication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Description of the characteristic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueString: typing.Optional[str]

    """ Description of the characteristic.
    Type `str`. """

    valueQuantity: typing.Optional["Quantity"]

    """ Description of the characteristic.
    Type `Quantity` (represented as `dict` in JSON). """

    valueBase64Binary: typing.Optional[str]

    """ Description of the characteristic.
    Type `str`. """



#   {'path': 'MedicationKnowledge.drugCharacteristic.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCodeableConcept', 'name': 'valueCodeableConcept', 'parent_name': 'MedicationKnowledge.drugCharacteristic', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Description of the characteristic', 'formal': None, 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCodeableConcept', 'valueString', 'valueQuantity', 'valueBase64Binary']), True))


    

     
    



class MedicationKnowledgeRegulatory(BackboneElement):
    """ Regulatory information about a medication.
    """
    
    # [<FHIRClassProperty self.name='regulatoryAuthority' >, <FHIRClassProperty self.name='substitution' >, <FHIRClassProperty self.name='schedule' >, <FHIRClassProperty self.name='maxDispense' >]
  

    regulatoryAuthority: "Reference"

    """ Specifies the authority of the regulation.
    Type `Reference` (represented as `dict` in JSON). """

    substitution: typing.Optional[typing.List["MedicationKnowledgeRegulatorySubstitution"]]

    """ Specifies if changes are allowed when dispensing a medication from
        a regulatory perspective.
    List of `MedicationKnowledgeRegulatorySubstitution` items (represented as `dict` in JSON). """

    schedule: typing.Optional[typing.List["MedicationKnowledgeRegulatorySchedule"]]

    """ Specifies the schedule of a medication in jurisdiction.
    List of `MedicationKnowledgeRegulatorySchedule` items (represented as `dict` in JSON). """

    maxDispense: typing.Optional["MedicationKnowledgeRegulatoryMaxDispense"]

    """ The maximum number of units of the medication that can be dispensed
        in a period.
    Type `MedicationKnowledgeRegulatoryMaxDispense` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeRegulatorySubstitution(BackboneElement):
    """ Specifies if changes are allowed when dispensing a medication from a
    regulatory perspective.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='allowed' >]
  

    type: "CodeableConcept"

    """ Specifies the type of substitution allowed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    allowed: bool

    """ Specifies if regulation allows for changes in the medication when
        dispensing.
    Type `bool`. """




    

     
    



class MedicationKnowledgeRegulatorySchedule(BackboneElement):
    """ Specifies the schedule of a medication in jurisdiction.
    """
    
    # [<FHIRClassProperty self.name='schedule' >]
  

    schedule: "CodeableConcept"

    """ Specifies the specific drug schedule.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeRegulatoryMaxDispense(BackboneElement):
    """ The maximum number of units of the medication that can be dispensed in a
    period.
    """
    
    # [<FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='period' >]
  

    quantity: "Quantity"

    """ The maximum number of units of the medication that can be dispensed.
    Type `Quantity` (represented as `dict` in JSON). """

    period: typing.Optional["Duration"]

    """ The period that applies to the maximum number of units.
    Type `Duration` (represented as `dict` in JSON). """




    

     
    



class MedicationKnowledgeKinetics(BackboneElement):
    """ The time course of drug absorption, distribution, metabolism and excretion
    of a medication from the body.
    """
    
    # [<FHIRClassProperty self.name='areaUnderCurve' >, <FHIRClassProperty self.name='lethalDose50' >, <FHIRClassProperty self.name='halfLifePeriod' >]
  

    areaUnderCurve: typing.Optional[typing.List["Quantity"]]

    """ The drug concentration measured at certain discrete points in time.
    List of `Quantity` items (represented as `dict` in JSON). """

    lethalDose50: typing.Optional[typing.List["Quantity"]]

    """ The median lethal dose of a drug.
    List of `Quantity` items (represented as `dict` in JSON). """

    halfLifePeriod: typing.Optional["Duration"]

    """ Time required for concentration in the body to decrease by half.
    Type `Duration` (represented as `dict` in JSON). """




    

     
    



class MedicationRequestDispenseRequest(BackboneElement):
    """ Medication supply authorization.
    
    Indicates the specific details for the dispense or medication supply part
    of a medication request (also known as a Medication Prescription or
    Medication Order).  Note that this information is not always sent with the
    order.  There may be in some settings (e.g. hospitals) institutional or
    system support for completing the dispense details in the pharmacy
    department.
    """
    
    # [<FHIRClassProperty self.name='initialFill' >, <FHIRClassProperty self.name='dispenseInterval' >, <FHIRClassProperty self.name='validityPeriod' >, <FHIRClassProperty self.name='numberOfRepeatsAllowed' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='expectedSupplyDuration' >, <FHIRClassProperty self.name='performer' >]
  

    initialFill: typing.Optional["MedicationRequestDispenseRequestInitialFill"]

    """ First fill details.
    Type `MedicationRequestDispenseRequestInitialFill` (represented as `dict` in JSON). """

    dispenseInterval: typing.Optional["Duration"]

    """ Minimum period of time between dispenses.
    Type `Duration` (represented as `dict` in JSON). """

    validityPeriod: typing.Optional["Period"]

    """ Time period supply is authorized for.
    Type `Period` (represented as `dict` in JSON). """

    numberOfRepeatsAllowed: typing.Optional[int]

    """ Number of refills authorized.
    Type `int`. """

    quantity: typing.Optional["Quantity"]

    """ Amount of medication to supply per dispense.
    Type `Quantity` (represented as `dict` in JSON). """

    expectedSupplyDuration: typing.Optional["Duration"]

    """ Number of days supply per dispense.
    Type `Duration` (represented as `dict` in JSON). """

    performer: typing.Optional["Reference"]

    """ Intended dispenser.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicationRequestDispenseRequestInitialFill(BackboneElement):
    """ First fill details.
    
    Indicates the quantity or duration for the first dispense of the
    medication.
    """
    
    # [<FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='duration' >]
  

    quantity: typing.Optional["Quantity"]

    """ First fill quantity.
    Type `Quantity` (represented as `dict` in JSON). """

    duration: typing.Optional["Duration"]

    """ First fill duration.
    Type `Duration` (represented as `dict` in JSON). """




    

     
    



class MedicationRequestSubstitution(BackboneElement):
    """ Any restrictions on medication substitution.
    
    Indicates whether or not substitution can or should be part of the
    dispense. In some cases, substitution must happen, in other cases
    substitution must not happen. This block explains the prescriber's intent.
    If nothing is specified substitution may be done.
    """
    
    # [<FHIRClassProperty self.name='allowedBoolean' >, <FHIRClassProperty self.name='allowedCodeableConcept' >, <FHIRClassProperty self.name='reason' >]
  

    allowedBoolean: typing.Optional[bool]

    """ Whether substitution is allowed or not.
    Type `bool`. """

    allowedCodeableConcept: typing.Optional["CodeableConcept"]

    """ Whether substitution is allowed or not.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    reason: typing.Optional["CodeableConcept"]

    """ Why should (not) substitution be made.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'MedicationRequest.substitution.allowed[x]', 'choice_of_type': 'allowed', 'orig_name': 'allowedBoolean', 'name': 'allowedBoolean', 'parent_name': 'MedicationRequest.substitution', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Whether substitution is allowed or not', 'formal': 'True if the prescriber allows a different drug to be dispensed from what was prescribed.', 'representation': None}

    _allowed_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['allowedBoolean', 'allowedCodeableConcept']), False))


    

     
    



class MedicinalProductName(BackboneElement):
    """ The product's name, including full name and possibly coded parts.
    """
    
    # [<FHIRClassProperty self.name='productName' >, <FHIRClassProperty self.name='namePart' >, <FHIRClassProperty self.name='countryLanguage' >]
  

    productName: str

    """ The full product name.
    Type `str`. """

    namePart: typing.Optional[typing.List["MedicinalProductNameNamePart"]]

    """ Coding words or phrases of the name.
    List of `MedicinalProductNameNamePart` items (represented as `dict` in JSON). """

    countryLanguage: typing.Optional[typing.List["MedicinalProductNameCountryLanguage"]]

    """ Country where the name applies.
    List of `MedicinalProductNameCountryLanguage` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductNameNamePart(BackboneElement):
    """ Coding words or phrases of the name.
    """
    
    # [<FHIRClassProperty self.name='part' >, <FHIRClassProperty self.name='type' >]
  

    part: str

    """ A fragment of a product name.
    Type `str`. """

    type: "Coding"

    """ Idenifying type for this part of the name (e.g. strength part).
    Type `Coding` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductNameCountryLanguage(BackboneElement):
    """ Country where the name applies.
    """
    
    # [<FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='language' >]
  

    country: "CodeableConcept"

    """ Country code for where this name applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    jurisdiction: typing.Optional["CodeableConcept"]

    """ Jurisdiction code for where this name applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    language: "CodeableConcept"

    """ Language code for this name.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductManufacturingBusinessOperation(BackboneElement):
    """ An operation applied to the product, for manufacturing or adminsitrative
    purpose.
    """
    
    # [<FHIRClassProperty self.name='operationType' >, <FHIRClassProperty self.name='authorisationReferenceNumber' >, <FHIRClassProperty self.name='effectiveDate' >, <FHIRClassProperty self.name='confidentialityIndicator' >, <FHIRClassProperty self.name='manufacturer' >, <FHIRClassProperty self.name='regulator' >]
  

    operationType: typing.Optional["CodeableConcept"]

    """ The type of manufacturing operation.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    authorisationReferenceNumber: typing.Optional["Identifier"]

    """ Regulatory authorization reference number.
    Type `Identifier` (represented as `dict` in JSON). """

    effectiveDate: typing.Optional["FHIRDate"]

    """ Regulatory authorization date.
    Type `FHIRDate` (represented as `str` in JSON). """

    confidentialityIndicator: typing.Optional["CodeableConcept"]

    """ To indicate if this proces is commercially confidential.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    manufacturer: typing.Optional[typing.List["Reference"]]

    """ The manufacturer or establishment associated with the process.
    List of `Reference` items (represented as `dict` in JSON). """

    regulator: typing.Optional["Reference"]

    """ A regulator which oversees the operation.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductSpecialDesignation(BackboneElement):
    """ Indicates if the medicinal product has an orphan designation for the
    treatment of a rare disease.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='intendedUse' >, <FHIRClassProperty self.name='indicationCodeableConcept' >, <FHIRClassProperty self.name='indicationReference' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='species' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Identifier for the designation, or procedure number.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ The type of special designation, e.g. orphan drug, minor use.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intendedUse: typing.Optional["CodeableConcept"]

    """ The intended use of the product, e.g. prevention, treatment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    indicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Condition for which the medicinal use applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    indicationReference: typing.Optional["Reference"]

    """ Condition for which the medicinal use applies.
    Type `Reference` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ For example granted, pending, expired or withdrawn.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date when the designation was granted.
    Type `FHIRDate` (represented as `str` in JSON). """

    species: typing.Optional["CodeableConcept"]

    """ Animal species for which this applies.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'MedicinalProduct.specialDesignation.indication[x]', 'choice_of_type': 'indication', 'orig_name': 'indicationCodeableConcept', 'name': 'indicationCodeableConcept', 'parent_name': 'MedicinalProduct.specialDesignation', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Condition for which the medicinal use applies', 'formal': None, 'representation': None}

    _indication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['indicationCodeableConcept', 'indicationReference']), True))


    

     
    



class MedicinalProductAuthorizationJurisdictionalAuthorization(BackboneElement):
    """ Authorization in areas within a country.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='legalStatusOfSupply' >, <FHIRClassProperty self.name='validityPeriod' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ The assigned number for the marketing authorization.
    List of `Identifier` items (represented as `dict` in JSON). """

    country: typing.Optional["CodeableConcept"]

    """ Country of authorization.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ Jurisdiction within a country.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    legalStatusOfSupply: typing.Optional["CodeableConcept"]

    """ The legal status of supply in a jurisdiction or region.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    validityPeriod: typing.Optional["Period"]

    """ The start and expected end date of the authorization.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductAuthorizationProcedure(BackboneElement):
    """ The regulatory procedure for granting or amending a marketing authorization.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='datePeriod' >, <FHIRClassProperty self.name='dateDateTime' >, <FHIRClassProperty self.name='application' >]
  

    identifier: typing.Optional["Identifier"]

    """ Identifier for this procedure.
    Type `Identifier` (represented as `dict` in JSON). """

    type: "CodeableConcept"

    """ Type of procedure.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    datePeriod: typing.Optional["Period"]

    """ Date of procedure.
    Type `Period` (represented as `dict` in JSON). """

    dateDateTime: typing.Optional["FHIRDate"]

    """ Date of procedure.
    Type `FHIRDate` (represented as `str` in JSON). """

    application: typing.Optional[typing.List["MedicinalProductAuthorizationProcedure"]]

    """ Applcations submitted to obtain a marketing authorization.
    List of `MedicinalProductAuthorizationProcedure` items (represented as `dict` in JSON). """



#   {'path': 'MedicinalProductAuthorization.procedure.date[x]', 'choice_of_type': 'date', 'orig_name': 'datePeriod', 'name': 'datePeriod', 'parent_name': 'MedicinalProductAuthorization.procedure', 'class_name': 'Period', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date of procedure', 'formal': None, 'representation': None}

    _date_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['datePeriod', 'dateDateTime']), True))


    

     
    



class MedicinalProductContraindicationOtherTherapy(BackboneElement):
    """ Information about the use of the medicinal product in relation to other
    therapies described as part of the indication.
    """
    
    # [<FHIRClassProperty self.name='therapyRelationshipType' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >]
  

    therapyRelationshipType: "CodeableConcept"

    """ The type of relationship between the medicinal product indication
        or contraindication and another therapy.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Reference to a specific medication (active substance, medicinal
        product or class of products) as part of an indication or
        contraindication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ Reference to a specific medication (active substance, medicinal
        product or class of products) as part of an indication or
        contraindication.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'MedicinalProductContraindication.otherTherapy.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicinalProductContraindication.otherTherapy', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Reference to a specific medication (active substance, medicinal product or class of products) as part of an indication or contraindication', 'formal': None, 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))


    

     
    



class MedicinalProductIndicationOtherTherapy(BackboneElement):
    """ Information about the use of the medicinal product in relation to other
    therapies described as part of the indication.
    """
    
    # [<FHIRClassProperty self.name='therapyRelationshipType' >, <FHIRClassProperty self.name='medicationCodeableConcept' >, <FHIRClassProperty self.name='medicationReference' >]
  

    therapyRelationshipType: "CodeableConcept"

    """ The type of relationship between the medicinal product indication
        or contraindication and another therapy.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationCodeableConcept: typing.Optional["CodeableConcept"]

    """ Reference to a specific medication (active substance, medicinal
        product or class of products) as part of an indication or
        contraindication.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    medicationReference: typing.Optional["Reference"]

    """ Reference to a specific medication (active substance, medicinal
        product or class of products) as part of an indication or
        contraindication.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'MedicinalProductIndication.otherTherapy.medication[x]', 'choice_of_type': 'medication', 'orig_name': 'medicationCodeableConcept', 'name': 'medicationCodeableConcept', 'parent_name': 'MedicinalProductIndication.otherTherapy', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Reference to a specific medication (active substance, medicinal product or class of products) as part of an indication or contraindication', 'formal': None, 'representation': None}

    _medication_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['medicationCodeableConcept', 'medicationReference']), False))


    

     
    



class MedicinalProductIngredientSpecifiedSubstance(BackboneElement):
    """ A specified substance that comprises this ingredient.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='group' >, <FHIRClassProperty self.name='confidentiality' >, <FHIRClassProperty self.name='strength' >]
  

    code: "CodeableConcept"

    """ The specified substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    group: "CodeableConcept"

    """ The group of specified substance, e.g. group 1 to 4.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    confidentiality: typing.Optional["CodeableConcept"]

    """ Confidentiality level of the specified substance as the ingredient.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    strength: typing.Optional[typing.List["MedicinalProductIngredientSpecifiedSubstanceStrength"]]

    """ Quantity of the substance or specified substance present in the
        manufactured item or pharmaceutical product.
    List of `MedicinalProductIngredientSpecifiedSubstanceStrength` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductIngredientSpecifiedSubstanceStrength(BackboneElement):
    """ Quantity of the substance or specified substance present in the
    manufactured item or pharmaceutical product.
    """
    
    # [<FHIRClassProperty self.name='presentation' >, <FHIRClassProperty self.name='presentationLowLimit' >, <FHIRClassProperty self.name='concentration' >, <FHIRClassProperty self.name='concentrationLowLimit' >, <FHIRClassProperty self.name='measurementPoint' >, <FHIRClassProperty self.name='country' >, <FHIRClassProperty self.name='referenceStrength' >]
  

    presentation: "Ratio"

    """ The quantity of substance in the unit of presentation, or in the
        volume (or mass) of the single pharmaceutical product or
        manufactured item.
    Type `Ratio` (represented as `dict` in JSON). """

    presentationLowLimit: typing.Optional["Ratio"]

    """ A lower limit for the quantity of substance in the unit of
        presentation. For use when there is a range of strengths, this is
        the lower limit, with the presentation attribute becoming the upper
        limit.
    Type `Ratio` (represented as `dict` in JSON). """

    concentration: typing.Optional["Ratio"]

    """ The strength per unitary volume (or mass).
    Type `Ratio` (represented as `dict` in JSON). """

    concentrationLowLimit: typing.Optional["Ratio"]

    """ A lower limit for the strength per unitary volume (or mass), for
        when there is a range. The concentration attribute then becomes the
        upper limit.
    Type `Ratio` (represented as `dict` in JSON). """

    measurementPoint: typing.Optional[str]

    """ For when strength is measured at a particular point or distance.
    Type `str`. """

    country: typing.Optional[typing.List["CodeableConcept"]]

    """ The country or countries for which the strength range applies.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    referenceStrength: typing.Optional[typing.List["MedicinalProductIngredientSpecifiedSubstanceStrengthReferenceStrength"]]

    """ Strength expressed in terms of a reference substance.
    List of `MedicinalProductIngredientSpecifiedSubstanceStrengthReferenceStrength` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductIngredientSpecifiedSubstanceStrengthReferenceStrength(BackboneElement):
    """ Strength expressed in terms of a reference substance.
    """
    
    # [<FHIRClassProperty self.name='substance' >, <FHIRClassProperty self.name='strength' >, <FHIRClassProperty self.name='strengthLowLimit' >, <FHIRClassProperty self.name='measurementPoint' >, <FHIRClassProperty self.name='country' >]
  

    substance: typing.Optional["CodeableConcept"]

    """ Relevant reference substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    strength: "Ratio"

    """ Strength expressed in terms of a reference substance.
    Type `Ratio` (represented as `dict` in JSON). """

    strengthLowLimit: typing.Optional["Ratio"]

    """ Strength expressed in terms of a reference substance.
    Type `Ratio` (represented as `dict` in JSON). """

    measurementPoint: typing.Optional[str]

    """ For when strength is measured at a particular point or distance.
    Type `str`. """

    country: typing.Optional[typing.List["CodeableConcept"]]

    """ The country or countries for which the strength range applies.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductIngredientSubstance(BackboneElement):
    """ The ingredient substance.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='strength' >]
  

    code: "CodeableConcept"

    """ The ingredient substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    strength: typing.Optional[typing.List["MedicinalProductIngredientSpecifiedSubstanceStrength"]]

    """ Quantity of the substance or specified substance present in the
        manufactured item or pharmaceutical product.
    List of `MedicinalProductIngredientSpecifiedSubstanceStrength` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductInteractionInteractant(BackboneElement):
    """ The specific medication, food or laboratory test that interacts.
    """
    
    # [<FHIRClassProperty self.name='itemReference' >, <FHIRClassProperty self.name='itemCodeableConcept' >]
  

    itemReference: typing.Optional["Reference"]

    """ The specific medication, food or laboratory test that interacts.
    Type `Reference` (represented as `dict` in JSON). """

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ The specific medication, food or laboratory test that interacts.
    Type `CodeableConcept` (represented as `dict` in JSON). """



#   {'path': 'MedicinalProductInteraction.interactant.item[x]', 'choice_of_type': 'item', 'orig_name': 'itemReference', 'name': 'itemReference', 'parent_name': 'MedicinalProductInteraction.interactant', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'The specific medication, food or laboratory test that interacts', 'formal': None, 'representation': None}

    _item_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['itemReference', 'itemCodeableConcept']), False))


    

     
    



class MedicinalProductPackagedBatchIdentifier(BackboneElement):
    """ Batch numbering.
    """
    
    # [<FHIRClassProperty self.name='outerPackaging' >, <FHIRClassProperty self.name='immediatePackaging' >]
  

    outerPackaging: "Identifier"

    """ A number appearing on the outer packaging of a specific batch.
    Type `Identifier` (represented as `dict` in JSON). """

    immediatePackaging: typing.Optional["Identifier"]

    """ A number appearing on the immediate packaging (and not the outer
        packaging).
    Type `Identifier` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPackagedPackageItem(BackboneElement):
    """ A packaging item, as a contained for medicine, possibly with other
    packaging items within.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='material' >, <FHIRClassProperty self.name='alternateMaterial' >, <FHIRClassProperty self.name='device' >, <FHIRClassProperty self.name='manufacturedItem' >, <FHIRClassProperty self.name='packageItem' >, <FHIRClassProperty self.name='physicalCharacteristics' >, <FHIRClassProperty self.name='otherCharacteristics' >, <FHIRClassProperty self.name='shelfLifeStorage' >, <FHIRClassProperty self.name='manufacturer' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Including possibly Data Carrier Identifier.
    List of `Identifier` items (represented as `dict` in JSON). """

    type: "CodeableConcept"

    """ The physical type of the container of the medicine.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    quantity: "Quantity"

    """ The quantity of this package in the medicinal product, at the
        current level of packaging. The outermost is always 1.
    Type `Quantity` (represented as `dict` in JSON). """

    material: typing.Optional[typing.List["CodeableConcept"]]

    """ Material type of the package item.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    alternateMaterial: typing.Optional[typing.List["CodeableConcept"]]

    """ A possible alternate material for the packaging.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    device: typing.Optional[typing.List["Reference"]]

    """ A device accompanying a medicinal product.
    List of `Reference` items (represented as `dict` in JSON). """

    manufacturedItem: typing.Optional[typing.List["Reference"]]

    """ The manufactured item as contained in the packaged medicinal
        product.
    List of `Reference` items (represented as `dict` in JSON). """

    packageItem: typing.Optional[typing.List["MedicinalProductPackagedPackageItem"]]

    """ Allows containers within containers.
    List of `MedicinalProductPackagedPackageItem` items (represented as `dict` in JSON). """

    physicalCharacteristics: typing.Optional["ProdCharacteristic"]

    """ Dimensions, color etc..
    Type `ProdCharacteristic` (represented as `dict` in JSON). """

    otherCharacteristics: typing.Optional[typing.List["CodeableConcept"]]

    """ Other codeable characteristics.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    shelfLifeStorage: typing.Optional[typing.List["ProductShelfLife"]]

    """ Shelf Life and storage information.
    List of `ProductShelfLife` items (represented as `dict` in JSON). """

    manufacturer: typing.Optional[typing.List["Reference"]]

    """ Manufacturer of this Package Item.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPharmaceuticalCharacteristics(BackboneElement):
    """ Characteristics e.g. a products onset of action.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='status' >]
  

    code: "CodeableConcept"

    """ A coded characteristic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ The status of characteristic e.g. assigned or pending.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPharmaceuticalRouteOfAdministration(BackboneElement):
    """ The path by which the pharmaceutical product is taken into or makes contact
    with the body.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='firstDose' >, <FHIRClassProperty self.name='maxSingleDose' >, <FHIRClassProperty self.name='maxDosePerDay' >, <FHIRClassProperty self.name='maxDosePerTreatmentPeriod' >, <FHIRClassProperty self.name='maxTreatmentPeriod' >, <FHIRClassProperty self.name='targetSpecies' >]
  

    code: "CodeableConcept"

    """ Coded expression for the route.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    firstDose: typing.Optional["Quantity"]

    """ The first dose (dose quantity) administered in humans can be
        specified, for a product under investigation, using a numerical
        value and its unit of measurement.
    Type `Quantity` (represented as `dict` in JSON). """

    maxSingleDose: typing.Optional["Quantity"]

    """ The maximum single dose that can be administered as per the
        protocol of a clinical trial can be specified using a numerical
        value and its unit of measurement.
    Type `Quantity` (represented as `dict` in JSON). """

    maxDosePerDay: typing.Optional["Quantity"]

    """ The maximum dose per day (maximum dose quantity to be administered
        in any one 24-h period) that can be administered as per the
        protocol referenced in the clinical trial authorisation.
    Type `Quantity` (represented as `dict` in JSON). """

    maxDosePerTreatmentPeriod: typing.Optional["Ratio"]

    """ The maximum dose per treatment period that can be administered as
        per the protocol referenced in the clinical trial authorisation.
    Type `Ratio` (represented as `dict` in JSON). """

    maxTreatmentPeriod: typing.Optional["Duration"]

    """ The maximum treatment period during which an Investigational
        Medicinal Product can be administered as per the protocol
        referenced in the clinical trial authorisation.
    Type `Duration` (represented as `dict` in JSON). """

    targetSpecies: typing.Optional[typing.List["MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpecies"]]

    """ A species for which this route applies.
    List of `MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpecies` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpecies(BackboneElement):
    """ A species for which this route applies.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='withdrawalPeriod' >]
  

    code: "CodeableConcept"

    """ Coded expression for the species.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    withdrawalPeriod: typing.Optional[typing.List["MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpeciesWithdrawalPeriod"]]

    """ A species specific time during which consumption of animal product
        is not appropriate.
    List of `MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpeciesWithdrawalPeriod` items (represented as `dict` in JSON). """




    

     
    



class MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpeciesWithdrawalPeriod(BackboneElement):
    """ A species specific time during which consumption of animal product is not
    appropriate.
    """
    
    # [<FHIRClassProperty self.name='tissue' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='supportingInformation' >]
  

    tissue: "CodeableConcept"

    """ Coded expression for the type of tissue for which the withdrawal
        period applues, e.g. meat, milk.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: "Quantity"

    """ A value for the time.
    Type `Quantity` (represented as `dict` in JSON). """

    supportingInformation: typing.Optional[str]

    """ Extra information about the withdrawal period.
    Type `str`. """




    

     
    



class MessageDefinitionFocus(BackboneElement):
    """ Resource(s) that are the subject of the event.
    
    Identifies the resource (or resources) that are being addressed by the
    event.  For example, the Encounter for an admit message or two Account
    records for a merge.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='profile' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >]
  

    code: "str"

    """ Type of resource.
    Type `str`. """

    profile: typing.Optional[str]

    """ Profile that must be adhered to by focus.
    Type `str`. """

    min: int

    """ Minimum number of focuses of this type.
    Type `int`. """

    max: typing.Optional[str]

    """ Maximum number of focuses of this type.
    Type `str`. """




    

     
    



class MessageDefinitionAllowedResponse(BackboneElement):
    """ Responses to this message.
    
    Indicates what types of messages may be sent as an application-level
    response to this message.
    """
    
    # [<FHIRClassProperty self.name='message' >, <FHIRClassProperty self.name='situation' >]
  

    message: str

    """ Reference to allowed message definition response.
    Type `str`. """

    situation: typing.Optional[str]

    """ When should this response be used.
    Type `str`. """




    

     
    



class MessageHeaderDestination(BackboneElement):
    """ Message destination application(s).
    
    The destination application which the message is intended for.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='receiver' >]
  

    name: typing.Optional[str]

    """ Name of system.
    Type `str`. """

    target: typing.Optional["Reference"]

    """ Particular delivery destination within the destination.
    Type `Reference` (represented as `dict` in JSON). """

    endpoint: str

    """ Actual destination address or id.
    Type `str`. """

    receiver: typing.Optional["Reference"]

    """ Intended "real-world" recipient for the data.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MessageHeaderSource(BackboneElement):
    """ Message source application.
    
    The source application from which this message originated.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='software' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='contact' >, <FHIRClassProperty self.name='endpoint' >]
  

    name: typing.Optional[str]

    """ Name of system.
    Type `str`. """

    software: typing.Optional[str]

    """ Name of software running the system.
    Type `str`. """

    version: typing.Optional[str]

    """ Version of software running.
    Type `str`. """

    contact: typing.Optional["ContactPoint"]

    """ Human contact for problems.
    Type `ContactPoint` (represented as `dict` in JSON). """

    endpoint: str

    """ Actual message source address or id.
    Type `str`. """




    

     
    



class MessageHeaderResponse(BackboneElement):
    """ If this is a reply to prior message.
    
    Information about the message that this message is a response to.  Only
    present if this message is a response.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='details' >]
  

    identifier: str

    """ Id of original message.
    Type `str`. """

    code: "str"

    """ ok | transient-error | fatal-error.
    Type `str`. """

    details: typing.Optional["Reference"]

    """ Specific list of hints/warnings/errors.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MolecularSequenceReferenceSeq(BackboneElement):
    """ A sequence used as reference.
    
    A sequence that is used as a reference to describe variants that are
    present in a sequence analyzed.
    """
    
    # [<FHIRClassProperty self.name='chromosome' >, <FHIRClassProperty self.name='genomeBuild' >, <FHIRClassProperty self.name='orientation' >, <FHIRClassProperty self.name='referenceSeqId' >, <FHIRClassProperty self.name='referenceSeqPointer' >, <FHIRClassProperty self.name='referenceSeqString' >, <FHIRClassProperty self.name='strand' >, <FHIRClassProperty self.name='windowStart' >, <FHIRClassProperty self.name='windowEnd' >]
  

    chromosome: typing.Optional["CodeableConcept"]

    """ Chromosome containing genetic finding.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    genomeBuild: typing.Optional[str]

    """ The Genome Build used for reference, following GRCh build versions
        e.g. 'GRCh 37'.
    Type `str`. """

    orientation: typing.Optional["str"]

    """ sense | antisense.
    Type `str`. """

    referenceSeqId: typing.Optional["CodeableConcept"]

    """ Reference identifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    referenceSeqPointer: typing.Optional["Reference"]

    """ A pointer to another MolecularSequence entity as reference sequence.
    Type `Reference` (represented as `dict` in JSON). """

    referenceSeqString: typing.Optional[str]

    """ A string to represent reference sequence.
    Type `str`. """

    strand: typing.Optional["str"]

    """ watson | crick.
    Type `str`. """

    windowStart: typing.Optional[int]

    """ Start position of the window on the  reference sequence.
    Type `int`. """

    windowEnd: typing.Optional[int]

    """ End position of the window on the reference sequence.
    Type `int`. """




    

     
    



class MolecularSequenceVariant(BackboneElement):
    """ Variant in sequence.
    
    The definition of variant here originates from Sequence ontology ([variant_
    of](http://www.sequenceontology.org/browser/current_svn/term/variant_of)).
    This element can represent amino acid or nucleic sequence change(including
    insertion,deletion,SNP,etc.)  It can represent some complex mutation or
    segment variation with the assist of CIGAR string.
    """
    
    # [<FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='observedAllele' >, <FHIRClassProperty self.name='referenceAllele' >, <FHIRClassProperty self.name='cigar' >, <FHIRClassProperty self.name='variantPointer' >]
  

    start: typing.Optional[int]

    """ Start position of the variant on the  reference sequence.
    Type `int`. """

    end: typing.Optional[int]

    """ End position of the variant on the reference sequence.
    Type `int`. """

    observedAllele: typing.Optional[str]

    """ Allele that was observed.
    Type `str`. """

    referenceAllele: typing.Optional[str]

    """ Allele in the reference sequence.
    Type `str`. """

    cigar: typing.Optional[str]

    """ Extended CIGAR string for aligning the sequence with reference
        bases.
    Type `str`. """

    variantPointer: typing.Optional["Reference"]

    """ Pointer to observed variant information.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class MolecularSequenceQuality(BackboneElement):
    """ An set of value as quality of sequence.
    
    An experimental feature attribute that defines the quality of the feature
    in a quantitative way, such as a phred quality score ([SO:0001686](http://w
    ww.sequenceontology.org/browser/current_svn/term/SO:0001686)).
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='standardSequence' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >, <FHIRClassProperty self.name='score' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='truthTP' >, <FHIRClassProperty self.name='queryTP' >, <FHIRClassProperty self.name='truthFN' >, <FHIRClassProperty self.name='queryFP' >, <FHIRClassProperty self.name='gtFP' >, <FHIRClassProperty self.name='precision' >, <FHIRClassProperty self.name='recall' >, <FHIRClassProperty self.name='fScore' >, <FHIRClassProperty self.name='roc' >]
  

    type: "str"

    """ indel | snp | unknown.
    Type `str`. """

    standardSequence: typing.Optional["CodeableConcept"]

    """ Standard sequence for comparison.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    start: typing.Optional[int]

    """ Start position of the sequence.
    Type `int`. """

    end: typing.Optional[int]

    """ End position of the sequence.
    Type `int`. """

    score: typing.Optional["Quantity"]

    """ Quality score for the comparison.
    Type `Quantity` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ Method to get quality.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    truthTP: typing.Optional[float]

    """ True positives from the perspective of the truth data.
    Type `float`. """

    queryTP: typing.Optional[float]

    """ True positives from the perspective of the query data.
    Type `float`. """

    truthFN: typing.Optional[float]

    """ False negatives.
    Type `float`. """

    queryFP: typing.Optional[float]

    """ False positives.
    Type `float`. """

    gtFP: typing.Optional[float]

    """ False positives where the non-REF alleles in the Truth and Query
        Call Sets match.
    Type `float`. """

    precision: typing.Optional[float]

    """ Precision of comparison.
    Type `float`. """

    recall: typing.Optional[float]

    """ Recall of comparison.
    Type `float`. """

    fScore: typing.Optional[float]

    """ F-score.
    Type `float`. """

    roc: typing.Optional["MolecularSequenceQualityRoc"]

    """ Receiver Operator Characteristic (ROC) Curve.
    Type `MolecularSequenceQualityRoc` (represented as `dict` in JSON). """




    

     
    



class MolecularSequenceQualityRoc(BackboneElement):
    """ Receiver Operator Characteristic (ROC) Curve.
    
    Receiver Operator Characteristic (ROC) Curve  to give
    sensitivity/specificity tradeoff.
    """
    
    # [<FHIRClassProperty self.name='score' >, <FHIRClassProperty self.name='numTP' >, <FHIRClassProperty self.name='numFP' >, <FHIRClassProperty self.name='numFN' >, <FHIRClassProperty self.name='precision' >, <FHIRClassProperty self.name='sensitivity' >, <FHIRClassProperty self.name='fMeasure' >]
  

    score: typing.Optional[typing.List[int]]

    """ Genotype quality score.
    List of `int` items. """

    numTP: typing.Optional[typing.List[int]]

    """ Roc score true positive numbers.
    List of `int` items. """

    numFP: typing.Optional[typing.List[int]]

    """ Roc score false positive numbers.
    List of `int` items. """

    numFN: typing.Optional[typing.List[int]]

    """ Roc score false negative numbers.
    List of `int` items. """

    precision: typing.Optional[typing.List[float]]

    """ Precision of the GQ score.
    List of `float` items. """

    sensitivity: typing.Optional[typing.List[float]]

    """ Sensitivity of the GQ score.
    List of `float` items. """

    fMeasure: typing.Optional[typing.List[float]]

    """ FScore of the GQ score.
    List of `float` items. """




    

     
    



class MolecularSequenceRepository(BackboneElement):
    """ External repository which contains detailed report related with observedSeq
    in this resource.
    
    Configurations of the external repository. The repository shall store
    target's observedSeq or records related with target's observedSeq.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='datasetId' >, <FHIRClassProperty self.name='variantsetId' >, <FHIRClassProperty self.name='readsetId' >]
  

    type: "str"

    """ directlink | openapi | login | oauth | other.
    Type `str`. """

    url: typing.Optional[str]

    """ URI of the repository.
    Type `str`. """

    name: typing.Optional[str]

    """ Repository's name.
    Type `str`. """

    datasetId: typing.Optional[str]

    """ Id of the dataset that used to call for dataset in repository.
    Type `str`. """

    variantsetId: typing.Optional[str]

    """ Id of the variantset that used to call for variantset in repository.
    Type `str`. """

    readsetId: typing.Optional[str]

    """ Id of the read.
    Type `str`. """




    

     
    



class MolecularSequenceStructureVariant(BackboneElement):
    """ Structural variant.
    
    Information about chromosome structure variation.
    """
    
    # [<FHIRClassProperty self.name='variantType' >, <FHIRClassProperty self.name='exact' >, <FHIRClassProperty self.name='length' >, <FHIRClassProperty self.name='outer' >, <FHIRClassProperty self.name='inner' >]
  

    variantType: typing.Optional["CodeableConcept"]

    """ Structural variant change type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    exact: typing.Optional[bool]

    """ Does the structural variant have base pair resolution breakpoints?.
    Type `bool`. """

    length: typing.Optional[int]

    """ Structural variant length.
    Type `int`. """

    outer: typing.Optional["MolecularSequenceStructureVariantOuter"]

    """ Structural variant outer.
    Type `MolecularSequenceStructureVariantOuter` (represented as `dict` in JSON). """

    inner: typing.Optional["MolecularSequenceStructureVariantInner"]

    """ Structural variant inner.
    Type `MolecularSequenceStructureVariantInner` (represented as `dict` in JSON). """




    

     
    



class MolecularSequenceStructureVariantOuter(BackboneElement):
    """ Structural variant outer.
    """
    
    # [<FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >]
  

    start: typing.Optional[int]

    """ Structural variant outer start.
    Type `int`. """

    end: typing.Optional[int]

    """ Structural variant outer end.
    Type `int`. """




    

     
    



class MolecularSequenceStructureVariantInner(BackboneElement):
    """ Structural variant inner.
    """
    
    # [<FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='end' >]
  

    start: typing.Optional[int]

    """ Structural variant inner start.
    Type `int`. """

    end: typing.Optional[int]

    """ Structural variant inner end.
    Type `int`. """




    

     
    



class NamingSystemUniqueId(BackboneElement):
    """ Unique identifiers used for system.
    
    Indicates how the system may be identified when referenced in electronic
    exchange.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='preferred' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='period' >]
  

    type: "str"

    """ oid | uuid | uri | other.
    Type `str`. """

    value: str

    """ The unique identifier.
    Type `str`. """

    preferred: typing.Optional[bool]

    """ Is this the id that should be used for this type.
    Type `bool`. """

    comment: typing.Optional[str]

    """ Notes about identifier usage.
    Type `str`. """

    period: typing.Optional["Period"]

    """ When is identifier valid?.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class NutritionOrderOralDiet(BackboneElement):
    """ Oral diet components.
    
    Diet given orally in contrast to enteral (tube) feeding.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='schedule' >, <FHIRClassProperty self.name='nutrient' >, <FHIRClassProperty self.name='texture' >, <FHIRClassProperty self.name='fluidConsistencyType' >, <FHIRClassProperty self.name='instruction' >]
  

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of oral diet or diet restrictions that describe what can be
        consumed orally.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    schedule: typing.Optional[typing.List["Timing"]]

    """ Scheduled frequency of diet.
    List of `Timing` items (represented as `dict` in JSON). """

    nutrient: typing.Optional[typing.List["NutritionOrderOralDietNutrient"]]

    """ Required  nutrient modifications.
    List of `NutritionOrderOralDietNutrient` items (represented as `dict` in JSON). """

    texture: typing.Optional[typing.List["NutritionOrderOralDietTexture"]]

    """ Required  texture modifications.
    List of `NutritionOrderOralDietTexture` items (represented as `dict` in JSON). """

    fluidConsistencyType: typing.Optional[typing.List["CodeableConcept"]]

    """ The required consistency of fluids and liquids provided to the
        patient.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    instruction: typing.Optional[str]

    """ Instructions or additional information about the oral diet.
    Type `str`. """




    

     
    



class NutritionOrderOralDietNutrient(BackboneElement):
    """ Required  nutrient modifications.
    
    Class that defines the quantity and type of nutrient modifications (for
    example carbohydrate, fiber or sodium) required for the oral diet.
    """
    
    # [<FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='amount' >]
  

    modifier: typing.Optional["CodeableConcept"]

    """ Type of nutrient that is being modified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Quantity"]

    """ Quantity of the specified nutrient.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class NutritionOrderOralDietTexture(BackboneElement):
    """ Required  texture modifications.
    
    Class that describes any texture modifications required for the patient to
    safely consume various types of solid foods.
    """
    
    # [<FHIRClassProperty self.name='modifier' >, <FHIRClassProperty self.name='foodType' >]
  

    modifier: typing.Optional["CodeableConcept"]

    """ Code to indicate how to alter the texture of the foods, e.g. pureed.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    foodType: typing.Optional["CodeableConcept"]

    """ Concepts that are used to identify an entity that is ingested for
        nutritional purposes.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class NutritionOrderSupplement(BackboneElement):
    """ Supplement components.
    
    Oral nutritional products given in order to add further nutritional value
    to the patient's diet.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='productName' >, <FHIRClassProperty self.name='schedule' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='instruction' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of supplement product requested.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    productName: typing.Optional[str]

    """ Product or brand name of the nutritional supplement.
    Type `str`. """

    schedule: typing.Optional[typing.List["Timing"]]

    """ Scheduled frequency of supplement.
    List of `Timing` items (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Amount of the nutritional supplement.
    Type `Quantity` (represented as `dict` in JSON). """

    instruction: typing.Optional[str]

    """ Instructions or additional information about the oral supplement.
    Type `str`. """




    

     
    



class NutritionOrderEnteralFormula(BackboneElement):
    """ Enteral formula components.
    
    Feeding provided through the gastrointestinal tract via a tube, catheter,
    or stoma that delivers nutrition distal to the oral cavity.
    """
    
    # [<FHIRClassProperty self.name='baseFormulaType' >, <FHIRClassProperty self.name='baseFormulaProductName' >, <FHIRClassProperty self.name='additiveType' >, <FHIRClassProperty self.name='additiveProductName' >, <FHIRClassProperty self.name='caloricDensity' >, <FHIRClassProperty self.name='routeofAdministration' >, <FHIRClassProperty self.name='administration' >, <FHIRClassProperty self.name='maxVolumeToDeliver' >, <FHIRClassProperty self.name='administrationInstruction' >]
  

    baseFormulaType: typing.Optional["CodeableConcept"]

    """ Type of enteral or infant formula.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    baseFormulaProductName: typing.Optional[str]

    """ Product or brand name of the enteral or infant formula.
    Type `str`. """

    additiveType: typing.Optional["CodeableConcept"]

    """ Type of modular component to add to the feeding.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additiveProductName: typing.Optional[str]

    """ Product or brand name of the modular additive.
    Type `str`. """

    caloricDensity: typing.Optional["Quantity"]

    """ Amount of energy per specified volume that is required.
    Type `Quantity` (represented as `dict` in JSON). """

    routeofAdministration: typing.Optional["CodeableConcept"]

    """ How the formula should enter the patient's gastrointestinal tract.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    administration: typing.Optional[typing.List["NutritionOrderEnteralFormulaAdministration"]]

    """ Formula feeding instruction as structured data.
    List of `NutritionOrderEnteralFormulaAdministration` items (represented as `dict` in JSON). """

    maxVolumeToDeliver: typing.Optional["Quantity"]

    """ Upper limit on formula volume per unit of time.
    Type `Quantity` (represented as `dict` in JSON). """

    administrationInstruction: typing.Optional[str]

    """ Formula feeding instructions expressed as text.
    Type `str`. """




    

     
    



class NutritionOrderEnteralFormulaAdministration(BackboneElement):
    """ Formula feeding instruction as structured data.
    
    Formula administration instructions as structured data.  This repeating
    structure allows for changing the administration rate or volume over time
    for both bolus and continuous feeding.  An example of this would be an
    instruction to increase the rate of continuous feeding every 2 hours.
    """
    
    # [<FHIRClassProperty self.name='schedule' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='rateQuantity' >, <FHIRClassProperty self.name='rateRatio' >]
  

    schedule: typing.Optional["Timing"]

    """ Scheduled frequency of enteral feeding.
    Type `Timing` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ The volume of formula to provide.
    Type `Quantity` (represented as `dict` in JSON). """

    rateQuantity: typing.Optional["Quantity"]

    """ Speed with which the formula is provided per period of time.
    Type `Quantity` (represented as `dict` in JSON). """

    rateRatio: typing.Optional["Ratio"]

    """ Speed with which the formula is provided per period of time.
    Type `Ratio` (represented as `dict` in JSON). """



#   {'path': 'NutritionOrder.enteralFormula.administration.rate[x]', 'choice_of_type': 'rate', 'orig_name': 'rateQuantity', 'name': 'rateQuantity', 'parent_name': 'NutritionOrder.enteralFormula.administration', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Speed with which the formula is provided per period of time', 'formal': 'The rate of administration of formula via a feeding pump, e.g. 60 mL per hour, according to the specified schedule.', 'representation': None}

    _rate_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['rateQuantity', 'rateRatio']), True))


    

     
    



class ObservationReferenceRange(BackboneElement):
    """ Provides guide for interpretation.
    
    Guidance on how to interpret the value by comparison to a normal or
    recommended range.  Multiple reference ranges are interpreted as an "OR".
    In other words, to represent two distinct target populations, two
    `referenceRange` elements would be used.
    """
    
    # [<FHIRClassProperty self.name='low' >, <FHIRClassProperty self.name='high' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='appliesTo' >, <FHIRClassProperty self.name='age' >, <FHIRClassProperty self.name='text' >]
  

    low: typing.Optional["Quantity"]

    """ Low Range, if relevant.
    Type `Quantity` (represented as `dict` in JSON). """

    high: typing.Optional["Quantity"]

    """ High Range, if relevant.
    Type `Quantity` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Reference range qualifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    appliesTo: typing.Optional[typing.List["CodeableConcept"]]

    """ Reference range population.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    age: typing.Optional["Range"]

    """ Applicable age range, if relevant.
    Type `Range` (represented as `dict` in JSON). """

    text: typing.Optional[str]

    """ Text based reference range in an observation.
    Type `str`. """




    

     
    



class ObservationComponent(BackboneElement):
    """ Component results.
    
    Some observations have multiple component observations.  These component
    observations are expressed as separate code value pairs that share the same
    attributes.  Examples include systolic and diastolic component observations
    for blood pressure measurement and multiple component observations for
    genetics observations.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='dataAbsentReason' >, <FHIRClassProperty self.name='interpretation' >, <FHIRClassProperty self.name='referenceRange' >]
  

    code: "CodeableConcept"

    """ Type of component observation (code / type).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Actual component result.
    Type `Quantity` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Actual component result.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueString: typing.Optional[str]

    """ Actual component result.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Actual component result.
    Type `bool`. """

    valueInteger: typing.Optional[int]

    """ Actual component result.
    Type `int`. """

    valueRange: typing.Optional["Range"]

    """ Actual component result.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Actual component result.
    Type `Ratio` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Actual component result.
    Type `SampledData` (represented as `dict` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ Actual component result.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Actual component result.
    Type `FHIRDate` (represented as `str` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Actual component result.
    Type `Period` (represented as `dict` in JSON). """

    dataAbsentReason: typing.Optional["CodeableConcept"]

    """ Why the component result is missing.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    interpretation: typing.Optional[typing.List["CodeableConcept"]]

    """ High, low, normal, etc..
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    referenceRange: typing.Optional[typing.List["ObservationReferenceRange"]]

    """ Provides guide for interpretation of component result.
    List of `ObservationReferenceRange` items (represented as `dict` in JSON). """



#   {'path': 'Observation.component.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueQuantity', 'name': 'valueQuantity', 'parent_name': 'Observation.component', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Actual component result', 'formal': 'The information determined as a result of making the observation, if the information has a simple value.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueQuantity', 'valueCodeableConcept', 'valueString', 'valueBoolean', 'valueInteger', 'valueRange', 'valueRatio', 'valueSampledData', 'valueTime', 'valueDateTime', 'valuePeriod']), True))


    

     
    



class ObservationDefinitionQuantitativeDetails(BackboneElement):
    """ Characteristics of quantitative results.
    
    Characteristics for quantitative results of this observation.
    """
    
    # [<FHIRClassProperty self.name='customaryUnit' >, <FHIRClassProperty self.name='unit' >, <FHIRClassProperty self.name='conversionFactor' >, <FHIRClassProperty self.name='decimalPrecision' >]
  

    customaryUnit: typing.Optional["CodeableConcept"]

    """ Customary unit for quantitative results.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    unit: typing.Optional["CodeableConcept"]

    """ SI unit for quantitative results.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    conversionFactor: typing.Optional[float]

    """ SI to Customary unit conversion factor.
    Type `float`. """

    decimalPrecision: typing.Optional[int]

    """ Decimal precision of observation quantitative results.
    Type `int`. """




    

     
    



class ObservationDefinitionQualifiedInterval(BackboneElement):
    """ Qualified range for continuous and ordinal observation results.
    
    Multiple  ranges of results qualified by different contexts for ordinal or
    continuous observations conforming to this ObservationDefinition.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='range' >, <FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='appliesTo' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='age' >, <FHIRClassProperty self.name='gestationalAge' >, <FHIRClassProperty self.name='condition' >]
  

    category: typing.Optional["str"]

    """ reference | critical | absolute.
    Type `str`. """

    range: typing.Optional["Range"]

    """ The interval itself, for continuous or ordinal observations.
    Type `Range` (represented as `dict` in JSON). """

    context: typing.Optional["CodeableConcept"]

    """ Range context qualifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    appliesTo: typing.Optional[typing.List["CodeableConcept"]]

    """ Targetted population of the range.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    age: typing.Optional["Range"]

    """ Applicable age range, if relevant.
    Type `Range` (represented as `dict` in JSON). """

    gestationalAge: typing.Optional["Range"]

    """ Applicable gestational age range, if relevant.
    Type `Range` (represented as `dict` in JSON). """

    condition: typing.Optional[str]

    """ Condition associated with the reference range.
    Type `str`. """




    

     
    



class OperationDefinitionParameter(BackboneElement):
    """ Parameters for the operation/query.
    
    The parameters for the operation/query.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='targetProfile' >, <FHIRClassProperty self.name='searchType' >, <FHIRClassProperty self.name='binding' >, <FHIRClassProperty self.name='referencedFrom' >, <FHIRClassProperty self.name='part' >]
  

    name: str

    """ Name in Parameters.parameter.name or in URL.
    Type `str`. """

    use: "str"

    """ in | out.
    Type `str`. """

    min: int

    """ Minimum Cardinality.
    Type `int`. """

    max: str

    """ Maximum Cardinality (a number or *).
    Type `str`. """

    documentation: typing.Optional[str]

    """ Description of meaning/use.
    Type `str`. """

    type: typing.Optional[str]

    """ What type this parameter has.
    Type `str`. """

    targetProfile: typing.Optional[typing.List[str]]

    """ If type is Reference | canonical, allowed targets.
    List of `str` items. """

    searchType: typing.Optional["str"]

    """ number | date | string | token | reference | composite | quantity |
        uri | special.
    Type `str`. """

    binding: typing.Optional["OperationDefinitionParameterBinding"]

    """ ValueSet details if this is coded.
    Type `OperationDefinitionParameterBinding` (represented as `dict` in JSON). """

    referencedFrom: typing.Optional[typing.List["OperationDefinitionParameterReferencedFrom"]]

    """ References to this parameter.
    List of `OperationDefinitionParameterReferencedFrom` items (represented as `dict` in JSON). """

    part: typing.Optional[typing.List["OperationDefinitionParameter"]]

    """ Parts of a nested Parameter.
    List of `OperationDefinitionParameter` items (represented as `dict` in JSON). """




    

     
    



class OperationDefinitionParameterBinding(BackboneElement):
    """ ValueSet details if this is coded.
    
    Binds to a value set if this parameter is coded (code, Coding,
    CodeableConcept).
    """
    
    # [<FHIRClassProperty self.name='strength' >, <FHIRClassProperty self.name='valueSet' >]
  

    strength: "str"

    """ required | extensible | preferred | example.
    Type `str`. """

    valueSet: str

    """ Source of value set.
    Type `str`. """




    

     
    



class OperationDefinitionParameterReferencedFrom(BackboneElement):
    """ References to this parameter.
    
    Identifies other resource parameters within the operation invocation that
    are expected to resolve to this resource.
    """
    
    # [<FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='sourceId' >]
  

    source: str

    """ Referencing parameter.
    Type `str`. """

    sourceId: typing.Optional[str]

    """ Element id of reference.
    Type `str`. """




    

     
    



class OperationDefinitionOverload(BackboneElement):
    """ Define overloaded variants for when  generating code.
    
    Defines an appropriate combination of parameters to use when invoking this
    operation, to help code generators when generating overloaded parameter
    sets for this operation.
    """
    
    # [<FHIRClassProperty self.name='parameterName' >, <FHIRClassProperty self.name='comment' >]
  

    parameterName: typing.Optional[typing.List[str]]

    """ Name of parameter to include in overload.
    List of `str` items. """

    comment: typing.Optional[str]

    """ Comments to go on overload.
    Type `str`. """




    

     
    



class OperationOutcomeIssue(BackboneElement):
    """ A single issue associated with the action.
    
    An error, warning, or information message that results from a system
    action.
    """
    
    # [<FHIRClassProperty self.name='severity' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='details' >, <FHIRClassProperty self.name='diagnostics' >, <FHIRClassProperty self.name='location' >, <FHIRClassProperty self.name='expression' >]
  

    severity: "str"

    """ fatal | error | warning | information.
    Type `str`. """

    code: "str"

    """ Error or warning code.
    Type `str`. """

    details: typing.Optional["CodeableConcept"]

    """ Additional details about the error.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    diagnostics: typing.Optional[str]

    """ Additional diagnostic information about the issue.
    Type `str`. """

    location: typing.Optional[typing.List[str]]

    """ Deprecated: Path of element(s) related to issue.
    List of `str` items. """

    expression: typing.Optional[typing.List[str]]

    """ FHIRPath of element(s) related to issue.
    List of `str` items. """




    

     
    



class OrganizationContact(BackboneElement):
    """ Contact for the organization for a certain purpose.
    """
    
    # [<FHIRClassProperty self.name='purpose' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >]
  

    purpose: typing.Optional["CodeableConcept"]

    """ The type of contact.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    name: typing.Optional["HumanName"]

    """ A name associated with the contact.
    Type `HumanName` (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ Contact details (telephone, email, etc.)  for a contact.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional["Address"]

    """ Visiting or postal addresses for the contact.
    Type `Address` (represented as `dict` in JSON). """




    

     
    



class ParametersParameter(BackboneElement):
    """ Operation Parameter.
    
    A parameter passed to or received from the operation.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='valueBase64Binary' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueCanonical' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueInstant' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueMarkdown' >, <FHIRClassProperty self.name='valueOid' >, <FHIRClassProperty self.name='valuePositiveInt' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueUnsignedInt' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueUrl' >, <FHIRClassProperty self.name='valueUuid' >, <FHIRClassProperty self.name='valueAddress' >, <FHIRClassProperty self.name='valueAge' >, <FHIRClassProperty self.name='valueAnnotation' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueContactPoint' >, <FHIRClassProperty self.name='valueCount' >, <FHIRClassProperty self.name='valueDistance' >, <FHIRClassProperty self.name='valueDuration' >, <FHIRClassProperty self.name='valueHumanName' >, <FHIRClassProperty self.name='valueIdentifier' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueSignature' >, <FHIRClassProperty self.name='valueTiming' >, <FHIRClassProperty self.name='valueContactDetail' >, <FHIRClassProperty self.name='valueContributor' >, <FHIRClassProperty self.name='valueDataRequirement' >, <FHIRClassProperty self.name='valueExpression' >, <FHIRClassProperty self.name='valueParameterDefinition' >, <FHIRClassProperty self.name='valueRelatedArtifact' >, <FHIRClassProperty self.name='valueTriggerDefinition' >, <FHIRClassProperty self.name='valueUsageContext' >, <FHIRClassProperty self.name='valueDosage' >, <FHIRClassProperty self.name='valueMeta' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='part' >]
  

    name: str

    """ Name from the definition.
    Type `str`. """

    valueBase64Binary: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ If parameter is a data type.
    Type `bool`. """

    valueCanonical: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueDate: typing.Optional["FHIRDate"]

    """ If parameter is a data type.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ If parameter is a data type.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ If parameter is a data type.
    Type `float`. """

    valueId: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueInstant: typing.Optional["FHIRDate"]

    """ If parameter is a data type.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueInteger: typing.Optional[int]

    """ If parameter is a data type.
    Type `int`. """

    valueMarkdown: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueOid: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valuePositiveInt: typing.Optional[int]

    """ If parameter is a data type.
    Type `int`. """

    valueString: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueTime: typing.Optional["FHIRDate"]

    """ If parameter is a data type.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueUnsignedInt: typing.Optional[int]

    """ If parameter is a data type.
    Type `int`. """

    valueUri: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueUrl: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueUuid: typing.Optional[str]

    """ If parameter is a data type.
    Type `str`. """

    valueAddress: typing.Optional["Address"]

    """ If parameter is a data type.
    Type `Address` (represented as `dict` in JSON). """

    valueAge: typing.Optional["Age"]

    """ If parameter is a data type.
    Type `Age` (represented as `dict` in JSON). """

    valueAnnotation: typing.Optional["Annotation"]

    """ If parameter is a data type.
    Type `Annotation` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ If parameter is a data type.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ If parameter is a data type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ If parameter is a data type.
    Type `Coding` (represented as `dict` in JSON). """

    valueContactPoint: typing.Optional["ContactPoint"]

    """ If parameter is a data type.
    Type `ContactPoint` (represented as `dict` in JSON). """

    valueCount: typing.Optional["Count"]

    """ If parameter is a data type.
    Type `Count` (represented as `dict` in JSON). """

    valueDistance: typing.Optional["Distance"]

    """ If parameter is a data type.
    Type `Distance` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ If parameter is a data type.
    Type `Duration` (represented as `dict` in JSON). """

    valueHumanName: typing.Optional["HumanName"]

    """ If parameter is a data type.
    Type `HumanName` (represented as `dict` in JSON). """

    valueIdentifier: typing.Optional["Identifier"]

    """ If parameter is a data type.
    Type `Identifier` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ If parameter is a data type.
    Type `Money` (represented as `dict` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ If parameter is a data type.
    Type `Period` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ If parameter is a data type.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ If parameter is a data type.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ If parameter is a data type.
    Type `Ratio` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ If parameter is a data type.
    Type `Reference` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ If parameter is a data type.
    Type `SampledData` (represented as `dict` in JSON). """

    valueSignature: typing.Optional["Signature"]

    """ If parameter is a data type.
    Type `Signature` (represented as `dict` in JSON). """

    valueTiming: typing.Optional["Timing"]

    """ If parameter is a data type.
    Type `Timing` (represented as `dict` in JSON). """

    valueContactDetail: typing.Optional["ContactDetail"]

    """ If parameter is a data type.
    Type `ContactDetail` (represented as `dict` in JSON). """

    valueContributor: typing.Optional["Contributor"]

    """ If parameter is a data type.
    Type `Contributor` (represented as `dict` in JSON). """

    valueDataRequirement: typing.Optional["DataRequirement"]

    """ If parameter is a data type.
    Type `DataRequirement` (represented as `dict` in JSON). """

    valueExpression: typing.Optional["Expression"]

    """ If parameter is a data type.
    Type `Expression` (represented as `dict` in JSON). """

    valueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ If parameter is a data type.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    valueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ If parameter is a data type.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    valueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ If parameter is a data type.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    valueUsageContext: typing.Optional["UsageContext"]

    """ If parameter is a data type.
    Type `UsageContext` (represented as `dict` in JSON). """

    valueDosage: typing.Optional["Dosage"]

    """ If parameter is a data type.
    Type `Dosage` (represented as `dict` in JSON). """

    valueMeta: typing.Optional["Meta"]

    """ If parameter is a data type.
    Type `Meta` (represented as `dict` in JSON). """

    resource: typing.Optional["Resource"]

    """ If parameter is a whole resource.
    Type `Resource` (represented as `dict` in JSON). """

    part: typing.Optional[typing.List["ParametersParameter"]]

    """ Named part of a multi-part parameter.
    List of `ParametersParameter` items (represented as `dict` in JSON). """



#   {'path': 'Parameters.parameter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBase64Binary', 'name': 'valueBase64Binary', 'parent_name': 'Parameters.parameter', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'If parameter is a data type', 'formal': 'If the parameter is a data type.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBase64Binary', 'valueBoolean', 'valueCanonical', 'valueCode', 'valueDate', 'valueDateTime', 'valueDecimal', 'valueId', 'valueInstant', 'valueInteger', 'valueMarkdown', 'valueOid', 'valuePositiveInt', 'valueString', 'valueTime', 'valueUnsignedInt', 'valueUri', 'valueUrl', 'valueUuid', 'valueAddress', 'valueAge', 'valueAnnotation', 'valueAttachment', 'valueCodeableConcept', 'valueCoding', 'valueContactPoint', 'valueCount', 'valueDistance', 'valueDuration', 'valueHumanName', 'valueIdentifier', 'valueMoney', 'valuePeriod', 'valueQuantity', 'valueRange', 'valueRatio', 'valueReference', 'valueSampledData', 'valueSignature', 'valueTiming', 'valueContactDetail', 'valueContributor', 'valueDataRequirement', 'valueExpression', 'valueParameterDefinition', 'valueRelatedArtifact', 'valueTriggerDefinition', 'valueUsageContext', 'valueDosage', 'valueMeta']), True))


    

     
    



class PatientContact(BackboneElement):
    """ A contact party (e.g. guardian, partner, friend) for the patient.
    """
    
    # [<FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='telecom' >, <FHIRClassProperty self.name='address' >, <FHIRClassProperty self.name='gender' >, <FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='period' >]
  

    relationship: typing.Optional[typing.List["CodeableConcept"]]

    """ The kind of relationship.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    name: typing.Optional["HumanName"]

    """ A name associated with the contact person.
    Type `HumanName` (represented as `dict` in JSON). """

    telecom: typing.Optional[typing.List["ContactPoint"]]

    """ A contact detail for the person.
    List of `ContactPoint` items (represented as `dict` in JSON). """

    address: typing.Optional["Address"]

    """ Address for the contact person.
    Type `Address` (represented as `dict` in JSON). """

    gender: typing.Optional["str"]

    """ male | female | other | unknown.
    Type `str`. """

    organization: typing.Optional["Reference"]

    """ Organization that is associated with the contact.
    Type `Reference` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ The period during which this contact person or organization is
        valid to be contacted relating to this patient.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class PatientCommunication(BackboneElement):
    """ A language which may be used to communicate with the patient about his or
    her health.
    """
    
    # [<FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='preferred' >]
  

    language: "CodeableConcept"

    """ The language which can be used to communicate with the patient
        about his or her health.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    preferred: typing.Optional[bool]

    """ Language preference indicator.
    Type `bool`. """




    

     
    



class PatientLink(BackboneElement):
    """ Link to another patient resource that concerns the same actual person.
    
    Link to another patient resource that concerns the same actual patient.
    """
    
    # [<FHIRClassProperty self.name='other' >, <FHIRClassProperty self.name='type' >]
  

    other: "Reference"

    """ The other patient or related person resource that the link refers
        to.
    Type `Reference` (represented as `dict` in JSON). """

    type: "str"

    """ replaced-by | replaces | refer | seealso.
    Type `str`. """




    

     
    



class PaymentReconciliationDetail(BackboneElement):
    """ Settlement particulars.
    
    Distribution of the payment amount for a previously acknowledged payable.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='predecessor' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='request' >, <FHIRClassProperty self.name='submitter' >, <FHIRClassProperty self.name='response' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='responsible' >, <FHIRClassProperty self.name='payee' >, <FHIRClassProperty self.name='amount' >]
  

    identifier: typing.Optional["Identifier"]

    """ Business identifier of the payment detail.
    Type `Identifier` (represented as `dict` in JSON). """

    predecessor: typing.Optional["Identifier"]

    """ Business identifier of the prior payment detail.
    Type `Identifier` (represented as `dict` in JSON). """

    type: "CodeableConcept"

    """ Category of payment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    request: typing.Optional["Reference"]

    """ Request giving rise to the payment.
    Type `Reference` (represented as `dict` in JSON). """

    submitter: typing.Optional["Reference"]

    """ Submitter of the request.
    Type `Reference` (represented as `dict` in JSON). """

    response: typing.Optional["Reference"]

    """ Response committing to a payment.
    Type `Reference` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date of commitment to pay.
    Type `FHIRDate` (represented as `str` in JSON). """

    responsible: typing.Optional["Reference"]

    """ Contact for the response.
    Type `Reference` (represented as `dict` in JSON). """

    payee: typing.Optional["Reference"]

    """ Recipient of the payment.
    Type `Reference` (represented as `dict` in JSON). """

    amount: typing.Optional["Money"]

    """ Amount allocated to this payable.
    Type `Money` (represented as `dict` in JSON). """




    

     
    



class PaymentReconciliationProcessNote(BackboneElement):
    """ Note concerning processing.
    
    A note that describes or explains the processing in a human readable form.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='text' >]
  

    type: typing.Optional["str"]

    """ display | print | printoper.
    Type `str`. """

    text: typing.Optional[str]

    """ Note explanatory text.
    Type `str`. """




    

     
    



class PersonLink(BackboneElement):
    """ Link to a resource that concerns the same actual person.
    """
    
    # [<FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='assurance' >]
  

    target: "Reference"

    """ The resource to which this actual person is associated.
    Type `Reference` (represented as `dict` in JSON). """

    assurance: typing.Optional["str"]

    """ level1 | level2 | level3 | level4.
    Type `str`. """




    

     
    



class PlanDefinitionGoal(BackboneElement):
    """ What the plan is trying to accomplish.
    
    Goals that describe what the activities within the plan are intended to
    achieve. For example, weight loss, restoring an activity of daily living,
    obtaining herd immunity via immunization, meeting a process improvement
    objective, etc.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='start' >, <FHIRClassProperty self.name='addresses' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='target' >]
  

    category: typing.Optional["CodeableConcept"]

    """ E.g. Treatment, dietary, behavioral.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: "CodeableConcept"

    """ Code or text describing the goal.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    priority: typing.Optional["CodeableConcept"]

    """ high-priority | medium-priority | low-priority.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    start: typing.Optional["CodeableConcept"]

    """ When goal pursuit begins.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    addresses: typing.Optional[typing.List["CodeableConcept"]]

    """ What does the goal address.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    documentation: typing.Optional[typing.List["RelatedArtifact"]]

    """ Supporting documentation for the goal.
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    target: typing.Optional[typing.List["PlanDefinitionGoalTarget"]]

    """ Target outcome for the goal.
    List of `PlanDefinitionGoalTarget` items (represented as `dict` in JSON). """




    

     
    



class PlanDefinitionGoalTarget(BackboneElement):
    """ Target outcome for the goal.
    
    Indicates what should be done and within what timeframe.
    """
    
    # [<FHIRClassProperty self.name='measure' >, <FHIRClassProperty self.name='detailQuantity' >, <FHIRClassProperty self.name='detailRange' >, <FHIRClassProperty self.name='detailCodeableConcept' >, <FHIRClassProperty self.name='due' >]
  

    measure: typing.Optional["CodeableConcept"]

    """ The parameter whose value is to be tracked.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    detailQuantity: typing.Optional["Quantity"]

    """ The target value to be achieved.
    Type `Quantity` (represented as `dict` in JSON). """

    detailRange: typing.Optional["Range"]

    """ The target value to be achieved.
    Type `Range` (represented as `dict` in JSON). """

    detailCodeableConcept: typing.Optional["CodeableConcept"]

    """ The target value to be achieved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    due: typing.Optional["Duration"]

    """ Reach goal within.
    Type `Duration` (represented as `dict` in JSON). """



#   {'path': 'PlanDefinition.goal.target.detail[x]', 'choice_of_type': 'detail', 'orig_name': 'detailQuantity', 'name': 'detailQuantity', 'parent_name': 'PlanDefinition.goal.target', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'The target value to be achieved', 'formal': 'The target value of the measure to be achieved to signify fulfillment of the goal, e.g. 150 pounds or 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any value at or above the low value.', 'representation': None}

    _detail_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['detailQuantity', 'detailRange', 'detailCodeableConcept']), True))


    

     
    



class PlanDefinitionAction(BackboneElement):
    """ Action defined by the plan.
    
    An action or group of actions to be taken as part of the plan.
    """
    
    # [<FHIRClassProperty self.name='prefix' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='textEquivalent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='reason' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='goalId' >, <FHIRClassProperty self.name='subjectCodeableConcept' >, <FHIRClassProperty self.name='subjectReference' >, <FHIRClassProperty self.name='trigger' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='input' >, <FHIRClassProperty self.name='output' >, <FHIRClassProperty self.name='relatedAction' >, <FHIRClassProperty self.name='timingDateTime' >, <FHIRClassProperty self.name='timingAge' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='timingDuration' >, <FHIRClassProperty self.name='timingRange' >, <FHIRClassProperty self.name='timingTiming' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='groupingBehavior' >, <FHIRClassProperty self.name='selectionBehavior' >, <FHIRClassProperty self.name='requiredBehavior' >, <FHIRClassProperty self.name='precheckBehavior' >, <FHIRClassProperty self.name='cardinalityBehavior' >, <FHIRClassProperty self.name='definitionCanonical' >, <FHIRClassProperty self.name='definitionUri' >, <FHIRClassProperty self.name='transform' >, <FHIRClassProperty self.name='dynamicValue' >, <FHIRClassProperty self.name='action' >]
  

    prefix: typing.Optional[str]

    """ User-visible prefix for the action (e.g. 1. or A.).
    Type `str`. """

    title: typing.Optional[str]

    """ User-visible title.
    Type `str`. """

    description: typing.Optional[str]

    """ Brief description of the action.
    Type `str`. """

    textEquivalent: typing.Optional[str]

    """ Static text equivalent of the action, used if the dynamic aspects
        cannot be interpreted by the receiving system.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Code representing the meaning of the action or sub-actions.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    reason: typing.Optional[typing.List["CodeableConcept"]]

    """ Why the action should be performed.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    documentation: typing.Optional[typing.List["RelatedArtifact"]]

    """ Supporting documentation for the intended performer of the action.
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    goalId: typing.Optional[typing.List[str]]

    """ What goals this action supports.
    List of `str` items. """

    subjectCodeableConcept: typing.Optional["CodeableConcept"]

    """ Type of individual the action is focused on.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subjectReference: typing.Optional["Reference"]

    """ Type of individual the action is focused on.
    Type `Reference` (represented as `dict` in JSON). """

    trigger: typing.Optional[typing.List["TriggerDefinition"]]

    """ When the action should be triggered.
    List of `TriggerDefinition` items (represented as `dict` in JSON). """

    condition: typing.Optional[typing.List["PlanDefinitionActionCondition"]]

    """ Whether or not the action is applicable.
    List of `PlanDefinitionActionCondition` items (represented as `dict` in JSON). """

    input: typing.Optional[typing.List["DataRequirement"]]

    """ Input data requirements.
    List of `DataRequirement` items (represented as `dict` in JSON). """

    output: typing.Optional[typing.List["DataRequirement"]]

    """ Output data definition.
    List of `DataRequirement` items (represented as `dict` in JSON). """

    relatedAction: typing.Optional[typing.List["PlanDefinitionActionRelatedAction"]]

    """ Relationship to another action.
    List of `PlanDefinitionActionRelatedAction` items (represented as `dict` in JSON). """

    timingDateTime: typing.Optional["FHIRDate"]

    """ When the action should take place.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingAge: typing.Optional["Age"]

    """ When the action should take place.
    Type `Age` (represented as `dict` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ When the action should take place.
    Type `Period` (represented as `dict` in JSON). """

    timingDuration: typing.Optional["Duration"]

    """ When the action should take place.
    Type `Duration` (represented as `dict` in JSON). """

    timingRange: typing.Optional["Range"]

    """ When the action should take place.
    Type `Range` (represented as `dict` in JSON). """

    timingTiming: typing.Optional["Timing"]

    """ When the action should take place.
    Type `Timing` (represented as `dict` in JSON). """

    participant: typing.Optional[typing.List["PlanDefinitionActionParticipant"]]

    """ Who should participate in the action.
    List of `PlanDefinitionActionParticipant` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ create | update | remove | fire-event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    groupingBehavior: typing.Optional["str"]

    """ visual-group | logical-group | sentence-group.
    Type `str`. """

    selectionBehavior: typing.Optional["str"]

    """ any | all | all-or-none | exactly-one | at-most-one | one-or-more.
    Type `str`. """

    requiredBehavior: typing.Optional["str"]

    """ must | could | must-unless-documented.
    Type `str`. """

    precheckBehavior: typing.Optional["str"]

    """ yes | no.
    Type `str`. """

    cardinalityBehavior: typing.Optional["str"]

    """ single | multiple.
    Type `str`. """

    definitionCanonical: typing.Optional[str]

    """ Description of the activity to be performed.
    Type `str`. """

    definitionUri: typing.Optional[str]

    """ Description of the activity to be performed.
    Type `str`. """

    transform: typing.Optional[str]

    """ Transform to apply the template.
    Type `str`. """

    dynamicValue: typing.Optional[typing.List["PlanDefinitionActionDynamicValue"]]

    """ Dynamic aspects of the definition.
    List of `PlanDefinitionActionDynamicValue` items (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["PlanDefinitionAction"]]

    """ A sub-action.
    List of `PlanDefinitionAction` items (represented as `dict` in JSON). """



#   {'path': 'PlanDefinition.action.subject[x]', 'choice_of_type': 'subject', 'orig_name': 'subjectCodeableConcept', 'name': 'subjectCodeableConcept', 'parent_name': 'PlanDefinition.action', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Type of individual the action is focused on', 'formal': 'A code or group definition that describes the intended subject of the action and its children, if any.', 'representation': None}

    _subject_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['subjectCodeableConcept', 'subjectReference']), True))

#   {'path': 'PlanDefinition.action.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingDateTime', 'name': 'timingDateTime', 'parent_name': 'PlanDefinition.action', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the action should take place', 'formal': 'An optional value describing when the action should be performed.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingDateTime', 'timingAge', 'timingPeriod', 'timingDuration', 'timingRange', 'timingTiming']), True))

#   {'path': 'PlanDefinition.action.definition[x]', 'choice_of_type': 'definition', 'orig_name': 'definitionCanonical', 'name': 'definitionCanonical', 'parent_name': 'PlanDefinition.action', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Description of the activity to be performed', 'formal': 'A reference to an ActivityDefinition that describes the action to be taken in detail, or a PlanDefinition that describes a series of actions to be taken.', 'representation': None}

    _definition_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['definitionCanonical', 'definitionUri']), True))


    

     
    



class PlanDefinitionActionCondition(BackboneElement):
    """ Whether or not the action is applicable.
    
    An expression that describes applicability criteria or start/stop
    conditions for the action.
    """
    
    # [<FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='expression' >]
  

    kind: "str"

    """ applicability | start | stop.
    Type `str`. """

    expression: typing.Optional["Expression"]

    """ Boolean-valued expression.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class PlanDefinitionActionRelatedAction(BackboneElement):
    """ Relationship to another action.
    
    A relationship to another action such as "before" or "30-60 minutes after
    start of".
    """
    
    # [<FHIRClassProperty self.name='actionId' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='offsetDuration' >, <FHIRClassProperty self.name='offsetRange' >]
  

    actionId: str

    """ What action is this related to.
    Type `str`. """

    relationship: "str"

    """ before-start | before | before-end | concurrent-with-start |
        concurrent | concurrent-with-end | after-start | after | after-end.
    Type `str`. """

    offsetDuration: typing.Optional["Duration"]

    """ Time offset for the relationship.
    Type `Duration` (represented as `dict` in JSON). """

    offsetRange: typing.Optional["Range"]

    """ Time offset for the relationship.
    Type `Range` (represented as `dict` in JSON). """



#   {'path': 'PlanDefinition.action.relatedAction.offset[x]', 'choice_of_type': 'offset', 'orig_name': 'offsetDuration', 'name': 'offsetDuration', 'parent_name': 'PlanDefinition.action.relatedAction', 'class_name': 'Duration', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time offset for the relationship', 'formal': 'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.', 'representation': None}

    _offset_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['offsetDuration', 'offsetRange']), True))


    

     
    



class PlanDefinitionActionParticipant(BackboneElement):
    """ Who should participate in the action.
    
    Indicates who should participate in performing the action described.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='role' >]
  

    type: "str"

    """ patient | practitioner | related-person | device.
    Type `str`. """

    role: typing.Optional["CodeableConcept"]

    """ E.g. Nurse, Surgeon, Parent.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class PlanDefinitionActionDynamicValue(BackboneElement):
    """ Dynamic aspects of the definition.
    
    Customizations that should be applied to the statically defined resource.
    For example, if the dosage of a medication must be computed based on the
    patient's weight, a customization would be used to specify an expression
    that calculated the weight, and the path on the resource that would contain
    the result.
    """
    
    # [<FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='expression' >]
  

    path: typing.Optional[str]

    """ The path to the element to be set dynamically.
    Type `str`. """

    expression: typing.Optional["Expression"]

    """ An expression that provides the dynamic value for the customization.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class PractitionerQualification(BackboneElement):
    """ Certification, licenses, or training pertaining to the provision of care.
    
    The official certifications, training, and licenses that authorize or
    otherwise pertain to the provision of care by the practitioner.  For
    example, a medical license issued by a medical board authorizing the
    practitioner to practice medicine within a certian locality.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='issuer' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ An identifier for this qualification for the practitioner.
    List of `Identifier` items (represented as `dict` in JSON). """

    code: "CodeableConcept"

    """ Coded representation of the qualification.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    period: typing.Optional["Period"]

    """ Period during which the qualification is valid.
    Type `Period` (represented as `dict` in JSON). """

    issuer: typing.Optional["Reference"]

    """ Organization that regulates and issues the qualification.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class PractitionerRoleAvailableTime(BackboneElement):
    """ Times the Service Site is available.
    
    A collection of times the practitioner is available or performing this role
    at the location and/or healthcareservice.
    """
    
    # [<FHIRClassProperty self.name='daysOfWeek' >, <FHIRClassProperty self.name='allDay' >, <FHIRClassProperty self.name='availableStartTime' >, <FHIRClassProperty self.name='availableEndTime' >]
  

    daysOfWeek: typing.Optional[typing.List["str"]]

    """ mon | tue | wed | thu | fri | sat | sun.
    List of `str` items. """

    allDay: typing.Optional[bool]

    """ Always available? e.g. 24 hour service.
    Type `bool`. """

    availableStartTime: typing.Optional["FHIRDate"]

    """ Opening time of day (ignored if allDay = true).
    Type `FHIRDate` (represented as `str` in JSON). """

    availableEndTime: typing.Optional["FHIRDate"]

    """ Closing time of day (ignored if allDay = true).
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class PractitionerRoleNotAvailable(BackboneElement):
    """ Not available during this time due to provided reason.
    
    The practitioner is not available or performing this role during this
    period of time due to the provided reason.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='during' >]
  

    description: str

    """ Reason presented to the user explaining why time not available.
    Type `str`. """

    during: typing.Optional["Period"]

    """ Service not available from this date.
    Type `Period` (represented as `dict` in JSON). """




    

     
    



class ProcedurePerformer(BackboneElement):
    """ The people who performed the procedure.
    
    Limited to "real" people rather than equipment.
    """
    
    # [<FHIRClassProperty self.name='function' >, <FHIRClassProperty self.name='actor' >, <FHIRClassProperty self.name='onBehalfOf' >]
  

    function: typing.Optional["CodeableConcept"]

    """ Type of performance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    actor: "Reference"

    """ The reference to the practitioner.
    Type `Reference` (represented as `dict` in JSON). """

    onBehalfOf: typing.Optional["Reference"]

    """ Organization the device or practitioner was acting for.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ProcedureFocalDevice(BackboneElement):
    """ Manipulated, implanted, or removed device.
    
    A device that is implanted, removed or otherwise manipulated (calibration,
    battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as
    a focal portion of the Procedure.
    """
    
    # [<FHIRClassProperty self.name='action' >, <FHIRClassProperty self.name='manipulated' >]
  

    action: typing.Optional["CodeableConcept"]

    """ Kind of change to device.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    manipulated: "Reference"

    """ Device that was changed.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ProvenanceAgent(BackboneElement):
    """ Actor involved.
    
    An actor taking a role in an activity  for which it can be assigned some
    degree of responsibility for the activity taking place.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='who' >, <FHIRClassProperty self.name='onBehalfOf' >]
  

    type: typing.Optional["CodeableConcept"]

    """ How the agent participated.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    role: typing.Optional[typing.List["CodeableConcept"]]

    """ What the agents role was.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    who: "Reference"

    """ Who participated.
    Type `Reference` (represented as `dict` in JSON). """

    onBehalfOf: typing.Optional["Reference"]

    """ Who the agent is representing.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class ProvenanceEntity(BackboneElement):
    """ An entity used in this activity.
    """
    
    # [<FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='what' >, <FHIRClassProperty self.name='agent' >]
  

    role: "str"

    """ derivation | revision | quotation | source | removal.
    Type `str`. """

    what: "Reference"

    """ Identity of entity.
    Type `Reference` (represented as `dict` in JSON). """

    agent: typing.Optional[typing.List["ProvenanceAgent"]]

    """ Entity is attributed to this agent.
    List of `ProvenanceAgent` items (represented as `dict` in JSON). """




    

     
    



class QuestionnaireItem(BackboneElement):
    """ Questions and sections within the Questionnaire.
    
    A particular question, question grouping or display text that is part of
    the questionnaire.
    """
    
    # [<FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='prefix' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='enableWhen' >, <FHIRClassProperty self.name='enableBehavior' >, <FHIRClassProperty self.name='required' >, <FHIRClassProperty self.name='repeats' >, <FHIRClassProperty self.name='readOnly' >, <FHIRClassProperty self.name='maxLength' >, <FHIRClassProperty self.name='answerValueSet' >, <FHIRClassProperty self.name='answerOption' >, <FHIRClassProperty self.name='initial' >, <FHIRClassProperty self.name='item' >]
  

    linkId: str

    """ Unique id for item in questionnaire.
    Type `str`. """

    definition: typing.Optional[str]

    """ ElementDefinition - details for the item.
    Type `str`. """

    code: typing.Optional[typing.List["Coding"]]

    """ Corresponding concept for this item in a terminology.
    List of `Coding` items (represented as `dict` in JSON). """

    prefix: typing.Optional[str]

    """ E.g. "1(a)", "2.5.3".
    Type `str`. """

    text: typing.Optional[str]

    """ Primary text for the item.
    Type `str`. """

    type: "str"

    """ group | display | boolean | decimal | integer | date | dateTime +.
    Type `str`. """

    enableWhen: typing.Optional[typing.List["QuestionnaireItemEnableWhen"]]

    """ Only allow data when.
    List of `QuestionnaireItemEnableWhen` items (represented as `dict` in JSON). """

    enableBehavior: typing.Optional["str"]

    """ all | any.
    Type `str`. """

    required: typing.Optional[bool]

    """ Whether the item must be included in data results.
    Type `bool`. """

    repeats: typing.Optional[bool]

    """ Whether the item may repeat.
    Type `bool`. """

    readOnly: typing.Optional[bool]

    """ Don't allow human editing.
    Type `bool`. """

    maxLength: typing.Optional[int]

    """ No more than this many characters.
    Type `int`. """

    answerValueSet: typing.Optional[str]

    """ Valueset containing permitted answers.
    Type `str`. """

    answerOption: typing.Optional[typing.List["QuestionnaireItemAnswerOption"]]

    """ Permitted answer.
    List of `QuestionnaireItemAnswerOption` items (represented as `dict` in JSON). """

    initial: typing.Optional[typing.List["QuestionnaireItemInitial"]]

    """ Initial value(s) when item is first rendered.
    List of `QuestionnaireItemInitial` items (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["QuestionnaireItem"]]

    """ Nested questionnaire items.
    List of `QuestionnaireItem` items (represented as `dict` in JSON). """




    

     
    



class QuestionnaireItemEnableWhen(BackboneElement):
    """ Only allow data when.
    
    A constraint indicating that this item should only be enabled
    (displayed/allow answers to be captured) when the specified condition is
    true.
    """
    
    # [<FHIRClassProperty self.name='question' >, <FHIRClassProperty self.name='operator' >, <FHIRClassProperty self.name='answerBoolean' >, <FHIRClassProperty self.name='answerDecimal' >, <FHIRClassProperty self.name='answerInteger' >, <FHIRClassProperty self.name='answerDate' >, <FHIRClassProperty self.name='answerDateTime' >, <FHIRClassProperty self.name='answerTime' >, <FHIRClassProperty self.name='answerString' >, <FHIRClassProperty self.name='answerCoding' >, <FHIRClassProperty self.name='answerQuantity' >, <FHIRClassProperty self.name='answerReference' >]
  

    question: str

    """ Question that determines whether item is enabled.
    Type `str`. """

    operator: "str"

    """ exists | = | != | > | < | >= | <=.
    Type `str`. """

    answerBoolean: typing.Optional[bool]

    """ Value for question comparison based on operator.
    Type `bool`. """

    answerDecimal: typing.Optional[float]

    """ Value for question comparison based on operator.
    Type `float`. """

    answerInteger: typing.Optional[int]

    """ Value for question comparison based on operator.
    Type `int`. """

    answerDate: typing.Optional["FHIRDate"]

    """ Value for question comparison based on operator.
    Type `FHIRDate` (represented as `str` in JSON). """

    answerDateTime: typing.Optional["FHIRDate"]

    """ Value for question comparison based on operator.
    Type `FHIRDate` (represented as `str` in JSON). """

    answerTime: typing.Optional["FHIRDate"]

    """ Value for question comparison based on operator.
    Type `FHIRDate` (represented as `str` in JSON). """

    answerString: typing.Optional[str]

    """ Value for question comparison based on operator.
    Type `str`. """

    answerCoding: typing.Optional["Coding"]

    """ Value for question comparison based on operator.
    Type `Coding` (represented as `dict` in JSON). """

    answerQuantity: typing.Optional["Quantity"]

    """ Value for question comparison based on operator.
    Type `Quantity` (represented as `dict` in JSON). """

    answerReference: typing.Optional["Reference"]

    """ Value for question comparison based on operator.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Questionnaire.item.enableWhen.answer[x]', 'choice_of_type': 'answer', 'orig_name': 'answerBoolean', 'name': 'answerBoolean', 'parent_name': 'Questionnaire.item.enableWhen', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Value for question comparison based on operator', 'formal': 'A value that the referenced question is tested using the specified operator in order for the item to be enabled.', 'representation': None}

    _answer_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['answerBoolean', 'answerDecimal', 'answerInteger', 'answerDate', 'answerDateTime', 'answerTime', 'answerString', 'answerCoding', 'answerQuantity', 'answerReference']), False))


    

     
    



class QuestionnaireItemAnswerOption(BackboneElement):
    """ Permitted answer.
    
    One of the permitted answers for a "choice" or "open-choice" question.
    """
    
    # [<FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='initialSelected' >]
  

    valueInteger: typing.Optional[int]

    """ Answer value.
    Type `int`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Answer value.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ Answer value.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueString: typing.Optional[str]

    """ Answer value.
    Type `str`. """

    valueCoding: typing.Optional["Coding"]

    """ Answer value.
    Type `Coding` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Answer value.
    Type `Reference` (represented as `dict` in JSON). """

    initialSelected: typing.Optional[bool]

    """ Whether option is selected by default.
    Type `bool`. """



#   {'path': 'Questionnaire.item.answerOption.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueInteger', 'name': 'valueInteger', 'parent_name': 'Questionnaire.item.answerOption', 'class_name': 'int', 'enum': None, 'module_name': None, 'json_class': 'int', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Answer value', 'formal': "A potential answer that's allowed as the answer to this question.", 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueInteger', 'valueDate', 'valueTime', 'valueString', 'valueCoding', 'valueReference']), False))


    

     
    



class QuestionnaireItemInitial(BackboneElement):
    """ Initial value(s) when item is first rendered.
    
    One or more values that should be pre-populated in the answer when
    initially rendering the questionnaire for user input.
    """
    
    # [<FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueReference' >]
  

    valueBoolean: typing.Optional[bool]

    """ Actual value for initializing the question.
    Type `bool`. """

    valueDecimal: typing.Optional[float]

    """ Actual value for initializing the question.
    Type `float`. """

    valueInteger: typing.Optional[int]

    """ Actual value for initializing the question.
    Type `int`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Actual value for initializing the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Actual value for initializing the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ Actual value for initializing the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueString: typing.Optional[str]

    """ Actual value for initializing the question.
    Type `str`. """

    valueUri: typing.Optional[str]

    """ Actual value for initializing the question.
    Type `str`. """

    valueAttachment: typing.Optional["Attachment"]

    """ Actual value for initializing the question.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Actual value for initializing the question.
    Type `Coding` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Actual value for initializing the question.
    Type `Quantity` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Actual value for initializing the question.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Questionnaire.item.initial.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBoolean', 'name': 'valueBoolean', 'parent_name': 'Questionnaire.item.initial', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Actual value for initializing the question', 'formal': 'The actual value to for an initial answer.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBoolean', 'valueDecimal', 'valueInteger', 'valueDate', 'valueDateTime', 'valueTime', 'valueString', 'valueUri', 'valueAttachment', 'valueCoding', 'valueQuantity', 'valueReference']), False))


    

     
    



class QuestionnaireResponseItem(BackboneElement):
    """ Groups and questions.
    
    A group or question item from the original questionnaire for which answers
    are provided.
    """
    
    # [<FHIRClassProperty self.name='linkId' >, <FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='text' >, <FHIRClassProperty self.name='answer' >, <FHIRClassProperty self.name='item' >]
  

    linkId: str

    """ Pointer to specific item from Questionnaire.
    Type `str`. """

    definition: typing.Optional[str]

    """ ElementDefinition - details for the item.
    Type `str`. """

    text: typing.Optional[str]

    """ Name for group or question text.
    Type `str`. """

    answer: typing.Optional[typing.List["QuestionnaireResponseItemAnswer"]]

    """ The response(s) to the question.
    List of `QuestionnaireResponseItemAnswer` items (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["QuestionnaireResponseItem"]]

    """ Nested questionnaire response items.
    List of `QuestionnaireResponseItem` items (represented as `dict` in JSON). """




    

     
    



class QuestionnaireResponseItemAnswer(BackboneElement):
    """ The response(s) to the question.
    
    The respondent's answer(s) to the question.
    """
    
    # [<FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='item' >]
  

    valueBoolean: typing.Optional[bool]

    """ Single-valued answer to the question.
    Type `bool`. """

    valueDecimal: typing.Optional[float]

    """ Single-valued answer to the question.
    Type `float`. """

    valueInteger: typing.Optional[int]

    """ Single-valued answer to the question.
    Type `int`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Single-valued answer to the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Single-valued answer to the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueTime: typing.Optional["FHIRDate"]

    """ Single-valued answer to the question.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueString: typing.Optional[str]

    """ Single-valued answer to the question.
    Type `str`. """

    valueUri: typing.Optional[str]

    """ Single-valued answer to the question.
    Type `str`. """

    valueAttachment: typing.Optional["Attachment"]

    """ Single-valued answer to the question.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Single-valued answer to the question.
    Type `Coding` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Single-valued answer to the question.
    Type `Quantity` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Single-valued answer to the question.
    Type `Reference` (represented as `dict` in JSON). """

    item: typing.Optional[typing.List["QuestionnaireResponseItem"]]

    """ Nested groups and questions.
    List of `QuestionnaireResponseItem` items (represented as `dict` in JSON). """



#   {'path': 'QuestionnaireResponse.item.answer.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBoolean', 'name': 'valueBoolean', 'parent_name': 'QuestionnaireResponse.item.answer', 'class_name': 'bool', 'enum': None, 'module_name': None, 'json_class': 'bool', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Single-valued answer to the question', 'formal': 'The answer (or one of the answers) provided by the respondent to the question.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBoolean', 'valueDecimal', 'valueInteger', 'valueDate', 'valueDateTime', 'valueTime', 'valueString', 'valueUri', 'valueAttachment', 'valueCoding', 'valueQuantity', 'valueReference']), True))


    

     
    



class RelatedPersonCommunication(BackboneElement):
    """ A language which may be used to communicate with about the patient's health.
    """
    
    # [<FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='preferred' >]
  

    language: "CodeableConcept"

    """ The language which can be used to communicate with the patient
        about his or her health.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    preferred: typing.Optional[bool]

    """ Language preference indicator.
    Type `bool`. """




    

     
    



class RequestGroupAction(BackboneElement):
    """ Proposed actions, if any.
    
    The actions, if any, produced by the evaluation of the artifact.
    """
    
    # [<FHIRClassProperty self.name='prefix' >, <FHIRClassProperty self.name='title' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='textEquivalent' >, <FHIRClassProperty self.name='priority' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='relatedAction' >, <FHIRClassProperty self.name='timingDateTime' >, <FHIRClassProperty self.name='timingAge' >, <FHIRClassProperty self.name='timingPeriod' >, <FHIRClassProperty self.name='timingDuration' >, <FHIRClassProperty self.name='timingRange' >, <FHIRClassProperty self.name='timingTiming' >, <FHIRClassProperty self.name='participant' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='groupingBehavior' >, <FHIRClassProperty self.name='selectionBehavior' >, <FHIRClassProperty self.name='requiredBehavior' >, <FHIRClassProperty self.name='precheckBehavior' >, <FHIRClassProperty self.name='cardinalityBehavior' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='action' >]
  

    prefix: typing.Optional[str]

    """ User-visible prefix for the action (e.g. 1. or A.).
    Type `str`. """

    title: typing.Optional[str]

    """ User-visible title.
    Type `str`. """

    description: typing.Optional[str]

    """ Short description of the action.
    Type `str`. """

    textEquivalent: typing.Optional[str]

    """ Static text equivalent of the action, used if the dynamic aspects
        cannot be interpreted by the receiving system.
    Type `str`. """

    priority: typing.Optional["str"]

    """ routine | urgent | asap | stat.
    Type `str`. """

    code: typing.Optional[typing.List["CodeableConcept"]]

    """ Code representing the meaning of the action or sub-actions.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    documentation: typing.Optional[typing.List["RelatedArtifact"]]

    """ Supporting documentation for the intended performer of the action.
    List of `RelatedArtifact` items (represented as `dict` in JSON). """

    condition: typing.Optional[typing.List["RequestGroupActionCondition"]]

    """ Whether or not the action is applicable.
    List of `RequestGroupActionCondition` items (represented as `dict` in JSON). """

    relatedAction: typing.Optional[typing.List["RequestGroupActionRelatedAction"]]

    """ Relationship to another action.
    List of `RequestGroupActionRelatedAction` items (represented as `dict` in JSON). """

    timingDateTime: typing.Optional["FHIRDate"]

    """ When the action should take place.
    Type `FHIRDate` (represented as `str` in JSON). """

    timingAge: typing.Optional["Age"]

    """ When the action should take place.
    Type `Age` (represented as `dict` in JSON). """

    timingPeriod: typing.Optional["Period"]

    """ When the action should take place.
    Type `Period` (represented as `dict` in JSON). """

    timingDuration: typing.Optional["Duration"]

    """ When the action should take place.
    Type `Duration` (represented as `dict` in JSON). """

    timingRange: typing.Optional["Range"]

    """ When the action should take place.
    Type `Range` (represented as `dict` in JSON). """

    timingTiming: typing.Optional["Timing"]

    """ When the action should take place.
    Type `Timing` (represented as `dict` in JSON). """

    participant: typing.Optional[typing.List["Reference"]]

    """ Who should perform the action.
    List of `Reference` items (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ create | update | remove | fire-event.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    groupingBehavior: typing.Optional["str"]

    """ visual-group | logical-group | sentence-group.
    Type `str`. """

    selectionBehavior: typing.Optional["str"]

    """ any | all | all-or-none | exactly-one | at-most-one | one-or-more.
    Type `str`. """

    requiredBehavior: typing.Optional["str"]

    """ must | could | must-unless-documented.
    Type `str`. """

    precheckBehavior: typing.Optional["str"]

    """ yes | no.
    Type `str`. """

    cardinalityBehavior: typing.Optional["str"]

    """ single | multiple.
    Type `str`. """

    resource: typing.Optional["Reference"]

    """ The target of the action.
    Type `Reference` (represented as `dict` in JSON). """

    action: typing.Optional[typing.List["RequestGroupAction"]]

    """ Sub action.
    List of `RequestGroupAction` items (represented as `dict` in JSON). """



#   {'path': 'RequestGroup.action.timing[x]', 'choice_of_type': 'timing', 'orig_name': 'timingDateTime', 'name': 'timingDateTime', 'parent_name': 'RequestGroup.action', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'When the action should take place', 'formal': 'An optional value describing when the action should be performed.', 'representation': None}

    _timing_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timingDateTime', 'timingAge', 'timingPeriod', 'timingDuration', 'timingRange', 'timingTiming']), True))


    

     
    



class RequestGroupActionCondition(BackboneElement):
    """ Whether or not the action is applicable.
    
    An expression that describes applicability criteria, or start/stop
    conditions for the action.
    """
    
    # [<FHIRClassProperty self.name='kind' >, <FHIRClassProperty self.name='expression' >]
  

    kind: "str"

    """ applicability | start | stop.
    Type `str`. """

    expression: typing.Optional["Expression"]

    """ Boolean-valued expression.
    Type `Expression` (represented as `dict` in JSON). """




    

     
    



class RequestGroupActionRelatedAction(BackboneElement):
    """ Relationship to another action.
    
    A relationship to another action such as "before" or "30-60 minutes after
    start of".
    """
    
    # [<FHIRClassProperty self.name='actionId' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='offsetDuration' >, <FHIRClassProperty self.name='offsetRange' >]
  

    actionId: str

    """ What action this is related to.
    Type `str`. """

    relationship: "str"

    """ before-start | before | before-end | concurrent-with-start |
        concurrent | concurrent-with-end | after-start | after | after-end.
    Type `str`. """

    offsetDuration: typing.Optional["Duration"]

    """ Time offset for the relationship.
    Type `Duration` (represented as `dict` in JSON). """

    offsetRange: typing.Optional["Range"]

    """ Time offset for the relationship.
    Type `Range` (represented as `dict` in JSON). """



#   {'path': 'RequestGroup.action.relatedAction.offset[x]', 'choice_of_type': 'offset', 'orig_name': 'offsetDuration', 'name': 'offsetDuration', 'parent_name': 'RequestGroup.action.relatedAction', 'class_name': 'Duration', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Time offset for the relationship', 'formal': 'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.', 'representation': None}

    _offset_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['offsetDuration', 'offsetRange']), True))


    

     
    



class ResearchElementDefinitionCharacteristic(BackboneElement):
    """ What defines the members of the research element.
    
    A characteristic that defines the members of the research element. Multiple
    characteristics are applied with "and" semantics.
    """
    
    # [<FHIRClassProperty self.name='definitionCodeableConcept' >, <FHIRClassProperty self.name='definitionCanonical' >, <FHIRClassProperty self.name='definitionExpression' >, <FHIRClassProperty self.name='definitionDataRequirement' >, <FHIRClassProperty self.name='usageContext' >, <FHIRClassProperty self.name='exclude' >, <FHIRClassProperty self.name='unitOfMeasure' >, <FHIRClassProperty self.name='studyEffectiveDescription' >, <FHIRClassProperty self.name='studyEffectiveDateTime' >, <FHIRClassProperty self.name='studyEffectivePeriod' >, <FHIRClassProperty self.name='studyEffectiveDuration' >, <FHIRClassProperty self.name='studyEffectiveTiming' >, <FHIRClassProperty self.name='studyEffectiveTimeFromStart' >, <FHIRClassProperty self.name='studyEffectiveGroupMeasure' >, <FHIRClassProperty self.name='participantEffectiveDescription' >, <FHIRClassProperty self.name='participantEffectiveDateTime' >, <FHIRClassProperty self.name='participantEffectivePeriod' >, <FHIRClassProperty self.name='participantEffectiveDuration' >, <FHIRClassProperty self.name='participantEffectiveTiming' >, <FHIRClassProperty self.name='participantEffectiveTimeFromStart' >, <FHIRClassProperty self.name='participantEffectiveGroupMeasure' >]
  

    definitionCodeableConcept: typing.Optional["CodeableConcept"]

    """ What code or expression defines members?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    definitionCanonical: typing.Optional[str]

    """ What code or expression defines members?.
    Type `str`. """

    definitionExpression: typing.Optional["Expression"]

    """ What code or expression defines members?.
    Type `Expression` (represented as `dict` in JSON). """

    definitionDataRequirement: typing.Optional["DataRequirement"]

    """ What code or expression defines members?.
    Type `DataRequirement` (represented as `dict` in JSON). """

    usageContext: typing.Optional[typing.List["UsageContext"]]

    """ What code/value pairs define members?.
    List of `UsageContext` items (represented as `dict` in JSON). """

    exclude: typing.Optional[bool]

    """ Whether the characteristic includes or excludes members.
    Type `bool`. """

    unitOfMeasure: typing.Optional["CodeableConcept"]

    """ What unit is the outcome described in?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    studyEffectiveDescription: typing.Optional[str]

    """ What time period does the study cover.
    Type `str`. """

    studyEffectiveDateTime: typing.Optional["FHIRDate"]

    """ What time period does the study cover.
    Type `FHIRDate` (represented as `str` in JSON). """

    studyEffectivePeriod: typing.Optional["Period"]

    """ What time period does the study cover.
    Type `Period` (represented as `dict` in JSON). """

    studyEffectiveDuration: typing.Optional["Duration"]

    """ What time period does the study cover.
    Type `Duration` (represented as `dict` in JSON). """

    studyEffectiveTiming: typing.Optional["Timing"]

    """ What time period does the study cover.
    Type `Timing` (represented as `dict` in JSON). """

    studyEffectiveTimeFromStart: typing.Optional["Duration"]

    """ Observation time from study start.
    Type `Duration` (represented as `dict` in JSON). """

    studyEffectiveGroupMeasure: typing.Optional["str"]

    """ mean | median | mean-of-mean | mean-of-median | median-of-mean |
        median-of-median.
    Type `str`. """

    participantEffectiveDescription: typing.Optional[str]

    """ What time period do participants cover.
    Type `str`. """

    participantEffectiveDateTime: typing.Optional["FHIRDate"]

    """ What time period do participants cover.
    Type `FHIRDate` (represented as `str` in JSON). """

    participantEffectivePeriod: typing.Optional["Period"]

    """ What time period do participants cover.
    Type `Period` (represented as `dict` in JSON). """

    participantEffectiveDuration: typing.Optional["Duration"]

    """ What time period do participants cover.
    Type `Duration` (represented as `dict` in JSON). """

    participantEffectiveTiming: typing.Optional["Timing"]

    """ What time period do participants cover.
    Type `Timing` (represented as `dict` in JSON). """

    participantEffectiveTimeFromStart: typing.Optional["Duration"]

    """ Observation time from study start.
    Type `Duration` (represented as `dict` in JSON). """

    participantEffectiveGroupMeasure: typing.Optional["str"]

    """ mean | median | mean-of-mean | mean-of-median | median-of-mean |
        median-of-median.
    Type `str`. """



#   {'path': 'ResearchElementDefinition.characteristic.definition[x]', 'choice_of_type': 'definition', 'orig_name': 'definitionCodeableConcept', 'name': 'definitionCodeableConcept', 'parent_name': 'ResearchElementDefinition.characteristic', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'What code or expression defines members?', 'formal': 'Define members of the research element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).', 'representation': None}

    _definition_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['definitionCodeableConcept', 'definitionCanonical', 'definitionExpression', 'definitionDataRequirement']), False))

#   {'path': 'ResearchElementDefinition.characteristic.studyEffective[x]', 'choice_of_type': 'studyEffective', 'orig_name': 'studyEffectiveDateTime', 'name': 'studyEffectiveDateTime', 'parent_name': 'ResearchElementDefinition.characteristic', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'What time period does the study cover', 'formal': 'Indicates what effective period the study covers.', 'representation': None}

    _studyEffective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['studyEffectiveDateTime', 'studyEffectivePeriod', 'studyEffectiveDuration', 'studyEffectiveTiming']), True))

#   {'path': 'ResearchElementDefinition.characteristic.participantEffective[x]', 'choice_of_type': 'participantEffective', 'orig_name': 'participantEffectiveDateTime', 'name': 'participantEffectiveDateTime', 'parent_name': 'ResearchElementDefinition.characteristic', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'What time period do participants cover', 'formal': 'Indicates what effective period the study covers.', 'representation': None}

    _participantEffective_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['participantEffectiveDateTime', 'participantEffectivePeriod', 'participantEffectiveDuration', 'participantEffectiveTiming']), True))


    

     
    



class ResearchStudyArm(BackboneElement):
    """ Defined path through the study for a subject.
    
    Describes an expected sequence of events for one of the participants of a
    study.  E.g. Exposure to drug A, wash-out, exposure to drug B, wash-out,
    follow-up.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='description' >]
  

    name: str

    """ Label for study arm.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Categorization of study arm.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Short explanation of study path.
    Type `str`. """




    

     
    



class ResearchStudyObjective(BackboneElement):
    """ A goal for the study.
    
    A goal that the study is aiming to achieve in terms of a scientific
    question to be answered by the analysis of data collected during the study.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >]
  

    name: typing.Optional[str]

    """ Label for the objective.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ primary | secondary | exploratory.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class RiskAssessmentPrediction(BackboneElement):
    """ Outcome predicted.
    
    Describes the expected outcome for the subject.
    """
    
    # [<FHIRClassProperty self.name='outcome' >, <FHIRClassProperty self.name='probabilityDecimal' >, <FHIRClassProperty self.name='probabilityRange' >, <FHIRClassProperty self.name='qualitativeRisk' >, <FHIRClassProperty self.name='relativeRisk' >, <FHIRClassProperty self.name='whenPeriod' >, <FHIRClassProperty self.name='whenRange' >, <FHIRClassProperty self.name='rationale' >]
  

    outcome: typing.Optional["CodeableConcept"]

    """ Possible outcome for the subject.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    probabilityDecimal: typing.Optional[float]

    """ Likelihood of specified outcome.
    Type `float`. """

    probabilityRange: typing.Optional["Range"]

    """ Likelihood of specified outcome.
    Type `Range` (represented as `dict` in JSON). """

    qualitativeRisk: typing.Optional["CodeableConcept"]

    """ Likelihood of specified outcome as a qualitative value.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    relativeRisk: typing.Optional[float]

    """ Relative likelihood.
    Type `float`. """

    whenPeriod: typing.Optional["Period"]

    """ Timeframe or age range.
    Type `Period` (represented as `dict` in JSON). """

    whenRange: typing.Optional["Range"]

    """ Timeframe or age range.
    Type `Range` (represented as `dict` in JSON). """

    rationale: typing.Optional[str]

    """ Explanation of prediction.
    Type `str`. """



#   {'path': 'RiskAssessment.prediction.probability[x]', 'choice_of_type': 'probability', 'orig_name': 'probabilityDecimal', 'name': 'probabilityDecimal', 'parent_name': 'RiskAssessment.prediction', 'class_name': 'float', 'enum': None, 'module_name': None, 'json_class': 'float', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Likelihood of specified outcome', 'formal': 'Indicates how likely the outcome is (in the specified timeframe).', 'representation': None}

    _probability_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['probabilityDecimal', 'probabilityRange']), True))

#   {'path': 'RiskAssessment.prediction.when[x]', 'choice_of_type': 'when', 'orig_name': 'whenPeriod', 'name': 'whenPeriod', 'parent_name': 'RiskAssessment.prediction', 'class_name': 'Period', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Timeframe or age range', 'formal': 'Indicates the period of time or age range of the subject to which the specified probability applies.', 'representation': None}

    _when_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['whenPeriod', 'whenRange']), True))


    

     
    



class RiskEvidenceSynthesisSampleSize(BackboneElement):
    """ What sample size was involved?.
    
    A description of the size of the sample involved in the synthesis.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='numberOfStudies' >, <FHIRClassProperty self.name='numberOfParticipants' >]
  

    description: typing.Optional[str]

    """ Description of sample size.
    Type `str`. """

    numberOfStudies: typing.Optional[int]

    """ How many studies?.
    Type `int`. """

    numberOfParticipants: typing.Optional[int]

    """ How many participants?.
    Type `int`. """




    

     
    



class RiskEvidenceSynthesisRiskEstimate(BackboneElement):
    """ What was the estimated risk.
    
    The estimated risk of the outcome.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='unitOfMeasure' >, <FHIRClassProperty self.name='denominatorCount' >, <FHIRClassProperty self.name='numeratorCount' >, <FHIRClassProperty self.name='precisionEstimate' >]
  

    description: typing.Optional[str]

    """ Description of risk estimate.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Type of risk estimate.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    value: typing.Optional[float]

    """ Point estimate.
    Type `float`. """

    unitOfMeasure: typing.Optional["CodeableConcept"]

    """ What unit is the outcome described in?.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    denominatorCount: typing.Optional[int]

    """ Sample size for group measured.
    Type `int`. """

    numeratorCount: typing.Optional[int]

    """ Number with the outcome.
    Type `int`. """

    precisionEstimate: typing.Optional[typing.List["RiskEvidenceSynthesisRiskEstimatePrecisionEstimate"]]

    """ How precise the estimate is.
    List of `RiskEvidenceSynthesisRiskEstimatePrecisionEstimate` items (represented as `dict` in JSON). """




    

     
    



class RiskEvidenceSynthesisRiskEstimatePrecisionEstimate(BackboneElement):
    """ How precise the estimate is.
    
    A description of the precision of the estimate for the effect.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='level' >, <FHIRClassProperty self.name='from_' >, <FHIRClassProperty self.name='to' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of precision estimate.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    level: typing.Optional[float]

    """ Level of confidence interval.
    Type `float`. """

    from_: typing.Optional[float]

    """ Lower bound.
    Type `float`. """

    to: typing.Optional[float]

    """ Upper bound.
    Type `float`. """




    

     
    



class RiskEvidenceSynthesisCertainty(BackboneElement):
    """ How certain is the risk.
    
    A description of the certainty of the risk estimate.
    """
    
    # [<FHIRClassProperty self.name='rating' >, <FHIRClassProperty self.name='note' >, <FHIRClassProperty self.name='certaintySubcomponent' >]
  

    rating: typing.Optional[typing.List["CodeableConcept"]]

    """ Certainty rating.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """

    certaintySubcomponent: typing.Optional[typing.List["RiskEvidenceSynthesisCertaintyCertaintySubcomponent"]]

    """ A component that contributes to the overall certainty.
    List of `RiskEvidenceSynthesisCertaintyCertaintySubcomponent` items (represented as `dict` in JSON). """




    

     
    



class RiskEvidenceSynthesisCertaintyCertaintySubcomponent(BackboneElement):
    """ A component that contributes to the overall certainty.
    
    A description of a component of the overall certainty.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='rating' >, <FHIRClassProperty self.name='note' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Type of subcomponent of certainty rating.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    rating: typing.Optional[typing.List["CodeableConcept"]]

    """ Subcomponent certainty rating.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    note: typing.Optional[typing.List["Annotation"]]

    """ Used for footnotes or explanatory notes.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class SearchParameterComponent(BackboneElement):
    """ For Composite resources to define the parts.
    
    Used to define the parts of a composite search parameter.
    """
    
    # [<FHIRClassProperty self.name='definition' >, <FHIRClassProperty self.name='expression' >]
  

    definition: str

    """ Defines how the part works.
    Type `str`. """

    expression: str

    """ Subexpression relative to main expression.
    Type `str`. """




    

     
    



class SpecimenCollection(BackboneElement):
    """ Collection details.
    
    Details concerning the specimen collection.
    """
    
    # [<FHIRClassProperty self.name='collector' >, <FHIRClassProperty self.name='collectedDateTime' >, <FHIRClassProperty self.name='collectedPeriod' >, <FHIRClassProperty self.name='duration' >, <FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='bodySite' >, <FHIRClassProperty self.name='fastingStatusCodeableConcept' >, <FHIRClassProperty self.name='fastingStatusDuration' >]
  

    collector: typing.Optional["Reference"]

    """ Who collected the specimen.
    Type `Reference` (represented as `dict` in JSON). """

    collectedDateTime: typing.Optional["FHIRDate"]

    """ Collection time.
    Type `FHIRDate` (represented as `str` in JSON). """

    collectedPeriod: typing.Optional["Period"]

    """ Collection time.
    Type `Period` (represented as `dict` in JSON). """

    duration: typing.Optional["Duration"]

    """ How long it took to collect specimen.
    Type `Duration` (represented as `dict` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ The quantity of specimen collected.
    Type `Quantity` (represented as `dict` in JSON). """

    method: typing.Optional["CodeableConcept"]

    """ Technique used to perform collection.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    bodySite: typing.Optional["CodeableConcept"]

    """ Anatomical collection site.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fastingStatusCodeableConcept: typing.Optional["CodeableConcept"]

    """ Whether or how long patient abstained from food and/or drink.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    fastingStatusDuration: typing.Optional["Duration"]

    """ Whether or how long patient abstained from food and/or drink.
    Type `Duration` (represented as `dict` in JSON). """



#   {'path': 'Specimen.collection.collected[x]', 'choice_of_type': 'collected', 'orig_name': 'collectedDateTime', 'name': 'collectedDateTime', 'parent_name': 'Specimen.collection', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Collection time', 'formal': 'Time when specimen was collected from subject - the physiologically relevant time.', 'representation': None}

    _collected_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['collectedDateTime', 'collectedPeriod']), True))

#   {'path': 'Specimen.collection.fastingStatus[x]', 'choice_of_type': 'fastingStatus', 'orig_name': 'fastingStatusCodeableConcept', 'name': 'fastingStatusCodeableConcept', 'parent_name': 'Specimen.collection', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Whether or how long patient abstained from food and/or drink', 'formal': 'Abstinence or reduction from some or all food, drink, or both, for a period of time prior to sample collection.', 'representation': None}

    _fastingStatus_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['fastingStatusCodeableConcept', 'fastingStatusDuration']), True))


    

     
    



class SpecimenProcessing(BackboneElement):
    """ Processing and processing step details.
    
    Details concerning processing and processing steps for the specimen.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='procedure' >, <FHIRClassProperty self.name='additive' >, <FHIRClassProperty self.name='timeDateTime' >, <FHIRClassProperty self.name='timePeriod' >]
  

    description: typing.Optional[str]

    """ Textual description of procedure.
    Type `str`. """

    procedure: typing.Optional["CodeableConcept"]

    """ Indicates the treatment step  applied to the specimen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additive: typing.Optional[typing.List["Reference"]]

    """ Material used in the processing step.
    List of `Reference` items (represented as `dict` in JSON). """

    timeDateTime: typing.Optional["FHIRDate"]

    """ Date and time of specimen processing.
    Type `FHIRDate` (represented as `str` in JSON). """

    timePeriod: typing.Optional["Period"]

    """ Date and time of specimen processing.
    Type `Period` (represented as `dict` in JSON). """



#   {'path': 'Specimen.processing.time[x]', 'choice_of_type': 'time', 'orig_name': 'timeDateTime', 'name': 'timeDateTime', 'parent_name': 'Specimen.processing', 'class_name': 'FHIRDate', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Date and time of specimen processing', 'formal': 'A record of the time or period when the specimen processing occurred.  For example the time of sample fixation or the period of time the sample was in formalin.', 'representation': None}

    _time_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['timeDateTime', 'timePeriod']), True))


    

     
    



class SpecimenContainer(BackboneElement):
    """ Direct container of specimen (tube/slide, etc.).
    
    The container holding the specimen.  The recursive nature of containers;
    i.e. blood in tube in tray in rack is not addressed here.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='capacity' >, <FHIRClassProperty self.name='specimenQuantity' >, <FHIRClassProperty self.name='additiveCodeableConcept' >, <FHIRClassProperty self.name='additiveReference' >]
  

    identifier: typing.Optional[typing.List["Identifier"]]

    """ Id for the container.
    List of `Identifier` items (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Textual description of the container.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Kind of container directly associated with specimen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    capacity: typing.Optional["Quantity"]

    """ Container volume or size.
    Type `Quantity` (represented as `dict` in JSON). """

    specimenQuantity: typing.Optional["Quantity"]

    """ Quantity of specimen within container.
    Type `Quantity` (represented as `dict` in JSON). """

    additiveCodeableConcept: typing.Optional["CodeableConcept"]

    """ Additive associated with container.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additiveReference: typing.Optional["Reference"]

    """ Additive associated with container.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Specimen.container.additive[x]', 'choice_of_type': 'additive', 'orig_name': 'additiveCodeableConcept', 'name': 'additiveCodeableConcept', 'parent_name': 'Specimen.container', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Additive associated with container', 'formal': 'Introduced substance to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.', 'representation': None}

    _additive_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['additiveCodeableConcept', 'additiveReference']), True))


    

     
    



class SpecimenDefinitionTypeTested(BackboneElement):
    """ Specimen in container intended for testing by lab.
    
    Specimen conditioned in a container as expected by the testing laboratory.
    """
    
    # [<FHIRClassProperty self.name='isDerived' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='preference' >, <FHIRClassProperty self.name='container' >, <FHIRClassProperty self.name='requirement' >, <FHIRClassProperty self.name='retentionTime' >, <FHIRClassProperty self.name='rejectionCriterion' >, <FHIRClassProperty self.name='handling' >]
  

    isDerived: typing.Optional[bool]

    """ Primary or secondary specimen.
    Type `bool`. """

    type: typing.Optional["CodeableConcept"]

    """ Type of intended specimen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    preference: "str"

    """ preferred | alternate.
    Type `str`. """

    container: typing.Optional["SpecimenDefinitionTypeTestedContainer"]

    """ The specimen's container.
    Type `SpecimenDefinitionTypeTestedContainer` (represented as `dict` in JSON). """

    requirement: typing.Optional[str]

    """ Specimen requirements.
    Type `str`. """

    retentionTime: typing.Optional["Duration"]

    """ Specimen retention time.
    Type `Duration` (represented as `dict` in JSON). """

    rejectionCriterion: typing.Optional[typing.List["CodeableConcept"]]

    """ Rejection criterion.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    handling: typing.Optional[typing.List["SpecimenDefinitionTypeTestedHandling"]]

    """ Specimen handling before testing.
    List of `SpecimenDefinitionTypeTestedHandling` items (represented as `dict` in JSON). """




    

     
    



class SpecimenDefinitionTypeTestedContainer(BackboneElement):
    """ The specimen's container.
    """
    
    # [<FHIRClassProperty self.name='material' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='cap' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='capacity' >, <FHIRClassProperty self.name='minimumVolumeQuantity' >, <FHIRClassProperty self.name='minimumVolumeString' >, <FHIRClassProperty self.name='additive' >, <FHIRClassProperty self.name='preparation' >]
  

    material: typing.Optional["CodeableConcept"]

    """ Container material.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Kind of container associated with the kind of specimen.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    cap: typing.Optional["CodeableConcept"]

    """ Color of container cap.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    description: typing.Optional[str]

    """ Container description.
    Type `str`. """

    capacity: typing.Optional["Quantity"]

    """ Container capacity.
    Type `Quantity` (represented as `dict` in JSON). """

    minimumVolumeQuantity: typing.Optional["Quantity"]

    """ Minimum volume.
    Type `Quantity` (represented as `dict` in JSON). """

    minimumVolumeString: typing.Optional[str]

    """ Minimum volume.
    Type `str`. """

    additive: typing.Optional[typing.List["SpecimenDefinitionTypeTestedContainerAdditive"]]

    """ Additive associated with container.
    List of `SpecimenDefinitionTypeTestedContainerAdditive` items (represented as `dict` in JSON). """

    preparation: typing.Optional[str]

    """ Specimen container preparation.
    Type `str`. """



#   {'path': 'SpecimenDefinition.typeTested.container.minimumVolume[x]', 'choice_of_type': 'minimumVolume', 'orig_name': 'minimumVolumeQuantity', 'name': 'minimumVolumeQuantity', 'parent_name': 'SpecimenDefinition.typeTested.container', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Minimum volume', 'formal': 'The minimum volume to be conditioned in the container.', 'representation': None}

    _minimumVolume_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['minimumVolumeQuantity', 'minimumVolumeString']), True))


    

     
    



class SpecimenDefinitionTypeTestedContainerAdditive(BackboneElement):
    """ Additive associated with container.
    
    Substance introduced in the kind of container to preserve, maintain or
    enhance the specimen. Examples: Formalin, Citrate, EDTA.
    """
    
    # [<FHIRClassProperty self.name='additiveCodeableConcept' >, <FHIRClassProperty self.name='additiveReference' >]
  

    additiveCodeableConcept: typing.Optional["CodeableConcept"]

    """ Additive associated with container.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    additiveReference: typing.Optional["Reference"]

    """ Additive associated with container.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'SpecimenDefinition.typeTested.container.additive.additive[x]', 'choice_of_type': 'additive', 'orig_name': 'additiveCodeableConcept', 'name': 'additiveCodeableConcept', 'parent_name': 'SpecimenDefinition.typeTested.container.additive', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Additive associated with container', 'formal': 'Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.', 'representation': None}

    _additive_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['additiveCodeableConcept', 'additiveReference']), False))


    

     
    



class SpecimenDefinitionTypeTestedHandling(BackboneElement):
    """ Specimen handling before testing.
    
    Set of instructions for preservation/transport of the specimen at a defined
    temperature interval, prior the testing process.
    """
    
    # [<FHIRClassProperty self.name='temperatureQualifier' >, <FHIRClassProperty self.name='temperatureRange' >, <FHIRClassProperty self.name='maxDuration' >, <FHIRClassProperty self.name='instruction' >]
  

    temperatureQualifier: typing.Optional["CodeableConcept"]

    """ Temperature qualifier.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    temperatureRange: typing.Optional["Range"]

    """ Temperature range.
    Type `Range` (represented as `dict` in JSON). """

    maxDuration: typing.Optional["Duration"]

    """ Maximum preservation time.
    Type `Duration` (represented as `dict` in JSON). """

    instruction: typing.Optional[str]

    """ Preservation instruction.
    Type `str`. """




    

     
    



class StructureDefinitionMapping(BackboneElement):
    """ External specification that the content is mapped to.
    
    An external specification that the content is mapped to.
    """
    
    # [<FHIRClassProperty self.name='identity' >, <FHIRClassProperty self.name='uri' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='comment' >]
  

    identity: str

    """ Internal id when this mapping is used.
    Type `str`. """

    uri: typing.Optional[str]

    """ Identifies what this mapping refers to.
    Type `str`. """

    name: typing.Optional[str]

    """ Names what this mapping refers to.
    Type `str`. """

    comment: typing.Optional[str]

    """ Versions, Issues, Scope limitations etc..
    Type `str`. """




    

     
    



class StructureDefinitionContext(BackboneElement):
    """ If an extension, where it can be used in instances.
    
    Identifies the types of resource or data type elements to which the
    extension can be applied.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='expression' >]
  

    type: "str"

    """ fhirpath | element | extension.
    Type `str`. """

    expression: str

    """ Where the extension can be used in instances.
    Type `str`. """




    

     
    



class StructureDefinitionSnapshot(BackboneElement):
    """ Snapshot view of the structure.
    
    A snapshot view is expressed in a standalone form that can be used and
    interpreted without considering the base StructureDefinition.
    """
    
    # [<FHIRClassProperty self.name='element' >]
  

    element: typing.List["ElementDefinition"]

    """ Definition of elements in the resource (if no StructureDefinition).
    List of `ElementDefinition` items (represented as `dict` in JSON). """




    

     
    



class StructureDefinitionDifferential(BackboneElement):
    """ Differential view of the structure.
    
    A differential view is expressed relative to the base StructureDefinition -
    a statement of differences that it applies.
    """
    
    # [<FHIRClassProperty self.name='element' >]
  

    element: typing.List["ElementDefinition"]

    """ Definition of elements in the resource (if no StructureDefinition).
    List of `ElementDefinition` items (represented as `dict` in JSON). """




    

     
    



class StructureMapStructure(BackboneElement):
    """ Structure Definition used by this map.
    
    A structure definition used by this map. The structure definition may
    describe instances that are converted, or the instances that are produced.
    """
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='alias' >, <FHIRClassProperty self.name='documentation' >]
  

    url: str

    """ Canonical reference to structure definition.
    Type `str`. """

    mode: "str"

    """ source | queried | target | produced.
    Type `str`. """

    alias: typing.Optional[str]

    """ Name for type in this map.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Documentation on use of structure.
    Type `str`. """




    

     
    



class StructureMapGroup(BackboneElement):
    """ Named sections for reader convenience.
    
    Organizes the mapping into manageable chunks for human review/ease of
    maintenance.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='extends' >, <FHIRClassProperty self.name='typeMode' >, <FHIRClassProperty self.name='documentation' >, <FHIRClassProperty self.name='input' >, <FHIRClassProperty self.name='rule' >]
  

    name: str

    """ Human-readable label.
    Type `str`. """

    extends: typing.Optional[str]

    """ Another group that this group adds rules to.
    Type `str`. """

    typeMode: "str"

    """ none | types | type-and-types.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Additional description/explanation for group.
    Type `str`. """

    input: typing.List["StructureMapGroupInput"]

    """ Named instance provided when invoking the map.
    List of `StructureMapGroupInput` items (represented as `dict` in JSON). """

    rule: typing.List["StructureMapGroupRule"]

    """ Transform Rule from source to target.
    List of `StructureMapGroupRule` items (represented as `dict` in JSON). """




    

     
    



class StructureMapGroupInput(BackboneElement):
    """ Named instance provided when invoking the map.
    
    A name assigned to an instance of data. The instance must be provided when
    the mapping is invoked.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='mode' >, <FHIRClassProperty self.name='documentation' >]
  

    name: str

    """ Name for this instance of data.
    Type `str`. """

    type: typing.Optional[str]

    """ Type for this instance of data.
    Type `str`. """

    mode: "str"

    """ source | target.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Documentation for this instance of data.
    Type `str`. """




    

     
    



class StructureMapGroupRule(BackboneElement):
    """ Transform Rule from source to target.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='rule' >, <FHIRClassProperty self.name='dependent' >, <FHIRClassProperty self.name='documentation' >]
  

    name: str

    """ Name of the rule for internal references.
    Type `str`. """

    source: typing.List["StructureMapGroupRuleSource"]

    """ Source inputs to the mapping.
    List of `StructureMapGroupRuleSource` items (represented as `dict` in JSON). """

    target: typing.Optional[typing.List["StructureMapGroupRuleTarget"]]

    """ Content to create because of this mapping rule.
    List of `StructureMapGroupRuleTarget` items (represented as `dict` in JSON). """

    rule: typing.Optional[typing.List["StructureMapGroupRule"]]

    """ Rules contained in this rule.
    List of `StructureMapGroupRule` items (represented as `dict` in JSON). """

    dependent: typing.Optional[typing.List["StructureMapGroupRuleDependent"]]

    """ Which other rules to apply in the context of this rule.
    List of `StructureMapGroupRuleDependent` items (represented as `dict` in JSON). """

    documentation: typing.Optional[str]

    """ Documentation for this instance of data.
    Type `str`. """




    

     
    



class StructureMapGroupRuleSource(BackboneElement):
    """ Source inputs to the mapping.
    """
    
    # [<FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='min' >, <FHIRClassProperty self.name='max' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='defaultValueBase64Binary' >, <FHIRClassProperty self.name='defaultValueBoolean' >, <FHIRClassProperty self.name='defaultValueCanonical' >, <FHIRClassProperty self.name='defaultValueCode' >, <FHIRClassProperty self.name='defaultValueDate' >, <FHIRClassProperty self.name='defaultValueDateTime' >, <FHIRClassProperty self.name='defaultValueDecimal' >, <FHIRClassProperty self.name='defaultValueId' >, <FHIRClassProperty self.name='defaultValueInstant' >, <FHIRClassProperty self.name='defaultValueInteger' >, <FHIRClassProperty self.name='defaultValueMarkdown' >, <FHIRClassProperty self.name='defaultValueOid' >, <FHIRClassProperty self.name='defaultValuePositiveInt' >, <FHIRClassProperty self.name='defaultValueString' >, <FHIRClassProperty self.name='defaultValueTime' >, <FHIRClassProperty self.name='defaultValueUnsignedInt' >, <FHIRClassProperty self.name='defaultValueUri' >, <FHIRClassProperty self.name='defaultValueUrl' >, <FHIRClassProperty self.name='defaultValueUuid' >, <FHIRClassProperty self.name='defaultValueAddress' >, <FHIRClassProperty self.name='defaultValueAge' >, <FHIRClassProperty self.name='defaultValueAnnotation' >, <FHIRClassProperty self.name='defaultValueAttachment' >, <FHIRClassProperty self.name='defaultValueCodeableConcept' >, <FHIRClassProperty self.name='defaultValueCoding' >, <FHIRClassProperty self.name='defaultValueContactPoint' >, <FHIRClassProperty self.name='defaultValueCount' >, <FHIRClassProperty self.name='defaultValueDistance' >, <FHIRClassProperty self.name='defaultValueDuration' >, <FHIRClassProperty self.name='defaultValueHumanName' >, <FHIRClassProperty self.name='defaultValueIdentifier' >, <FHIRClassProperty self.name='defaultValueMoney' >, <FHIRClassProperty self.name='defaultValuePeriod' >, <FHIRClassProperty self.name='defaultValueQuantity' >, <FHIRClassProperty self.name='defaultValueRange' >, <FHIRClassProperty self.name='defaultValueRatio' >, <FHIRClassProperty self.name='defaultValueReference' >, <FHIRClassProperty self.name='defaultValueSampledData' >, <FHIRClassProperty self.name='defaultValueSignature' >, <FHIRClassProperty self.name='defaultValueTiming' >, <FHIRClassProperty self.name='defaultValueContactDetail' >, <FHIRClassProperty self.name='defaultValueContributor' >, <FHIRClassProperty self.name='defaultValueDataRequirement' >, <FHIRClassProperty self.name='defaultValueExpression' >, <FHIRClassProperty self.name='defaultValueParameterDefinition' >, <FHIRClassProperty self.name='defaultValueRelatedArtifact' >, <FHIRClassProperty self.name='defaultValueTriggerDefinition' >, <FHIRClassProperty self.name='defaultValueUsageContext' >, <FHIRClassProperty self.name='defaultValueDosage' >, <FHIRClassProperty self.name='defaultValueMeta' >, <FHIRClassProperty self.name='element' >, <FHIRClassProperty self.name='listMode' >, <FHIRClassProperty self.name='variable' >, <FHIRClassProperty self.name='condition' >, <FHIRClassProperty self.name='check' >, <FHIRClassProperty self.name='logMessage' >]
  

    context: str

    """ Type or variable this rule applies to.
    Type `str`. """

    min: typing.Optional[int]

    """ Specified minimum cardinality.
    Type `int`. """

    max: typing.Optional[str]

    """ Specified maximum cardinality (number or *).
    Type `str`. """

    type: typing.Optional[str]

    """ Rule only applies if source has this type.
    Type `str`. """

    defaultValueBase64Binary: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueBoolean: typing.Optional[bool]

    """ Default value if no value exists.
    Type `bool`. """

    defaultValueCanonical: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueCode: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueDate: typing.Optional["FHIRDate"]

    """ Default value if no value exists.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueDateTime: typing.Optional["FHIRDate"]

    """ Default value if no value exists.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueDecimal: typing.Optional[float]

    """ Default value if no value exists.
    Type `float`. """

    defaultValueId: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueInstant: typing.Optional["FHIRDate"]

    """ Default value if no value exists.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueInteger: typing.Optional[int]

    """ Default value if no value exists.
    Type `int`. """

    defaultValueMarkdown: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueOid: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValuePositiveInt: typing.Optional[int]

    """ Default value if no value exists.
    Type `int`. """

    defaultValueString: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueTime: typing.Optional["FHIRDate"]

    """ Default value if no value exists.
    Type `FHIRDate` (represented as `str` in JSON). """

    defaultValueUnsignedInt: typing.Optional[int]

    """ Default value if no value exists.
    Type `int`. """

    defaultValueUri: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueUrl: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueUuid: typing.Optional[str]

    """ Default value if no value exists.
    Type `str`. """

    defaultValueAddress: typing.Optional["Address"]

    """ Default value if no value exists.
    Type `Address` (represented as `dict` in JSON). """

    defaultValueAge: typing.Optional["Age"]

    """ Default value if no value exists.
    Type `Age` (represented as `dict` in JSON). """

    defaultValueAnnotation: typing.Optional["Annotation"]

    """ Default value if no value exists.
    Type `Annotation` (represented as `dict` in JSON). """

    defaultValueAttachment: typing.Optional["Attachment"]

    """ Default value if no value exists.
    Type `Attachment` (represented as `dict` in JSON). """

    defaultValueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Default value if no value exists.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    defaultValueCoding: typing.Optional["Coding"]

    """ Default value if no value exists.
    Type `Coding` (represented as `dict` in JSON). """

    defaultValueContactPoint: typing.Optional["ContactPoint"]

    """ Default value if no value exists.
    Type `ContactPoint` (represented as `dict` in JSON). """

    defaultValueCount: typing.Optional["Count"]

    """ Default value if no value exists.
    Type `Count` (represented as `dict` in JSON). """

    defaultValueDistance: typing.Optional["Distance"]

    """ Default value if no value exists.
    Type `Distance` (represented as `dict` in JSON). """

    defaultValueDuration: typing.Optional["Duration"]

    """ Default value if no value exists.
    Type `Duration` (represented as `dict` in JSON). """

    defaultValueHumanName: typing.Optional["HumanName"]

    """ Default value if no value exists.
    Type `HumanName` (represented as `dict` in JSON). """

    defaultValueIdentifier: typing.Optional["Identifier"]

    """ Default value if no value exists.
    Type `Identifier` (represented as `dict` in JSON). """

    defaultValueMoney: typing.Optional["Money"]

    """ Default value if no value exists.
    Type `Money` (represented as `dict` in JSON). """

    defaultValuePeriod: typing.Optional["Period"]

    """ Default value if no value exists.
    Type `Period` (represented as `dict` in JSON). """

    defaultValueQuantity: typing.Optional["Quantity"]

    """ Default value if no value exists.
    Type `Quantity` (represented as `dict` in JSON). """

    defaultValueRange: typing.Optional["Range"]

    """ Default value if no value exists.
    Type `Range` (represented as `dict` in JSON). """

    defaultValueRatio: typing.Optional["Ratio"]

    """ Default value if no value exists.
    Type `Ratio` (represented as `dict` in JSON). """

    defaultValueReference: typing.Optional["Reference"]

    """ Default value if no value exists.
    Type `Reference` (represented as `dict` in JSON). """

    defaultValueSampledData: typing.Optional["SampledData"]

    """ Default value if no value exists.
    Type `SampledData` (represented as `dict` in JSON). """

    defaultValueSignature: typing.Optional["Signature"]

    """ Default value if no value exists.
    Type `Signature` (represented as `dict` in JSON). """

    defaultValueTiming: typing.Optional["Timing"]

    """ Default value if no value exists.
    Type `Timing` (represented as `dict` in JSON). """

    defaultValueContactDetail: typing.Optional["ContactDetail"]

    """ Default value if no value exists.
    Type `ContactDetail` (represented as `dict` in JSON). """

    defaultValueContributor: typing.Optional["Contributor"]

    """ Default value if no value exists.
    Type `Contributor` (represented as `dict` in JSON). """

    defaultValueDataRequirement: typing.Optional["DataRequirement"]

    """ Default value if no value exists.
    Type `DataRequirement` (represented as `dict` in JSON). """

    defaultValueExpression: typing.Optional["Expression"]

    """ Default value if no value exists.
    Type `Expression` (represented as `dict` in JSON). """

    defaultValueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Default value if no value exists.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    defaultValueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Default value if no value exists.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    defaultValueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Default value if no value exists.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    defaultValueUsageContext: typing.Optional["UsageContext"]

    """ Default value if no value exists.
    Type `UsageContext` (represented as `dict` in JSON). """

    defaultValueDosage: typing.Optional["Dosage"]

    """ Default value if no value exists.
    Type `Dosage` (represented as `dict` in JSON). """

    defaultValueMeta: typing.Optional["Meta"]

    """ Default value if no value exists.
    Type `Meta` (represented as `dict` in JSON). """

    element: typing.Optional[str]

    """ Optional field for this source.
    Type `str`. """

    listMode: typing.Optional["str"]

    """ first | not_first | last | not_last | only_one.
    Type `str`. """

    variable: typing.Optional[str]

    """ Named context for field, if a field is specified.
    Type `str`. """

    condition: typing.Optional[str]

    """ FHIRPath expression  - must be true or the rule does not apply.
    Type `str`. """

    check: typing.Optional[str]

    """ FHIRPath expression  - must be true or the mapping engine throws an
        error instead of completing.
    Type `str`. """

    logMessage: typing.Optional[str]

    """ Message to put in log if source exists (FHIRPath).
    Type `str`. """



#   {'path': 'StructureMap.group.rule.source.defaultValue[x]', 'choice_of_type': 'defaultValue', 'orig_name': 'defaultValueBase64Binary', 'name': 'defaultValueBase64Binary', 'parent_name': 'StructureMap.group.rule.source', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Default value if no value exists', 'formal': 'A value to use if there is no existing value in the source object.', 'representation': None}

    _defaultValue_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['defaultValueBase64Binary', 'defaultValueBoolean', 'defaultValueCanonical', 'defaultValueCode', 'defaultValueDate', 'defaultValueDateTime', 'defaultValueDecimal', 'defaultValueId', 'defaultValueInstant', 'defaultValueInteger', 'defaultValueMarkdown', 'defaultValueOid', 'defaultValuePositiveInt', 'defaultValueString', 'defaultValueTime', 'defaultValueUnsignedInt', 'defaultValueUri', 'defaultValueUrl', 'defaultValueUuid', 'defaultValueAddress', 'defaultValueAge', 'defaultValueAnnotation', 'defaultValueAttachment', 'defaultValueCodeableConcept', 'defaultValueCoding', 'defaultValueContactPoint', 'defaultValueCount', 'defaultValueDistance', 'defaultValueDuration', 'defaultValueHumanName', 'defaultValueIdentifier', 'defaultValueMoney', 'defaultValuePeriod', 'defaultValueQuantity', 'defaultValueRange', 'defaultValueRatio', 'defaultValueReference', 'defaultValueSampledData', 'defaultValueSignature', 'defaultValueTiming', 'defaultValueContactDetail', 'defaultValueContributor', 'defaultValueDataRequirement', 'defaultValueExpression', 'defaultValueParameterDefinition', 'defaultValueRelatedArtifact', 'defaultValueTriggerDefinition', 'defaultValueUsageContext', 'defaultValueDosage', 'defaultValueMeta']), True))


    

     
    



class StructureMapGroupRuleTarget(BackboneElement):
    """ Content to create because of this mapping rule.
    """
    
    # [<FHIRClassProperty self.name='context' >, <FHIRClassProperty self.name='contextType' >, <FHIRClassProperty self.name='element' >, <FHIRClassProperty self.name='variable' >, <FHIRClassProperty self.name='listMode' >, <FHIRClassProperty self.name='listRuleId' >, <FHIRClassProperty self.name='transform' >, <FHIRClassProperty self.name='parameter' >]
  

    context: typing.Optional[str]

    """ Type or variable this rule applies to.
    Type `str`. """

    contextType: typing.Optional["str"]

    """ type | variable.
    Type `str`. """

    element: typing.Optional[str]

    """ Field to create in the context.
    Type `str`. """

    variable: typing.Optional[str]

    """ Named context for field, if desired, and a field is specified.
    Type `str`. """

    listMode: typing.Optional[typing.List["str"]]

    """ first | share | last | collate.
    List of `str` items. """

    listRuleId: typing.Optional[str]

    """ Internal rule reference for shared list items.
    Type `str`. """

    transform: typing.Optional["str"]

    """ create | copy +.
    Type `str`. """

    parameter: typing.Optional[typing.List["StructureMapGroupRuleTargetParameter"]]

    """ Parameters to the transform.
    List of `StructureMapGroupRuleTargetParameter` items (represented as `dict` in JSON). """




    

     
    



class StructureMapGroupRuleTargetParameter(BackboneElement):
    """ Parameters to the transform.
    """
    
    # [<FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDecimal' >]
  

    valueId: typing.Optional[str]

    """ Parameter value - variable or literal.
    Type `str`. """

    valueString: typing.Optional[str]

    """ Parameter value - variable or literal.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Parameter value - variable or literal.
    Type `bool`. """

    valueInteger: typing.Optional[int]

    """ Parameter value - variable or literal.
    Type `int`. """

    valueDecimal: typing.Optional[float]

    """ Parameter value - variable or literal.
    Type `float`. """



#   {'path': 'StructureMap.group.rule.target.parameter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueId', 'name': 'valueId', 'parent_name': 'StructureMap.group.rule.target.parameter', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Parameter value - variable or literal', 'formal': None, 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueId', 'valueString', 'valueBoolean', 'valueInteger', 'valueDecimal']), False))


    

     
    



class StructureMapGroupRuleDependent(BackboneElement):
    """ Which other rules to apply in the context of this rule.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='variable' >]
  

    name: str

    """ Name of a rule or group to apply.
    Type `str`. """

    variable: typing.List[str]

    """ Variable to pass to the rule or group.
    List of `str` items. """




    

     
    



class SubscriptionChannel(BackboneElement):
    """ The channel on which to report matches to the criteria.
    
    Details where to send notifications when resources are received that meet
    the criteria.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='endpoint' >, <FHIRClassProperty self.name='payload' >, <FHIRClassProperty self.name='header' >]
  

    type: "str"

    """ rest-hook | websocket | email | sms | message.
    Type `str`. """

    endpoint: typing.Optional[str]

    """ Where the channel points to.
    Type `str`. """

    payload: typing.Optional[str]

    """ MIME type to send, or omit for no payload.
    Type `str`. """

    header: typing.Optional[typing.List[str]]

    """ Usage depends on the channel type.
    List of `str` items. """




    

     
    



class SubstanceInstance(BackboneElement):
    """ If this describes a specific package/container of the substance.
    
    Substance may be used to describe a kind of substance, or a specific
    package/container of the substance: an instance.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='expiry' >, <FHIRClassProperty self.name='quantity' >]
  

    identifier: typing.Optional["Identifier"]

    """ Identifier of the package/container.
    Type `Identifier` (represented as `dict` in JSON). """

    expiry: typing.Optional["FHIRDate"]

    """ When no longer valid to use.
    Type `FHIRDate` (represented as `str` in JSON). """

    quantity: typing.Optional["Quantity"]

    """ Amount of substance in the package.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class SubstanceIngredient(BackboneElement):
    """ Composition information about the substance.
    
    A substance can be composed of other substances.
    """
    
    # [<FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='substanceCodeableConcept' >, <FHIRClassProperty self.name='substanceReference' >]
  

    quantity: typing.Optional["Ratio"]

    """ Optional amount (concentration).
    Type `Ratio` (represented as `dict` in JSON). """

    substanceCodeableConcept: typing.Optional["CodeableConcept"]

    """ A component of the substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    substanceReference: typing.Optional["Reference"]

    """ A component of the substance.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'Substance.ingredient.substance[x]', 'choice_of_type': 'substance', 'orig_name': 'substanceCodeableConcept', 'name': 'substanceCodeableConcept', 'parent_name': 'Substance.ingredient', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'A component of the substance', 'formal': 'Another substance that is a component of this substance.', 'representation': None}

    _substance_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['substanceCodeableConcept', 'substanceReference']), False))


    

     
    



class SubstanceNucleicAcidSubunit(BackboneElement):
    """ Subunits are listed in order of decreasing length; sequences of the same
    length will be ordered by molecular weight; subunits that have identical
    sequences will be repeated multiple times.
    """
    
    # [<FHIRClassProperty self.name='subunit' >, <FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='length' >, <FHIRClassProperty self.name='sequenceAttachment' >, <FHIRClassProperty self.name='fivePrime' >, <FHIRClassProperty self.name='threePrime' >, <FHIRClassProperty self.name='linkage' >, <FHIRClassProperty self.name='sugar' >]
  

    subunit: typing.Optional[int]

    """ Index of linear sequences of nucleic acids in order of decreasing
        length. Sequences of the same length will be ordered by molecular
        weight. Subunits that have identical sequences will be repeated and
        have sequential subscripts.
    Type `int`. """

    sequence: typing.Optional[str]

    """ Actual nucleotide sequence notation from 5' to 3' end using
        standard single letter codes. In addition to the base sequence,
        sugar and type of phosphate or non-phosphate linkage should also be
        captured.
    Type `str`. """

    length: typing.Optional[int]

    """ The length of the sequence shall be captured.
    Type `int`. """

    sequenceAttachment: typing.Optional["Attachment"]

    """ (TBC).
    Type `Attachment` (represented as `dict` in JSON). """

    fivePrime: typing.Optional["CodeableConcept"]

    """ The nucleotide present at the 5’ terminal shall be specified based
        on a controlled vocabulary. Since the sequence is represented from
        the 5' to the 3' end, the 5’ prime nucleotide is the letter at the
        first position in the sequence. A separate representation would be
        redundant.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    threePrime: typing.Optional["CodeableConcept"]

    """ The nucleotide present at the 3’ terminal shall be specified based
        on a controlled vocabulary. Since the sequence is represented from
        the 5' to the 3' end, the 5’ prime nucleotide is the letter at the
        last position in the sequence. A separate representation would be
        redundant.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    linkage: typing.Optional[typing.List["SubstanceNucleicAcidSubunitLinkage"]]

    """ The linkages between sugar residues will also be captured.
    List of `SubstanceNucleicAcidSubunitLinkage` items (represented as `dict` in JSON). """

    sugar: typing.Optional[typing.List["SubstanceNucleicAcidSubunitSugar"]]

    """ 5.3.6.8.1 Sugar ID (Mandatory).
    List of `SubstanceNucleicAcidSubunitSugar` items (represented as `dict` in JSON). """




    

     
    



class SubstanceNucleicAcidSubunitLinkage(BackboneElement):
    """ The linkages between sugar residues will also be captured.
    """
    
    # [<FHIRClassProperty self.name='connectivity' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='residueSite' >]
  

    connectivity: typing.Optional[str]

    """ The entity that links the sugar residues together should also be
        captured for nearly all naturally occurring nucleic acid the
        linkage is a phosphate group. For many synthetic oligonucleotides
        phosphorothioate linkages are often seen. Linkage connectivity is
        assumed to be 3’-5’. If the linkage is either 3’-3’ or 5’-5’ this
        should be specified.
    Type `str`. """

    identifier: typing.Optional["Identifier"]

    """ Each linkage will be registered as a fragment and have an ID.
    Type `Identifier` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Each linkage will be registered as a fragment and have at least one
        name. A single name shall be assigned to each linkage.
    Type `str`. """

    residueSite: typing.Optional[str]

    """ Residues shall be captured as described in 5.3.6.8.3.
    Type `str`. """




    

     
    



class SubstanceNucleicAcidSubunitSugar(BackboneElement):
    """ 5.3.6.8.1 Sugar ID (Mandatory).
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='residueSite' >]
  

    identifier: typing.Optional["Identifier"]

    """ The Substance ID of the sugar or sugar-like component that make up
        the nucleotide.
    Type `Identifier` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ The name of the sugar or sugar-like component that make up the
        nucleotide.
    Type `str`. """

    residueSite: typing.Optional[str]

    """ The residues that contain a given sugar will be captured. The order
        of given residues will be captured in the 5‘-3‘direction consistent
        with the base sequences listed above.
    Type `str`. """




    

     
    



class SubstancePolymerMonomerSet(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='ratioType' >, <FHIRClassProperty self.name='startingMaterial' >]
  

    ratioType: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    startingMaterial: typing.Optional[typing.List["SubstancePolymerMonomerSetStartingMaterial"]]

    """ Todo.
    List of `SubstancePolymerMonomerSetStartingMaterial` items (represented as `dict` in JSON). """




    

     
    



class SubstancePolymerMonomerSetStartingMaterial(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='material' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='isDefining' >, <FHIRClassProperty self.name='amount' >]
  

    material: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    isDefining: typing.Optional[bool]

    """ Todo.
    Type `bool`. """

    amount: typing.Optional["SubstanceAmount"]

    """ Todo.
    Type `SubstanceAmount` (represented as `dict` in JSON). """




    

     
    



class SubstancePolymerRepeat(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='numberOfUnits' >, <FHIRClassProperty self.name='averageMolecularFormula' >, <FHIRClassProperty self.name='repeatUnitAmountType' >, <FHIRClassProperty self.name='repeatUnit' >]
  

    numberOfUnits: typing.Optional[int]

    """ Todo.
    Type `int`. """

    averageMolecularFormula: typing.Optional[str]

    """ Todo.
    Type `str`. """

    repeatUnitAmountType: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    repeatUnit: typing.Optional[typing.List["SubstancePolymerRepeatRepeatUnit"]]

    """ Todo.
    List of `SubstancePolymerRepeatRepeatUnit` items (represented as `dict` in JSON). """




    

     
    



class SubstancePolymerRepeatRepeatUnit(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='orientationOfPolymerisation' >, <FHIRClassProperty self.name='repeatUnit' >, <FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='degreeOfPolymerisation' >, <FHIRClassProperty self.name='structuralRepresentation' >]
  

    orientationOfPolymerisation: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    repeatUnit: typing.Optional[str]

    """ Todo.
    Type `str`. """

    amount: typing.Optional["SubstanceAmount"]

    """ Todo.
    Type `SubstanceAmount` (represented as `dict` in JSON). """

    degreeOfPolymerisation: typing.Optional[typing.List["SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisation"]]

    """ Todo.
    List of `SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisation` items (represented as `dict` in JSON). """

    structuralRepresentation: typing.Optional[typing.List["SubstancePolymerRepeatRepeatUnitStructuralRepresentation"]]

    """ Todo.
    List of `SubstancePolymerRepeatRepeatUnitStructuralRepresentation` items (represented as `dict` in JSON). """




    

     
    



class SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisation(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='degree' >, <FHIRClassProperty self.name='amount' >]
  

    degree: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["SubstanceAmount"]

    """ Todo.
    Type `SubstanceAmount` (represented as `dict` in JSON). """




    

     
    



class SubstancePolymerRepeatRepeatUnitStructuralRepresentation(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='representation' >, <FHIRClassProperty self.name='attachment' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    representation: typing.Optional[str]

    """ Todo.
    Type `str`. """

    attachment: typing.Optional["Attachment"]

    """ Todo.
    Type `Attachment` (represented as `dict` in JSON). """




    

     
    



class SubstanceProteinSubunit(BackboneElement):
    """ This subclause refers to the description of each subunit constituting the
    SubstanceProtein. A subunit is a linear sequence of amino acids linked
    through peptide bonds. The Subunit information shall be provided when the
    finished SubstanceProtein is a complex of multiple sequences; subunits are
    not used to delineate domains within a single sequence. Subunits are listed
    in order of decreasing length; sequences of the same length will be ordered
    by decreasing molecular weight; subunits that have identical sequences will
    be repeated multiple times.
    """
    
    # [<FHIRClassProperty self.name='subunit' >, <FHIRClassProperty self.name='sequence' >, <FHIRClassProperty self.name='length' >, <FHIRClassProperty self.name='sequenceAttachment' >, <FHIRClassProperty self.name='nTerminalModificationId' >, <FHIRClassProperty self.name='nTerminalModification' >, <FHIRClassProperty self.name='cTerminalModificationId' >, <FHIRClassProperty self.name='cTerminalModification' >]
  

    subunit: typing.Optional[int]

    """ Index of primary sequences of amino acids linked through peptide
        bonds in order of decreasing length. Sequences of the same length
        will be ordered by molecular weight. Subunits that have identical
        sequences will be repeated and have sequential subscripts.
    Type `int`. """

    sequence: typing.Optional[str]

    """ The sequence information shall be provided enumerating the amino
        acids from N- to C-terminal end using standard single-letter amino
        acid codes. Uppercase shall be used for L-amino acids and lowercase
        for D-amino acids. Transcribed SubstanceProteins will always be
        described using the translated sequence; for synthetic peptide
        containing amino acids that are not represented with a single
        letter code an X should be used within the sequence. The modified
        amino acids will be distinguished by their position in the sequence.
    Type `str`. """

    length: typing.Optional[int]

    """ Length of linear sequences of amino acids contained in the subunit.
    Type `int`. """

    sequenceAttachment: typing.Optional["Attachment"]

    """ The sequence information shall be provided enumerating the amino
        acids from N- to C-terminal end using standard single-letter amino
        acid codes. Uppercase shall be used for L-amino acids and lowercase
        for D-amino acids. Transcribed SubstanceProteins will always be
        described using the translated sequence; for synthetic peptide
        containing amino acids that are not represented with a single
        letter code an X should be used within the sequence. The modified
        amino acids will be distinguished by their position in the sequence.
    Type `Attachment` (represented as `dict` in JSON). """

    nTerminalModificationId: typing.Optional["Identifier"]

    """ Unique identifier for molecular fragment modification based on the
        ISO 11238 Substance ID.
    Type `Identifier` (represented as `dict` in JSON). """

    nTerminalModification: typing.Optional[str]

    """ The name of the fragment modified at the N-terminal of the
        SubstanceProtein shall be specified.
    Type `str`. """

    cTerminalModificationId: typing.Optional["Identifier"]

    """ Unique identifier for molecular fragment modification based on the
        ISO 11238 Substance ID.
    Type `Identifier` (represented as `dict` in JSON). """

    cTerminalModification: typing.Optional[str]

    """ The modification at the C-terminal shall be specified.
    Type `str`. """




    

     
    



class SubstanceReferenceInformationGene(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='geneSequenceOrigin' >, <FHIRClassProperty self.name='gene' >, <FHIRClassProperty self.name='source' >]
  

    geneSequenceOrigin: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    gene: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Todo.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class SubstanceReferenceInformationGeneElement(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='element' >, <FHIRClassProperty self.name='source' >]
  

    type: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    element: typing.Optional["Identifier"]

    """ Todo.
    Type `Identifier` (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Todo.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class SubstanceReferenceInformationClassification(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='domain' >, <FHIRClassProperty self.name='classification' >, <FHIRClassProperty self.name='subtype' >, <FHIRClassProperty self.name='source' >]
  

    domain: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    classification: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    subtype: typing.Optional[typing.List["CodeableConcept"]]

    """ Todo.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Todo.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class SubstanceReferenceInformationTarget(BackboneElement):
    """ Todo.
    """
    
    # [<FHIRClassProperty self.name='target' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='interaction' >, <FHIRClassProperty self.name='organism' >, <FHIRClassProperty self.name='organismType' >, <FHIRClassProperty self.name='amountQuantity' >, <FHIRClassProperty self.name='amountRange' >, <FHIRClassProperty self.name='amountString' >, <FHIRClassProperty self.name='amountType' >, <FHIRClassProperty self.name='source' >]
  

    target: typing.Optional["Identifier"]

    """ Todo.
    Type `Identifier` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    interaction: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    organism: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    organismType: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amountQuantity: typing.Optional["Quantity"]

    """ Todo.
    Type `Quantity` (represented as `dict` in JSON). """

    amountRange: typing.Optional["Range"]

    """ Todo.
    Type `Range` (represented as `dict` in JSON). """

    amountString: typing.Optional[str]

    """ Todo.
    Type `str`. """

    amountType: typing.Optional["CodeableConcept"]

    """ Todo.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Todo.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'SubstanceReferenceInformation.target.amount[x]', 'choice_of_type': 'amount', 'orig_name': 'amountQuantity', 'name': 'amountQuantity', 'parent_name': 'SubstanceReferenceInformation.target', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Todo', 'formal': None, 'representation': None}

    _amount_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['amountQuantity', 'amountRange', 'amountString']), True))


    

     
    



class SubstanceSourceMaterialFractionDescription(BackboneElement):
    """ Many complex materials are fractions of parts of plants, animals, or
    minerals. Fraction elements are often necessary to define both Substances
    and Specified Group 1 Substances. For substances derived from Plants,
    fraction information will be captured at the Substance information level (
    . Oils, Juices and Exudates). Additional information for Extracts, such as
    extraction solvent composition, will be captured at the Specified Substance
    Group 1 information level. For plasma-derived products fraction information
    will be captured at the Substance and the Specified Substance Group 1
    levels.
    """
    
    # [<FHIRClassProperty self.name='fraction' >, <FHIRClassProperty self.name='materialType' >]
  

    fraction: typing.Optional[str]

    """ This element is capturing information about the fraction of a plant
        part, or human plasma for fractionation.
    Type `str`. """

    materialType: typing.Optional["CodeableConcept"]

    """ The specific type of the material constituting the component. For
        Herbal preparations the particulars of the extracts (liquid/dry) is
        described in Specified Substance Group 1.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class SubstanceSourceMaterialOrganism(BackboneElement):
    """ This subclause describes the organism which the substance is derived from.
    For vaccines, the parent organism shall be specified based on these
    subclause elements. As an example, full taxonomy will be described for the
    Substance Name: ., Leaf.
    """
    
    # [<FHIRClassProperty self.name='family' >, <FHIRClassProperty self.name='genus' >, <FHIRClassProperty self.name='species' >, <FHIRClassProperty self.name='intraspecificType' >, <FHIRClassProperty self.name='intraspecificDescription' >, <FHIRClassProperty self.name='author' >, <FHIRClassProperty self.name='hybrid' >, <FHIRClassProperty self.name='organismGeneral' >]
  

    family: typing.Optional["CodeableConcept"]

    """ The family of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    genus: typing.Optional["CodeableConcept"]

    """ The genus of an organism shall be specified; refers to the Latin
        epithet of the genus element of the plant/animal scientific name;
        it is present in names for genera, species and infraspecies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    species: typing.Optional["CodeableConcept"]

    """ The species of an organism shall be specified; refers to the Latin
        epithet of the species of the plant/animal; it is present in names
        for species and infraspecies.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intraspecificType: typing.Optional["CodeableConcept"]

    """ The Intraspecific type of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    intraspecificDescription: typing.Optional[str]

    """ The intraspecific description of an organism shall be specified
        based on a controlled vocabulary. For Influenza Vaccine, the
        intraspecific description shall contain the syntax of the antigen
        in line with the WHO convention.
    Type `str`. """

    author: typing.Optional[typing.List["SubstanceSourceMaterialOrganismAuthor"]]

    """ 4.9.13.6.1 Author type (Conditional).
    List of `SubstanceSourceMaterialOrganismAuthor` items (represented as `dict` in JSON). """

    hybrid: typing.Optional["SubstanceSourceMaterialOrganismHybrid"]

    """ 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
    Type `SubstanceSourceMaterialOrganismHybrid` (represented as `dict` in JSON). """

    organismGeneral: typing.Optional["SubstanceSourceMaterialOrganismOrganismGeneral"]

    """ 4.9.13.7.1 Kingdom (Conditional).
    Type `SubstanceSourceMaterialOrganismOrganismGeneral` (represented as `dict` in JSON). """




    

     
    



class SubstanceSourceMaterialOrganismAuthor(BackboneElement):
    """ 4.9.13.6.1 Author type (Conditional).
    """
    
    # [<FHIRClassProperty self.name='authorType' >, <FHIRClassProperty self.name='authorDescription' >]
  

    authorType: typing.Optional["CodeableConcept"]

    """ The type of author of an organism species shall be specified. The
        parenthetical author of an organism species refers to the first
        author who published the plant/animal name (of any rank). The
        primary author of an organism species refers to the first
        author(s), who validly published the plant/animal name.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    authorDescription: typing.Optional[str]

    """ The author of an organism species shall be specified. The author
        year of an organism shall also be specified when applicable; refers
        to the year in which the first author(s) published the
        infraspecific plant/animal name (of any rank).
    Type `str`. """




    

     
    



class SubstanceSourceMaterialOrganismHybrid(BackboneElement):
    """ 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
    """
    
    # [<FHIRClassProperty self.name='maternalOrganismId' >, <FHIRClassProperty self.name='maternalOrganismName' >, <FHIRClassProperty self.name='paternalOrganismId' >, <FHIRClassProperty self.name='paternalOrganismName' >, <FHIRClassProperty self.name='hybridType' >]
  

    maternalOrganismId: typing.Optional[str]

    """ The identifier of the maternal species constituting the hybrid
        organism shall be specified based on a controlled vocabulary. For
        plants, the parents aren’t always known, and it is unlikely that it
        will be known which is maternal and which is paternal.
    Type `str`. """

    maternalOrganismName: typing.Optional[str]

    """ The name of the maternal species constituting the hybrid organism
        shall be specified. For plants, the parents aren’t always known,
        and it is unlikely that it will be known which is maternal and
        which is paternal.
    Type `str`. """

    paternalOrganismId: typing.Optional[str]

    """ The identifier of the paternal species constituting the hybrid
        organism shall be specified based on a controlled vocabulary.
    Type `str`. """

    paternalOrganismName: typing.Optional[str]

    """ The name of the paternal species constituting the hybrid organism
        shall be specified.
    Type `str`. """

    hybridType: typing.Optional["CodeableConcept"]

    """ The hybrid type of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class SubstanceSourceMaterialOrganismOrganismGeneral(BackboneElement):
    """ 4.9.13.7.1 Kingdom (Conditional).
    """
    
    # [<FHIRClassProperty self.name='kingdom' >, <FHIRClassProperty self.name='phylum' >, <FHIRClassProperty self.name='class_' >, <FHIRClassProperty self.name='order' >]
  

    kingdom: typing.Optional["CodeableConcept"]

    """ The kingdom of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    phylum: typing.Optional["CodeableConcept"]

    """ The phylum of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    class_: typing.Optional["CodeableConcept"]

    """ The class of an organism shall be specified.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    order: typing.Optional["CodeableConcept"]

    """ The order of an organism shall be specified,.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class SubstanceSourceMaterialPartDescription(BackboneElement):
    """ To do.
    """
    
    # [<FHIRClassProperty self.name='part' >, <FHIRClassProperty self.name='partLocation' >]
  

    part: typing.Optional["CodeableConcept"]

    """ Entity of anatomical origin of source material within an organism.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    partLocation: typing.Optional["CodeableConcept"]

    """ The detailed anatomic location when the part can be extracted from
        different anatomical locations of the organism. Multiple
        alternative locations may apply.
    Type `CodeableConcept` (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationMoiety(BackboneElement):
    """ Moiety, for structural modifications.
    """
    
    # [<FHIRClassProperty self.name='role' >, <FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='stereochemistry' >, <FHIRClassProperty self.name='opticalActivity' >, <FHIRClassProperty self.name='molecularFormula' >, <FHIRClassProperty self.name='amountQuantity' >, <FHIRClassProperty self.name='amountString' >]
  

    role: typing.Optional["CodeableConcept"]

    """ Role that the moiety is playing.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    identifier: typing.Optional["Identifier"]

    """ Identifier by which this moiety substance is known.
    Type `Identifier` (represented as `dict` in JSON). """

    name: typing.Optional[str]

    """ Textual name for this moiety substance.
    Type `str`. """

    stereochemistry: typing.Optional["CodeableConcept"]

    """ Stereochemistry type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    opticalActivity: typing.Optional["CodeableConcept"]

    """ Optical activity type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    molecularFormula: typing.Optional[str]

    """ Molecular formula.
    Type `str`. """

    amountQuantity: typing.Optional["Quantity"]

    """ Quantitative value for this moiety.
    Type `Quantity` (represented as `dict` in JSON). """

    amountString: typing.Optional[str]

    """ Quantitative value for this moiety.
    Type `str`. """



#   {'path': 'SubstanceSpecification.moiety.amount[x]', 'choice_of_type': 'amount', 'orig_name': 'amountQuantity', 'name': 'amountQuantity', 'parent_name': 'SubstanceSpecification.moiety', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Quantitative value for this moiety', 'formal': None, 'representation': None}

    _amount_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['amountQuantity', 'amountString']), True))


    

     
    



class SubstanceSpecificationProperty(BackboneElement):
    """ General specifications for this substance, including how it is related to
    other substances.
    """
    
    # [<FHIRClassProperty self.name='category' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='parameters' >, <FHIRClassProperty self.name='definingSubstanceReference' >, <FHIRClassProperty self.name='definingSubstanceCodeableConcept' >, <FHIRClassProperty self.name='amountQuantity' >, <FHIRClassProperty self.name='amountString' >]
  

    category: typing.Optional["CodeableConcept"]

    """ A category for this property, e.g. Physical, Chemical, Enzymatic.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    code: typing.Optional["CodeableConcept"]

    """ Property type e.g. viscosity, pH, isoelectric point.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    parameters: typing.Optional[str]

    """ Parameters that were used in the measurement of a property (e.g.
        for viscosity: measured at 20C with a pH of 7.1).
    Type `str`. """

    definingSubstanceReference: typing.Optional["Reference"]

    """ A substance upon which a defining property depends (e.g. for
        solubility: in water, in alcohol).
    Type `Reference` (represented as `dict` in JSON). """

    definingSubstanceCodeableConcept: typing.Optional["CodeableConcept"]

    """ A substance upon which a defining property depends (e.g. for
        solubility: in water, in alcohol).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amountQuantity: typing.Optional["Quantity"]

    """ Quantitative value for this property.
    Type `Quantity` (represented as `dict` in JSON). """

    amountString: typing.Optional[str]

    """ Quantitative value for this property.
    Type `str`. """



#   {'path': 'SubstanceSpecification.property.definingSubstance[x]', 'choice_of_type': 'definingSubstance', 'orig_name': 'definingSubstanceReference', 'name': 'definingSubstanceReference', 'parent_name': 'SubstanceSpecification.property', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'A substance upon which a defining property depends (e.g. for solubility: in water, in alcohol)', 'formal': None, 'representation': None}

    _definingSubstance_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['definingSubstanceReference', 'definingSubstanceCodeableConcept']), True))

#   {'path': 'SubstanceSpecification.property.amount[x]', 'choice_of_type': 'amount', 'orig_name': 'amountQuantity', 'name': 'amountQuantity', 'parent_name': 'SubstanceSpecification.property', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Quantitative value for this property', 'formal': None, 'representation': None}

    _amount_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['amountQuantity', 'amountString']), True))


    

     
    



class SubstanceSpecificationStructure(BackboneElement):
    """ Structural information.
    """
    
    # [<FHIRClassProperty self.name='stereochemistry' >, <FHIRClassProperty self.name='opticalActivity' >, <FHIRClassProperty self.name='molecularFormula' >, <FHIRClassProperty self.name='molecularFormulaByMoiety' >, <FHIRClassProperty self.name='isotope' >, <FHIRClassProperty self.name='molecularWeight' >, <FHIRClassProperty self.name='source' >, <FHIRClassProperty self.name='representation' >]
  

    stereochemistry: typing.Optional["CodeableConcept"]

    """ Stereochemistry type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    opticalActivity: typing.Optional["CodeableConcept"]

    """ Optical activity type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    molecularFormula: typing.Optional[str]

    """ Molecular formula.
    Type `str`. """

    molecularFormulaByMoiety: typing.Optional[str]

    """ Specified per moiety according to the Hill system, i.e. first C,
        then H, then alphabetical, each moiety separated by a dot.
    Type `str`. """

    isotope: typing.Optional[typing.List["SubstanceSpecificationStructureIsotope"]]

    """ Applicable for single substances that contain a radionuclide or a
        non-natural isotopic ratio.
    List of `SubstanceSpecificationStructureIsotope` items (represented as `dict` in JSON). """

    molecularWeight: typing.Optional["SubstanceSpecificationStructureIsotopeMolecularWeight"]

    """ The molecular weight or weight range (for proteins, polymers or
        nucleic acids).
    Type `SubstanceSpecificationStructureIsotopeMolecularWeight` (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Supporting literature.
    List of `Reference` items (represented as `dict` in JSON). """

    representation: typing.Optional[typing.List["SubstanceSpecificationStructureRepresentation"]]

    """ Molecular structural representation.
    List of `SubstanceSpecificationStructureRepresentation` items (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationStructureIsotope(BackboneElement):
    """ Applicable for single substances that contain a radionuclide or a non-
    natural isotopic ratio.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='substitution' >, <FHIRClassProperty self.name='halfLife' >, <FHIRClassProperty self.name='molecularWeight' >]
  

    identifier: typing.Optional["Identifier"]

    """ Substance identifier for each non-natural or radioisotope.
    Type `Identifier` (represented as `dict` in JSON). """

    name: typing.Optional["CodeableConcept"]

    """ Substance name for each non-natural or radioisotope.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    substitution: typing.Optional["CodeableConcept"]

    """ The type of isotopic substitution present in a single substance.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    halfLife: typing.Optional["Quantity"]

    """ Half life - for a non-natural nuclide.
    Type `Quantity` (represented as `dict` in JSON). """

    molecularWeight: typing.Optional["SubstanceSpecificationStructureIsotopeMolecularWeight"]

    """ The molecular weight or weight range (for proteins, polymers or
        nucleic acids).
    Type `SubstanceSpecificationStructureIsotopeMolecularWeight` (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationStructureIsotopeMolecularWeight(BackboneElement):
    """ The molecular weight or weight range (for proteins, polymers or nucleic
    acids).
    """
    
    # [<FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='amount' >]
  

    method: typing.Optional["CodeableConcept"]

    """ The method by which the molecular weight was determined.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    type: typing.Optional["CodeableConcept"]

    """ Type of molecular weight such as exact, average (also known as.
        number average), weight average.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    amount: typing.Optional["Quantity"]

    """ Used to capture quantitative values for a variety of elements. If
        only limits are given, the arithmetic mean would be the average. If
        only a single definite value for a given element is given, it would
        be captured in this field.
    Type `Quantity` (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationStructureRepresentation(BackboneElement):
    """ Molecular structural representation.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='representation' >, <FHIRClassProperty self.name='attachment' >]
  

    type: typing.Optional["CodeableConcept"]

    """ The type of structure (e.g. Full, Partial, Representative).
    Type `CodeableConcept` (represented as `dict` in JSON). """

    representation: typing.Optional[str]

    """ The structural representation as text string in a format e.g.
        InChI, SMILES, MOLFILE, CDX.
    Type `str`. """

    attachment: typing.Optional["Attachment"]

    """ An attached file with the structural representation.
    Type `Attachment` (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationstr(BackboneElement):
    """ Codes associated with the substance.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='statusDate' >, <FHIRClassProperty self.name='comment' >, <FHIRClassProperty self.name='source' >]
  

    code: typing.Optional["CodeableConcept"]

    """ The specific code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ Status of the code assignment.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    statusDate: typing.Optional["FHIRDate"]

    """ The date at which the code status is changed as part of the
        terminology maintenance.
    Type `FHIRDate` (represented as `str` in JSON). """

    comment: typing.Optional[str]

    """ Any comment can be provided in this field, if necessary.
    Type `str`. """

    source: typing.Optional[typing.List["Reference"]]

    """ Supporting literature.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationName(BackboneElement):
    """ Names applicable to this substance.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='preferred' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='domain' >, <FHIRClassProperty self.name='jurisdiction' >, <FHIRClassProperty self.name='synonym' >, <FHIRClassProperty self.name='translation' >, <FHIRClassProperty self.name='official' >, <FHIRClassProperty self.name='source' >]
  

    name: str

    """ The actual name.
    Type `str`. """

    type: typing.Optional["CodeableConcept"]

    """ Name type.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ The status of the name.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    preferred: typing.Optional[bool]

    """ If this is the preferred name for this substance.
    Type `bool`. """

    language: typing.Optional[typing.List["CodeableConcept"]]

    """ Language of the name.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    domain: typing.Optional[typing.List["CodeableConcept"]]

    """ The use context of this name for example if there is a different
        name a drug active ingredient as opposed to a food colour additive.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    jurisdiction: typing.Optional[typing.List["CodeableConcept"]]

    """ The jurisdiction where this name applies.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    synonym: typing.Optional[typing.List["SubstanceSpecificationName"]]

    """ A synonym of this name.
    List of `SubstanceSpecificationName` items (represented as `dict` in JSON). """

    translation: typing.Optional[typing.List["SubstanceSpecificationName"]]

    """ A translation for this name.
    List of `SubstanceSpecificationName` items (represented as `dict` in JSON). """

    official: typing.Optional[typing.List["SubstanceSpecificationNameOfficial"]]

    """ Details of the official nature of this name.
    List of `SubstanceSpecificationNameOfficial` items (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Supporting literature.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class SubstanceSpecificationNameOfficial(BackboneElement):
    """ Details of the official nature of this name.
    """
    
    # [<FHIRClassProperty self.name='authority' >, <FHIRClassProperty self.name='status' >, <FHIRClassProperty self.name='date' >]
  

    authority: typing.Optional["CodeableConcept"]

    """ Which authority uses this official name.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    status: typing.Optional["CodeableConcept"]

    """ The status of the official name.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ Date of official name change.
    Type `FHIRDate` (represented as `str` in JSON). """




    

     
    



class SubstanceSpecificationRelationship(BackboneElement):
    """ A link between this substance and another, with details of the relationship.
    """
    
    # [<FHIRClassProperty self.name='substanceReference' >, <FHIRClassProperty self.name='substanceCodeableConcept' >, <FHIRClassProperty self.name='relationship' >, <FHIRClassProperty self.name='isDefining' >, <FHIRClassProperty self.name='amountQuantity' >, <FHIRClassProperty self.name='amountRange' >, <FHIRClassProperty self.name='amountRatio' >, <FHIRClassProperty self.name='amountString' >, <FHIRClassProperty self.name='amountRatioLowLimit' >, <FHIRClassProperty self.name='amountType' >, <FHIRClassProperty self.name='source' >]
  

    substanceReference: typing.Optional["Reference"]

    """ A pointer to another substance, as a resource or just a
        representational code.
    Type `Reference` (represented as `dict` in JSON). """

    substanceCodeableConcept: typing.Optional["CodeableConcept"]

    """ A pointer to another substance, as a resource or just a
        representational code.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    relationship: typing.Optional["CodeableConcept"]

    """ For example "salt to parent", "active moiety", "starting material".
    Type `CodeableConcept` (represented as `dict` in JSON). """

    isDefining: typing.Optional[bool]

    """ For example where an enzyme strongly bonds with a particular
        substance, this is a defining relationship for that enzyme, out of
        several possible substance relationships.
    Type `bool`. """

    amountQuantity: typing.Optional["Quantity"]

    """ A numeric factor for the relationship, for instance to express that
        the salt of a substance has some percentage of the active substance
        in relation to some other.
    Type `Quantity` (represented as `dict` in JSON). """

    amountRange: typing.Optional["Range"]

    """ A numeric factor for the relationship, for instance to express that
        the salt of a substance has some percentage of the active substance
        in relation to some other.
    Type `Range` (represented as `dict` in JSON). """

    amountRatio: typing.Optional["Ratio"]

    """ A numeric factor for the relationship, for instance to express that
        the salt of a substance has some percentage of the active substance
        in relation to some other.
    Type `Ratio` (represented as `dict` in JSON). """

    amountString: typing.Optional[str]

    """ A numeric factor for the relationship, for instance to express that
        the salt of a substance has some percentage of the active substance
        in relation to some other.
    Type `str`. """

    amountRatioLowLimit: typing.Optional["Ratio"]

    """ For use when the numeric.
    Type `Ratio` (represented as `dict` in JSON). """

    amountType: typing.Optional["CodeableConcept"]

    """ An operator for the amount, for example "average", "approximately",
        "less than".
    Type `CodeableConcept` (represented as `dict` in JSON). """

    source: typing.Optional[typing.List["Reference"]]

    """ Supporting literature.
    List of `Reference` items (represented as `dict` in JSON). """



#   {'path': 'SubstanceSpecification.relationship.substance[x]', 'choice_of_type': 'substance', 'orig_name': 'substanceReference', 'name': 'substanceReference', 'parent_name': 'SubstanceSpecification.relationship', 'class_name': 'Reference', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'A pointer to another substance, as a resource or just a representational code', 'formal': None, 'representation': None}

    _substance_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['substanceReference', 'substanceCodeableConcept']), True))

#   {'path': 'SubstanceSpecification.relationship.amount[x]', 'choice_of_type': 'amount', 'orig_name': 'amountQuantity', 'name': 'amountQuantity', 'parent_name': 'SubstanceSpecification.relationship', 'class_name': 'Quantity', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': True, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'A numeric factor for the relationship, for instance to express that the salt of a substance has some percentage of the active substance in relation to some other', 'formal': None, 'representation': None}

    _amount_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['amountQuantity', 'amountRange', 'amountRatio', 'amountString']), True))


    

     
    



class SupplyDeliverySuppliedItem(BackboneElement):
    """ The item that is delivered or supplied.
    
    The item that is being delivered or has been supplied.
    """
    
    # [<FHIRClassProperty self.name='quantity' >, <FHIRClassProperty self.name='itemCodeableConcept' >, <FHIRClassProperty self.name='itemReference' >]
  

    quantity: typing.Optional["Quantity"]

    """ Amount dispensed.
    Type `Quantity` (represented as `dict` in JSON). """

    itemCodeableConcept: typing.Optional["CodeableConcept"]

    """ Medication, Substance, or Device supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    itemReference: typing.Optional["Reference"]

    """ Medication, Substance, or Device supplied.
    Type `Reference` (represented as `dict` in JSON). """



#   {'path': 'SupplyDelivery.suppliedItem.item[x]', 'choice_of_type': 'item', 'orig_name': 'itemCodeableConcept', 'name': 'itemCodeableConcept', 'parent_name': 'SupplyDelivery.suppliedItem', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Medication, Substance, or Device supplied', 'formal': 'Identifies the medication, substance or device being dispensed. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.', 'representation': None}

    _item_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['itemCodeableConcept', 'itemReference']), True))


    

     
    



class SupplyRequestParameter(BackboneElement):
    """ Ordered item details.
    
    Specific parameters for the ordered item.  For example, the size of the
    indicated item.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueBoolean' >]
  

    code: typing.Optional["CodeableConcept"]

    """ Item detail.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Value of detail.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Value of detail.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Value of detail.
    Type `Range` (represented as `dict` in JSON). """

    valueBoolean: typing.Optional[bool]

    """ Value of detail.
    Type `bool`. """



#   {'path': 'SupplyRequest.parameter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueCodeableConcept', 'name': 'valueCodeableConcept', 'parent_name': 'SupplyRequest.parameter', 'class_name': 'CodeableConcept', 'enum': None, 'module_name': None, 'json_class': 'dict', 'is_native': False, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value of detail', 'formal': 'The value of the device detail.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueCodeableConcept', 'valueQuantity', 'valueRange', 'valueBoolean']), True))


    

     
    



class TaskRestriction(BackboneElement):
    """ Constraints on fulfillment tasks.
    
    If the Task.focus is a request resource and the task is seeking fulfillment
    (i.e. is asking for the request to be actioned), this element identifies
    any limitations on what parts of the referenced request should be actioned.
    """
    
    # [<FHIRClassProperty self.name='repetitions' >, <FHIRClassProperty self.name='period' >, <FHIRClassProperty self.name='recipient' >]
  

    repetitions: typing.Optional[int]

    """ How many times to repeat.
    Type `int`. """

    period: typing.Optional["Period"]

    """ When fulfillment sought.
    Type `Period` (represented as `dict` in JSON). """

    recipient: typing.Optional[typing.List["Reference"]]

    """ For whom is fulfillment sought?.
    List of `Reference` items (represented as `dict` in JSON). """




    

     
    



class TaskInput(BackboneElement):
    """ Information used to perform task.
    
    Additional information that may be needed in the execution of the task.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueBase64Binary' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueCanonical' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueInstant' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueMarkdown' >, <FHIRClassProperty self.name='valueOid' >, <FHIRClassProperty self.name='valuePositiveInt' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueUnsignedInt' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueUrl' >, <FHIRClassProperty self.name='valueUuid' >, <FHIRClassProperty self.name='valueAddress' >, <FHIRClassProperty self.name='valueAge' >, <FHIRClassProperty self.name='valueAnnotation' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueContactPoint' >, <FHIRClassProperty self.name='valueCount' >, <FHIRClassProperty self.name='valueDistance' >, <FHIRClassProperty self.name='valueDuration' >, <FHIRClassProperty self.name='valueHumanName' >, <FHIRClassProperty self.name='valueIdentifier' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueSignature' >, <FHIRClassProperty self.name='valueTiming' >, <FHIRClassProperty self.name='valueContactDetail' >, <FHIRClassProperty self.name='valueContributor' >, <FHIRClassProperty self.name='valueDataRequirement' >, <FHIRClassProperty self.name='valueExpression' >, <FHIRClassProperty self.name='valueParameterDefinition' >, <FHIRClassProperty self.name='valueRelatedArtifact' >, <FHIRClassProperty self.name='valueTriggerDefinition' >, <FHIRClassProperty self.name='valueUsageContext' >, <FHIRClassProperty self.name='valueDosage' >, <FHIRClassProperty self.name='valueMeta' >]
  

    type: "CodeableConcept"

    """ Label for the input.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueBase64Binary: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Content to use in performing the task.
    Type `bool`. """

    valueCanonical: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Content to use in performing the task.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Content to use in performing the task.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ Content to use in performing the task.
    Type `float`. """

    valueId: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueInstant: typing.Optional["FHIRDate"]

    """ Content to use in performing the task.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueInteger: typing.Optional[int]

    """ Content to use in performing the task.
    Type `int`. """

    valueMarkdown: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueOid: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valuePositiveInt: typing.Optional[int]

    """ Content to use in performing the task.
    Type `int`. """

    valueString: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueTime: typing.Optional["FHIRDate"]

    """ Content to use in performing the task.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueUnsignedInt: typing.Optional[int]

    """ Content to use in performing the task.
    Type `int`. """

    valueUri: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueUrl: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueUuid: typing.Optional[str]

    """ Content to use in performing the task.
    Type `str`. """

    valueAddress: typing.Optional["Address"]

    """ Content to use in performing the task.
    Type `Address` (represented as `dict` in JSON). """

    valueAge: typing.Optional["Age"]

    """ Content to use in performing the task.
    Type `Age` (represented as `dict` in JSON). """

    valueAnnotation: typing.Optional["Annotation"]

    """ Content to use in performing the task.
    Type `Annotation` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Content to use in performing the task.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Content to use in performing the task.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Content to use in performing the task.
    Type `Coding` (represented as `dict` in JSON). """

    valueContactPoint: typing.Optional["ContactPoint"]

    """ Content to use in performing the task.
    Type `ContactPoint` (represented as `dict` in JSON). """

    valueCount: typing.Optional["Count"]

    """ Content to use in performing the task.
    Type `Count` (represented as `dict` in JSON). """

    valueDistance: typing.Optional["Distance"]

    """ Content to use in performing the task.
    Type `Distance` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ Content to use in performing the task.
    Type `Duration` (represented as `dict` in JSON). """

    valueHumanName: typing.Optional["HumanName"]

    """ Content to use in performing the task.
    Type `HumanName` (represented as `dict` in JSON). """

    valueIdentifier: typing.Optional["Identifier"]

    """ Content to use in performing the task.
    Type `Identifier` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ Content to use in performing the task.
    Type `Money` (represented as `dict` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Content to use in performing the task.
    Type `Period` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Content to use in performing the task.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Content to use in performing the task.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Content to use in performing the task.
    Type `Ratio` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Content to use in performing the task.
    Type `Reference` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Content to use in performing the task.
    Type `SampledData` (represented as `dict` in JSON). """

    valueSignature: typing.Optional["Signature"]

    """ Content to use in performing the task.
    Type `Signature` (represented as `dict` in JSON). """

    valueTiming: typing.Optional["Timing"]

    """ Content to use in performing the task.
    Type `Timing` (represented as `dict` in JSON). """

    valueContactDetail: typing.Optional["ContactDetail"]

    """ Content to use in performing the task.
    Type `ContactDetail` (represented as `dict` in JSON). """

    valueContributor: typing.Optional["Contributor"]

    """ Content to use in performing the task.
    Type `Contributor` (represented as `dict` in JSON). """

    valueDataRequirement: typing.Optional["DataRequirement"]

    """ Content to use in performing the task.
    Type `DataRequirement` (represented as `dict` in JSON). """

    valueExpression: typing.Optional["Expression"]

    """ Content to use in performing the task.
    Type `Expression` (represented as `dict` in JSON). """

    valueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Content to use in performing the task.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    valueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Content to use in performing the task.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    valueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Content to use in performing the task.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    valueUsageContext: typing.Optional["UsageContext"]

    """ Content to use in performing the task.
    Type `UsageContext` (represented as `dict` in JSON). """

    valueDosage: typing.Optional["Dosage"]

    """ Content to use in performing the task.
    Type `Dosage` (represented as `dict` in JSON). """

    valueMeta: typing.Optional["Meta"]

    """ Content to use in performing the task.
    Type `Meta` (represented as `dict` in JSON). """



#   {'path': 'Task.input.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBase64Binary', 'name': 'valueBase64Binary', 'parent_name': 'Task.input', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Content to use in performing the task', 'formal': 'The value of the input parameter as a basic type.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBase64Binary', 'valueBoolean', 'valueCanonical', 'valueCode', 'valueDate', 'valueDateTime', 'valueDecimal', 'valueId', 'valueInstant', 'valueInteger', 'valueMarkdown', 'valueOid', 'valuePositiveInt', 'valueString', 'valueTime', 'valueUnsignedInt', 'valueUri', 'valueUrl', 'valueUuid', 'valueAddress', 'valueAge', 'valueAnnotation', 'valueAttachment', 'valueCodeableConcept', 'valueCoding', 'valueContactPoint', 'valueCount', 'valueDistance', 'valueDuration', 'valueHumanName', 'valueIdentifier', 'valueMoney', 'valuePeriod', 'valueQuantity', 'valueRange', 'valueRatio', 'valueReference', 'valueSampledData', 'valueSignature', 'valueTiming', 'valueContactDetail', 'valueContributor', 'valueDataRequirement', 'valueExpression', 'valueParameterDefinition', 'valueRelatedArtifact', 'valueTriggerDefinition', 'valueUsageContext', 'valueDosage', 'valueMeta']), False))


    

     
    



class TaskOutput(BackboneElement):
    """ Information produced as part of task.
    
    Outputs produced by the Task.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='valueBase64Binary' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueCanonical' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDate' >, <FHIRClassProperty self.name='valueDateTime' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueId' >, <FHIRClassProperty self.name='valueInstant' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueMarkdown' >, <FHIRClassProperty self.name='valueOid' >, <FHIRClassProperty self.name='valuePositiveInt' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueTime' >, <FHIRClassProperty self.name='valueUnsignedInt' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueUrl' >, <FHIRClassProperty self.name='valueUuid' >, <FHIRClassProperty self.name='valueAddress' >, <FHIRClassProperty self.name='valueAge' >, <FHIRClassProperty self.name='valueAnnotation' >, <FHIRClassProperty self.name='valueAttachment' >, <FHIRClassProperty self.name='valueCodeableConcept' >, <FHIRClassProperty self.name='valueCoding' >, <FHIRClassProperty self.name='valueContactPoint' >, <FHIRClassProperty self.name='valueCount' >, <FHIRClassProperty self.name='valueDistance' >, <FHIRClassProperty self.name='valueDuration' >, <FHIRClassProperty self.name='valueHumanName' >, <FHIRClassProperty self.name='valueIdentifier' >, <FHIRClassProperty self.name='valueMoney' >, <FHIRClassProperty self.name='valuePeriod' >, <FHIRClassProperty self.name='valueQuantity' >, <FHIRClassProperty self.name='valueRange' >, <FHIRClassProperty self.name='valueRatio' >, <FHIRClassProperty self.name='valueReference' >, <FHIRClassProperty self.name='valueSampledData' >, <FHIRClassProperty self.name='valueSignature' >, <FHIRClassProperty self.name='valueTiming' >, <FHIRClassProperty self.name='valueContactDetail' >, <FHIRClassProperty self.name='valueContributor' >, <FHIRClassProperty self.name='valueDataRequirement' >, <FHIRClassProperty self.name='valueExpression' >, <FHIRClassProperty self.name='valueParameterDefinition' >, <FHIRClassProperty self.name='valueRelatedArtifact' >, <FHIRClassProperty self.name='valueTriggerDefinition' >, <FHIRClassProperty self.name='valueUsageContext' >, <FHIRClassProperty self.name='valueDosage' >, <FHIRClassProperty self.name='valueMeta' >]
  

    type: "CodeableConcept"

    """ Label for output.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueBase64Binary: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Result of output.
    Type `bool`. """

    valueCanonical: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueDate: typing.Optional["FHIRDate"]

    """ Result of output.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Result of output.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueDecimal: typing.Optional[float]

    """ Result of output.
    Type `float`. """

    valueId: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueInstant: typing.Optional["FHIRDate"]

    """ Result of output.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueInteger: typing.Optional[int]

    """ Result of output.
    Type `int`. """

    valueMarkdown: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueOid: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valuePositiveInt: typing.Optional[int]

    """ Result of output.
    Type `int`. """

    valueString: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueTime: typing.Optional["FHIRDate"]

    """ Result of output.
    Type `FHIRDate` (represented as `str` in JSON). """

    valueUnsignedInt: typing.Optional[int]

    """ Result of output.
    Type `int`. """

    valueUri: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueUrl: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueUuid: typing.Optional[str]

    """ Result of output.
    Type `str`. """

    valueAddress: typing.Optional["Address"]

    """ Result of output.
    Type `Address` (represented as `dict` in JSON). """

    valueAge: typing.Optional["Age"]

    """ Result of output.
    Type `Age` (represented as `dict` in JSON). """

    valueAnnotation: typing.Optional["Annotation"]

    """ Result of output.
    Type `Annotation` (represented as `dict` in JSON). """

    valueAttachment: typing.Optional["Attachment"]

    """ Result of output.
    Type `Attachment` (represented as `dict` in JSON). """

    valueCodeableConcept: typing.Optional["CodeableConcept"]

    """ Result of output.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    valueCoding: typing.Optional["Coding"]

    """ Result of output.
    Type `Coding` (represented as `dict` in JSON). """

    valueContactPoint: typing.Optional["ContactPoint"]

    """ Result of output.
    Type `ContactPoint` (represented as `dict` in JSON). """

    valueCount: typing.Optional["Count"]

    """ Result of output.
    Type `Count` (represented as `dict` in JSON). """

    valueDistance: typing.Optional["Distance"]

    """ Result of output.
    Type `Distance` (represented as `dict` in JSON). """

    valueDuration: typing.Optional["Duration"]

    """ Result of output.
    Type `Duration` (represented as `dict` in JSON). """

    valueHumanName: typing.Optional["HumanName"]

    """ Result of output.
    Type `HumanName` (represented as `dict` in JSON). """

    valueIdentifier: typing.Optional["Identifier"]

    """ Result of output.
    Type `Identifier` (represented as `dict` in JSON). """

    valueMoney: typing.Optional["Money"]

    """ Result of output.
    Type `Money` (represented as `dict` in JSON). """

    valuePeriod: typing.Optional["Period"]

    """ Result of output.
    Type `Period` (represented as `dict` in JSON). """

    valueQuantity: typing.Optional["Quantity"]

    """ Result of output.
    Type `Quantity` (represented as `dict` in JSON). """

    valueRange: typing.Optional["Range"]

    """ Result of output.
    Type `Range` (represented as `dict` in JSON). """

    valueRatio: typing.Optional["Ratio"]

    """ Result of output.
    Type `Ratio` (represented as `dict` in JSON). """

    valueReference: typing.Optional["Reference"]

    """ Result of output.
    Type `Reference` (represented as `dict` in JSON). """

    valueSampledData: typing.Optional["SampledData"]

    """ Result of output.
    Type `SampledData` (represented as `dict` in JSON). """

    valueSignature: typing.Optional["Signature"]

    """ Result of output.
    Type `Signature` (represented as `dict` in JSON). """

    valueTiming: typing.Optional["Timing"]

    """ Result of output.
    Type `Timing` (represented as `dict` in JSON). """

    valueContactDetail: typing.Optional["ContactDetail"]

    """ Result of output.
    Type `ContactDetail` (represented as `dict` in JSON). """

    valueContributor: typing.Optional["Contributor"]

    """ Result of output.
    Type `Contributor` (represented as `dict` in JSON). """

    valueDataRequirement: typing.Optional["DataRequirement"]

    """ Result of output.
    Type `DataRequirement` (represented as `dict` in JSON). """

    valueExpression: typing.Optional["Expression"]

    """ Result of output.
    Type `Expression` (represented as `dict` in JSON). """

    valueParameterDefinition: typing.Optional["ParameterDefinition"]

    """ Result of output.
    Type `ParameterDefinition` (represented as `dict` in JSON). """

    valueRelatedArtifact: typing.Optional["RelatedArtifact"]

    """ Result of output.
    Type `RelatedArtifact` (represented as `dict` in JSON). """

    valueTriggerDefinition: typing.Optional["TriggerDefinition"]

    """ Result of output.
    Type `TriggerDefinition` (represented as `dict` in JSON). """

    valueUsageContext: typing.Optional["UsageContext"]

    """ Result of output.
    Type `UsageContext` (represented as `dict` in JSON). """

    valueDosage: typing.Optional["Dosage"]

    """ Result of output.
    Type `Dosage` (represented as `dict` in JSON). """

    valueMeta: typing.Optional["Meta"]

    """ Result of output.
    Type `Meta` (represented as `dict` in JSON). """



#   {'path': 'Task.output.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueBase64Binary', 'name': 'valueBase64Binary', 'parent_name': 'Task.output', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': True, 'is_optional': False, 'reference_to_names': [], 'short': 'Result of output', 'formal': 'The value of the Output parameter as a basic type.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueBase64Binary', 'valueBoolean', 'valueCanonical', 'valueCode', 'valueDate', 'valueDateTime', 'valueDecimal', 'valueId', 'valueInstant', 'valueInteger', 'valueMarkdown', 'valueOid', 'valuePositiveInt', 'valueString', 'valueTime', 'valueUnsignedInt', 'valueUri', 'valueUrl', 'valueUuid', 'valueAddress', 'valueAge', 'valueAnnotation', 'valueAttachment', 'valueCodeableConcept', 'valueCoding', 'valueContactPoint', 'valueCount', 'valueDistance', 'valueDuration', 'valueHumanName', 'valueIdentifier', 'valueMoney', 'valuePeriod', 'valueQuantity', 'valueRange', 'valueRatio', 'valueReference', 'valueSampledData', 'valueSignature', 'valueTiming', 'valueContactDetail', 'valueContributor', 'valueDataRequirement', 'valueExpression', 'valueParameterDefinition', 'valueRelatedArtifact', 'valueTriggerDefinition', 'valueUsageContext', 'valueDosage', 'valueMeta']), False))


    

     
    



class TerminologyCapabilitiesSoftware(BackboneElement):
    """ Software that is covered by this terminology capability statement.
    
    Software that is covered by this terminology capability statement.  It is
    used when the statement describes the capabilities of a particular software
    version, independent of an installation.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='version' >]
  

    name: str

    """ A name the software is known by.
    Type `str`. """

    version: typing.Optional[str]

    """ Version covered by this statement.
    Type `str`. """




    

     
    



class TerminologyCapabilitiesImplementation(BackboneElement):
    """ If this describes a specific instance.
    
    Identifies a specific implementation instance that is described by the
    terminology capability statement - i.e. a particular installation, rather
    than the capabilities of a software program.
    """
    
    # [<FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='url' >]
  

    description: str

    """ Describes this specific instance.
    Type `str`. """

    url: typing.Optional[str]

    """ Base URL for the implementation.
    Type `str`. """




    

     
    



class TerminologyCapabilitiesCodeSystem(BackboneElement):
    """ A code system supported by the server.
    
    Identifies a code system that is supported by the server. If there is a no
    code system URL, then this declares the general assumptions a client can
    make about support for any CodeSystem resource.
    """
    
    # [<FHIRClassProperty self.name='uri' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='subsumption' >]
  

    uri: typing.Optional[str]

    """ URI for the Code System.
    Type `str`. """

    version: typing.Optional[typing.List["TerminologyCapabilitiesCodeSystemVersion"]]

    """ Version of Code System supported.
    List of `TerminologyCapabilitiesCodeSystemVersion` items (represented as `dict` in JSON). """

    subsumption: typing.Optional[bool]

    """ Whether subsumption is supported.
    Type `bool`. """




    

     
    



class TerminologyCapabilitiesCodeSystemVersion(BackboneElement):
    """ Version of Code System supported.
    
    For the code system, a list of versions that are supported by the server.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='isDefault' >, <FHIRClassProperty self.name='compositional' >, <FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='filter' >, <FHIRClassProperty self.name='property' >]
  

    code: typing.Optional[str]

    """ Version identifier for this version.
    Type `str`. """

    isDefault: typing.Optional[bool]

    """ If this is the default version for this code system.
    Type `bool`. """

    compositional: typing.Optional[bool]

    """ If compositional grammar is supported.
    Type `bool`. """

    language: typing.Optional[typing.List[str]]

    """ Language Displays supported.
    List of `str` items. """

    filter: typing.Optional[typing.List["TerminologyCapabilitiesCodeSystemVersionFilter"]]

    """ Filter Properties supported.
    List of `TerminologyCapabilitiesCodeSystemVersionFilter` items (represented as `dict` in JSON). """

    property: typing.Optional[typing.List[str]]

    """ Properties supported for $lookup.
    List of `str` items. """




    

     
    



class TerminologyCapabilitiesCodeSystemVersionFilter(BackboneElement):
    """ Filter Properties supported.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='op' >]
  

    code: str

    """ Code of the property supported.
    Type `str`. """

    op: typing.List[str]

    """ Operations supported for the property.
    List of `str` items. """




    

     
    



class TerminologyCapabilitiesExpansion(BackboneElement):
    """ Information about the [ValueSet/$expand](valueset-operation-expand.html)
    operation.
    """
    
    # [<FHIRClassProperty self.name='hierarchical' >, <FHIRClassProperty self.name='paging' >, <FHIRClassProperty self.name='incomplete' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='textFilter' >]
  

    hierarchical: typing.Optional[bool]

    """ Whether the server can return nested value sets.
    Type `bool`. """

    paging: typing.Optional[bool]

    """ Whether the server supports paging on expansion.
    Type `bool`. """

    incomplete: typing.Optional[bool]

    """ Allow request for incomplete expansions?.
    Type `bool`. """

    parameter: typing.Optional[typing.List["TerminologyCapabilitiesExpansionParameter"]]

    """ Supported expansion parameter.
    List of `TerminologyCapabilitiesExpansionParameter` items (represented as `dict` in JSON). """

    textFilter: typing.Optional[str]

    """ Documentation about text searching works.
    Type `str`. """




    

     
    



class TerminologyCapabilitiesExpansionParameter(BackboneElement):
    """ Supported expansion parameter.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='documentation' >]
  

    name: str

    """ Expansion Parameter name.
    Type `str`. """

    documentation: typing.Optional[str]

    """ Description of support for parameter.
    Type `str`. """




    

     
    



class TerminologyCapabilitiesValidateCode(BackboneElement):
    """ Information about the [ValueSet/$validate-code](valueset-operation-
    validate-code.html) operation.
    """
    
    # [<FHIRClassProperty self.name='translations' >]
  

    translations: bool

    """ Whether translations are validated.
    Type `bool`. """




    

     
    



class TerminologyCapabilitiesTranslation(BackboneElement):
    """ Information about the [ConceptMap/$translate](conceptmap-operation-
    translate.html) operation.
    """
    
    # [<FHIRClassProperty self.name='needsMap' >]
  

    needsMap: bool

    """ Whether the client must identify the map.
    Type `bool`. """




    

     
    



class TerminologyCapabilitiesClosure(BackboneElement):
    """ Information about the [ConceptMap/$closure](conceptmap-operation-
    closure.html) operation.
    
    Whether the $closure operation is supported.
    """
    
    # [<FHIRClassProperty self.name='translation' >]
  

    translation: typing.Optional[bool]

    """ If cross-system closure is supported.
    Type `bool`. """




    

     
    



class TestReportParticipant(BackboneElement):
    """ A participant in the test execution, either the execution engine, a client,
    or a server.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='uri' >, <FHIRClassProperty self.name='display' >]
  

    type: "str"

    """ test-engine | client | server.
    Type `str`. """

    uri: str

    """ The uri of the participant. An absolute URL is preferred.
    Type `str`. """

    display: typing.Optional[str]

    """ The display name of the participant.
    Type `str`. """




    

     
    



class TestReportSetup(BackboneElement):
    """ The results of the series of required setup operations before the tests
    were executed.
    """
    
    # [<FHIRClassProperty self.name='action' >]
  

    action: typing.List["TestReportSetupAction"]

    """ A setup operation or assert that was executed.
    List of `TestReportSetupAction` items (represented as `dict` in JSON). """




    

     
    



class TestReportSetupAction(BackboneElement):
    """ A setup operation or assert that was executed.
    
    Action would contain either an operation or an assertion.
    """
    
    # [<FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='assert_' >]
  

    operation: typing.Optional["TestReportSetupActionOperation"]

    """ The operation to perform.
    Type `TestReportSetupActionOperation` (represented as `dict` in JSON). """

    assert_: typing.Optional["TestReportSetupActionAssert"]

    """ The assertion to perform.
    Type `TestReportSetupActionAssert` (represented as `dict` in JSON). """




    

     
    



class TestReportSetupActionOperation(BackboneElement):
    """ The operation to perform.
    
    The operation performed.
    """
    
    # [<FHIRClassProperty self.name='result' >, <FHIRClassProperty self.name='message' >, <FHIRClassProperty self.name='detail' >]
  

    result: "str"

    """ pass | skip | fail | warning | error.
    Type `str`. """

    message: typing.Optional[str]

    """ A message associated with the result.
    Type `str`. """

    detail: typing.Optional[str]

    """ A link to further details on the result.
    Type `str`. """




    

     
    



class TestReportSetupActionAssert(BackboneElement):
    """ The assertion to perform.
    
    The results of the assertion performed on the previous operations.
    """
    
    # [<FHIRClassProperty self.name='result' >, <FHIRClassProperty self.name='message' >, <FHIRClassProperty self.name='detail' >]
  

    result: "str"

    """ pass | skip | fail | warning | error.
    Type `str`. """

    message: typing.Optional[str]

    """ A message associated with the result.
    Type `str`. """

    detail: typing.Optional[str]

    """ A link to further details on the result.
    Type `str`. """




    

     
    



class TestReportTest(BackboneElement):
    """ A test executed from the test script.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='action' >]
  

    name: typing.Optional[str]

    """ Tracking/logging name of this test.
    Type `str`. """

    description: typing.Optional[str]

    """ Tracking/reporting short description of the test.
    Type `str`. """

    action: typing.List["TestReportTestAction"]

    """ A test operation or assert that was performed.
    List of `TestReportTestAction` items (represented as `dict` in JSON). """




    

     
    



class TestReportTestAction(BackboneElement):
    """ A test operation or assert that was performed.
    
    Action would contain either an operation or an assertion.
    """
    
    # [<FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='assert_' >]
  

    operation: typing.Optional["TestReportSetupActionOperation"]

    """ The operation performed.
    Type `TestReportSetupActionOperation` (represented as `dict` in JSON). """

    assert_: typing.Optional["TestReportSetupActionAssert"]

    """ The assertion performed.
    Type `TestReportSetupActionAssert` (represented as `dict` in JSON). """




    

     
    



class TestReportTeardown(BackboneElement):
    """ The results of running the series of required clean up steps.
    
    The results of the series of operations required to clean up after all the
    tests were executed (successfully or otherwise).
    """
    
    # [<FHIRClassProperty self.name='action' >]
  

    action: typing.List["TestReportTeardownAction"]

    """ One or more teardown operations performed.
    List of `TestReportTeardownAction` items (represented as `dict` in JSON). """




    

     
    



class TestReportTeardownAction(BackboneElement):
    """ One or more teardown operations performed.
    
    The teardown action will only contain an operation.
    """
    
    # [<FHIRClassProperty self.name='operation' >]
  

    operation: "TestReportSetupActionOperation"

    """ The teardown operation performed.
    Type `TestReportSetupActionOperation` (represented as `dict` in JSON). """




    

     
    



class TestScriptOrigin(BackboneElement):
    """ An abstract server representing a client or sender in a message exchange.
    
    An abstract server used in operations within this test script in the origin
    element.
    """
    
    # [<FHIRClassProperty self.name='index' >, <FHIRClassProperty self.name='profile' >]
  

    index: int

    """ The index of the abstract origin server starting at 1.
    Type `int`. """

    profile: "Coding"

    """ FHIR-Client | FHIR-SDC-FormFiller.
    Type `Coding` (represented as `dict` in JSON). """




    

     
    



class TestScriptDestination(BackboneElement):
    """ An abstract server representing a destination or receiver in a message
    exchange.
    
    An abstract server used in operations within this test script in the
    destination element.
    """
    
    # [<FHIRClassProperty self.name='index' >, <FHIRClassProperty self.name='profile' >]
  

    index: int

    """ The index of the abstract destination server starting at 1.
    Type `int`. """

    profile: "Coding"

    """ FHIR-Server | FHIR-SDC-FormManager | FHIR-SDC-FormReceiver | FHIR-
        SDC-FormProcessor.
    Type `Coding` (represented as `dict` in JSON). """




    

     
    



class TestScriptMetadata(BackboneElement):
    """ Required capability that is assumed to function correctly on the FHIR
    server being tested.
    
    The required capability must exist and are assumed to function correctly on
    the FHIR server being tested.
    """
    
    # [<FHIRClassProperty self.name='link' >, <FHIRClassProperty self.name='capability' >]
  

    link: typing.Optional[typing.List["TestScriptMetadataLink"]]

    """ Links to the FHIR specification.
    List of `TestScriptMetadataLink` items (represented as `dict` in JSON). """

    capability: typing.List["TestScriptMetadataCapability"]

    """ Capabilities  that are assumed to function correctly on the FHIR
        server being tested.
    List of `TestScriptMetadataCapability` items (represented as `dict` in JSON). """




    

     
    



class TestScriptMetadataLink(BackboneElement):
    """ Links to the FHIR specification.
    
    A link to the FHIR specification that this test is covering.
    """
    
    # [<FHIRClassProperty self.name='url' >, <FHIRClassProperty self.name='description' >]
  

    url: str

    """ URL to the specification.
    Type `str`. """

    description: typing.Optional[str]

    """ Short description.
    Type `str`. """




    

     
    



class TestScriptMetadataCapability(BackboneElement):
    """ Capabilities  that are assumed to function correctly on the FHIR server
    being tested.
    
    Capabilities that must exist and are assumed to function correctly on the
    FHIR server being tested.
    """
    
    # [<FHIRClassProperty self.name='required' >, <FHIRClassProperty self.name='validated' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='origin' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='link' >, <FHIRClassProperty self.name='capabilities' >]
  

    required: bool

    """ Are the capabilities required?.
    Type `bool`. """

    validated: bool

    """ Are the capabilities validated?.
    Type `bool`. """

    description: typing.Optional[str]

    """ The expected capabilities of the server.
    Type `str`. """

    origin: typing.Optional[typing.List[int]]

    """ Which origin server these requirements apply to.
    List of `int` items. """

    destination: typing.Optional[int]

    """ Which server these requirements apply to.
    Type `int`. """

    link: typing.Optional[typing.List[str]]

    """ Links to the FHIR specification.
    List of `str` items. """

    capabilities: str

    """ Required Capability Statement.
    Type `str`. """




    

     
    



class TestScriptFixture(BackboneElement):
    """ Fixture in the test script - by reference (uri).
    
    Fixture in the test script - by reference (uri). All fixtures are required
    for the test script to execute.
    """
    
    # [<FHIRClassProperty self.name='autocreate' >, <FHIRClassProperty self.name='autodelete' >, <FHIRClassProperty self.name='resource' >]
  

    autocreate: bool

    """ Whether or not to implicitly create the fixture during setup.
    Type `bool`. """

    autodelete: bool

    """ Whether or not to implicitly delete the fixture during teardown.
    Type `bool`. """

    resource: typing.Optional["Reference"]

    """ Reference of the resource.
    Type `Reference` (represented as `dict` in JSON). """




    

     
    



class TestScriptVariable(BackboneElement):
    """ Placeholder for evaluated elements.
    
    Variable is set based either on element value in response body or on header
    field value in the response headers.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='defaultValue' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='headerField' >, <FHIRClassProperty self.name='hint' >, <FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='sourceId' >]
  

    name: str

    """ Descriptive name for this variable.
    Type `str`. """

    defaultValue: typing.Optional[str]

    """ Default, hard-coded, or user-defined value for this variable.
    Type `str`. """

    description: typing.Optional[str]

    """ Natural language description of the variable.
    Type `str`. """

    expression: typing.Optional[str]

    """ The FHIRPath expression against the fixture body.
    Type `str`. """

    headerField: typing.Optional[str]

    """ HTTP header field name for source.
    Type `str`. """

    hint: typing.Optional[str]

    """ Hint help text for default value to enter.
    Type `str`. """

    path: typing.Optional[str]

    """ XPath or JSONPath against the fixture body.
    Type `str`. """

    sourceId: typing.Optional[str]

    """ Fixture Id of source expression or headerField within this variable.
    Type `str`. """




    

     
    



class TestScriptSetup(BackboneElement):
    """ A series of required setup operations before tests are executed.
    """
    
    # [<FHIRClassProperty self.name='action' >]
  

    action: typing.List["TestScriptSetupAction"]

    """ A setup operation or assert to perform.
    List of `TestScriptSetupAction` items (represented as `dict` in JSON). """




    

     
    



class TestScriptSetupAction(BackboneElement):
    """ A setup operation or assert to perform.
    
    Action would contain either an operation or an assertion.
    """
    
    # [<FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='assert_' >]
  

    operation: typing.Optional["TestScriptSetupActionOperation"]

    """ The setup operation to perform.
    Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """

    assert_: typing.Optional["TestScriptSetupActionAssert"]

    """ The assertion to perform.
    Type `TestScriptSetupActionAssert` (represented as `dict` in JSON). """




    

     
    



class TestScriptSetupActionOperation(BackboneElement):
    """ The setup operation to perform.
    
    The operation to perform.
    """
    
    # [<FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='label' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='accept' >, <FHIRClassProperty self.name='contentType' >, <FHIRClassProperty self.name='destination' >, <FHIRClassProperty self.name='encodeRequestUrl' >, <FHIRClassProperty self.name='method' >, <FHIRClassProperty self.name='origin' >, <FHIRClassProperty self.name='params' >, <FHIRClassProperty self.name='requestHeader' >, <FHIRClassProperty self.name='requestId' >, <FHIRClassProperty self.name='responseId' >, <FHIRClassProperty self.name='sourceId' >, <FHIRClassProperty self.name='targetId' >, <FHIRClassProperty self.name='url' >]
  

    type: typing.Optional["Coding"]

    """ The operation code type that will be executed.
    Type `Coding` (represented as `dict` in JSON). """

    resource: typing.Optional[str]

    """ Resource type.
    Type `str`. """

    label: typing.Optional[str]

    """ Tracking/logging operation label.
    Type `str`. """

    description: typing.Optional[str]

    """ Tracking/reporting operation description.
    Type `str`. """

    accept: typing.Optional[str]

    """ Mime type to accept in the payload of the response, with charset
        etc..
    Type `str`. """

    contentType: typing.Optional[str]

    """ Mime type of the request payload contents, with charset etc..
    Type `str`. """

    destination: typing.Optional[int]

    """ Server responding to the request.
    Type `int`. """

    encodeRequestUrl: bool

    """ Whether or not to send the request url in encoded format.
    Type `bool`. """

    method: typing.Optional["str"]

    """ delete | get | options | patch | post | put | head.
    Type `str`. """

    origin: typing.Optional[int]

    """ Server initiating the request.
    Type `int`. """

    params: typing.Optional[str]

    """ Explicitly defined path parameters.
    Type `str`. """

    requestHeader: typing.Optional[typing.List["TestScriptSetupActionOperationRequestHeader"]]

    """ Each operation can have one or more header elements.
    List of `TestScriptSetupActionOperationRequestHeader` items (represented as `dict` in JSON). """

    requestId: typing.Optional[str]

    """ Fixture Id of mapped request.
    Type `str`. """

    responseId: typing.Optional[str]

    """ Fixture Id of mapped response.
    Type `str`. """

    sourceId: typing.Optional[str]

    """ Fixture Id of body for PUT and POST requests.
    Type `str`. """

    targetId: typing.Optional[str]

    """ Id of fixture used for extracting the [id],  [type], and [vid] for
        GET requests.
    Type `str`. """

    url: typing.Optional[str]

    """ Request URL.
    Type `str`. """




    

     
    



class TestScriptSetupActionOperationRequestHeader(BackboneElement):
    """ Each operation can have one or more header elements.
    
    Header elements would be used to set HTTP headers.
    """
    
    # [<FHIRClassProperty self.name='field' >, <FHIRClassProperty self.name='value' >]
  

    field: str

    """ HTTP header field name.
    Type `str`. """

    value: str

    """ HTTP headerfield value.
    Type `str`. """




    

     
    



class TestScriptSetupActionAssert(BackboneElement):
    """ The assertion to perform.
    
    Evaluates the results of previous operations to determine if the server
    under test behaves appropriately.
    """
    
    # [<FHIRClassProperty self.name='label' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='direction' >, <FHIRClassProperty self.name='compareToSourceId' >, <FHIRClassProperty self.name='compareToSourceExpression' >, <FHIRClassProperty self.name='compareToSourcePath' >, <FHIRClassProperty self.name='contentType' >, <FHIRClassProperty self.name='expression' >, <FHIRClassProperty self.name='headerField' >, <FHIRClassProperty self.name='minimumId' >, <FHIRClassProperty self.name='navigationLinks' >, <FHIRClassProperty self.name='operator' >, <FHIRClassProperty self.name='path' >, <FHIRClassProperty self.name='requestMethod' >, <FHIRClassProperty self.name='requestURL' >, <FHIRClassProperty self.name='resource' >, <FHIRClassProperty self.name='response' >, <FHIRClassProperty self.name='responseCode' >, <FHIRClassProperty self.name='sourceId' >, <FHIRClassProperty self.name='validateProfileId' >, <FHIRClassProperty self.name='value' >, <FHIRClassProperty self.name='warningOnly' >]
  

    label: typing.Optional[str]

    """ Tracking/logging assertion label.
    Type `str`. """

    description: typing.Optional[str]

    """ Tracking/reporting assertion description.
    Type `str`. """

    direction: typing.Optional["str"]

    """ response | request.
    Type `str`. """

    compareToSourceId: typing.Optional[str]

    """ Id of the source fixture to be evaluated.
    Type `str`. """

    compareToSourceExpression: typing.Optional[str]

    """ The FHIRPath expression to evaluate against the source fixture.
    Type `str`. """

    compareToSourcePath: typing.Optional[str]

    """ XPath or JSONPath expression to evaluate against the source fixture.
    Type `str`. """

    contentType: typing.Optional[str]

    """ Mime type to compare against the 'Content-Type' header.
    Type `str`. """

    expression: typing.Optional[str]

    """ The FHIRPath expression to be evaluated.
    Type `str`. """

    headerField: typing.Optional[str]

    """ HTTP header field name.
    Type `str`. """

    minimumId: typing.Optional[str]

    """ Fixture Id of minimum content resource.
    Type `str`. """

    navigationLinks: typing.Optional[bool]

    """ Perform validation on navigation links?.
    Type `bool`. """

    operator: typing.Optional["str"]

    """ equals | notEquals | in | notIn | greaterThan | lessThan | empty |
        notEmpty | contains | notContains | eval.
    Type `str`. """

    path: typing.Optional[str]

    """ XPath or JSONPath expression.
    Type `str`. """

    requestMethod: typing.Optional["str"]

    """ delete | get | options | patch | post | put | head.
    Type `str`. """

    requestURL: typing.Optional[str]

    """ Request URL comparison value.
    Type `str`. """

    resource: typing.Optional[str]

    """ Resource type.
    Type `str`. """

    response: typing.Optional["str"]

    """ okay | created | noContent | notModified | bad | forbidden |
        notFound | methodNotAllowed | conflict | gone | preconditionFailed
        | unprocessable.
    Type `str`. """

    responseCode: typing.Optional[str]

    """ HTTP response code to test.
    Type `str`. """

    sourceId: typing.Optional[str]

    """ Fixture Id of source expression or headerField.
    Type `str`. """

    validateProfileId: typing.Optional[str]

    """ Profile Id of validation profile reference.
    Type `str`. """

    value: typing.Optional[str]

    """ The value to compare to.
    Type `str`. """

    warningOnly: bool

    """ Will this assert produce a warning only on error?.
    Type `bool`. """




    

     
    



class TestScriptTest(BackboneElement):
    """ A test in this script.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='description' >, <FHIRClassProperty self.name='action' >]
  

    name: typing.Optional[str]

    """ Tracking/logging name of this test.
    Type `str`. """

    description: typing.Optional[str]

    """ Tracking/reporting short description of the test.
    Type `str`. """

    action: typing.List["TestScriptTestAction"]

    """ A test operation or assert to perform.
    List of `TestScriptTestAction` items (represented as `dict` in JSON). """




    

     
    



class TestScriptTestAction(BackboneElement):
    """ A test operation or assert to perform.
    
    Action would contain either an operation or an assertion.
    """
    
    # [<FHIRClassProperty self.name='operation' >, <FHIRClassProperty self.name='assert_' >]
  

    operation: typing.Optional["TestScriptSetupActionOperation"]

    """ The setup operation to perform.
    Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """

    assert_: typing.Optional["TestScriptSetupActionAssert"]

    """ The setup assertion to perform.
    Type `TestScriptSetupActionAssert` (represented as `dict` in JSON). """




    

     
    



class TestScriptTeardown(BackboneElement):
    """ A series of required clean up steps.
    
    A series of operations required to clean up after all the tests are
    executed (successfully or otherwise).
    """
    
    # [<FHIRClassProperty self.name='action' >]
  

    action: typing.List["TestScriptTeardownAction"]

    """ One or more teardown operations to perform.
    List of `TestScriptTeardownAction` items (represented as `dict` in JSON). """




    

     
    



class TestScriptTeardownAction(BackboneElement):
    """ One or more teardown operations to perform.
    
    The teardown action will only contain an operation.
    """
    
    # [<FHIRClassProperty self.name='operation' >]
  

    operation: "TestScriptSetupActionOperation"

    """ The teardown operation to perform.
    Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """




    

     
    



class ValueSetCompose(BackboneElement):
    """ Content logical definition of the value set (CLD).
    
    A set of criteria that define the contents of the value set by including or
    excluding codes selected from the specified code system(s) that the value
    set draws from. This is also known as the Content Logical Definition (CLD).
    """
    
    # [<FHIRClassProperty self.name='lockedDate' >, <FHIRClassProperty self.name='inactive' >, <FHIRClassProperty self.name='include' >, <FHIRClassProperty self.name='exclude' >]
  

    lockedDate: typing.Optional["FHIRDate"]

    """ Fixed date for references with no specified version (transitive).
    Type `FHIRDate` (represented as `str` in JSON). """

    inactive: typing.Optional[bool]

    """ Whether inactive codes are in the value set.
    Type `bool`. """

    include: typing.List["ValueSetComposeInclude"]

    """ Include one or more codes from a code system or other value set(s).
    List of `ValueSetComposeInclude` items (represented as `dict` in JSON). """

    exclude: typing.Optional[typing.List["ValueSetComposeInclude"]]

    """ Explicitly exclude codes from a code system or other value sets.
    List of `ValueSetComposeInclude` items (represented as `dict` in JSON). """




    

     
    



class ValueSetComposeInclude(BackboneElement):
    """ Include one or more codes from a code system or other value set(s).
    """
    
    # [<FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='concept' >, <FHIRClassProperty self.name='filter' >, <FHIRClassProperty self.name='valueSet' >]
  

    system: typing.Optional[str]

    """ The system the codes come from.
    Type `str`. """

    version: typing.Optional[str]

    """ Specific version of the code system referred to.
    Type `str`. """

    concept: typing.Optional[typing.List["ValueSetComposeIncludeConcept"]]

    """ A concept defined in the system.
    List of `ValueSetComposeIncludeConcept` items (represented as `dict` in JSON). """

    filter: typing.Optional[typing.List["ValueSetComposeIncludeFilter"]]

    """ Select codes/concepts by their properties (including relationships).
    List of `ValueSetComposeIncludeFilter` items (represented as `dict` in JSON). """

    valueSet: typing.Optional[typing.List[str]]

    """ Select the contents included in this value set.
    List of `str` items. """




    

     
    



class ValueSetComposeIncludeConcept(BackboneElement):
    """ A concept defined in the system.
    
    Specifies a concept to be included or excluded.
    """
    
    # [<FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='designation' >]
  

    code: str

    """ Code or expression from system.
    Type `str`. """

    display: typing.Optional[str]

    """ Text to display for this code for this value set in this valueset.
    Type `str`. """

    designation: typing.Optional[typing.List["ValueSetComposeIncludeConceptDesignation"]]

    """ Additional representations for this concept.
    List of `ValueSetComposeIncludeConceptDesignation` items (represented as `dict` in JSON). """




    

     
    



class ValueSetComposeIncludeConceptDesignation(BackboneElement):
    """ Additional representations for this concept.
    
    Additional representations for this concept when used in this value set -
    other languages, aliases, specialized purposes, used for particular
    purposes, etc.
    """
    
    # [<FHIRClassProperty self.name='language' >, <FHIRClassProperty self.name='use' >, <FHIRClassProperty self.name='value' >]
  

    language: typing.Optional[str]

    """ Human language of the designation.
    Type `str`. """

    use: typing.Optional["Coding"]

    """ Types of uses of designations.
    Type `Coding` (represented as `dict` in JSON). """

    value: str

    """ The text value for this designation.
    Type `str`. """




    

     
    



class ValueSetComposeIncludeFilter(BackboneElement):
    """ Select codes/concepts by their properties (including relationships).
    
    Select concepts by specify a matching criterion based on the properties
    (including relationships) defined by the system, or on filters defined by
    the system. If multiple filters are specified, they SHALL all be true.
    """
    
    # [<FHIRClassProperty self.name='property' >, <FHIRClassProperty self.name='op' >, <FHIRClassProperty self.name='value' >]
  

    property: str

    """ A property/filter defined by the code system.
    Type `str`. """

    op: "str"

    """ = | is-a | descendent-of | is-not-a | regex | in | not-in |
        generalizes | exists.
    Type `str`. """

    value: str

    """ Code from the system, or regex criteria, or boolean value for
        exists.
    Type `str`. """




    

     
    



class ValueSetExpansion(BackboneElement):
    """ Used when the value set is "expanded".
    
    A value set can also be "expanded", where the value set is turned into a
    simple collection of enumerated codes. This element holds the expansion, if
    it has been performed.
    """
    
    # [<FHIRClassProperty self.name='identifier' >, <FHIRClassProperty self.name='timestamp' >, <FHIRClassProperty self.name='total' >, <FHIRClassProperty self.name='offset' >, <FHIRClassProperty self.name='parameter' >, <FHIRClassProperty self.name='contains' >]
  

    identifier: typing.Optional[str]

    """ Identifies the value set expansion (business identifier).
    Type `str`. """

    timestamp: "FHIRDate"

    """ Time ValueSet expansion happened.
    Type `FHIRDate` (represented as `str` in JSON). """

    total: typing.Optional[int]

    """ Total number of codes in the expansion.
    Type `int`. """

    offset: typing.Optional[int]

    """ Offset at which this resource starts.
    Type `int`. """

    parameter: typing.Optional[typing.List["ValueSetExpansionParameter"]]

    """ Parameter that controlled the expansion process.
    List of `ValueSetExpansionParameter` items (represented as `dict` in JSON). """

    contains: typing.Optional[typing.List["ValueSetExpansionContains"]]

    """ Codes in the value set.
    List of `ValueSetExpansionContains` items (represented as `dict` in JSON). """




    

     
    



class ValueSetExpansionParameter(BackboneElement):
    """ Parameter that controlled the expansion process.
    
    A parameter that controlled the expansion process. These parameters may be
    used by users of expanded value sets to check whether the expansion is
    suitable for a particular purpose, or to pick the correct expansion.
    """
    
    # [<FHIRClassProperty self.name='name' >, <FHIRClassProperty self.name='valueString' >, <FHIRClassProperty self.name='valueBoolean' >, <FHIRClassProperty self.name='valueInteger' >, <FHIRClassProperty self.name='valueDecimal' >, <FHIRClassProperty self.name='valueUri' >, <FHIRClassProperty self.name='valueCode' >, <FHIRClassProperty self.name='valueDateTime' >]
  

    name: str

    """ Name as assigned by the client or server.
    Type `str`. """

    valueString: typing.Optional[str]

    """ Value of the named parameter.
    Type `str`. """

    valueBoolean: typing.Optional[bool]

    """ Value of the named parameter.
    Type `bool`. """

    valueInteger: typing.Optional[int]

    """ Value of the named parameter.
    Type `int`. """

    valueDecimal: typing.Optional[float]

    """ Value of the named parameter.
    Type `float`. """

    valueUri: typing.Optional[str]

    """ Value of the named parameter.
    Type `str`. """

    valueCode: typing.Optional[str]

    """ Value of the named parameter.
    Type `str`. """

    valueDateTime: typing.Optional["FHIRDate"]

    """ Value of the named parameter.
    Type `FHIRDate` (represented as `str` in JSON). """



#   {'path': 'ValueSet.expansion.parameter.value[x]', 'choice_of_type': 'value', 'orig_name': 'valueString', 'name': 'valueString', 'parent_name': 'ValueSet.expansion.parameter', 'class_name': 'str', 'enum': None, 'module_name': None, 'json_class': 'str', 'is_native': True, 'is_array': False, 'is_summary': None, 'is_summary_n_min_conflict': False, 'nonoptional': False, 'is_optional': True, 'reference_to_names': [], 'short': 'Value of the named parameter', 'formal': 'The value of the parameter.', 'representation': None}

    _value_choice_of_type_validator = pydantic.root_validator(allow_reuse=True) \
     (choice_of_validator(set(['valueString', 'valueBoolean', 'valueInteger', 'valueDecimal', 'valueUri', 'valueCode', 'valueDateTime']), True))


    

     
    



class ValueSetExpansionContains(BackboneElement):
    """ Codes in the value set.
    
    The codes that are contained in the value set expansion.
    """
    
    # [<FHIRClassProperty self.name='system' >, <FHIRClassProperty self.name='abstract' >, <FHIRClassProperty self.name='inactive' >, <FHIRClassProperty self.name='version' >, <FHIRClassProperty self.name='code' >, <FHIRClassProperty self.name='display' >, <FHIRClassProperty self.name='designation' >, <FHIRClassProperty self.name='contains' >]
  

    system: typing.Optional[str]

    """ System value for the code.
    Type `str`. """

    abstract: typing.Optional[bool]

    """ If user cannot select this entry.
    Type `bool`. """

    inactive: typing.Optional[bool]

    """ If concept is inactive in the code system.
    Type `bool`. """

    version: typing.Optional[str]

    """ Version in which this code/display is defined.
    Type `str`. """

    code: typing.Optional[str]

    """ Code - if blank, this is not a selectable code.
    Type `str`. """

    display: typing.Optional[str]

    """ User display for the concept.
    Type `str`. """

    designation: typing.Optional[typing.List["ValueSetComposeIncludeConceptDesignation"]]

    """ Additional representations for this item.
    List of `ValueSetComposeIncludeConceptDesignation` items (represented as `dict` in JSON). """

    contains: typing.Optional[typing.List["ValueSetExpansionContains"]]

    """ Codes contained under this entry.
    List of `ValueSetExpansionContains` items (represented as `dict` in JSON). """




    

     
    



class VerificationResultPrimarySource(BackboneElement):
    """ Information about the primary source(s) involved in validation.
    """
    
    # [<FHIRClassProperty self.name='who' >, <FHIRClassProperty self.name='type' >, <FHIRClassProperty self.name='communicationMethod' >, <FHIRClassProperty self.name='validationStatus' >, <FHIRClassProperty self.name='validationDate' >, <FHIRClassProperty self.name='canPushUpdates' >, <FHIRClassProperty self.name='pushTypeAvailable' >]
  

    who: typing.Optional["Reference"]

    """ Reference to the primary source.
    Type `Reference` (represented as `dict` in JSON). """

    type: typing.Optional[typing.List["CodeableConcept"]]

    """ Type of primary source (License Board; Primary Education;
        Continuing Education; Postal Service; Relationship owner;
        Registration Authority; legal source; issuing source; authoritative
        source).
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    communicationMethod: typing.Optional[typing.List["CodeableConcept"]]

    """ Method for exchanging information with the primary source.
    List of `CodeableConcept` items (represented as `dict` in JSON). """

    validationStatus: typing.Optional["CodeableConcept"]

    """ successful | failed | unknown.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    validationDate: typing.Optional["FHIRDate"]

    """ When the target was validated against the primary source.
    Type `FHIRDate` (represented as `str` in JSON). """

    canPushUpdates: typing.Optional["CodeableConcept"]

    """ yes | no | undetermined.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    pushTypeAvailable: typing.Optional[typing.List["CodeableConcept"]]

    """ specific | any | source.
    List of `CodeableConcept` items (represented as `dict` in JSON). """




    

     
    



class VerificationResultAttestation(BackboneElement):
    """ Information about the entity attesting to information.
    """
    
    # [<FHIRClassProperty self.name='who' >, <FHIRClassProperty self.name='onBehalfOf' >, <FHIRClassProperty self.name='communicationMethod' >, <FHIRClassProperty self.name='date' >, <FHIRClassProperty self.name='sourceIdentityCertificate' >, <FHIRClassProperty self.name='proxyIdentityCertificate' >, <FHIRClassProperty self.name='proxySignature' >, <FHIRClassProperty self.name='sourceSignature' >]
  

    who: typing.Optional["Reference"]

    """ The individual or organization attesting to information.
    Type `Reference` (represented as `dict` in JSON). """

    onBehalfOf: typing.Optional["Reference"]

    """ When the who is asserting on behalf of another (organization or
        individual).
    Type `Reference` (represented as `dict` in JSON). """

    communicationMethod: typing.Optional["CodeableConcept"]

    """ The method by which attested information was submitted/retrieved.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    date: typing.Optional["FHIRDate"]

    """ The date the information was attested to.
    Type `FHIRDate` (represented as `str` in JSON). """

    sourceIdentityCertificate: typing.Optional[str]

    """ A digital identity certificate associated with the attestation
        source.
    Type `str`. """

    proxyIdentityCertificate: typing.Optional[str]

    """ A digital identity certificate associated with the proxy entity
        submitting attested information on behalf of the attestation source.
    Type `str`. """

    proxySignature: typing.Optional["Signature"]

    """ Proxy signature.
    Type `Signature` (represented as `dict` in JSON). """

    sourceSignature: typing.Optional["Signature"]

    """ Attester signature.
    Type `Signature` (represented as `dict` in JSON). """




    

     
    



class VerificationResultValidator(BackboneElement):
    """ Information about the entity validating information.
    """
    
    # [<FHIRClassProperty self.name='organization' >, <FHIRClassProperty self.name='identityCertificate' >, <FHIRClassProperty self.name='attestationSignature' >]
  

    organization: "Reference"

    """ Reference to the organization validating information.
    Type `Reference` (represented as `dict` in JSON). """

    identityCertificate: typing.Optional[str]

    """ A digital identity certificate associated with the validator.
    Type `str`. """

    attestationSignature: typing.Optional["Signature"]

    """ Validator signature.
    Type `Signature` (represented as `dict` in JSON). """




    

     
    



class VisionPrescriptionLensSpecification(BackboneElement):
    """ Vision lens authorization.
    
    Contain the details of  the individual lens specifications and serves as
    the authorization for the fullfillment by certified professionals.
    """
    
    # [<FHIRClassProperty self.name='product' >, <FHIRClassProperty self.name='eye' >, <FHIRClassProperty self.name='sphere' >, <FHIRClassProperty self.name='cylinder' >, <FHIRClassProperty self.name='axis' >, <FHIRClassProperty self.name='prism' >, <FHIRClassProperty self.name='add' >, <FHIRClassProperty self.name='power' >, <FHIRClassProperty self.name='backCurve' >, <FHIRClassProperty self.name='diameter' >, <FHIRClassProperty self.name='duration' >, <FHIRClassProperty self.name='color' >, <FHIRClassProperty self.name='brand' >, <FHIRClassProperty self.name='note' >]
  

    product: "CodeableConcept"

    """ Product to be supplied.
    Type `CodeableConcept` (represented as `dict` in JSON). """

    eye: "str"

    """ right | left.
    Type `str`. """

    sphere: typing.Optional[float]

    """ Power of the lens.
    Type `float`. """

    cylinder: typing.Optional[float]

    """ Lens power for astigmatism.
    Type `float`. """

    axis: typing.Optional[int]

    """ Lens meridian which contain no power for astigmatism.
    Type `int`. """

    prism: typing.Optional[typing.List["VisionPrescriptionLensSpecificationPrism"]]

    """ Eye alignment compensation.
    List of `VisionPrescriptionLensSpecificationPrism` items (represented as `dict` in JSON). """

    add: typing.Optional[float]

    """ Added power for multifocal levels.
    Type `float`. """

    power: typing.Optional[float]

    """ Contact lens power.
    Type `float`. """

    backCurve: typing.Optional[float]

    """ Contact lens back curvature.
    Type `float`. """

    diameter: typing.Optional[float]

    """ Contact lens diameter.
    Type `float`. """

    duration: typing.Optional["Quantity"]

    """ Lens wear duration.
    Type `Quantity` (represented as `dict` in JSON). """

    color: typing.Optional[str]

    """ Color required.
    Type `str`. """

    brand: typing.Optional[str]

    """ Brand required.
    Type `str`. """

    note: typing.Optional[typing.List["Annotation"]]

    """ Notes for coatings.
    List of `Annotation` items (represented as `dict` in JSON). """




    

     
    



class VisionPrescriptionLensSpecificationPrism(BackboneElement):
    """ Eye alignment compensation.
    
    Allows for adjustment on two axis.
    """
    
    # [<FHIRClassProperty self.name='amount' >, <FHIRClassProperty self.name='base' >]
  

    amount: float

    """ Amount of adjustment.
    Type `float`. """

    base: "str"

    """ up | down | in | out.
    Type `str`. """




    

     
    

def inheritors(klass):
    subclasses = set()
    work = [klass]
    while work:
        parent = work.pop()
        for child in parent.__subclasses__():
            if child not in subclasses:
                subclasses.add(child)
                work.append(child)
    return subclasses


for subclass in inheritors(FHIRAbstractBase):
    subclass.update_forward_refs()


RESOURCE_TYPE_MAP: typing.Dict[str, Resource] = {}
for subclass in inheritors(Resource):
    RESOURCE_TYPE_MAP[subclass.__name__] = subclass


def from_dict(dict_: dict):
    """Factory to load resources directly.
    
    The resources will be instaciated based on their resourceType property."""
    return RESOURCE_TYPE_MAP[dict_["resourceType"]](**dict_)
